OC.L10N.register(
    "deck",
    {
    "You have created a new board {board}" : "Jūs sukūrėte naują lentą {board}",
    "{user} has created a new board {board}" : "{user} sukūrė naują lentą {board}",
    "You have deleted the board {board}" : "Jūs ištrynėte lentą {board}",
    "{user} has deleted the board {board}" : "{user} ištrynė lentą {board}",
    "You have restored the board {board}" : "Jūs atkūrėte lentą {board}",
    "{user} has restored the board {board}" : "{user} atkūrė lentą {board}",
    "You have shared the board {board} with {acl}" : "Jūs pradėjote bendrinti lentą {board} su {acl}",
    "{user} has shared the board {board} with {acl}" : "{user} pradėjo bendrinti lentą {board} su {acl}",
    "You have removed {acl} from the board {board}" : "Jūs pašalinote {acl} iš lentos {board}",
    "{user} has removed {acl} from the board {board}" : "{user} pašalino {acl} iš lentos {board}",
    "You have renamed the board {before} to {board}" : "Jūs pervadinote lentą {before} į {board}",
    "{user} has renamed the board {before} to {board}" : "{user} pervadino lentą {before} į {board}",
    "You have archived the board {board}" : "Jūs užarchyvavote lentą {board}",
    "{user} has archived the board {before}" : "{user} užarchyvavo lentą {before}",
    "You have unarchived the board {board}" : "Jūs išarchyvavote lentą {board}",
    "{user} has unarchived the board {before}" : "{user} išarchyvavo lentą {before}",
    "You have created a new list {stack} on board {board}" : "Jūs lentoje {board} sukūrėte naują sąrašą {stack}",
    "{user} has created a new list {stack} on board {board}" : "{user} lentoje {board} sukūrė naują sąrašą {stack}",
    "You have renamed list {before} to {stack} on board {board}" : "Jūs lentoje {board} pervadinote sąrašą {before} į {stack}",
    "{user} has renamed list {before} to {stack} on board {board}" : "{user} lentoje {board} pervadino sąrašą {before} į {stack}",
    "You have deleted list {stack} on board {board}" : "Jūs lentoje {board} ištrynėte sąrašą {stack}",
    "{user} has deleted list {stack} on board {board}" : "{user} lentoje {board} ištrynė sąrašą {stack}",
    "You have created card {card} in list {stack} on board {board}" : "Jūs lentoje {board}, sąraše {stack} sukūrėte kortelę {card}",
    "{user} has created card {card} in list {stack} on board {board}" : "{user} lentoje {board}, sąraše {stack} sukūrė kortelę {card}",
    "You have deleted card {card} in list {stack} on board {board}" : "Jūs lentoje {board}, sąraše {stack} ištrynėte kortelę {card}",
    "{user} has deleted card {card} in list {stack} on board {board}" : "{user} lentoje {board}, sąraše {stack} ištrynė kortelę {card} ",
    "You have renamed the card {before} to {card}" : "Jūs pervadinote kortelę {before} į {card}",
    "{user} has renamed the card {before} to {card}" : "{user} pervadino kortelę {before} į {card}",
    "You have added a description to card {card} in list {stack} on board {board}" : "Jūs lentoje {board}, sąraše {stack} į kortelę {card} pridėjote aprašą",
    "{user} has added a description to card {card} in list {stack} on board {board}" : "{user} lentoje {board}, sąraše {stack} į kortelę {card} pridėjo aprašą",
    "You have updated the description of card {card} in list {stack} on board {board}" : "Jūs lentoje {board}, sąraše {stack} atnaujinote kortelės {card} aprašą",
    "{user} has updated the description of the card {card} in list {stack} on board {board}" : "{user} lentoje {board}, sąraše {stack} atnaujino kortelės {card} aprašą",
    "You have archived card {card} in list {stack} on board {board}" : "Jūs lentoje {board}, sąraše {stack} užarchyvavote kortelę {card}",
    "{user} has archived card {card} in list {stack} on board {board}" : "{user} lentoje {board}, sąraše {stack} užarchyvavo kortelę {card}",
    "You have unarchived card {card} in list {stack} on board {board}" : "Jūs lentoje {board}, sąraše {stack} išarchyvavote kortelę {card}",
    "{user} has unarchived card {card} in list {stack} on board {board}" : "{user} lentoje {board}, sąraše {stack} išarchyvavo kortelę {card}",
    "You have removed the due date of card {card}" : "Jūs pašalinote galutinį kortelės {card} terminą",
    "{user} has removed the due date of card {card}" : "{user} pašalino galutinį kortelės {card} terminą",
    "You have set the due date of card {card} to {after}" : "Jūs nustatėte galutinį kortelės {card} terminą į {after}",
    "{user} has set the due date of card {card} to {after}" : "{user} nustatė galutinį kortelės {card} terminą į {after}",
    "You have updated the due date of card {card} to {after}" : "Jūs atnaujinote galutinį kortelės {card} terminą į {after}",
    "{user} has updated the due date of card {card} to {after}" : "{user} atnaujino galutinį kortelės {card} terminą į {after}",
    "You have added the tag {label} to card {card} in list {stack} on board {board}" : "Jūs lentoje {board}, sąraše {stack} į kortelę {card} pridėjote žymę {label}",
    "{user} has added the tag {label} to card {card} in list {stack} on board {board}" : "{user} lentoje {board}, sąraše {stack} į kortelę {card} pridėjo žymę {label}",
    "You have removed the tag {label} from card {card} in list {stack} on board {board}" : "Jūs lentoje {board}, sąraše {stack} iš kortelės {card} pašalinote žymę {label}",
    "{user} has removed the tag {label} from card {card} in list {stack} on board {board}" : "{user} lentoje {board}, sąraše {stack} iš kortelės {card} pašalino žymę {label}",
    "You have assigned {assigneduser} to card {card} on board {board}" : "Jūs lentoje {board} prie kortelės {card} priskyrėte {assigneduser}",
    "{user} has assigned {assigneduser} to card {card} on board {board}" : "{user} lentoje {board} prie kortelės {card} priskyrė {assigneduser}",
    "You have moved the card {card} from list {stackBefore} to {stack}" : "Jūs perkėlėte kortelę {card} iš sąrašo {stackBefore} į sąrašą {stack}",
    "{user} has moved the card {card} from list {stackBefore} to {stack}" : "{user} perkėlė kortelę {card} iš sąrašo {stackBefore} į sąrašą {stack}",
    "You have added the attachment {attachment} to card {card}" : "Jūs pridėjote priedą {attachment} į kortelę {card}",
    "{user} has added the attachment {attachment} to card {card}" : "{user} pridėjo priedą {attachment} į kortelę {card}",
    "You have updated the attachment {attachment} on card {card}" : "Jūs atnaujinote priedą {attachment} kortelėje {card}",
    "{user} has updated the attachment {attachment} on card {card}" : "{user} atnaujino priedą {attachment} kortelėje {card}",
    "You have deleted the attachment {attachment} from card {card}" : "Jūs ištrynėte priedą {attachment} iš kortelės {card}",
    "{user} has deleted the attachment {attachment} from card {card}" : "{user} ištrynė priedą {attachment} iš kortelės {card}",
    "You have restored the attachment {attachment} to card {card}" : "Jūs atkūrėte priedą {attachment} į kortelę {card}",
    "{user} has restored the attachment {attachment} to card {card}" : "{user} atkūrė priedą {attachment} į kortelę {card}",
    "You have commented on card {card}" : "Jūs pakomentavote kortelėje {card}",
    "{user} has commented on card {card}" : "{user} pakomentavo kortelėje {card}",
    "A <strong>card description</strong> inside the Deck app has been changed" : "Darbų programėlėje pakeistas <strong>kortelės aprašas</strong> ",
    "Deck" : "Darbai",
    "Changes in the <strong>Deck app</strong>" : "Pakeitimai <strong>Darbų programėlėje</strong>",
    "A <strong>comment</strong> was created on a card" : "Kortelėje buvo sukurtas <strong>komentaras</strong>",
    "Upcoming cards" : "Artėjančios kortelės",
    "Load more" : "Įkelti daugiau",
    "Personal" : "Asmeniniai",
    "The card \"%s\" on \"%s\" has been assigned to you by %s." : "Kortelę \"%s\" ties \"%s\" priskyrė jums %s.",
    "The card \"%s\" on \"%s\" has reached its due date." : "Kortelė „%s“, esanti lentoje „%s“, pasiekė savo galutinį terminą.",
    "The card {deck-card} on {deck-board} has reached its due date." : "Kortelė {deck-card}, esanti lentoje {deck-board} pasiekė savo galutinio termino datą.",
    "%s has mentioned you in a comment on \"%s\"." : "%s paminėjo jus komentare ties \"%s\".",
    "The board \"%s\" has been shared with you by %s." : "Lentą \"%s\" su jumis bendrina %s.",
    "%s on %s" : "%s ant %s",
    "No data was provided to create an attachment." : "Priedo sukūrimui nebuvo pateikta jokių duomenų.",
    "Finished" : "Baigta",
    "To review" : "Reikia peržiūrėti",
    "Action needed" : "Reikalingas veiksmas",
    "Later" : "Vėliau",
    "copy" : "kopija",
    "To do" : "Reikia atlikti",
    "Doing" : "Atliekama",
    "Done" : "Atlikta",
    "Example Task 3" : "Pavyzdinė užduotis 3",
    "Example Task 2" : "Pavyzdinė užduotis 2",
    "Example Task 1" : "Pavyzdinė užduotis 1",
    "The file was uploaded" : "Failas buvo įkeltas",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Įkeliamas failas viršija upload_max_filesize direktyvą, esančią faile php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Įkeltas failas viršija MAX_FILE_SIZE direktyvą, kuri buvo nurodyta HTML formoje",
    "The file was only partially uploaded" : "Failas buvo tik dalinai įkeltas",
    "No file was uploaded" : "Nebuvo įkeltas joks failas",
    "Missing a temporary folder" : "Trūksta laikinojo aplanko",
    "Could not write file to disk" : "Nepavyko įrašyti failą į diską",
    "A PHP extension stopped the file upload" : "PHP plėtinys sustabdė failo įkėlimą",
    "No file uploaded or file size exceeds maximum of %s" : "Neįkeltas joks failas arba failo dydis viršija maksimalų %s dydį",
    "Card not found" : "Kortelė nerasta",
    "Path is already shared with this card" : "Kelias jau yra bendrinamas su šia kortele",
    "Invalid date, date format must be YYYY-MM-DD" : "Netinkama data, datos formatas privalo būti MMMM-mm-dd",
    "Personal planning and team project organization" : "Asmeninis planavimas ir komandinių projektų organizavimas",
    "Card details" : "Išsamiau apie kortelę",
    "Add board" : "Pridėti lentą",
    "Select the board to link to a project" : "Pasirinkite lentą, kurią susieti su projektu",
    "Search by board title" : "Ieškoti pagal lentos pavadinimą",
    "Select board" : "Pasirinkti lentą",
    "Create a new card" : "Sukurti naują kortelę",
    "Select a board" : "Pasirinkite lentą",
    "Select a list" : "Pasirinkite sąrašą",
    "Card title" : "Kortelės pavadinimas",
    "Cancel" : "Atsisakyti",
    "Creating the new card …" : "Kuriama nauja kortelė…",
    "Card \"{card}\" was added to \"{board}\"" : "Kortelė „{card}“ buvo pridėta į lentą „{board}“",
    "Open card" : "Atverti kortelę",
    "Close" : "Užverti",
    "Create card" : "Sukurti kortelę",
    "Select a card" : "Pasirinkti kortelę",
    "Select the card to link to a project" : "Pasirinkite kortelę, kurią susieti su projektu",
    "Link to card" : "Susieti su kortele",
    "File already exists" : "Failas jau yra",
    "A file with the name {filename} already exists." : "Failas, pavadinimu {filename}, jau yra.",
    "Do you want to overwrite it?" : "Ar norite jį perrašyti?",
    "Overwrite file" : "Perrašyti failą",
    "Keep existing file" : "Palikti esamą failą",
    "This board is read only" : "Ši lenta yra tik skaitymui",
    "Drop your files to upload" : "Tempkite failus, norėdami juos išsiųsti",
    "Add card" : "Pridėti kortelę",
    "Archived cards" : "Archyvuotos kortelės",
    "Add list" : "Pridėti sąrašą",
    "List name" : "Sąrašo pavadinimas",
    "Apply filter" : "Taikyti filtrą",
    "Filter by tag" : "Filtruoti pagal žymę",
    "Filter by assigned user" : "Filtruoti pagal priskirtą naudotoją",
    "Filter by due date" : "Filtruoti pagal galutinio termino datą",
    "Overdue" : "Praėjęs galutinis terminas",
    "Next 24 hours" : "Artimiausios 24 val.",
    "Next 7 days" : "Artimiausios 7 dienos",
    "Next 30 days" : "Artimiausios 30 dienų",
    "No due date" : "Be galutinio termino",
    "Clear filter" : "Išvalyti filtrą",
    "Hide archived cards" : "Slėpti archyvuotas korteles",
    "Show archived cards" : "Rodyti archyvuotas korteles",
    "Toggle compact mode" : "Perjungti kompaktišką veikseną",
    "Details" : "Išsamiau",
    "Loading board" : "Įkeliama lenta",
    "No lists available" : "Nėra sąrašų",
    "Create a new list to add cards to this board" : "Norėdami pridėti korteles į šią lentą, sukurkite naują sąrašą",
    "Board not found" : "Lenta nerasta",
    "Sharing" : "Bendrinimas",
    "Tags" : "Žymės",
    "Deleted items" : "Ištrinti elementai",
    "Timeline" : "Laiko juosta",
    "Deleted lists" : "Ištrinti sąrašai",
    "Undo" : "Atšaukti",
    "Deleted cards" : "Ištrintos kortelės",
    "Share board with a user, group or circle …" : "Bendrinti lentą su naudotoju, grupe ar ratu…",
    "Searching for users, groups and circles …" : "Ieškoma naudotojų, grupių ir ratų…",
    "No participants found" : "Nerasta jokių dalyvių",
    "Board owner" : "Lentos savininkas",
    "(Group)" : "(Grupė)",
    "(Circle)" : "(Ratas)",
    "Can edit" : "Gali redaguoti",
    "Can share" : "Can share",
    "Can manage" : "Gali tvarkyti",
    "Owner" : "Savininkas",
    "Delete" : "Ištrinti",
    "Failed to create share with {displayName}" : "Nepavyko sukurti viešinio su {displayName}",
    "Transfer" : "Persiųsti",
    "Add a new list" : "Pridėti naują sąrašą",
    "Archive all cards" : "Archyvuoti visas korteles",
    "Delete list" : "Ištrinti sąrašą",
    "Archive all cards in this list" : "Archyvuoti visas korteles šiame sąraše",
    "Add a new card" : "Pridėti naują kortelę",
    "Card name" : "Kortelės pavadinimas",
    "List deleted" : "Sąrašas ištrintas",
    "Edit" : "Taisyti",
    "Add a new tag" : "Pridėti naują žymę",
    "title and color value must be provided" : "privalo būti pateiktos pavadinimo ir spalvos reikšmės",
    "Board name" : "Lentos pavadinimas",
    "Members" : "Nariai",
    "Upload new files" : "Išsiųsti naujus failus",
    "Share from Files" : "Bendrinti iš failų",
    "Add this attachment" : "Pridėti šį priedą",
    "Show in Files" : "Rodyti failuose",
    "Download" : "Atsisiųsti",
    "Remove attachment" : "Šalinti priedą",
    "Delete Attachment" : "Ištrinti priedą",
    "Restore Attachment" : "Atkurti priedą",
    "File to share" : "Failas, kurį bendrinti",
    "Invalid path selected" : "Pasirinktas neteisingas kelias",
    "Open in sidebar view" : "Atverti šoninės juostos rodinyje",
    "Open in bigger view" : "Atverti didesniame rodinyje",
    "Attachments" : "Priedai",
    "Comments" : "Komentarai",
    "Modified" : "Pakeistas",
    "Created" : "Sukurta",
    "The title cannot be empty." : "Pavadinimas negali būti tuščias.",
    "No comments yet. Begin the discussion!" : "Kol kas komentarų nėra. Pradėkite diskusiją!",
    "Failed to load comments" : "Nepavyko įkelti komentarų",
    "Assign a tag to this card…" : "Priskirti šiai kortelei žymę…",
    "Assign to users" : "Priskirti naudotojams",
    "Assign to users/groups/circles" : "Priskirti naudotojams/grupėms/ratams",
    "Assign a user to this card…" : "Priskirti šiai kortelei naudotoją…",
    "Due date" : "Galutinio termino data",
    "Set a due date" : "Nustatyti galutinį terminą",
    "Remove due date" : "Šalinti galutinio termino datą",
    "Select Date" : "Pasirinkti datą",
    "Today" : "Šiandien",
    "Tomorrow" : "Rytoj",
    "Next week" : "Kita savaitė",
    "Next month" : "Kitas mėnuo",
    "Save" : "Įrašyti",
    "The comment cannot be empty." : "Komentaras negali būti tuščias.",
    "The comment cannot be longer than 1000 characters." : "Komentaras negali būti ilgesnis nei 1000 simbolių.",
    "Reply" : "Atsakyti",
    "Update" : "Atnaujinti",
    "Description" : "Aprašas",
    "(Unsaved)" : "(Neįrašyta)",
    "(Saving…)" : "(Įrašoma…)",
    "Formatting help" : "Formatavimo pagalba",
    "Edit description" : "Taisyti aprašą",
    "View description" : "Rodyti aprašą",
    "Add Attachment" : "Pridėti priedą",
    "Write a description …" : "Parašykite aprašą…",
    "Choose attachment" : "Pasirinkite priedą",
    "(group)" : "(grupė)",
    "{count} comments, {unread} unread" : "Komentarų: {count}, neskaityta: {unread}",
    "Assign to me" : "Priskirti sau",
    "Move card" : "Perkelti kortelę",
    "Unarchive card" : "Išarchyvuoti kortelę",
    "Archive card" : "Archyvuoti kortelę",
    "Delete card" : "Ištrinti kortelę",
    "Move card to another board" : "Perkelti kortelę į kitą lentą",
    "List is empty" : "Sąrašas tuščias",
    "Card deleted" : "Kortelė ištrinta",
    "seconds ago" : "prieš keletą sekundžių",
    "All boards" : "Visos lentos",
    "Archived boards" : "Archyvuotos lentos",
    "Shared with you" : "Bendrinama su jumis",
    "Use bigger card view" : "Naudoti didesnį kortelių rodinį",
    "Show boards in calendar/tasks" : "Rodyti darbus kalendoriuje/užduotyse",
    "Board details" : "Išsamiau apie lentą",
    "Edit board" : "Taisyti lentą",
    "Clone board" : "Dubliuoti lentą",
    "Unarchive board" : "Išarchyvuoti lentą",
    "Archive board" : "Archyvuoti lentą",
    "Turn on due date reminders" : "Įjungti priminimus apie galutinio termino datą",
    "Turn off due date reminders" : "Išjungti priminimus apie galutinio termino datą",
    "Due date reminders" : "Priminimai apie galutinio termino datą",
    "All cards" : "Visos kortelės",
    "Assigned cards" : "Priskirtos kortelės",
    "No notifications" : "Pranešimų nėra",
    "Delete board" : "Ištrinti lentą",
    "Board {0} deleted" : "Lenta {0} ištrinta",
    "Only assigned cards" : "Tik priskirtos kortelės",
    "No reminder" : "Jokio priminimo",
    "An error occurred" : "Įvyko klaida",
    "Delete the board?" : "Ištrinti lentą?",
    "No due" : "Be galutinio termino",
    "No results found" : "Nerasta jokių rezultatų",
    "Due on {date}" : "Galutinis terminas {date}",
    "Link to a board" : "Susieti su lenta",
    "Link to a card" : "Susieti su kortele",
    "Create a card" : "Sukurti kortelę",
    "Something went wrong" : "Kažkas nutiko",
    "Maximum file size of {size} exceeded" : "Viršytas maksimalus {size} failo dydis",
    "Error creating the share" : "Klaida kuriant viešinį",
    "Share" : "Bendrinti",
    "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "Ar tikrai norite ištrinti lentą, pavadinimu {title}? Tai ištrins visus šios lentos duomenis.",
    "This week" : "Šią savaitę"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
