OC.L10N.register(
    "deck",
    {
    "You have created a new board {board}" : "As creadu una lavagna noa {board}",
    "{user} has created a new board {board}" : "{user} at creadu una lavagna noa {board}",
    "You have deleted the board {board}" : "As cantzelladu sa lavagna {board}",
    "{user} has deleted the board {board}" : "{user} at cantzelladu sa lavagna {board}",
    "You have restored the board {board}" : "As ripristinadu sa lavagna {board}",
    "{user} has restored the board {board}" : "{user} at ripristinadu sa lavagna {board}",
    "You have shared the board {board} with {acl}" : "As cumpartzidu sa lavagna {board} cun {acl}",
    "{user} has shared the board {board} with {acl}" : "{user} at cumpartzidu sa lavagna {board} cun {acl}",
    "You have removed {acl} from the board {board}" : "Ci nd'as bogadu {acl} dae sa lavagna {board}",
    "{user} has removed {acl} from the board {board}" : "{user} ci nd'at bogadu {acl} dae sa lavagna {board}",
    "You have renamed the board {before} to {board}" : "As torradu a numenare sa lavagna {before} comente {board}",
    "{user} has renamed the board {before} to {board}" : "{user} at torradu a numenare {before} comente {board}",
    "You have archived the board {board}" : "As archiviadu sa lavagna {board}",
    "{user} has archived the board {before}" : "{user} at archiviadu sa lavagna {before}",
    "You have unarchived the board {board}" : "As annulladu s'archiviatzione de sa lavagna {board}",
    "{user} has unarchived the board {before}" : "{user} at annulladu s'archiviatzione de sa lavagna {before}",
    "You have created a new list {stack} on board {board}" : "As creadu un'elencu nou {stack} in sa lavagna {board}",
    "{user} has created a new list {stack} on board {board}" : "{user} at creadu un'elencu nou {stack} in sa lavagna {board}",
    "You have renamed list {before} to {stack} on board {board}" : "As torradu a numenare s'elencu {before} comente {stack} in sa {board}",
    "{user} has renamed list {before} to {stack} on board {board}" : "{user} at torradu a numenare s'elencu {before} comente {stack} sulla lavagna {board}",
    "You have deleted list {stack} on board {board}" : "As cantzelladu s'elencu {stack} in sa lavagna {board}",
    "{user} has deleted list {stack} on board {board}" : "{user} at cantzelladu s'elencu {stack} in sa lavagna {board}",
    "You have created card {card} in list {stack} on board {board}" : "As creadu un'ischeda {card} in s'elencu {stack} in sa lavagna {board}",
    "{user} has created card {card} in list {stack} on board {board}" : "{user} at creadu un'ischeda {card} in s'elencu {stack} in sa lavagna {board}",
    "You have deleted card {card} in list {stack} on board {board}" : "As cantzelladu s'ischeda {card} in s'elencu {stack} in sa lavagna {board}",
    "{user} has deleted card {card} in list {stack} on board {board}" : "{user} at cantzelladu s'ischeda {card} in s'elencu {stack} in sa lavagna {board}",
    "You have renamed the card {before} to {card}" : "As torradu a numenare s'ischeda {before} comente {card}",
    "{user} has renamed the card {before} to {card}" : "{user} at torradu a numenare sa carta {before} comente {card}",
    "You have added a description to card {card} in list {stack} on board {board}" : "As agiuntu una descritzione a s'ischeda {card} in s'elencu {stack} in sa lavagna {board}",
    "{user} has added a description to card {card} in list {stack} on board {board}" : "{user} at agiuntu una descritzione a s'ischeda {card} in s'elencu {stack} in sa lavagna {board}",
    "You have updated the description of card {card} in list {stack} on board {board}" : "As agiornadu sa descritzione de s'ischeda {card} in s'elencu {stack} in sa lavagna {board}",
    "{user} has updated the description of the card {card} in list {stack} on board {board}" : "{user} at agiornadu sa descritzione de s'ischedas {card} in s'elencu {stack} in sa lavagna {board}",
    "You have archived card {card} in list {stack} on board {board}" : "As archiviadu s'ischeda {card} in s'elencu {stack} in sa lavagna {board}",
    "{user} has archived card {card} in list {stack} on board {board}" : "{user} at archiviadu s'ischeda {card} in s'elencu {stack} in sa lavagna {board}",
    "You have unarchived card {card} in list {stack} on board {board}" : "As annulladu s'archiviatzione de s'ischeda {card} in s'elencu {stack} in sa lavagna {board}",
    "{user} has unarchived card {card} in list {stack} on board {board}" : "{user} at annulladu s'archiviatzione de s'ischeda {card} in s'elencu {stack} in sa lavagna {board}",
    "You have removed the due date of card {card}" : "Ci nd'as bogadu sa data de iscadèntzia dae s'ischeda {card}",
    "{user} has removed the due date of card {card}" : "{user} ci nd'at bogadu sa data de iscadèntzia dae s'ischeda {card}",
    "You have set the due date of card {card} to {after}" : "As impostadu sa data de iscadèntzia de s'ischeda {card} a su {after}",
    "{user} has set the due date of card {card} to {after}" : "{user} at impostadu sa data de iscadèntzia de sa tèssera {card} a su {after}",
    "You have updated the due date of card {card} to {after}" : "As agiornadu sa data de iscadèntzia de s'ischeda {card} a su {after}",
    "{user} has updated the due date of card {card} to {after}" : "{user} as agiornadu sa data de iscadèntzia de s'ischeda {card} a su {after}",
    "You have added the tag {label} to card {card} in list {stack} on board {board}" : "As agiuntu s'eticheta {label} a s'ischeda {card} in s'elencu {stack} in sa lavagna {board}",
    "{user} has added the tag {label} to card {card} in list {stack} on board {board}" : "{user} at agiuntu s'eticheta {label} a s'ischeda {card} in s'elencu {stack} in sa lavagna {board}",
    "You have removed the tag {label} from card {card} in list {stack} on board {board}" : "Ci nd'as bogadu {label} dae s'ischeda {card} in s'elencu {stack} in sa lavagna {board}",
    "{user} has removed the tag {label} from card {card} in list {stack} on board {board}" : "{user} ci nd'at bogadu s'eticheta {label} dae s'ischeda {card} in s'elencu {stack} in sa lavagna {board}",
    "You have assigned {assigneduser} to card {card} on board {board}" : "As assignadu {assigneduser} a s'ischeda {card} in sa lavagna {board}",
    "{user} has assigned {assigneduser} to card {card} on board {board}" : "{user} at assignadu {assigneduser} a s'ischeda {card} in sa lavagna {board}",
    "You have unassigned {assigneduser} from card {card} on board {board}" : "As annulladu s'assignatzione {assigneduser} dae s'ischeda {card} in sa lavagna {board}",
    "{user} has unassigned {assigneduser} from card {card} on board {board}" : "{user} at annulladu s'assignatzione {assigneduser} dae s'ischeda {card} in sa lavagna {board}",
    "You have moved the card {card} from list {stackBefore} to {stack}" : "As tramudadu s'ischeda {card} dae s'elencu {stackBefore} a {stack}",
    "{user} has moved the card {card} from list {stackBefore} to {stack}" : "{user} at tramudadu s'ischeda {card} dae s'ischeda {stackBefore} a {stack}",
    "You have added the attachment {attachment} to card {card}" : "As agiuntu s'alligongiadu {attachment} a s'ischeda {card}",
    "{user} has added the attachment {attachment} to card {card}" : "{user} at agiuntu s'alligongiadu {attachment} a s'ischeda {card}",
    "You have updated the attachment {attachment} on card {card}" : "As agiornadu s'alligongiadu {attachment} a s'ischeda {card}",
    "{user} has updated the attachment {attachment} on card {card}" : "{user} at agiornadu s'alligongiadu {attachment} a s'ischeda {card}",
    "You have deleted the attachment {attachment} from card {card}" : "As cantzelladu s'alligongiadu {attachment} dae s'ischeda {card}",
    "{user} has deleted the attachment {attachment} from card {card}" : "{user} at eliminadu s'alligongiadu {attachment} dae s'ischeda {card}",
    "You have restored the attachment {attachment} to card {card}" : "As ripristinadu s'alligongiadu {attachment} in s'ischeda {card}",
    "{user} has restored the attachment {attachment} to card {card}" : "{user} at ripristinadu s'alligongiadu {attachment} in s'ischeda {card}",
    "You have commented on card {card}" : "As cummentadu in s'ischeda {card}",
    "{user} has commented on card {card}" : "{user} at cummentadu in s'ischeda {card}",
    "A <strong>card description</strong> inside the Deck app has been changed" : "Sa <strong>descritzione de un'ischeda</strong> in intro de s'aplicatzione Deck app est istada cambiada",
    "Deck" : "Deck",
    "Changes in the <strong>Deck app</strong>" : "Càmbios in <strong> s'aplicatzione Deck</strong>",
    "A <strong>comment</strong> was created on a card" : "Unu <strong>cummentu</strong> est istadu creadu in s'ischeda",
    "Upcoming cards" : "Ischedas imbenientes",
    "Load more" : "Càrriga àteru",
    "Personal" : "Personale",
    "The card \"%s\" on \"%s\" has been assigned to you by %s." : "S'ischeda \"%s\" in \"%s\" s'est istadu assignadu dae %s.",
    "{user} has assigned the card {deck-card} on {deck-board} to you." : "{user} t'at assignadu s'ischeda {deck-card} in {deck-board}.",
    "The card \"%s\" on \"%s\" has reached its due date." : "S'ischeda \"%s\" in \"%s\" est cròmpida a sa data de iscadèntzia.",
    "The card {deck-card} on {deck-board} has reached its due date." : "S'ischeda {deck-card} in {deck-board} est cròmpida a sa data de iscadèntzia.",
    "%s has mentioned you in a comment on \"%s\"." : "%s t'at mentovadu in unu cummentu \"%s\".",
    "{user} has mentioned you in a comment on {deck-card}." : "{user} t'at mentovadu in unu cummentu in {deck-card}.",
    "The board \"%s\" has been shared with you by %s." : "Sa lavagna \"%s\" est istada cumpartzida cun tegus dae %s.",
    "{user} has shared {deck-board} with you." : "{user} at cumpartzidu {deck-board} cun tegus.",
    "Card comments" : "Cummentos de is ischedas",
    "%s on %s" : "%s in %s",
    "No data was provided to create an attachment." : "Perunu datu frunidu pro creare un'alligongiadu",
    "Finished" : "Agabbadu",
    "To review" : "De revisionare",
    "Action needed" : "Bisòngiat un'atzione",
    "Later" : "Luego",
    "copy" : "còpia",
    "To do" : "De fàghere",
    "Doing" : "In cursu",
    "Done" : "Fatu",
    "Example Task 3" : "Atividade de esempru 3",
    "Example Task 2" : "Atividade de esempru 2",
    "Example Task 1" : "Atividade de esempru 1",
    "The file was uploaded" : "S'archìviu est istadu carrigadu",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "S'archìviu carrigadu superat sa diretiva upload_max_filesize in php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "S'archìviu carrigadu superat sa diretiva MAX_FILE_SIZE ispetzificada in su mòdulu HTML",
    "The file was only partially uploaded" : "Isceti una parte de s'archìviu est carrigada",
    "No file was uploaded" : "Perunu archìviu carrigadu",
    "Missing a temporary folder" : "Mancat una cartella temporànea",
    "Could not write file to disk" : "No at fatu a iscrìere s'archìviu in su discu",
    "A PHP extension stopped the file upload" : "Un'estensione PHP at firmadu su carrigamentu de s'archìviu",
    "No file uploaded or file size exceeds maximum of %s" : "Perun'archìviu carrigadu o sa mannària de s'archìviu superat su màssimu de %s",
    "Card not found" : "Ischeda no agatada",
    "Path is already shared with this card" : "Su caminu est giai cumpartzidu cun cust'ischeda",
    "Invalid date, date format must be YYYY-MM-DD" : "Data non bàlida, su formadu de sa data depet èssere AAAA-MM-GG",
    "Personal planning and team project organization" : "Pranificatzione personale e organizatzione de su progetu de iscuadra",
    "Card details" : "Detàllios ischeda",
    "Add board" : "Agiunghe lavagna",
    "Select the board to link to a project" : "Seletziona lavagna de collegare a unu progetu",
    "Search by board title" : "Chirca dae su tìtulu de sa lavagna",
    "Select board" : "Seletziona lavagna",
    "Create a new card" : "Crea un'ischeda noa",
    "Select a board" : "Seletziona una lavagna",
    "Select a list" : "Seletziona un'elencu",
    "Card title" : "Tìtulu ischeda",
    "Cancel" : "Annulla",
    "Creating the new card …" : "Creende s'ischeda noa ...",
    "Card \"{card}\" was added to \"{board}\"" : "S'ischeda \"{card}\" est istada agiunta a \"{board}\"",
    "Open card" : "Aberi ischeda",
    "Close" : "Serra",
    "Create card" : "Crea ischeda",
    "Select a card" : "Seletziona un'ischeda",
    "Select the card to link to a project" : "Seletzioan s'ischeda de collegare a unu progetu",
    "Link to card" : "Collega a un'ischeda",
    "File already exists" : "Cust'archìviu ddoe est giai",
    "A file with the name {filename} already exists." : "B'at giai un'archìviu cun su nùmene de {filename}.",
    "Do you want to overwrite it?" : "Ddu cheres subraiscrìere? ",
    "Overwrite file" : "Subraiscrie archìviu",
    "Keep existing file" : "Mantene s'archìviu chi ddoe est",
    "This board is read only" : "Custa lavagna est isceti pro lèghere",
    "Drop your files to upload" : "Lassa is archìvios pro ddos carrigare",
    "Add card" : "Agiunghe ischeda",
    "Archived cards" : "Ischedas archiviadas",
    "Add list" : "Agiunghe elencu",
    "List name" : "Nùmene elencu",
    "Apply filter" : "Àplica filtru",
    "Filter by tag" : "Filtra pro etichetas",
    "Filter by assigned user" : "Filtra pro utente assignadu",
    "Unassigned" : "No assignadu",
    "Filter by due date" : "Filtra pro data de iscadèntzia",
    "Overdue" : "Iscadèntzia",
    "Next 24 hours" : "24 oras imbenientes",
    "Next 7 days" : "7 dies imbenientes",
    "Next 30 days" : "30 dies imbenientes",
    "No due date" : "Peruna iscadèntzia",
    "Clear filter" : "Lìmpia filtru",
    "Hide archived cards" : "Cua is ischedas archiviadas",
    "Show archived cards" : "Mustra ischedas archiviadas",
    "Toggle compact mode" : "Càmbia a modalidade cumpata",
    "Details" : "Detàllios",
    "Loading board" : "Carrighende lavagna",
    "No lists available" : "Perunu elencu a disponimentu",
    "Create a new list to add cards to this board" : "Crea un'elencu nou de agiùnghere ischedas a custa lavagna",
    "Board not found" : "Lavagna no agatada",
    "Sharing" : "Cumpartzidura",
    "Tags" : "Etichetas",
    "Deleted items" : "Temas cantzellados",
    "Timeline" : "Fusu oràriu",
    "Deleted lists" : "Elencos cantzellados",
    "Undo" : "Annulla",
    "Deleted cards" : "Ischeda cantzellada",
    "Share board with a user, group or circle …" : "Cumpartzi lavagna cun un'utente, grupu o tropa...",
    "Searching for users, groups and circles …" : "Chirchende utentes, grupos e tropas ...",
    "No participants found" : "Perunu partetzipante agatadu",
    "Board owner" : "Mere lavagna",
    "(Group)" : "(Grupu)",
    "(Circle)" : "(Giru)",
    "Can edit" : "Faghet a modificare",
    "Can share" : "Faghet a cumpartzire",
    "Can manage" : "Faghet a gestire",
    "Owner" : "Mere",
    "Delete" : "Cantzella",
    "Failed to create share with {displayName}" : "No at fatu a creare cumpartzidura cun {displayName}",
    "Transfer" : "Tràmuda",
    "Add a new list" : "Agiunghe un'elencu nou",
    "Archive all cards" : "Archìvia totu is ischedas",
    "Delete list" : "Cantzella elencu",
    "Archive all cards in this list" : "Archìvia totu is ischedas in cust'elencu",
    "Add a new card" : "Agiùnghe un'ischeda noa",
    "Card name" : "Nùmene de s'ischeda",
    "List deleted" : "Elencu cantzelladu",
    "Edit" : "Modìfica ",
    "Add a new tag" : "Agiunghe un'eticheta noa",
    "title and color value must be provided" : "tocat de frunire su tìtulu e su balore de su colore",
    "Board name" : "Nùmene de sa lavagna",
    "Members" : "Membros",
    "Upload new files" : "Carriga archìvios noos",
    "Share from Files" : "Cumpartzi dae Archìvios",
    "Add this attachment" : "Agiunghe custu alligongiadu",
    "Show in Files" : "Mustra in Archìvios",
    "Download" : "Iscàrriga",
    "Delete Attachment" : "Cantzella alligongiadu",
    "Restore Attachment" : "Riprìstina alligongiadu",
    "File to share" : "Archìviu de cumpartzire",
    "Invalid path selected" : "Percursu seletzionadu non bàlidu",
    "Open in sidebar view" : "Aberi in s'istanca laterale",
    "Open in bigger view" : "Aberi in una bista prus ampra",
    "Attachments" : "Alligongiados",
    "Comments" : "Cummentos",
    "Modified" : "Modificadu",
    "Created" : "Creadu",
    "The title cannot be empty." : "Su tìtulu non podet èssere bòidu",
    "No comments yet. Begin the discussion!" : "Perunu cummentu ancora. Cumintzat sa chistionada!",
    "Failed to load comments" : "No at fatu a carrigare is cummentos",
    "Assign a tag to this card…" : "Assigna un'eticheta a cust'ischeda...",
    "Assign to users" : "Assigna a utentes",
    "Assign to users/groups/circles" : "Assigna a utentes/grupos/tropas",
    "Assign a user to this card…" : "Assigna utente a cust'ischeda...",
    "Due date" : "Iscadèntzia",
    "Set a due date" : "Imposta iscadèntzia",
    "Remove due date" : "Boga s'iscadèntzia",
    "Select Date" : "Seletziona data",
    "Today" : "Oe",
    "Tomorrow" : "Cras",
    "Next week" : "Sa chida chi benit",
    "Next month" : "Su mese chi benit",
    "Save" : "Sarva",
    "The comment cannot be empty." : "Su cummentu non podet èssere bòidu",
    "The comment cannot be longer than 1000 characters." : "Su cummentu non podet èssere prus longu de 1000 caràteres.",
    "In reply to" : "Rispondende a ",
    "Cancel reply" : "Annulla risposta",
    "Reply" : "Risponde",
    "Update" : "Agiorna",
    "Description" : "Descritzione",
    "(Unsaved)" : "(Non sarvada)",
    "(Saving…)" : "(Sarbende…)",
    "Formatting help" : "Ghia pro sa formatatzione",
    "Edit description" : "Modìfica descritzione",
    "View description" : "Visualiza descritzione",
    "Add Attachment" : "Agiunghe alligongiadu",
    "Write a description …" : "Iscrie una descritzione ...",
    "Choose attachment" : "Sèbera un'alligongiadu",
    "(group)" : "(grupu)",
    "{count} comments, {unread} unread" : "{count} cummentos, {unread} non lèghidos",
    "Assign to me" : "Assigna a mie",
    "Unassign myself" : "Annulla s'assignatzione a mie",
    "Move card" : "Tràmuda ischeda",
    "Unarchive card" : "Ischeda no archiviada",
    "Archive card" : "Archìviu no archiviadu",
    "Delete card" : "Cantzella ischeda",
    "Move card to another board" : "Tràmuda s'ischeda a un'àtera lavagna",
    "List is empty" : "Sa lista est bòida",
    "Card deleted" : "Ischeda cantzellada",
    "seconds ago" : "segundos a immoe",
    "All boards" : "Totu is lavagnas",
    "Archived boards" : "Lavagnas archiviadas",
    "Shared with you" : "Cumpartzidu cun tegus",
    "Use bigger card view" : "Imprea bista cun ischedas prus mannas",
    "Show boards in calendar/tasks" : "Mustra lavagnas in calendàriu/fainas",
    "Limit deck usage of groups" : "Mìnima s'impreu de deck de is grupos",
    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Su de minimare su deck at a impedire a is utentes chi non faghent parte de cuddos grupos de si creare lavagnas pròpias. Is utentes ant a èssere ancora capassos de traballare in is lavagnas chi fiant istadas cumpartzidas cun issos etotu,",
    "Board details" : "Detàllios lavagna",
    "Edit board" : "Modìfica lavagna",
    "Clone board" : "Clona lavagna",
    "Unarchive board" : "Annulla s'archiviatzione de sa lavagna",
    "Archive board" : "Archìvia lavagna",
    "Turn on due date reminders" : "Allughe is notìficas pro ammentare is iscadèntzias",
    "Turn off due date reminders" : "Istuda is notìficas pro ammentare is iscadèntzias",
    "Due date reminders" : "Notìficas pro ammentare is iscadèntzias",
    "All cards" : "Totu is ischedas",
    "Assigned cards" : "Ischedas assignadas",
    "No notifications" : "Peruna notìfica",
    "Delete board" : "Cantzella lavagna",
    "Board {0} deleted" : "Lavagna {0} cantzellada",
    "Only assigned cards" : "Isceti ischedas assignadas",
    "No reminder" : "Perunu apuntu",
    "An error occurred" : "B'at àpidu un'errore",
    "Delete the board?" : "Cheres cantzellare sa lavagna?",
    "Loading filtered view" : "Carrigamentu de sa bista cun su filtru",
    "No due" : "Peruna iscadèntzia",
    "Search for {searchQuery} in all boards" : "Chirca {searchQuery} in totu is lavagnas",
    "No results found" : "Perunu resurtadu agatadu",
    "{stack} in {board}" : "{stack} in {board}",
    "No upcoming cards" : "Peruna ischeda abarrada",
    "upcoming cards" : "ischedas abarradas",
    "Link to a board" : "Collega a una tabella",
    "Link to a card" : "Collega a un'ischeda",
    "Create a card" : "Crea un'ischeda",
    "Message from {author} in {conversationName}" : "Messàgiu de {author} in {conversationName}",
    "Something went wrong" : "Ddoe at àpidu un'errore",
    "Failed to upload {name}" : "No at fatu a agiornare {name}",
    "Maximum file size of {size} exceeded" : "Mannària màssima de s'archìviu de {size} superada",
    "Error creating the share" : "Errore in sa creatzione de sa cumpatzidura",
    "Share with a Deck card" : "Cumpartzi cun un'ischeda deck",
    "Share {file} with a Deck card" : "Cumpartzi {file} cun un'ischeda de deck",
    "Share" : "Cumpartzi",
    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Deck est unu trastu de organizatzione a sa moda de kanban destinadu a sa pranificatzione personale e a s'organizatzione de progetos in iscuadra integradu cun Nextcloud\n\n- 📥  Agiunghe is atividades tuas a is ischedas e mantene·ddas ordinadas\n- 📄 Iscrie notas in agiunta in markdown\n- 🔖 Assigna etichetas pro t'organizare mègius ancora\n- 👥 Cumpatzi cun s'iscuadra tua, famìlia e amigos\n- 📎 Aligongia archìvios e integra·ddos in sa descritzione tua in markdown\n- 💬 Chistiona cun s'iscuadra tua impreende is cummentos\n- ⚡ Mantene su rastru de is cummentos tuos in su flussu de atividades\n- 🚀 Organiza su progetu tuo",
    "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "Ses seguru chi cheres cantzellare sa lavagna {title}? Custa operatzione at a cantzellare totu is datos de custa lavagna.",
    "This week" : "Custa chida"
},
"nplurals=2; plural=(n != 1);");
