OC.L10N.register(
    "deck",
    {
    "You have created a new board {board}" : "Креиравте нова табла {board}",
    "{user} has created a new board {board}" : "{user} креирање нова табла {board}",
    "You have deleted the board {board}" : "Избришавте табла {board}",
    "{user} has deleted the board {board}" : "{user} избриша табла {board}",
    "You have restored the board {board}" : "Вративте табла {board}",
    "{user} has restored the board {board}" : "{user} врати табла {board}",
    "You have shared the board {board} with {acl}" : "Ја споделивте таблата {board} со {acl}",
    "{user} has shared the board {board} with {acl}" : "{user} ја сподели таблата {board} со {acl}",
    "You have removed {acl} from the board {board}" : "Го избришавте {acl} од таблата {board}",
    "{user} has removed {acl} from the board {board}" : "{user} го избриша {acl} од таблата {board}",
    "You have renamed the board {before} to {board}" : "Ја преименувавте таблата {before} во {board}",
    "{user} has renamed the board {before} to {board}" : "{user} ја преименување таблата {before} во {board}",
    "You have archived the board {board}" : "Ја архивиравте таблата {board}",
    "{user} has archived the board {before}" : "{user} ја архивирање таблата {before}",
    "You have unarchived the board {board}" : "Ја вративте од архива таблата {board}",
    "{user} has unarchived the board {before}" : "{user} ја врати од архива таблата {before}",
    "You have created a new list {stack} on board {board}" : "Креиравте нова листа {stack} на таблата {board}",
    "{user} has created a new list {stack} on board {board}" : "{user} креирање нова листа {stack} на таблата {board}",
    "You have renamed list {before} to {stack} on board {board}" : "Ја преименувавте листа {before} во {stack} на таблата {board}",
    "{user} has renamed list {before} to {stack} on board {board}" : "{user} ја преименување листата {before} во {stack} на таблата {board}",
    "You have deleted list {stack} on board {board}" : "Ја избришавте листата {stack} од таблата {board}",
    "{user} has deleted list {stack} on board {board}" : "{user} ја избриша листата {stack} од таблата {board}",
    "You have created card {card} in list {stack} on board {board}" : "Креиравте картица {card} во листата {stack} на таблата {board}",
    "{user} has created card {card} in list {stack} on board {board}" : "{user} креираше картица {card} во листата {stack} на таблата {board}",
    "You have deleted card {card} in list {stack} on board {board}" : "Избришавте картица {card} во листата {stack} на таблата {board}",
    "{user} has deleted card {card} in list {stack} on board {board}" : "{user} избриша картица {card} во листата {stack} на таблата {board}",
    "You have renamed the card {before} to {card}" : "Ја преименувавте картицата {before} во {card}",
    "{user} has renamed the card {before} to {card}" : "{user} ја преименување картицата {before} во {card}",
    "You have added a description to card {card} in list {stack} on board {board}" : "Додадовте опис на картицата {card} во листата {stack} на таблата {board}",
    "{user} has added a description to card {card} in list {stack} on board {board}" : "{user} додаде опис на картицата {card} во листата {stack} на таблата {board}",
    "You have updated the description of card {card} in list {stack} on board {board}" : "Го ажуриравте описот на картицата {card} во листата {stack} на таблата {board}",
    "{user} has updated the description of the card {card} in list {stack} on board {board}" : "{user} го ажурираше описот на картицата {card} во листата {stack} на таблата {board}",
    "You have archived card {card} in list {stack} on board {board}" : "Ја архивиравте картицата {card} во листата {stack} на таблата {board}",
    "{user} has archived card {card} in list {stack} on board {board}" : "{user} ја архивираше картицата {card} во листата {stack} на таблата {board}",
    "You have unarchived card {card} in list {stack} on board {board}" : "Ја вративте од архива картицата {card} во листата {stack} на таблата {board}",
    "{user} has unarchived card {card} in list {stack} on board {board}" : "{user} ја врати од архива картицата {card} во листата {stack} на таблата {board}",
    "You have removed the due date of card {card}" : "Го избришавте датумот на истекување на картицата {card}",
    "{user} has removed the due date of card {card}" : "{user} го избриша датумот на истекување на картицата {card}",
    "You have set the due date of card {card} to {after}" : "Поставивте датум на истекување на картицата {card}",
    "{user} has set the due date of card {card} to {after}" : "{user} постави датум на истекување на картицата {card}",
    "You have updated the due date of card {card} to {after}" : "Го ажуриравте датумот на истекување на картицата {card} до {after}",
    "{user} has updated the due date of card {card} to {after}" : "{user} го ажурираше датумот на истекување на картицата {card} до {after}",
    "You have added the tag {label} to card {card} in list {stack} on board {board}" : "Додадовте ознака {label} на картицата {card} во листата {stack} на таблата {board}",
    "{user} has added the tag {label} to card {card} in list {stack} on board {board}" : "{user} додаде ознака {label} на картицата {card} во листата {stack} на таблата {board}",
    "You have removed the tag {label} from card {card} in list {stack} on board {board}" : "Ја избришавте ознаката {label} од картицата {card} во листата {stack} на таблата {board}",
    "{user} has removed the tag {label} from card {card} in list {stack} on board {board}" : "{user} ја избриша ознаката {label} од картицата {card} во листата {stack} на таблата {board}",
    "You have assigned {assigneduser} to card {card} on board {board}" : "Го додадовте {assigneduser} во картицата {card} на таблата {board}",
    "{user} has assigned {assigneduser} to card {card} on board {board}" : "{user} го додада {assigneduser} во картицата {card} на таблата {board}",
    "You have unassigned {assigneduser} from card {card} on board {board}" : "Го отстранивте {assigneduser} од картицата {card} на таблата {board}",
    "{user} has unassigned {assigneduser} from card {card} on board {board}" : "{user} го отстрани {assigneduser} од картицата {card} на таблата {board}",
    "You have moved the card {card} from list {stackBefore} to {stack}" : "Ја преместивте картицата {card} од листата {stackBefore} во {stack}",
    "{user} has moved the card {card} from list {stackBefore} to {stack}" : "{user} ја премести картицата {card} од листата {stackBefore} во {stack}",
    "You have added the attachment {attachment} to card {card}" : "Додадовте прилог {attachment} на картицата {card}",
    "{user} has added the attachment {attachment} to card {card}" : "{user} додадте прилог {attachment} на картицата {card}",
    "You have updated the attachment {attachment} on card {card}" : "Го ажуриравте прилогот {attachment} на картицата {card}",
    "{user} has updated the attachment {attachment} on card {card}" : "{user} го ажурираше прилогот {attachment} на картицата {card}",
    "You have deleted the attachment {attachment} from card {card}" : "Го избришавте прилогот {attachment} од картицата {card}",
    "{user} has deleted the attachment {attachment} from card {card}" : "{user} го избриша прилогот {attachment} од картицата {card}",
    "You have restored the attachment {attachment} to card {card}" : "Го вративте прилогот {attachment} на картицата {card}",
    "{user} has restored the attachment {attachment} to card {card}" : "{user} го врати прилогот {attachment} на картицата {card}",
    "You have commented on card {card}" : "Коментиравте на картицата {card}",
    "{user} has commented on card {card}" : "{user} коментирање на картицата {card}",
    "A <strong>card description</strong> inside the Deck app has been changed" : "<strong>Описот на картицата</strong> во апликацијата Deck е изменет",
    "Deck" : "Deck",
    "Changes in the <strong>Deck app</strong>" : "Промени во <strong>апликацијата Deck</strong>",
    "A <strong>comment</strong> was created on a card" : "<strong>Коментар</strong> е креиран на картица",
    "Upcoming cards" : "Престојни картици",
    "Load more" : "Вчитај повеќе",
    "Personal" : "Лично",
    "The card \"%s\" on \"%s\" has been assigned to you by %s." : "Картицата \"%s\" на \"%s\" ти е доделена од %s.",
    "The card \"%s\" on \"%s\" has reached its due date." : "Картицата \"%s\" на \"%s\" го достигна датумот на истекување.",
    "%s has mentioned you in a comment on \"%s\"." : "%s те спомна во коментар на \"%s\".",
    "The board \"%s\" has been shared with you by %s." : "Таблата \"%s\" ја сподли со тебе %s.",
    "No data was provided to create an attachment." : "Нема податоци за креирање на прилог.",
    "Finished" : "Завршено",
    "To review" : "На ревизија",
    "Action needed" : "Потребна е акција",
    "Later" : "Покасно",
    "copy" : "копирај",
    "To do" : "За работење",
    "Doing" : "Се работи",
    "Done" : "Готово",
    "Example Task 3" : "Пример задача 3",
    "Example Task 2" : "Пример задача 2",
    "Example Task 1" : "Пример задача 1",
    "The file was uploaded" : "Датотеката е прикачена",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Подигнатата датотека ја надминува upload_max_filesize директивата во php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Големината на датотеката ја надминува MAX_FILE_SIZE директивата која беше специфицирана во HTML формата",
    "The file was only partially uploaded" : "Датотеката беше само делумно прикачена",
    "No file was uploaded" : "Нема прикачено дадотека",
    "Missing a temporary folder" : "Недостасува привремена папка",
    "Could not write file to disk" : "Неможе да се запишува на дискот",
    "A PHP extension stopped the file upload" : "PHP додаток го стопираше прикачувањето на датотеката",
    "No file uploaded or file size exceeds maximum of %s" : "Нема прикачена дадотека или големината го надмминува максимумот од %s",
    "Card not found" : "Картицата не е пронајдена",
    "Path is already shared with this card" : "Патеката веќе е споделена со оваа картица",
    "Invalid date, date format must be YYYY-MM-DD" : "Невалиден датум, форматот мора да биде ГГГГ-ММ-ДД",
    "Personal planning and team project organization" : "Персонален планер и тимски проект организер",
    "Card details" : "Детали за картица",
    "Add board" : "Додади табла",
    "Select the board to link to a project" : "Избери табла за поврзување со проект",
    "Search by board title" : "Барај по име на табла",
    "Select board" : "Избери табла",
    "Create a new card" : "Креирајте нова картица",
    "Select a board" : "Избери табла",
    "Select a list" : "Избери листа",
    "Card title" : "Наслов на картицата",
    "Cancel" : "Откажи",
    "Open card" : "Отвори картица",
    "Close" : "Затвори",
    "Create card" : "Креирајте картица",
    "Select a card" : "Избери картица",
    "Select the card to link to a project" : "Избери картица за поврзување со проект",
    "Link to card" : "Линк до картица",
    "File already exists" : "Датотека веќе постои",
    "A file with the name {filename} already exists." : "Датотека со име {filename} веќе постои.",
    "Do you want to overwrite it?" : "Дали сакате да го пребришете?",
    "Overwrite file" : "Пребриши датотека",
    "Keep existing file" : "Зачувај ја постоечката датотека",
    "This board is read only" : "Оваа табла е само за читање",
    "Drop your files to upload" : "Повлечи датотеки за да прикачите",
    "Add card" : "Додади картица",
    "Archived cards" : "Архивирани картици",
    "Add list" : "Додади листа",
    "List name" : "Име на листа",
    "Apply filter" : "Додади филтер",
    "Filter by tag" : "Филтрирај по ознака",
    "Filter by assigned user" : "Филтрирај по назначени корисници",
    "Unassigned" : "Неназначени",
    "Filter by due date" : "Филтрирај по краен рок",
    "Overdue" : "Заостанати",
    "Next 24 hours" : "Следни 24 часа",
    "Next 7 days" : "Следни 7 дена",
    "Next 30 days" : "Следни 30 дена",
    "No due date" : "Нема краен рок",
    "Clear filter" : "Исчисти филтри",
    "Hide archived cards" : "Сокриј ги архивираните картици",
    "Show archived cards" : "Прикажи ги архивираните картици",
    "Toggle compact mode" : "Вклучи компактен мод",
    "Details" : "Детали",
    "Loading board" : "Вчирување на табла",
    "No lists available" : "Нема достапни листи",
    "Create a new list to add cards to this board" : "Додадете нова листа за да додадете картици на таблата",
    "Board not found" : "Таблата не е пронајдена",
    "Sharing" : "Споделување",
    "Tags" : "Ознаки",
    "Deleted items" : "Избришани работи",
    "Timeline" : "Времеплов",
    "Deleted lists" : "Избришани листи",
    "Undo" : "Врати",
    "Deleted cards" : "Избришани картици",
    "Share board with a user, group or circle …" : "Сподели табла со корисник, група или круг ...",
    "Searching for users, groups and circles …" : "Пребарување на корисници, групи или кругови ...",
    "No participants found" : "Не се пронајдени учесници",
    "Board owner" : "Сопственик на таблата",
    "(Group)" : "(Група)",
    "(Circle)" : "(Круг)",
    "Can edit" : "Може да се уредува",
    "Can share" : "Can share",
    "Can manage" : "Може да ја менаџира",
    "Owner" : "Сопственик",
    "Delete" : "Избриши",
    "Failed to create share with {displayName}" : "Неможе да се сподели со {displayName}",
    "Transfer" : "Трансфер",
    "Add a new list" : "Додади нова листа",
    "Archive all cards" : "Архивирај ги сите картици",
    "Delete list" : "Избриши листа",
    "Archive all cards in this list" : "Архивирај ги сите картици во листата",
    "Add a new card" : "Додади нова картица",
    "Card name" : "Име на картицата",
    "List deleted" : "Листата е избришана",
    "Edit" : "Уреди",
    "Add a new tag" : "Додади нова ознака",
    "title and color value must be provided" : "наслов и боја мора да се приложи",
    "Board name" : "Име на табла",
    "Members" : "Членови",
    "Upload new files" : "Прикачи нови датотеки",
    "Share from Files" : "Сподели од датотеките",
    "Add this attachment" : "Додади го овој прилог",
    "Show in Files" : "Прикажи во датотеките",
    "Download" : "Преземи",
    "Delete Attachment" : "Избриши прилог",
    "Restore Attachment" : "Врати прилог",
    "File to share" : "Датотека за споделување",
    "Invalid path selected" : "Избрана невалидна патека",
    "Open in sidebar view" : "Отвори страничен поглед",
    "Open in bigger view" : "Отвори на голем екран",
    "Attachments" : "Прилози",
    "Comments" : "Коментари",
    "Modified" : "Изменето",
    "Created" : "Креирано",
    "The title cannot be empty." : "Насловот неможе да биде празен.",
    "No comments yet. Begin the discussion!" : "Сеуште нема коментари. Започни дискусија!",
    "Assign a tag to this card…" : "Додади ознака на оваа картица...",
    "Assign to users" : "Додели на корисници",
    "Assign to users/groups/circles" : "Додели на корисници/групи/кругови",
    "Assign a user to this card…" : "Додели корисник на оваа картица...",
    "Due date" : "До датум",
    "Set a due date" : "Постави краен рок",
    "Remove due date" : "Отстрани краен рок",
    "Select Date" : "Избери датум",
    "Today" : "Денес",
    "Tomorrow" : "Утре",
    "Next week" : "Следна недела",
    "Next month" : "Следен месец",
    "Save" : "Зачувај",
    "The comment cannot be empty." : "Коментарот неможе да биде празен.",
    "The comment cannot be longer than 1000 characters." : "Коментарот неможе да биде поголем од 1000 карактери.",
    "In reply to" : "Како одговор на",
    "Reply" : "Одговор",
    "Update" : "Ажурирај",
    "Description" : "Опис",
    "(Unsaved)" : "(Незачувано)",
    "(Saving…)" : "(Снимање…)",
    "Formatting help" : "Помош за форматирање",
    "Edit description" : "Измени опис",
    "View description" : "Види опис",
    "Add Attachment" : "Додади прилог",
    "Write a description …" : "Напиши опис ...",
    "Choose attachment" : "Избери прилог",
    "(group)" : "(group)",
    "Assign to me" : "Доделени мене",
    "Unassign myself" : "Откажи се",
    "Move card" : "Премести картица",
    "Unarchive card" : "Врати картица од архива",
    "Archive card" : "Архивирај картица",
    "Delete card" : "Избриши картица",
    "Move card to another board" : "Премести ја картицата на друга табла",
    "List is empty" : "Листата е празна",
    "Card deleted" : "Картицата е избришана",
    "seconds ago" : "пред неколку секунди",
    "All boards" : "Сите табли",
    "Archived boards" : "Архивирани табли",
    "Shared with you" : "Споделено со тебе",
    "Use bigger card view" : "Користи поголем преглед на картици",
    "Show boards in calendar/tasks" : "Прикажи ги таблите во календарнот",
    "Limit deck usage of groups" : "Ограничи ја апликацијата на групи",
    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Ограничувањето на апликацијата ќе ги блокира корисниците кој не се дел од овие групи. Корсниците ќе можат да работат на апликацијата само доколку биде споделена табла со нив.",
    "Board details" : "Детали за таблата",
    "Edit board" : "Измени табла",
    "Clone board" : "Клонирај табла",
    "Unarchive board" : "Врати табла од архива",
    "Archive board" : "Архивирај табла",
    "Turn on due date reminders" : "Вклучи потсетници за крајните рокови",
    "Turn off due date reminders" : "Исклучи потсетници за крајните рокови",
    "Due date reminders" : "Потсетници за крајните рокови",
    "All cards" : "Сите картици",
    "Assigned cards" : "Доделени картици",
    "No notifications" : "Нема известувања",
    "Delete board" : "Избриши табла",
    "Board {0} deleted" : "Таблата {0} е избришана",
    "Only assigned cards" : "Само доделени картици",
    "No reminder" : "Нема потсетник",
    "An error occurred" : "Настана грешка",
    "Delete the board?" : "Бришење на таблата?",
    "Loading filtered view" : "Вчитување на филтриран поглед",
    "No due" : "Не истекува",
    "No results found" : "Нема пронајдено резултати",
    "No upcoming cards" : "Нема престојни картици",
    "upcoming cards" : "престојни картици",
    "Link to a board" : "Линк до табла",
    "Link to a card" : "Линк до картица",
    "Create a card" : "Креирајте картица",
    "Message from {author} in {conversationName}" : "Порака од {author} во {conversationName}",
    "Something went wrong" : "Нешто не е во ред",
    "Failed to upload {name}" : "Неуспешно прикачување {name}",
    "Maximum file size of {size} exceeded" : "Максималната големина на датотека од {size} е достигната",
    "Error creating the share" : "Грешка при креирање на споделување",
    "Share with a Deck card" : "Споделено со Deck картица",
    "Share {file} with a Deck card" : "Сподели {file} со Deck картица",
    "Share" : "Сподели",
    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized",
    "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "Дали сте сигурени дека сакате да ја избришете оваа табла {title}? Ова ќе ги избрише и сите податоци на таблата.",
    "This week" : "Оваа недела"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
