<?php

// autoload_classmap.php @generated by Composer

$vendorDir = dirname(__DIR__);
$baseDir = dirname($vendorDir);

return array(
    'Composer\\InstalledVersions' => $vendorDir . '/composer/InstalledVersions.php',
    'JsonSchema\\Constraints\\BaseConstraint' => $vendorDir . '/justinrainbow/json-schema/src/JsonSchema/Constraints/BaseConstraint.php',
    'JsonSchema\\Constraints\\CollectionConstraint' => $vendorDir . '/justinrainbow/json-schema/src/JsonSchema/Constraints/CollectionConstraint.php',
    'JsonSchema\\Constraints\\Constraint' => $vendorDir . '/justinrainbow/json-schema/src/JsonSchema/Constraints/Constraint.php',
    'JsonSchema\\Constraints\\ConstraintInterface' => $vendorDir . '/justinrainbow/json-schema/src/JsonSchema/Constraints/ConstraintInterface.php',
    'JsonSchema\\Constraints\\EnumConstraint' => $vendorDir . '/justinrainbow/json-schema/src/JsonSchema/Constraints/EnumConstraint.php',
    'JsonSchema\\Constraints\\Factory' => $vendorDir . '/justinrainbow/json-schema/src/JsonSchema/Constraints/Factory.php',
    'JsonSchema\\Constraints\\FormatConstraint' => $vendorDir . '/justinrainbow/json-schema/src/JsonSchema/Constraints/FormatConstraint.php',
    'JsonSchema\\Constraints\\NumberConstraint' => $vendorDir . '/justinrainbow/json-schema/src/JsonSchema/Constraints/NumberConstraint.php',
    'JsonSchema\\Constraints\\ObjectConstraint' => $vendorDir . '/justinrainbow/json-schema/src/JsonSchema/Constraints/ObjectConstraint.php',
    'JsonSchema\\Constraints\\SchemaConstraint' => $vendorDir . '/justinrainbow/json-schema/src/JsonSchema/Constraints/SchemaConstraint.php',
    'JsonSchema\\Constraints\\StringConstraint' => $vendorDir . '/justinrainbow/json-schema/src/JsonSchema/Constraints/StringConstraint.php',
    'JsonSchema\\Constraints\\TypeCheck\\LooseTypeCheck' => $vendorDir . '/justinrainbow/json-schema/src/JsonSchema/Constraints/TypeCheck/LooseTypeCheck.php',
    'JsonSchema\\Constraints\\TypeCheck\\StrictTypeCheck' => $vendorDir . '/justinrainbow/json-schema/src/JsonSchema/Constraints/TypeCheck/StrictTypeCheck.php',
    'JsonSchema\\Constraints\\TypeCheck\\TypeCheckInterface' => $vendorDir . '/justinrainbow/json-schema/src/JsonSchema/Constraints/TypeCheck/TypeCheckInterface.php',
    'JsonSchema\\Constraints\\TypeConstraint' => $vendorDir . '/justinrainbow/json-schema/src/JsonSchema/Constraints/TypeConstraint.php',
    'JsonSchema\\Constraints\\UndefinedConstraint' => $vendorDir . '/justinrainbow/json-schema/src/JsonSchema/Constraints/UndefinedConstraint.php',
    'JsonSchema\\Entity\\JsonPointer' => $vendorDir . '/justinrainbow/json-schema/src/JsonSchema/Entity/JsonPointer.php',
    'JsonSchema\\Exception\\ExceptionInterface' => $vendorDir . '/justinrainbow/json-schema/src/JsonSchema/Exception/ExceptionInterface.php',
    'JsonSchema\\Exception\\InvalidArgumentException' => $vendorDir . '/justinrainbow/json-schema/src/JsonSchema/Exception/InvalidArgumentException.php',
    'JsonSchema\\Exception\\InvalidConfigException' => $vendorDir . '/justinrainbow/json-schema/src/JsonSchema/Exception/InvalidConfigException.php',
    'JsonSchema\\Exception\\InvalidSchemaException' => $vendorDir . '/justinrainbow/json-schema/src/JsonSchema/Exception/InvalidSchemaException.php',
    'JsonSchema\\Exception\\InvalidSchemaMediaTypeException' => $vendorDir . '/justinrainbow/json-schema/src/JsonSchema/Exception/InvalidSchemaMediaTypeException.php',
    'JsonSchema\\Exception\\InvalidSourceUriException' => $vendorDir . '/justinrainbow/json-schema/src/JsonSchema/Exception/InvalidSourceUriException.php',
    'JsonSchema\\Exception\\JsonDecodingException' => $vendorDir . '/justinrainbow/json-schema/src/JsonSchema/Exception/JsonDecodingException.php',
    'JsonSchema\\Exception\\ResourceNotFoundException' => $vendorDir . '/justinrainbow/json-schema/src/JsonSchema/Exception/ResourceNotFoundException.php',
    'JsonSchema\\Exception\\RuntimeException' => $vendorDir . '/justinrainbow/json-schema/src/JsonSchema/Exception/RuntimeException.php',
    'JsonSchema\\Exception\\UnresolvableJsonPointerException' => $vendorDir . '/justinrainbow/json-schema/src/JsonSchema/Exception/UnresolvableJsonPointerException.php',
    'JsonSchema\\Exception\\UriResolverException' => $vendorDir . '/justinrainbow/json-schema/src/JsonSchema/Exception/UriResolverException.php',
    'JsonSchema\\Exception\\ValidationException' => $vendorDir . '/justinrainbow/json-schema/src/JsonSchema/Exception/ValidationException.php',
    'JsonSchema\\Iterator\\ObjectIterator' => $vendorDir . '/justinrainbow/json-schema/src/JsonSchema/Iterator/ObjectIterator.php',
    'JsonSchema\\Rfc3339' => $vendorDir . '/justinrainbow/json-schema/src/JsonSchema/Rfc3339.php',
    'JsonSchema\\SchemaStorage' => $vendorDir . '/justinrainbow/json-schema/src/JsonSchema/SchemaStorage.php',
    'JsonSchema\\SchemaStorageInterface' => $vendorDir . '/justinrainbow/json-schema/src/JsonSchema/SchemaStorageInterface.php',
    'JsonSchema\\UriResolverInterface' => $vendorDir . '/justinrainbow/json-schema/src/JsonSchema/UriResolverInterface.php',
    'JsonSchema\\UriRetrieverInterface' => $vendorDir . '/justinrainbow/json-schema/src/JsonSchema/UriRetrieverInterface.php',
    'JsonSchema\\Uri\\Retrievers\\AbstractRetriever' => $vendorDir . '/justinrainbow/json-schema/src/JsonSchema/Uri/Retrievers/AbstractRetriever.php',
    'JsonSchema\\Uri\\Retrievers\\Curl' => $vendorDir . '/justinrainbow/json-schema/src/JsonSchema/Uri/Retrievers/Curl.php',
    'JsonSchema\\Uri\\Retrievers\\FileGetContents' => $vendorDir . '/justinrainbow/json-schema/src/JsonSchema/Uri/Retrievers/FileGetContents.php',
    'JsonSchema\\Uri\\Retrievers\\PredefinedArray' => $vendorDir . '/justinrainbow/json-schema/src/JsonSchema/Uri/Retrievers/PredefinedArray.php',
    'JsonSchema\\Uri\\Retrievers\\UriRetrieverInterface' => $vendorDir . '/justinrainbow/json-schema/src/JsonSchema/Uri/Retrievers/UriRetrieverInterface.php',
    'JsonSchema\\Uri\\UriResolver' => $vendorDir . '/justinrainbow/json-schema/src/JsonSchema/Uri/UriResolver.php',
    'JsonSchema\\Uri\\UriRetriever' => $vendorDir . '/justinrainbow/json-schema/src/JsonSchema/Uri/UriRetriever.php',
    'JsonSchema\\Validator' => $vendorDir . '/justinrainbow/json-schema/src/JsonSchema/Validator.php',
    'cogpowered\\FineDiff\\Delimiters' => $vendorDir . '/cogpowered/finediff/src/cogpowered/FineDiff/Delimiters.php',
    'cogpowered\\FineDiff\\Diff' => $vendorDir . '/cogpowered/finediff/src/cogpowered/FineDiff/Diff.php',
    'cogpowered\\FineDiff\\Exceptions\\GranularityCountException' => $vendorDir . '/cogpowered/finediff/src/cogpowered/FineDiff/Exceptions/GranularityCountException.php',
    'cogpowered\\FineDiff\\Exceptions\\OperationException' => $vendorDir . '/cogpowered/finediff/src/cogpowered/FineDiff/Exceptions/OperationException.php',
    'cogpowered\\FineDiff\\Granularity\\Character' => $vendorDir . '/cogpowered/finediff/src/cogpowered/FineDiff/Granularity/Character.php',
    'cogpowered\\FineDiff\\Granularity\\Granularity' => $vendorDir . '/cogpowered/finediff/src/cogpowered/FineDiff/Granularity/Granularity.php',
    'cogpowered\\FineDiff\\Granularity\\GranularityInterface' => $vendorDir . '/cogpowered/finediff/src/cogpowered/FineDiff/Granularity/GranularityInterface.php',
    'cogpowered\\FineDiff\\Granularity\\Paragraph' => $vendorDir . '/cogpowered/finediff/src/cogpowered/FineDiff/Granularity/Paragraph.php',
    'cogpowered\\FineDiff\\Granularity\\Sentence' => $vendorDir . '/cogpowered/finediff/src/cogpowered/FineDiff/Granularity/Sentence.php',
    'cogpowered\\FineDiff\\Granularity\\Word' => $vendorDir . '/cogpowered/finediff/src/cogpowered/FineDiff/Granularity/Word.php',
    'cogpowered\\FineDiff\\Parser\\Opcodes' => $vendorDir . '/cogpowered/finediff/src/cogpowered/FineDiff/Parser/Opcodes.php',
    'cogpowered\\FineDiff\\Parser\\OpcodesInterface' => $vendorDir . '/cogpowered/finediff/src/cogpowered/FineDiff/Parser/OpcodesInterface.php',
    'cogpowered\\FineDiff\\Parser\\Operations\\Copy' => $vendorDir . '/cogpowered/finediff/src/cogpowered/FineDiff/Parser/Operations/Copy.php',
    'cogpowered\\FineDiff\\Parser\\Operations\\Delete' => $vendorDir . '/cogpowered/finediff/src/cogpowered/FineDiff/Parser/Operations/Delete.php',
    'cogpowered\\FineDiff\\Parser\\Operations\\Insert' => $vendorDir . '/cogpowered/finediff/src/cogpowered/FineDiff/Parser/Operations/Insert.php',
    'cogpowered\\FineDiff\\Parser\\Operations\\OperationInterface' => $vendorDir . '/cogpowered/finediff/src/cogpowered/FineDiff/Parser/Operations/OperationInterface.php',
    'cogpowered\\FineDiff\\Parser\\Operations\\Replace' => $vendorDir . '/cogpowered/finediff/src/cogpowered/FineDiff/Parser/Operations/Replace.php',
    'cogpowered\\FineDiff\\Parser\\Parser' => $vendorDir . '/cogpowered/finediff/src/cogpowered/FineDiff/Parser/Parser.php',
    'cogpowered\\FineDiff\\Parser\\ParserInterface' => $vendorDir . '/cogpowered/finediff/src/cogpowered/FineDiff/Parser/ParserInterface.php',
    'cogpowered\\FineDiff\\Render\\Html' => $vendorDir . '/cogpowered/finediff/src/cogpowered/FineDiff/Render/Html.php',
    'cogpowered\\FineDiff\\Render\\Renderer' => $vendorDir . '/cogpowered/finediff/src/cogpowered/FineDiff/Render/Renderer.php',
    'cogpowered\\FineDiff\\Render\\RendererInterface' => $vendorDir . '/cogpowered/finediff/src/cogpowered/FineDiff/Render/RendererInterface.php',
    'cogpowered\\FineDiff\\Render\\Text' => $vendorDir . '/cogpowered/finediff/src/cogpowered/FineDiff/Render/Text.php',
);
