OC.L10N.register(
    "deck",
    {
    "Personal" : "පුද්ගලික",
    "Later" : "පසුව",
    "copy" : "පිටපත්",
    "Example Task 3" : "උදාහරණ කාර්යය 3",
    "Example Task 2" : "උදාහරණ කාර්යය 2",
    "Example Task 1" : "උදාහරණ කාර්යය 1",
    "No file was uploaded" : "කිසිදු ගොනුවක් උඩුගත කර නොමැත",
    "Missing a temporary folder" : "තාවකාලික බහාලුමක් අස්ථානගත වී ඇත",
    "Cancel" : "අවලංගු කරන්න",
    "Close" : "වසන්න",
    "File already exists" : "ගොනුව දැනටමත් පවතී",
    "Add list" : "ලැයිස්තුව එකතු කරන්න",
    "Details" : "විස්තර",
    "Undo" : "පෙරසේ",
    "(Group)" : "(සමූහය)",
    "Owner" : "හිමිකරු",
    "Edit" : "සංස්කරණය",
    "Download" : "බාගන්න",
    "Attachments" : "ඇමිණුම්",
    "Comments" : "අදහස්",
    "Select Date" : "දිනය තෝරන්න",
    "Today" : "අද",
    "Tomorrow" : "හෙට",
    "Next week" : "ඊළඟ සතිය",
    "Next month" : "ඊළඟ මාසය",
    "Save" : "සුරකින්න",
    "Reply" : "පිළිතුර",
    "Update" : "යාවත්කාල",
    "Description" : "විස්තරය",
    "seconds ago" : "තත්පර කිහිපයකට පෙර",
    "Share" : "බෙදාගන්න",
    "This week" : "මෙම සතිය"
},
"nplurals=2; plural=(n != 1);");
