OC.L10N.register(
    "deck",
    {
    "Personal" : "Udmawan",
    "Finished" : "Immed",
    "The file was uploaded" : "Ulac afaylu yettwaznen",
    "The file was only partially uploaded" : "Afaylu, cwiṭ kan i yettwaznen segs",
    "No file was uploaded" : "Ulac afaylu i d-yettwasulin",
    "Missing a temporary folder" : "Ixuṣ ukaram akudan",
    "Cancel" : "Sefsex",
    "Close" : "Mdel",
    "Details" : "Talqayt",
    "Sharing" : "Beṭṭu",
    "Tags" : "Tibzimin",
    "Delete" : "Kkes",
    "Edit" : "Ẓreg",
    "Download" : "Sider",
    "Modified" : "Yettwabeddel",
    "Today" : "Ass-a",
    "Save" : "Sekles",
    "No notifications" : "Ulac tisezmal",
    "Share" : "Bḍu",
    "This week" : "Dduṛt agi"
},
"nplurals=2; plural=(n != 1);");
