OC.L10N.register(
    "deck",
    {
    "Personal" : "Personal",
    "Finished" : "Finite",
    "To review" : "A revider",
    "Action needed" : "Action necessari",
    "Later" : "Depost",
    "Done" : "Preste",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Le file incargate excede le directiva MAX_FILE_SIZE que esseva specificate in le formulario HTML",
    "No file was uploaded" : "Nulle file esseva incargate",
    "Missing a temporary folder" : "Il manca un dossier temporari",
    "Cancel" : "Cancellar",
    "Close" : "Clauder",
    "Details" : "Detalios",
    "Sharing" : "Compartente",
    "Tags" : "Etiquettas",
    "Undo" : "Disfacer",
    "Can edit" : "Can edit",
    "Can share" : "Can share",
    "Owner" : "Owner",
    "Delete" : "Deler",
    "Edit" : "Modificar",
    "Members" : "Membros",
    "Download" : "Discargar",
    "Attachments" : "Attachamentos",
    "Comments" : "Commentarios",
    "Modified" : "Modificate",
    "Today" : "Hodie",
    "Tomorrow" : "Deman",
    "Save" : "Salveguardar",
    "Reply" : "Responder",
    "Update" : "Actualisation",
    "Description" : "Description",
    "(group)" : "(gruppo)",
    "seconds ago" : "secundas passate",
    "Shared with you" : "Compartite con te",
    "No notifications" : "Nulle notificationes",
    "Share" : "Compartir",
    "This week" : "Iste septimana"
},
"nplurals=2; plural=(n != 1);");
