OC.L10N.register(
    "deck",
    {
    "Personal" : "Personal",
    "copy" : "copiar",
    "Done" : "Done",
    "The file was uploaded" : "Lo fichièr es estat enviat",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Lo fichièr enviat despassa la directiva upload_max_filesize de php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Lo fichièr enviat despassa la directiva MAX_FILE_SIZE especificada dins lo formulari HTML",
    "The file was only partially uploaded" : "Lo fichièr es estat parcialament enviat",
    "No file was uploaded" : "Cap de fichièr pas enviat",
    "Missing a temporary folder" : "Dossièr temporari absent",
    "Could not write file to disk" : "Escritura impossibla al disc",
    "A PHP extension stopped the file upload" : "Una extension PHP a arrestat lo mandadís de fichièr",
    "Invalid date, date format must be YYYY-MM-DD" : "Invalida data, lo format de data deu èsser YYYY-MM-DD",
    "Create a new card" : "Crear una carta novèla",
    "Cancel" : "Anullar",
    "Close" : "Tampar",
    "Create card" : "Crear una carta",
    "File already exists" : "Lo fichièr existís ja",
    "Drop your files to upload" : "Depausatz los fichièrs d’enviar",
    "Details" : "Detalhs",
    "Sharing" : "Partiment",
    "Tags" : "Etiquetas",
    "Deleted items" : "Elements suprimits",
    "Deleted lists" : "Listas suprimidas",
    "Undo" : "Desfar",
    "(Group)" : "(Grop)",
    "Can edit" : "Can edit",
    "Can share" : "Can share",
    "Owner" : "Owner",
    "Delete" : "Suprimir",
    "Edit" : "Modificar",
    "Members" : "Membres",
    "Upload new files" : "Enviar fichièrs novèls",
    "Share from Files" : "Partejar a partir dels Fichièrs",
    "Download" : "Telecargar",
    "File to share" : "Fichièr de partejar",
    "Invalid path selected" : "Camin seleccionat invalid",
    "Comments" : "Comentaris",
    "Modified" : "Modificat",
    "Today" : "Uèi",
    "Tomorrow" : "Deman",
    "Next week" : "Setmana seguenta",
    "Next month" : "Mes seguent",
    "Save" : "Salvar",
    "Cancel reply" : "Anullar la responsa",
    "Reply" : "Respondre",
    "Update" : "Metre a jorn",
    "Description" : "Descripcion",
    "seconds ago" : "fa qualques segondas",
    "Shared with you" : "Shared with you",
    "No notifications" : "Cap de notificacion",
    "An error occurred" : "Una error s’es producha",
    "{stack} in {board}" : "{stack} dins {board}",
    "Create a card" : "Crear una carta",
    "Share" : "Partejar",
    "This week" : "Aquesta setmana"
},
"nplurals=2; plural=(n > 1);");
