OC.L10N.register(
    "deck",
    {
    "You have created a new board {board}" : "Létrehozta az új {board} táblát",
    "{user} has created a new board {board}" : "{user} létrehozta az új {board} táblát",
    "You have deleted the board {board}" : "Törölte a(z) {board} táblát",
    "{user} has deleted the board {board}" : "{user} törölte a(z) {board} táblát",
    "You have restored the board {board}" : "Visszaállította a(z) {board} táblát",
    "{user} has restored the board {board}" : "{user} visszaállította a(z) {board} táblát",
    "You have shared the board {board} with {acl}" : "Megosztotta a(z) {board} táblát a következővel: {acl}",
    "{user} has shared the board {board} with {acl}" : "{user} megosztotta a(z) {board} táblát a következővel: {acl}",
    "You have removed {acl} from the board {board}" : "Eltávolította a következőt a(z) {board} táblától: {acl}",
    "{user} has removed {acl} from the board {board}" : "{user} eltávolította a következőt a(z) {board} táblától: {acl}",
    "You have renamed the board {before} to {board}" : "Átnevezte a(z) {before} táblát erre: {board}",
    "{user} has renamed the board {before} to {board}" : "{user} átnevezte a(z) {before} táblát erre: {board}",
    "You have archived the board {board}" : "Archiválta a(z) {board} táblát",
    "{user} has archived the board {before}" : "{user} archiválta a(z) {before} táblát",
    "You have unarchived the board {board}" : "Visszavonta a(z) {board} tábla archiválását",
    "{user} has unarchived the board {before}" : "{user} visszavonta a(z) {board} tábla archiválását",
    "You have created a new list {stack} on board {board}" : "Létrehozta az új {stack} listát a(z) {board} táblán",
    "{user} has created a new list {stack} on board {board}" : "{user} létrehozta az új {stack} listát a(z) {board} táblán",
    "You have renamed list {before} to {stack} on board {board}" : "Átnevezte a(z) {board} tábla {before} listát erre: {stack}",
    "{user} has renamed list {before} to {stack} on board {board}" : "{user} átnevezte a(z) {board} tábla {before} listáját erre: {stack}",
    "You have deleted list {stack} on board {board}" : "Törölte a(z) {stack} listát a(z) {board} tábláról",
    "{user} has deleted list {stack} on board {board}" : "{user} törölte a(z) {stack} listát a(z) {board} tábláról",
    "You have created card {card} in list {stack} on board {board}" : "Létrehozta a(z) {card} kártyát a(z) {stack} listában, a(z) {board} táblán",
    "{user} has created card {card} in list {stack} on board {board}" : "{user} létrehozta a(z) {card} kártyát a(z) {stack} listában, a(z) {board} táblán",
    "You have deleted card {card} in list {stack} on board {board}" : "Törölte a(z) {card} kártyát a(z) {stack} listából, a(z) {board} táblán",
    "{user} has deleted card {card} in list {stack} on board {board}" : "{user} törölte a(z) {card} kártyát a(z) {stack} listában, a(z) {board} táblán",
    "You have renamed the card {before} to {card}" : "Átnevezte a(z) {before} kártyát erre: {card}",
    "{user} has renamed the card {before} to {card}" : "{user} átnevezte a(z) {before} kártyát erre: {card}",
    "You have added a description to card {card} in list {stack} on board {board}" : "Leírást adott hozzá a(z) {card} kártyához a(z) {stack} listában, a(z) {board} táblán",
    "{user} has added a description to card {card} in list {stack} on board {board}" : "{user} leírást adott hozzá a(z) {card} kártyához a(z) {stack} listában, a(z) {board} táblán",
    "You have updated the description of card {card} in list {stack} on board {board}" : "Frissítette a(z) {card} kártya leírását a(z) {stack} listában, a(z) {board} táblán",
    "{user} has updated the description of the card {card} in list {stack} on board {board}" : "{user} frissítette a(z) {card} kártya leírását a(z) {stack} listában, a(z) {board} táblán",
    "You have archived card {card} in list {stack} on board {board}" : "Archiválta a(z) {card} kártyát a(z) {stack} listában, a(z) {board} táblán",
    "{user} has archived card {card} in list {stack} on board {board}" : "{user} archiválta a(z) {card} kártyát a(z) {stack} listában, a(z) {board} táblán",
    "You have unarchived card {card} in list {stack} on board {board}" : "Visszavonta a(z) {card} kártya archiválását a(z) {stack} listában, a(z) {board} táblán",
    "{user} has unarchived card {card} in list {stack} on board {board}" : "{user} visszavonta a(z) {card} kártya archiválását a(z) {stack} listában, a(z) {board} táblán",
    "You have removed the due date of card {card}" : "Eltávolította a(z) {card} kártya esedékességét",
    "{user} has removed the due date of card {card}" : "{user} eltávolította a(z) {card} kártya esedékességét",
    "You have set the due date of card {card} to {after}" : "Beállította a(z) {card} kártya esedékességét",
    "{user} has set the due date of card {card} to {after}" : "{user} beállította a(z) {card} kártya esedékességét",
    "You have updated the due date of card {card} to {after}" : "Frissítette a(z) {card} kártya esedékességét erre: {after}",
    "{user} has updated the due date of card {card} to {after}" : "{user} frissítette a(z) {card} kártya esedékességét erre: {after}",
    "You have added the tag {label} to card {card} in list {stack} on board {board}" : "Hozzáadta a(z) {label} címkét a(z) {card} kártyához, a(z) {stack} listában, a(z) {board} táblán",
    "{user} has added the tag {label} to card {card} in list {stack} on board {board}" : "{user} hozzáadta a(z) {label} címkét a(z) {card} kártyához, a(z) {stack} listában, a(z) {board} táblán",
    "You have removed the tag {label} from card {card} in list {stack} on board {board}" : "Eltávolította a(z) {label} címkét a(z) {card} kártyáról, a(z) {stack} listában, a(z) {board} táblán",
    "{user} has removed the tag {label} from card {card} in list {stack} on board {board}" : "{user} eltávolította a(z) {label} címkét a(z) {card} kártyáról, a(z) {stack} listában, a(z) {board} táblán",
    "You have assigned {assigneduser} to card {card} on board {board}" : "Hozzárendelte a(z) {card} kártyát a(z) {board} táblán a következőhöz: {assigneduser}",
    "{user} has assigned {assigneduser} to card {card} on board {board}" : "{user} hozzárendelte a(z) {card} kártyát a(z) {board} táblán a következőhöz: {assigneduser}",
    "You have unassigned {assigneduser} from card {card} on board {board}" : "Eltávolította a(z) {card} kártyát a(z) {board} táblán a következőtől: {assigneduser}",
    "{user} has unassigned {assigneduser} from card {card} on board {board}" : "{user} eltávolította a(z) {card} kártyát a(z) {board} táblán a következőtől: {assigneduser}",
    "You have moved the card {card} from list {stackBefore} to {stack}" : "Áthelyezte a(z) {card} kártyát a(z) {stackBefore} listából a(z) {stack} listába",
    "{user} has moved the card {card} from list {stackBefore} to {stack}" : "{user} áthelyezte a(z) {card} kártyát a(z) {stackBefore} listából a(z) {stack} listába",
    "You have added the attachment {attachment} to card {card}" : "Hozzáadta a(z) {attachment} mellékletet a(z) {card} kártyához",
    "{user} has added the attachment {attachment} to card {card}" : "{user} hozzáadta a(z) {attachment} mellékletet a(z) {card} kártyához",
    "You have updated the attachment {attachment} on card {card}" : "Frissítette a(z) {attachment} mellékletet a(z) {card} kártyánál",
    "{user} has updated the attachment {attachment} on card {card}" : "{user} frissítette a(z) {attachment} mellékletet a(z) {card} kártyán",
    "You have deleted the attachment {attachment} from card {card}" : "Eltávolította a(z) {attachment} mellékletet a(z) {card} kártyáról",
    "{user} has deleted the attachment {attachment} from card {card}" : "{user} eltávolította a(z) {attachment} mellékletet a(z) {card} kártyáról",
    "You have restored the attachment {attachment} to card {card}" : "Visszaállította a(z) {attachment} mellékletet a(z) {card} kártyánál",
    "{user} has restored the attachment {attachment} to card {card}" : "{user} visszaállította a(z) {attachment} mellékletet a(z) {card} kártyánál",
    "You have commented on card {card}" : "Hozzászólt a(z) {card} kártyához",
    "{user} has commented on card {card}" : "{user} hozzászólt a(z) {card} kártyához",
    "A <strong>card description</strong> inside the Deck app has been changed" : "A <strong>kártyaleírás</strong> megváltozott a Kártyák alkalmazásban",
    "Deck" : "Kártyák",
    "Changes in the <strong>Deck app</strong>" : "Változások a <strong>Kártyák alkalmazásban</strong>",
    "A <strong>comment</strong> was created on a card" : "Egy <strong>hozzászólás</strong> lett létrehozva egy kártyán",
    "Upcoming cards" : "Közelgő kártyák",
    "Load more" : "Továbbiak betöltése",
    "Personal" : "Személyes",
    "The card \"%s\" on \"%s\" has been assigned to you by %s." : "A(z) „%s” kártyát a(z) „%s” táblán %s hozzárendelte Önhöz.",
    "{user} has assigned the card {deck-card} on {deck-board} to you." : "{user} hozzárendelte Önhöz a(z) {deck-board} táblán lévő {deck-card} kártyát.",
    "The card \"%s\" on \"%s\" has reached its due date." : "A(z) „%s” kártya a(z) „%s” táblán elérte a határidejét.",
    "The card {deck-card} on {deck-board} has reached its due date." : "A(z) {deck-board} táblán lévő {deck-card} kártya elérte a határidejét.",
    "%s has mentioned you in a comment on \"%s\"." : "%s megemlítette egy hozzászólásban ennél: „%s”.",
    "{user} has mentioned you in a comment on {deck-card}." : "{user} megemlítette egy hozzászólásban a(z) {deck-card} kártyán.",
    "The board \"%s\" has been shared with you by %s." : "A(z) „%s” táblát %s osztotta meg Önnel.",
    "{user} has shared {deck-board} with you." : "{user} megosztotta Önnel a(z) {deck-board} táblát.",
    "Card comments" : "Kártya hozzászólásai",
    "%s on %s" : "%s ezen: %s",
    "No data was provided to create an attachment." : "Nincsenek megadva adatok a melléklet létrehozásához.",
    "Finished" : "Kész",
    "To review" : "Áttekintendő",
    "Action needed" : "Művelet szükséges",
    "Later" : "Később",
    "copy" : "másolat",
    "To do" : "Teendő",
    "Doing" : "Folyamatban",
    "Done" : "Kész",
    "Example Task 3" : "3. példafeladat",
    "Example Task 2" : "2. példafeladat",
    "Example Task 1" : "1. példafeladat",
    "The file was uploaded" : "A fájl fel lett töltve",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "A feltöltött fájl meghaladja a php.ini-ben szereplő upload_max_filesize direktívában megadott méretet",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "A feltöltött fájl meghaladja a HTML űrlapon megadott MAX_FILE_SIZE direktívában meghatározott méretet.",
    "The file was only partially uploaded" : "A fájl csak részlegesen lett feltöltve",
    "No file was uploaded" : "Nincs feltöltött fájl",
    "Missing a temporary folder" : "Átmeneti mappa hiányzik",
    "Could not write file to disk" : "Nem lehet a fájlt lemezre írni",
    "A PHP extension stopped the file upload" : "A PHP kiterjesztés megállította a fájl feltöltését",
    "No file uploaded or file size exceeds maximum of %s" : "Nincs fájl feltöltve, vagy a fájl meghaladja a maximumot: %s",
    "This comment has more than %s characters.\nAdded as an attachment to the card with name %s.\nAccessible on URL: %s." : "Ez a megjegyzés több mint %s karakter hosszú.\nMellékletként lett hozzáadva a(z) %s nevű kártyához.\nEzen az URL-en érhető el: %s.",
    "Card not found" : "A kártya nem található",
    "Path is already shared with this card" : "Az útvonal már meg van osztva ezzel a kártyával",
    "Invalid date, date format must be YYYY-MM-DD" : "Érvénytelen dátum, a dátumnak YYYY-MM-DD formátumúnak kell lennie",
    "Personal planning and team project organization" : "Személyes tervezés és csapatos projektszervezés",
    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in Markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your Markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "A Kártyák egy kanban-stílusú szervezőeszköz, amely a személyes tervezést és a csapatok projektszervezését célozza, a Nextcloudba integrálva.\n\n\n- 📥 Saját feladatok kártyákhoz adása, és azok sorrendezése\n- 📄 További jegyzetek leírása Markdownban\n- 🔖 Címkék hozzárendelése a még jobb rendszerezés miatt\n- 👥 Megosztás a csapattal, barátokkal vagy családdal\n- 📎 Fájlok hozzáadása mellékletként, vagy beágyazás a Markdown leírásba\n- 💬 Megbeszélés a csapattal hozzászólások használatával\n- ⚡ A változások követése a tevékenységnaplóban\n- 🚀 Rendszerezze a projektjét",
    "Card details" : "Kártya részletei",
    "Add board" : "Tábla hozzáadása",
    "Select the board to link to a project" : "Válasszon ki egy táblát, amely egy projektre fog hivatkozni",
    "Search by board title" : "Keresés táblacím szerint",
    "Select board" : "Válasszon táblát",
    "Create a new card" : "Új kártya létrehozása",
    "Select a board" : "Válasszon egy táblát",
    "Select a list" : "Válasszon listát",
    "Card title" : "Kártya címe",
    "Cancel" : "Mégse",
    "Creating the new card …" : "Új kártya létrehozása…",
    "Card \"{card}\" was added to \"{board}\"" : "A(z) „{card}” kártya hozzáadva a(z) „{board}” táblához",
    "Open card" : "Kártya megnyitása",
    "Close" : "Bezárás",
    "Create card" : "Kártya létrehozása",
    "Select a card" : "Válasszon egy kártyát",
    "Select the card to link to a project" : "Válasszon ki egy kártyát, amely egy projektre fog hivatkozni",
    "Link to card" : "Hivatkozás egy kártyára",
    "File already exists" : "A fájl már létezik",
    "A file with the name {filename} already exists." : "{filename} nevű fájl már létezik.",
    "Do you want to overwrite it?" : "Felülírja?",
    "Overwrite file" : "Fájl felülírása",
    "Keep existing file" : "Meglévő fájl megtartása",
    "This board is read only" : "Ez a tábla csak olvasható",
    "Drop your files to upload" : "Dobja ide a fájljait a feltöltéshez",
    "Add card" : "Kártya hozzáadása",
    "Archived cards" : "Archivált kártyák",
    "Add list" : "Lista hozzáadása",
    "List name" : "Listanév",
    "Active filters" : "Aktív szűrők",
    "Apply filter" : "Szűrő alkalmazása",
    "Filter by tag" : "Szűrés címke szerint",
    "Filter by assigned user" : "Szűrés hozzárendelt felhasználó szerint",
    "Unassigned" : "Nem hozzárendelt",
    "Filter by due date" : "Szűrés határidő szerint",
    "Overdue" : "Lejárt",
    "Next 24 hours" : "Következő 24 óra",
    "Next 7 days" : "Következő 7 nap",
    "Next 30 days" : "Következő 30 nap",
    "No due date" : "Nincs határidő",
    "Clear filter" : "Szűrő törlése",
    "Hide archived cards" : "Archivált kártyák elrejtése",
    "Show archived cards" : "Archivált kártyák megjelenítése",
    "Toggle compact mode" : "Kompakt mód be/ki",
    "Open details" : "Részletek megnyitása",
    "Details" : "Részletek",
    "Loading board" : "Tábla betöltése",
    "No lists available" : "Nincs elérhető lista",
    "Create a new list to add cards to this board" : "Hozzon létre egy új listát a kártyák ehhez a táblához való hozzáadásához",
    "Board not found" : "A tábla nem található",
    "Sharing" : "Megosztás",
    "Tags" : "Címkék",
    "Deleted items" : "Törölt elemek",
    "Timeline" : "Idővonal",
    "Deleted lists" : "Törölt listák",
    "Undo" : "Visszavonás",
    "Deleted cards" : "Törölt kártyák",
    "Share board with a user, group or circle …" : "Tábla megosztása felhasználóval, csoporttal vagy körrel…",
    "Searching for users, groups and circles …" : "Felhasználók, csoportok és körök keresése…",
    "No participants found" : "Nem találhatók résztvevők",
    "Board owner" : "Tábla tulajdonosa",
    "(Group)" : "(Csoport)",
    "(Circle)" : "(Kör)",
    "Can edit" : "Szerkesztheti",
    "Can share" : "Megoszthatja",
    "Can manage" : "Kezelheti",
    "Owner" : "Tulajdonos",
    "Delete" : "Törlés",
    "Failed to create share with {displayName}" : "Nem lehet létrehozni a következő megosztást: {displayName}",
    "Are you sure you want to transfer the board {title} to {user}?" : "Biztos, hogy átadja a(z) {board} tábla tulajdonjogát {user} számára?",
    "Transfer the board." : "A tábla átadása.",
    "Transfer" : "Átadás",
    "The board has been transferred to {user}" : "A tábla átadása {user} számára sikeres",
    "Failed to transfer the board to {user}" : "A tábla átadása {user} számára sikertelen",
    "Add a new list" : "Új lista hozzáadása",
    "Archive all cards" : "Az összes kártya archiválása",
    "Unarchive all cards" : "Az összes kártya archiválásának visszavonása",
    "Delete list" : "Lista törlése",
    "Archive all cards in this list" : "Az összes kártya archiválása ebben a listában",
    "Unarchive all cards in this list" : "Az összes kártya archiválásának visszavonása ebben a listában",
    "Add a new card" : "Új kártya hozzáadása",
    "Card name" : "Kártya neve",
    "List deleted" : "Lista törölve",
    "Edit" : "Szerkesztés",
    "Add a new tag" : "Új címke hozzáadása",
    "title and color value must be provided" : "a cím és szín értékét meg kell adni",
    "Board name" : "Tábla neve",
    "Members" : "Tagok",
    "Upload new files" : "Új fájlok feltöltése",
    "Share from Files" : "Megosztás a Fájlokból",
    "Pending share" : "Függőben lévő megosztás",
    "Add this attachment" : "E melléklet hozzáadása",
    "Show in Files" : "Megjelenítés a Fájlokban",
    "Download" : "Letöltés",
    "Remove attachment" : "Melléklet eltávolítása",
    "Delete Attachment" : "Melléklet törlése",
    "Restore Attachment" : "Melléklet visszaállítása",
    "File to share" : "Fájl megosztása",
    "Invalid path selected" : "Érvénytelen útvonal kiválasztva",
    "Open in sidebar view" : "Oldalsáv nézet megnyitása",
    "Open in bigger view" : "Megtekintés nagyobb nézetben",
    "Attachments" : "Mellékletek",
    "Comments" : "Hozzászólások",
    "Modified" : "Módosítva",
    "Created" : "Létrehozva",
    "The title cannot be empty." : "A cím nem lehet üres.",
    "No comments yet. Begin the discussion!" : "Még nincsenek hozzászólások. Kezdje el a beszélgetést!",
    "Failed to load comments" : "A hozzászólások betöltése sikertelen",
    "Assign a tag to this card…" : "Címke rendelése ehhez a kártyához…",
    "Assign to users" : "Felhasználókhoz rendelés",
    "Assign to users/groups/circles" : "Felhasználókhoz/csoportokhoz/körökhöz rendelés",
    "Assign a user to this card…" : "Felhasználó rendelése ehhez a kártyához…",
    "Due date" : "Határidő",
    "Set a due date" : "Határidő beállítása",
    "Remove due date" : "Határidő eltávolítása",
    "Select Date" : "Dátum kiválasztása",
    "Today" : "Ma",
    "Tomorrow" : "Holnap",
    "Next week" : "Következő hét",
    "Next month" : "Következő hónap",
    "Save" : "Mentés",
    "The comment cannot be empty." : "A hozzászólás nem lehet üres.",
    "The comment cannot be longer than 1000 characters." : "A megjegyzés nem lehet 1000 karakternél hosszabb.",
    "In reply to" : "Válaszként erre:",
    "Cancel reply" : "Válasz elvetése",
    "Reply" : "Válasz",
    "Update" : "Frissítés",
    "Description" : "Leírás",
    "(Unsaved)" : "(Nem mentett)",
    "(Saving…)" : "(Mentés…)",
    "Formatting help" : "Formázási súgó",
    "Edit description" : "Leírás szerkesztése",
    "View description" : "Leírás megtekintése",
    "Add Attachment" : "Melléklet hozzáadása",
    "Write a description …" : "Leírás megadása…",
    "Choose attachment" : "Válasszon mellékletet",
    "(group)" : "(csoport)",
    "Todo items" : "Teendő elemek",
    "{count} comments, {unread} unread" : "{count} hozzászólás, {unread} olvasatlan",
    "Edit card title" : "Kártyacím szerkesztése",
    "Assign to me" : "Hozzám rendelés",
    "Unassign myself" : "Saját magam hozzárendelésének eltávolítása",
    "Move card" : "Kártya áthelyezése",
    "Unarchive card" : "Kártya archiválásának visszavonása",
    "Archive card" : "Kártya archiválása",
    "Delete card" : "Kártya törlése",
    "Move card to another board" : "Kártya áthelyezése egy másik táblára",
    "List is empty" : "A lista üres",
    "Card deleted" : "Kártya törölve",
    "seconds ago" : "másodperce",
    "All boards" : "Az összes tábla",
    "Archived boards" : "Archivált táblák",
    "Shared with you" : "Megosztva Önnel",
    "Deck settings" : "Kártyák beállításai",
    "Use bigger card view" : "Nagyobb kártyanézet használata",
    "Show card ID badge" : "Kártyaazonosító jelvény megjelenítése",
    "Show boards in calendar/tasks" : "Táblák megjelenítése a naptárak/teendők között",
    "Limit deck usage of groups" : "A kártyák használatának csoportokra korlátozása",
    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "A Kártyák korlátozása blokkolja a saját táblák létrehozását azoknál a felhasználóknál, akik nem tagjai a megadott csoportoknak. A felhasználók továbbra is tudnak dolgozni a velük megosztott táblákon.",
    "Board details" : "Tábla részletei",
    "Edit board" : "Tábla szerkesztése",
    "Clone board" : "Tábla klónozása",
    "Unarchive board" : "Tábla archiválásának visszavonása",
    "Archive board" : "Tábla archiválása",
    "Turn on due date reminders" : "Határidő emlékeztető beállítása",
    "Turn off due date reminders" : "Határidő emlékeztető kikapcsolása",
    "Due date reminders" : "Határidő emlékeztetők",
    "All cards" : "Összes kártya",
    "Assigned cards" : "Hozzárendelt kártyák",
    "No notifications" : "Nincsenek értesítések",
    "Delete board" : "Tábla törlése",
    "Board {0} deleted" : "A(z) {board} tábla törölve",
    "Only assigned cards" : "Csak hozzárendelt kártyák",
    "No reminder" : "Nincs emlékeztető",
    "An error occurred" : "Hiba történt",
    "Are you sure you want to delete the board {title}? This will delete all the data of this board including archived cards." : "Biztos, hogy törli a(z) {title} táblát? Ez törölni fogja a tábla összes adatát, köztük az archivált kártyákat is.",
    "Delete the board?" : "Törli a táblát?",
    "Loading filtered view" : "Szűrt nézet betöltése",
    "No due" : "Nincs határidő",
    "Search for {searchQuery} in all boards" : "Keresés a(z) {searchQuery} kifejezésre az összes táblában",
    "No results found" : "Nincs találat",
    "{stack} in {board}" : "{stack} itt: {board}",
    "Click to expand description" : "Kattintson a leírás kibontásához",
    "* Created on {created}\n* Last modified on {lastMod}\n* {nbAttachments} attachments\n* {nbComments} comments" : "* Létrehozva: {created}\n* Utoljára módosítva: {lastMod}\n* {nbAttachments} melléklet\n* {nbComments} megjegyzés",
    "{nbCards} cards" : "{nbCards} kártya",
    "No upcoming cards" : "Nincsenek közelgő kártyák",
    "upcoming cards" : "közelgő kártyák",
    "Due on {date}" : "Határidő: {date}",
    "Link to a board" : "Hivatkozás egy táblához",
    "Link to a card" : "Hivatkozás egy kártyához",
    "Create a card" : "Kártya létrehozása",
    "Message from {author} in {conversationName}" : "Üzenet a(z) {conversationName} beszélgetésben tőle: {author}",
    "Something went wrong" : "Valami hiba történt",
    "Failed to upload {name}" : "Feltöltés sikertelen: {name}",
    "Maximum file size of {size} exceeded" : "A legnagyobb fájlméret ({size}) túllépve",
    "Error creating the share" : "Megosztás létrehozása sikertelen",
    "Share with a Deck card" : "Megosztás kártyával",
    "Share {file} with a Deck card" : "A(z) {file} megosztása egy kártyával",
    "Share" : "Megosztás",
    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "A Kártyák egy kanban-stílusú szervezőeszköz, amely a személyes tervezést és a csapatok projektszervezését célozza, a Nextcloudba integrálva.\n\n\n- 📥 Saját feladatok kártyákhoz adása, és azok sorrendezése\n- 📄 További jegyzetek leírása markdownban\n- 🔖 Címkék hozzárendelése a még jobb rendszerezés miatt\n- 👥 Megosztás a csapattal, barátokkal vagy családdal\n- 📎 Fájlok hozzáadása mellékletként, vagy beágyazás a markdown leírásba\n- 💬 Megbeszélés a csapattal hozzászólások használatával\n- ⚡ A változások követése a tevékenységnaplóban\n- 🚀 Rendszerezze a projektjét",
    "Are you sure you want to transfer the board {title} for {user} ?" : "Biztos, hogy átadja a(z) {board} tábla tulajdonjogát {user} számára?",
    "Transfer the board for {user} successfully" : "A tábla átadása {user} számára sikeres",
    "Failed to transfer the board for {user}" : "A tábla átadása {user} számára sikertelen",
    "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "Biztos, hogy törli a(z) {title} táblát? Ez törölni fogja a tábla összes adatát.",
    "This week" : "Ez a hét",
    "Are you sure you want to transfer the board {title} for {user}?" : "Biztos, hogy átadja a(z) {board} tábla tulajdonjogát {user} számára?"
},
"nplurals=2; plural=(n != 1);");
