OC.L10N.register(
    "deck",
    {
    "Personal" : "ផ្ទាល់​ខ្លួន",
    "copy" : "ចម្លង",
    "Done" : "Done",
    "Cancel" : "បោះបង់",
    "Close" : "បិទ",
    "Details" : "ព័ត៌មាន​លម្អិត",
    "Sharing" : "ការ​ចែក​រំលែក",
    "Tags" : "ស្លាក",
    "Can edit" : "Can edit",
    "Can share" : "Can share",
    "Owner" : "Owner",
    "Delete" : "លុប",
    "Edit" : "កែប្រែ",
    "Download" : "ទាញយក",
    "Modified" : "បាន​កែ​ប្រែ",
    "Today" : "ថ្ងៃ​នេះ",
    "Save" : "រក្សាទុក",
    "Reply" : "ឆ្លើយតប",
    "Update" : "ធ្វើ​បច្ចុប្បន្នភាព",
    "Description" : "ការ​អធិប្បាយ",
    "seconds ago" : "វិនាទី​មុន",
    "Shared with you" : "Shared with you",
    "Share" : "ចែក​រំលែក"
},
"nplurals=1; plural=0;");
