OC.L10N.register(
    "deck",
    {
    "You have created a new board {board}" : "{board} panosunu eklediniz",
    "{user} has created a new board {board}" : "{user}, {board} panosunu ekledi",
    "You have deleted the board {board}" : "{board} panosunu sildiniz",
    "{user} has deleted the board {board}" : "{user}, {board} panosunu sildi",
    "You have restored the board {board}" : "{board} panosunu geri yüklediniz",
    "{user} has restored the board {board}" : "{user}, {board} panosunu geri yükledi",
    "You have shared the board {board} with {acl}" : "{board} panosunu {acl} ile paylaştınız",
    "{user} has shared the board {board} with {acl}" : "{user}, {board} panosunu {acl} ile paylaştı",
    "You have removed {acl} from the board {board}" : "{board} panosunun {acl} ile paylaşımını kaldırdınız",
    "{user} has removed {acl} from the board {board}" : "{user}, {board} panosunun {acl} ile paylaşımını kaldırdı",
    "You have renamed the board {before} to {board}" : "{before} panosunun adını {board} olarak değiştirdiniz",
    "{user} has renamed the board {before} to {board}" : "{user}, {before} panosunun adını {board} olarak değiştirdi",
    "You have archived the board {board}" : "{board} panosunu arşive kaldırdınız",
    "{user} has archived the board {before}" : "{user}, {board} panosunu arşive kaldırdı",
    "You have unarchived the board {board}" : "{board} panosunu arşivden çıkardınız",
    "{user} has unarchived the board {before}" : "{user}, {board} panosunu arşivden çıkardı",
    "You have created a new list {stack} on board {board}" : "{board} panosuna yeni {stack} listesini eklediniz",
    "{user} has created a new list {stack} on board {board}" : "{user}, {board} panosuna yeni {stack} listesini ekledi",
    "You have renamed list {before} to {stack} on board {board}" : "{board} panosundaki {before} listesinin adını {stack} olarak değiştirdiniz",
    "{user} has renamed list {before} to {stack} on board {board}" : "{user}, {board} panosundaki {before} listesinin adını {stack} olarak değiştirdi",
    "You have deleted list {stack} on board {board}" : "{board} panosundaki {stack} listesini sildiniz",
    "{user} has deleted list {stack} on board {board}" : "{user}, {board} panosundaki {stack} listesini sildi",
    "You have created card {card} in list {stack} on board {board}" : "{board} panosundaki {stack} listesine {card} kartını eklediniz",
    "{user} has created card {card} in list {stack} on board {board}" : "{user}, {board} panosundaki {stack} listesine {card} kartını ekledi",
    "You have deleted card {card} in list {stack} on board {board}" : "{board} panosunda {stack} listesindeki {card} kartını sildiniz",
    "{user} has deleted card {card} in list {stack} on board {board}" : "{user}, {board} panosunda {stack} listesindeki {card} kartını sildi",
    "You have renamed the card {before} to {card}" : "{before} kartının adını {card} olarak değiştirdiniz",
    "{user} has renamed the card {before} to {card}" : "{user}, {before} kartının adını {card} olarak değiştirdi",
    "You have added a description to card {card} in list {stack} on board {board}" : "{board} panosunda {stack} listesindeki {card} kartına bir açıklama eklediniz",
    "{user} has added a description to card {card} in list {stack} on board {board}" : "{user}, {board} panosunda {stack} listesindeki {card} kartına bir açıklama ekledi",
    "You have updated the description of card {card} in list {stack} on board {board}" : "{board} panosunda {stack} listesindeki {card} kartının açıklamasını güncellediniz",
    "{user} has updated the description of the card {card} in list {stack} on board {board}" : "{user}, {board} panosunda {stack} listesindeki {card} kartının açıklamasını güncelledi",
    "You have archived card {card} in list {stack} on board {board}" : "{board} panosunda {stack} listesindeki {card} kartını arşive kaldırdınız",
    "{user} has archived card {card} in list {stack} on board {board}" : "{user}, {board} panosunda {stack} listesindeki {card} kartını arşive kaldırdı",
    "You have unarchived card {card} in list {stack} on board {board}" : "{board} panosunda {stack} listesindeki {card} kartını arşivden çıkardınız",
    "{user} has unarchived card {card} in list {stack} on board {board}" : "{user}, {board} panosunda {stack} listesindeki {card} kartını arşivden çıkardı",
    "You have removed the due date of card {card}" : "{card} kartının bitiş tarihini kaldırdınız",
    "{user} has removed the due date of card {card}" : "{user}, {card} kartının bitiş tarihini kaldırdı",
    "You have set the due date of card {card} to {after}" : "{card} kartının bitiş tarihini {after} olarak ayarladınız",
    "{user} has set the due date of card {card} to {after}" : "{user}, {card} kartının bitiş tarihini {after} olarak ayarladı",
    "You have updated the due date of card {card} to {after}" : "{card} kartının bitiş tarihini {after} olarak güncellediniz",
    "{user} has updated the due date of card {card} to {after}" : "{user}, {card} kartının bitiş tarihini {after} olarak güncelledi",
    "You have added the tag {label} to card {card} in list {stack} on board {board}" : "{board} panosunda {stack} listesindeki {card} kartına {label} etiketini eklediniz",
    "{user} has added the tag {label} to card {card} in list {stack} on board {board}" : "{user}, {board} panosunda {stack} listesindeki {card} kartına {label} etiketini ekledi",
    "You have removed the tag {label} from card {card} in list {stack} on board {board}" : "{board} panosunda {stack} listesindeki {card} kartından {label} etiketini kaldırdınız",
    "{user} has removed the tag {label} from card {card} in list {stack} on board {board}" : "{user}, {board} panosunda {stack} listesindeki {card} kartından {label} etiketini kaldırdı",
    "You have assigned {assigneduser} to card {card} on board {board}" : "{board} panosundaki {card} kartını {assigneduser} kullanıcısına atadınız",
    "{user} has assigned {assigneduser} to card {card} on board {board}" : "{user}, {board} panosundaki {card} kartını {assigneduser} kullanıcısına atadı",
    "You have unassigned {assigneduser} from card {card} on board {board}" : "{board} panosundaki {card} kartının atamasını {assigneduser} kullanıcısından geri aldınız",
    "{user} has unassigned {assigneduser} from card {card} on board {board}" : "{user}, {board} panosundaki {card} kartının atamasını {assigneduser} kullanıcısından geri aldı",
    "You have moved the card {card} from list {stackBefore} to {stack}" : "{card} kartını {stackBefore} listesinden {stack} listesine taşıdınız",
    "{user} has moved the card {card} from list {stackBefore} to {stack}" : "{user}, {card} kartını {stackBefore} listesinden {stack} listesine taşıdı",
    "You have added the attachment {attachment} to card {card}" : "{card} kartına {attachment} dosyasını eklediniz",
    "{user} has added the attachment {attachment} to card {card}" : "{user}, {card} kartına {attachment} dosyasını ekledi",
    "You have updated the attachment {attachment} on card {card}" : "{card} kartındaki {attachment} dosyasını güncellediniz",
    "{user} has updated the attachment {attachment} on card {card}" : "{user}, {card} kartındaki {attachment} dosyasını güncelledi",
    "You have deleted the attachment {attachment} from card {card}" : "{card} kartındaki {attachment} dosyasını sildiniz",
    "{user} has deleted the attachment {attachment} from card {card}" : "{user}, {card} kartındaki {attachment} dosyasını sildi",
    "You have restored the attachment {attachment} to card {card}" : "{card} kartındaki {attachment} dosyasını geri yüklediniz",
    "{user} has restored the attachment {attachment} to card {card}" : "{user}, {card} kartındaki {attachment} dosyasını geri yükledi",
    "You have commented on card {card}" : "{card} kartı hakkında yorum yaptınız",
    "{user} has commented on card {card}" : "{user}, {card} kartı hakkında yorum yaptı",
    "A <strong>card description</strong> inside the Deck app has been changed" : "Tahta uygulamasında bir <strong>kart açıklaması</strong> değiştirildi",
    "Deck" : "Tahta",
    "Changes in the <strong>Deck app</strong>" : "<strong>Tahta uygulamasındaki</strong> değişiklikler",
    "A <strong>comment</strong> was created on a card" : "Bir kart için bir <strong>yorum</strong> yapıldı",
    "Upcoming cards" : "Yaklaşan kartlar",
    "Load more" : "Diğerlerini yükle",
    "Personal" : "Kişisel",
    "The card \"%s\" on \"%s\" has been assigned to you by %s." : "\"%s\" kartı \"%s\" zamanında %s tarafından size atandı.",
    "{user} has assigned the card {deck-card} on {deck-board} to you." : "{user}, {deck-board} panosundaki {deck-card} kartını size atadı.",
    "The card \"%s\" on \"%s\" has reached its due date." : "\"%s\" kartı \"%s\" zamanında son kullanma tarihine  ulaştı.",
    "The card {deck-card} on {deck-board} has reached its due date." : "{deck-board} panosundaki {deck-card} kartının bitiş tarihi geldi.",
    "%s has mentioned you in a comment on \"%s\"." : "%s kullanıcısı, \"%s\" üzerindeki bir yorumda sizi andı",
    "{user} has mentioned you in a comment on {deck-card}." : "{user}, {deck-card} kartına yaptığı yorumda sizi andı.",
    "The board \"%s\" has been shared with you by %s." : "\"%s\" panosu %s tarafından sizinle paylaşıldı.",
    "{user} has shared {deck-board} with you." : "{user}, {deck-card} kartını sizinle paylaştı.",
    "Card comments" : "Kart yorumları",
    "%s on %s" : "%s, %s hakkında",
    "No data was provided to create an attachment." : "Bir ek dosya oluşturmak için herhangi bir veri belirtilmedi.",
    "Finished" : "Tamamlandı",
    "To review" : "İncelenecek",
    "Action needed" : "İşlem yapılması gerekiyor",
    "Later" : "Sonra",
    "copy" : "kopyala",
    "To do" : "Yapılacak işler",
    "Doing" : "Yapılanlar",
    "Done" : "Bitenler",
    "Example Task 3" : "3. örnek görev",
    "Example Task 2" : "2. örnek görev",
    "Example Task 1" : "1. örnek görev",
    "The file was uploaded" : "Dosya yüklendi",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Yüklenen dosya php.ini dosyasındaki yüklenebilecek dosya boyutunu belirten upload_max_filesize değişkeninin değerini aşıyor",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Yüklenen dosya HTML formundaki yüklenebilecek dosya boyutunu belirten MAX_FILE_SIZE değişkeninin değerini aşıyor",
    "The file was only partially uploaded" : "Dosyanın yalnızca bir bölümü yüklendi",
    "No file was uploaded" : "Herhangi bir dosya yüklenmedi",
    "Missing a temporary folder" : "Geçici bir klasör eksik",
    "Could not write file to disk" : "Dosya diske yazılamadı",
    "A PHP extension stopped the file upload" : "Bir PHP eklentisi dosyanın yüklenmesini engelledi",
    "No file uploaded or file size exceeds maximum of %s" : "Herhangi bir dosya yüklenmedi ya da %s olan en büyük dosya boyutu sınırı aşıldı",
    "This comment has more than %s characters.\nAdded as an attachment to the card with name %s.\nAccessible on URL: %s." : "Bu yorum %s karakterden uzun.\nKarta %s adıyla ek dosya olarak eklendi.\nŞu adresten erişilebilir: %s.",
    "Card not found" : "Kart bulunamadı",
    "Path is already shared with this card" : "Bu yol bu kart ile zaten paylaşılmış",
    "Invalid date, date format must be YYYY-MM-DD" : "Tarih geçersiz. Tarih biçimi YYYY-AA-GG olmalıdır",
    "Personal planning and team project organization" : "Kişisel planlama ve takım projesi yönetimi",
    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in Markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your Markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Tahta, Nextcloud ile bütünleştirilmiş takımlar için Kanban tarzında bir kişisel planlama ve proje yönetimi uygulamasıdır.\n\n\n- 📥 Görevleri kartlara ekleyerek sıralayabilirsiniz\n- 📄 Markdown ile biçimlendirilmiş notlar ekleyebilirsiniz\n- 🔖 Daha iyi düzenleme için etiketler atayabilirsiniz\n- 👥 Takımınız, arkadaşlarınız ya da aileniz ile paylaşabilirsiniz\n- 📎 Dosyalar ekleyebilir ve Markdown açıklamasına gömebilirsiniz\n- 💬 Yorumları kullanarak konular üzerinde takımınız ile yazışabilirsiniz\n- ⚡ İşlem akışı ile değişiklikleri görebilirsiniz\n- 🚀 Projelerinizi düzenli tutarak izleyebilirsiniz",
    "Card details" : "Kart ayrıntıları",
    "Add board" : "Pano ekle",
    "Select the board to link to a project" : "Bir proje ile ilişkilendirilecek pano bağlantısını seçin",
    "Search by board title" : "Pano başlığına göre arama",
    "Select board" : "Pano seçin",
    "Create a new card" : "Yeni kart ekle",
    "Select a board" : "Bir pano seçin",
    "Select a list" : "Bir liste seçin",
    "Card title" : "Kart başlığı",
    "Cancel" : "İptal",
    "Creating the new card …" : "Yeni kart ekleniyor …",
    "Card \"{card}\" was added to \"{board}\"" : "\"{card}\" kartı \"{board}\" panosuna eklendi",
    "Open card" : "Kartı aç",
    "Close" : "Kapat",
    "Create card" : "Kart ekle",
    "Select a card" : "Bir kart seçin",
    "Select the card to link to a project" : "Bir proje ile ilişkilendirilecek kart bağlantısını seçin",
    "Link to card" : "Kart ile ilişkilendir",
    "File already exists" : "Dosya zaten var",
    "A file with the name {filename} already exists." : "{filename} adlı bir dosya zaten var.",
    "Do you want to overwrite it?" : "Üzerine yazmak ister misiniz?",
    "Overwrite file" : "Üzerine yaz",
    "Keep existing file" : "Var olan dosya korunsun",
    "This board is read only" : "Bu pano salt okunur",
    "Drop your files to upload" : "Yüklenecek dosyaları sürükleyip bırakın",
    "Add card" : "Kart ekle",
    "Archived cards" : "Arşivlenmiş kartlar",
    "Add list" : "Liste ekle",
    "List name" : "Liste adı",
    "Active filters" : "Etkin süzgeçler",
    "Apply filter" : "Süzgeci uygula",
    "Filter by tag" : "Etikete göre süz",
    "Filter by assigned user" : "Atanmış kullanıcıya göre süz",
    "Unassigned" : "Atanmamış",
    "Filter by due date" : "Bitiş tarihine göre süz",
    "Overdue" : "Zamanı geçmiş",
    "Next 24 hours" : "Gelecek 24 saat",
    "Next 7 days" : "Gelecek 7 gün",
    "Next 30 days" : "Gelecek 30 gün",
    "No due date" : "Bitiş tarihi yok",
    "Clear filter" : "Süzgeci temizle",
    "Hide archived cards" : "Arşivlenmiş kartları gizle",
    "Show archived cards" : "Arşivlenmiş kartları görüntüle",
    "Toggle compact mode" : "Sıkışık kipi değiştir",
    "Open details" : "Ayrıntıları aç",
    "Details" : "Ayrıntılar",
    "Loading board" : "Pano yükleniyor",
    "No lists available" : "Kullanılabilecek bir liste yok",
    "Create a new list to add cards to this board" : "Bu panoya kartlar eklemek için yeni bir liste ekleyin",
    "Board not found" : "Pano bulunamadı",
    "Sharing" : "Paylaşım",
    "Tags" : "Etiketler",
    "Deleted items" : "Silinmiş ögeler",
    "Timeline" : "Zaman tüneli",
    "Deleted lists" : "Silinmiş listeler",
    "Undo" : "Geri al",
    "Deleted cards" : "Silinmiş kartlar",
    "Share board with a user, group or circle …" : "Panoyu kullanıcılar, gruplar ve çevrelerle paylaş …",
    "Searching for users, groups and circles …" : "Kullanıcılar, gruplar ve çevreler aranıyor …",
    "No participants found" : "Herhangi bir katılımcı bulunamadı",
    "Board owner" : "Pano sahibi",
    "(Group)" : "(Grup)",
    "(Circle)" : "(Çevre)",
    "Can edit" : "Düzenleyebilir",
    "Can share" : "Paylaşabilir",
    "Can manage" : "Yönetebilir",
    "Owner" : "Sahibi",
    "Delete" : "Sil",
    "Failed to create share with {displayName}" : "{displayName} ile paylaşılamadı",
    "Are you sure you want to transfer the board {title} to {user}?" : "{title} panosunu {user} kullanıcısına aktarmak istediğinize emin misiniz?",
    "Transfer the board." : "Panoyu aktar.",
    "Transfer" : "Aktar",
    "The board has been transferred to {user}" : "Pano {user} kullanıcısına aktarıldı",
    "Failed to transfer the board to {user}" : "Pano {user} kullanıcısına aktarılamadı",
    "Add a new list" : "Yeni liste ekle",
    "Archive all cards" : "Tüm kartları arşivle",
    "Unarchive all cards" : "Tüm kartları arşivden çıkar",
    "Delete list" : "Listeyi sil",
    "Archive all cards in this list" : "Bu listedeki tüm kartları arşivle",
    "Unarchive all cards in this list" : "Bu listedeki tüm kartları arşivden çıkar",
    "Add a new card" : "Yeni kart ekle",
    "Card name" : "Kart adı",
    "List deleted" : "Liste silindi",
    "Edit" : "Düzenle",
    "Add a new tag" : "Yeni etiket ekle",
    "title and color value must be provided" : "başlık ve renk değeri belirtilmelidir",
    "Board name" : "Pano adı",
    "Members" : "Üyeler",
    "Upload new files" : "Yeni dosyaları yükle",
    "Share from Files" : "Dosyalardan paylaş",
    "Pending share" : "Bekleyen paylaşım",
    "Add this attachment" : "Bu dosyayı ekle",
    "Show in Files" : "Dosyalarda görüntüle",
    "Download" : "İndir",
    "Remove attachment" : "Ek dosyayı sil",
    "Delete Attachment" : "Ek dosyasını sil",
    "Restore Attachment" : "Ek dosyasını geri yükle",
    "File to share" : "Paylaşılacak dosya",
    "Invalid path selected" : "Seçilen yol geçersiz",
    "Open in sidebar view" : "Yan çubuk görünümünde aç",
    "Open in bigger view" : "Daha büyük görünümde aç",
    "Attachments" : "Ek dosyalar",
    "Comments" : "Yorumlar",
    "Modified" : "Değiştirilme",
    "Created" : "Oluşturulma",
    "The title cannot be empty." : "Başlık boş olamaz.",
    "No comments yet. Begin the discussion!" : "Henüz bir yorum yapılmamış. Tartışmayı başlatın!",
    "Failed to load comments" : "Yorumlar yüklenemedi",
    "Assign a tag to this card…" : "Bu karta bir etiket ata…",
    "Assign to users" : "Kullanıcılara ata",
    "Assign to users/groups/circles" : "Kullanıcılara/gruplara/çevrelere ata",
    "Assign a user to this card…" : "Bu karta bir kullanıcı ata…",
    "Due date" : "Bitiş tarihi",
    "Set a due date" : "Bitiş tarihi ayarla",
    "Remove due date" : "Bitiş tarihini kaldır",
    "Select Date" : "Tarih Seçin",
    "Today" : "Bugün",
    "Tomorrow" : "Yarın",
    "Next week" : "Sonraki hafta",
    "Next month" : "Sonraki ay",
    "Save" : "Kaydet",
    "The comment cannot be empty." : "Yorum boş olamaz.",
    "The comment cannot be longer than 1000 characters." : "Yorum 1000 karakterden uzun olamaz.",
    "In reply to" : "Şuna yanıtla",
    "Cancel reply" : "Yanıtı iptal et",
    "Reply" : "Yanıtla",
    "Update" : "Güncelle",
    "Description" : "Açıklama",
    "(Unsaved)" : "(Kaydedilmemiş)",
    "(Saving…)" : "(Kaydediliyor…)",
    "Formatting help" : "Biçimlendirme yardımı",
    "Edit description" : "Açıklamayı düzenle",
    "View description" : "Açıklamayı görüntüle",
    "Add Attachment" : "Dosya ekle",
    "Write a description …" : "Bir açıklama yazın …",
    "Choose attachment" : "Ek dosyayı seçin",
    "(group)" : "(grup)",
    "Todo items" : "Yapılacak iş ögeleri",
    "{count} comments, {unread} unread" : "{count} yorum, {unread} okunmamış",
    "Edit card title" : "Kart başlığını düzenle",
    "Assign to me" : "Bana ata",
    "Unassign myself" : "Kendi atamamı kaldır",
    "Move card" : "Kartı taşı",
    "Unarchive card" : "Kartı arşivden çıkar",
    "Archive card" : "Kartı arşivle",
    "Delete card" : "Kartı sil",
    "Move card to another board" : "Kartı başka bir panoya taşı",
    "List is empty" : "Liste boş",
    "Card deleted" : "Kart silindi",
    "seconds ago" : "saniye önce",
    "All boards" : "Tüm panolar",
    "Archived boards" : "Arşivlenmiş panolar",
    "Shared with you" : "Sizinle paylaşıldı",
    "Deck settings" : "Tahta ayarları",
    "Use bigger card view" : "Daha büyük kart görünümü kullanılsın",
    "Show card ID badge" : "Kart kodu etiketi görüntülensin",
    "Show boards in calendar/tasks" : "Takvimler ve görevlerde panolar görüntülensin",
    "Limit deck usage of groups" : "Tahtayı şu gruplar kullanabilsin",
    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Tahta kullanımı gruplar ile sınırlandığında belirtilen grupların üyesi olmayan kişiler kendi tahtalarını oluşturamaz. Bu kullanıcılar ancak kendileri ile paylaşılan tahtalar üzerinde çalışabilir.",
    "Board details" : "Pano ayrıntıları",
    "Edit board" : "Panoyu sil",
    "Clone board" : "Panoyu kopyala",
    "Unarchive board" : "Panoyu arşivden çıkar",
    "Archive board" : "Panoyu arşivle",
    "Turn on due date reminders" : "Tarih anımsatıcılarını aç",
    "Turn off due date reminders" : "Tarih anımsatıcılarını kapat",
    "Due date reminders" : "Bitiş tarihi anımsatıcıları",
    "All cards" : "Tüm kartlar",
    "Assigned cards" : "Atanmış kartlar",
    "No notifications" : "Bildirim yok",
    "Delete board" : "Panoyu sil",
    "Board {0} deleted" : "{0} panosu silindi",
    "Only assigned cards" : "Yalnızca atanmış kartlar",
    "No reminder" : "Anımsatıcı yok",
    "An error occurred" : "Bir sorun çıktı",
    "Are you sure you want to delete the board {title}? This will delete all the data of this board including archived cards." : "{title} panosunu silmek istediğinize emin misiniz? Bu işlem, bu panodaki ve arşivlenmiş kartlarındaki tüm verileri silecek.",
    "Delete the board?" : "Pano silinsin mi?",
    "Loading filtered view" : "Süzülmüş görünüm yükleniyor",
    "No due" : "Bitiş yok",
    "Search for {searchQuery} in all boards" : "Tüm panolarda {searchQuery} için sonuçlar",
    "No results found" : "Herhangi bir sonuç bulunamadı",
    "{stack} in {board}" : "{stack} {board} panosunda",
    "Click to expand description" : "Açıklamayı genişletmek için tıklayın",
    "* Created on {created}\n* Last modified on {lastMod}\n* {nbAttachments} attachments\n* {nbComments} comments" : "* Oluşturulma: {created}\n* Son değiştirilme: {lastMod}\n* {nbAttachments} ek dosya\n* {nbComments} yorum",
    "{nbCards} cards" : "{nbCards} kart",
    "No upcoming cards" : "Yaklaşan bir kart yok",
    "upcoming cards" : "yaklaşan kartlar",
    "Due on {date}" : "{date} tarihinde bitecek",
    "Link to a board" : "Bir pano ile ilişkilendir",
    "Link to a card" : "Bir kart ile ilişkilendir",
    "Create a card" : "Bir kart ekle",
    "Message from {author} in {conversationName}" : "{conversationName} görüşmesinde {author} iletisi",
    "Something went wrong" : "Bir şeyler ters gitti",
    "Failed to upload {name}" : "{name} yüklenemedi",
    "Maximum file size of {size} exceeded" : "{size} olan en büyük dosya boyutu sınırı aşıldı",
    "Error creating the share" : "Paylaşım oluşturulurken sorun çıktı",
    "Share with a Deck card" : "Bir tahta kartı ile paylaş",
    "Share {file} with a Deck card" : "{file} dosyasını bir tahta kartı ile paylaş",
    "Share" : "Paylaş",
    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Tahta, Nextcloud ile bütünleştirilmiş takımlar için Kanban tarzında bir kişisel planlama ve proje yönetimi uygulamasıdır.\n\n\n- 📥 Görevleri kartlara ekleyerek sıralayabilirsiniz\n- 📄 Markdown ile biçimlendirilmiş notlar ekleyebilirsiniz\n- 🔖 Daha iyi düzenleme için etiketler atayabilirsiniz\n- 👥 Takımınız, arkadaşlarınız ya da aileniz ile paylaşabilirsiniz\n- 💬 Yorumları kullanarak konular üzerinde takımınız ile yazışabilirsiniz\n- ⚡ İşlem akışı ile değişiklikleri görebilirsiniz\n- 🚀 Projelerinizi düzenli tutarak izleyebilirsiniz",
    "Are you sure you want to transfer the board {title} for {user} ?" : "{title} panosunu {user} kullanıcısına aktarmak istediğinize emin misiniz?",
    "Transfer the board for {user} successfully" : "Pano {user} kullanıcısına aktarıldı",
    "Failed to transfer the board for {user}" : "Pano {user} kullanıcısına aktarılamadı",
    "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "{title} panosunu silmek istediğinize emin misiniz? Bu işlem, bu panodaki tüm verileri silecek.",
    "This week" : "Bu hafta",
    "Are you sure you want to transfer the board {title} for {user}?" : "{title} panosunu {user} kullanıcısına aktarmak istediğinize emin misiniz?"
},
"nplurals=2; plural=(n > 1);");
