OC.L10N.register(
    "deck",
    {
    "Personal" : "شەخسىي",
    "Done" : "Done",
    "No file was uploaded" : "ھېچقانداق ھۆججەت يۈكلەنمىدى",
    "Missing a temporary folder" : "ۋاقىتلىق قىسقۇچ كەم.",
    "Cancel" : "ۋاز كەچ",
    "Close" : "ياپ",
    "Sharing" : "ھەمبەھىر",
    "Tags" : "بەلگەلەر",
    "Can edit" : "Can edit",
    "Can share" : "Can share",
    "Owner" : "Owner",
    "Delete" : "ئۆچۈر",
    "Edit" : "تەھرىر",
    "Download" : "چۈشۈر",
    "Modified" : "ئۆزگەرتكەن",
    "Today" : "بۈگۈن",
    "Save" : "ساقلا",
    "Reply" : "جاۋاب قايتۇر",
    "Update" : "يېڭىلا",
    "Description" : "چۈشەندۈرۈش",
    "Shared with you" : "Shared with you",
    "Share" : "ھەمبەھىر"
},
"nplurals=2; plural=(n != 1);");
