OC.L10N.register(
    "deck",
    {
    "You have created a new board {board}" : "Stworzyłeś nową tablicę {board}",
    "{user} has created a new board {board}" : "{user} utworzył nową tablicę {board}",
    "You have deleted the board {board}" : "Usunąłeś tablicę {board}",
    "{user} has deleted the board {board}" : "{user} usunął tablicę {board}",
    "You have restored the board {board}" : "Przywróciłeś tablicę {board}",
    "{user} has restored the board {board}" : "{user} przywrócił tablicę {board}",
    "You have shared the board {board} with {acl}" : "Udostępniłeś tablicę {board} z {acl}",
    "{user} has shared the board {board} with {acl}" : "{user} udostępnił tablicę {board} z {acl}",
    "You have removed {acl} from the board {board}" : "Usunąłeś {acl} z tablicy {board}",
    "{user} has removed {acl} from the board {board}" : "{user} usunął {acl} z tablicy {board}",
    "You have renamed the board {before} to {board}" : "Zmieniłeś nazwę tablicy {before} na {board}",
    "{user} has renamed the board {before} to {board}" : "{user} zmienił nazwę tablicy {before} na {board} ",
    "You have archived the board {board}" : "Zarchiwizowałeś tablicę {board}",
    "{user} has archived the board {before}" : "{user} zarchiwizował tablicę {before}",
    "You have unarchived the board {board}" : "Przywróciłeś tablicę {board} z archiwum",
    "{user} has unarchived the board {before}" : "{user} cofnął archiwizację tablicy {before}",
    "You have created a new list {stack} on board {board}" : "Utworzyłeś nową listę {stack} na tablicy {board}",
    "{user} has created a new list {stack} on board {board}" : "{user} utworzył nową listę {stack} na tablicy {board}",
    "You have renamed list {before} to {stack} on board {board}" : "Zmieniłeś nazwę listy {before} na {stack} na tablicy {board}",
    "{user} has renamed list {before} to {stack} on board {board}" : "{user} zmienił nazwę listy {before} na {stack} na tablicy {board}",
    "You have deleted list {stack} on board {board}" : "Usunąłeś listę {stack} na tablicy {board}",
    "{user} has deleted list {stack} on board {board}" : "{user} usunął listę {stack} na tablicy {board}",
    "You have created card {card} in list {stack} on board {board}" : "Utworzyłeś kartę {card} w liście {stack} na tablicy {board}",
    "{user} has created card {card} in list {stack} on board {board}" : "{user} utworzył kartę {card} w liście {stack} na tablicy {board}",
    "You have deleted card {card} in list {stack} on board {board}" : "Usunąłeś kartę {card} w liście {stack} na tablicy {board}",
    "{user} has deleted card {card} in list {stack} on board {board}" : "{user} usunął kartę {card} w liście {stack} na tablicy {board}",
    "You have renamed the card {before} to {card}" : "Zmieniłeś nazwę karty {before} na {card}",
    "{user} has renamed the card {before} to {card}" : "{user} zmienił nazwę karty {before} na {card}",
    "You have added a description to card {card} in list {stack} on board {board}" : "Dodałeś opis karty {card} w liście {stack} na tablicy {board}",
    "{user} has added a description to card {card} in list {stack} on board {board}" : "{user} dodał opis karty {card} w liście {stack} na tablicy {board}",
    "You have updated the description of card {card} in list {stack} on board {board}" : "Zaktualizowałeś opis karty {card} w liście {stack} na tablicy {board}",
    "{user} has updated the description of the card {card} in list {stack} on board {board}" : "{user} zaktualizował opis karty {card} w liście {stack} na tablicy {board}",
    "You have archived card {card} in list {stack} on board {board}" : "Zarchiwizowałeś kartę {card} w liście {stack} na tablicy {board}",
    "{user} has archived card {card} in list {stack} on board {board}" : "{user} zarchiwizował kartę {card} w liście {stack} na tablicy {board}",
    "You have unarchived card {card} in list {stack} on board {board}" : "Masz niezarchiwizowaną kartę {card} w liście {stack} na tablicy {board}",
    "{user} has unarchived card {card} in list {stack} on board {board}" : "{user} ma niezarchiwizowaną kartę {card} w liście {stack} na tablicy {board}",
    "You have removed the due date of card {card}" : "Usunąłeś datę ważności karty {card}",
    "{user} has removed the due date of card {card}" : "{user} usunął datę ważności karty {card}",
    "You have set the due date of card {card} to {after}" : "Ustawiłeś datę ważności karty {card} na {after}",
    "{user} has set the due date of card {card} to {after}" : "{user} ustawił datę ważności karty {card} na {after}",
    "You have updated the due date of card {card} to {after}" : "Zaktualizowałeś datę ważności karty {card} na {after}",
    "{user} has updated the due date of card {card} to {after}" : "{user} zaktualizował datę ważności karty {card} na {after}",
    "You have added the tag {label} to card {card} in list {stack} on board {board}" : "Dodałeś etykietę {label} do karty {card} w liście {stack} na tablicy {board}",
    "{user} has added the tag {label} to card {card} in list {stack} on board {board}" : "{user} dodał etykietę {label} do karty {card} w liście {stack} na tablicy {board}",
    "You have removed the tag {label} from card {card} in list {stack} on board {board}" : "Usunąłeś etykietę {label} do karty {card} w liście {stack} na tablicy {board}",
    "{user} has removed the tag {label} from card {card} in list {stack} on board {board}" : "{user} usunął etykietę {label} do karty {card} w liście {stack} na tablicy {board}",
    "You have assigned {assigneduser} to card {card} on board {board}" : "Przydzieliłeś {assigneduser} do karty {card} na tablicy {board}",
    "{user} has assigned {assigneduser} to card {card} on board {board}" : "{user} przydzielił {assigneduser} do karty {card} na tablicy {board}",
    "You have unassigned {assigneduser} from card {card} on board {board}" : "Usunąłeś przydzielenie {assigneduser} do karty {card} na tablicy {board}",
    "{user} has unassigned {assigneduser} from card {card} on board {board}" : "{user} usunął przydzielenie {assigneduser} do karty {card} na tablicy {board}",
    "You have moved the card {card} from list {stackBefore} to {stack}" : "Przeniosłeś kartę {card} z listy {stackBefore} do {stack}",
    "{user} has moved the card {card} from list {stackBefore} to {stack}" : "{user} przeniósł kartę {card} z listy {stackBefore} do {stack}",
    "You have added the attachment {attachment} to card {card}" : "Dodałeś załącznik {attachment} do karty {card}",
    "{user} has added the attachment {attachment} to card {card}" : "{user} dodał załącznik {attachment} do karty {card}",
    "You have updated the attachment {attachment} on card {card}" : "Zaktualizowałeś załącznik {attachment} na karcie {card}",
    "{user} has updated the attachment {attachment} on card {card}" : "{user} zaktualizował załącznik {attachment} na karcie {card}",
    "You have deleted the attachment {attachment} from card {card}" : "Usunąłeś załącznik {attachment} z karty {card}",
    "{user} has deleted the attachment {attachment} from card {card}" : "{user} usunął załącznik {attachment} z karty {card}",
    "You have restored the attachment {attachment} to card {card}" : "Przywróciłeś załącznik {attachment} do karty {card}",
    "{user} has restored the attachment {attachment} to card {card}" : "{user} przywrócił załącznik {attachment} do karty {card}",
    "You have commented on card {card}" : "Skomentowałeś kartę {card}",
    "{user} has commented on card {card}" : "{user} skomentował kartę {card}",
    "A <strong>card description</strong> inside the Deck app has been changed" : "<strong>Opis karty</strong> w aplikacji Tablica został zmieniony",
    "Deck" : "Tablica",
    "Changes in the <strong>Deck app</strong>" : "Zmiany w <strong>aplikacji Tablica</strong>",
    "A <strong>comment</strong> was created on a card" : "Na karcie utworzono <strong>komentarz</strong>",
    "Upcoming cards" : "Nadchodzące karty",
    "Load more" : "Wczytaj więcej",
    "Personal" : "Osobiste",
    "The card \"%s\" on \"%s\" has been assigned to you by %s." : "Karta \"%s\" na \"%s\" została przydzielona Tobie przez %s.",
    "{user} has assigned the card {deck-card} on {deck-board} to you." : "{user} przydzielił Tobie kartę {deck-card} na {deck-board}.",
    "The card \"%s\" on \"%s\" has reached its due date." : "Karta \"%s\" na \"%s\" wygasła.",
    "The card {deck-card} on {deck-board} has reached its due date." : "Karta {deck-card} na {deck-board} uzyskała swój termin.",
    "%s has mentioned you in a comment on \"%s\"." : "%s wspomniał o Tobie w komentarzu do \"%s\".",
    "{user} has mentioned you in a comment on {deck-card}." : "{user} wspomniał o Tobie w komentarzu w {deck-card}.",
    "The board \"%s\" has been shared with you by %s." : "Tablica \"%s\" została Tobie udostępniona przez %s.",
    "{user} has shared {deck-board} with you." : "{user} udostępnił Tobie {deck-board}.",
    "Card comments" : "Komentarze karty",
    "%s on %s" : "%s na %s",
    "No data was provided to create an attachment." : "Nie podano żadnych danych do utworzenia załącznika.",
    "Finished" : "Ukończone",
    "To review" : "Do sprawdzenia",
    "Action needed" : "Wymagana akcja",
    "Later" : "Później",
    "copy" : "kopiuj",
    "To do" : "Do zrobienia",
    "Doing" : "W trakcie",
    "Done" : "Zrobione",
    "Example Task 3" : "Przykład Zadanie 3",
    "Example Task 2" : "Przykład Zadanie 2",
    "Example Task 1" : "Przykład Zadanie 1",
    "The file was uploaded" : "Plik został wysłany",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Wgrany plik przekracza wartość upload_max_filesize zdefiniowaną w php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Wysłany plik przekracza wielkość dyrektywy MAX_FILE_SIZE określonej w formularzu HTML",
    "The file was only partially uploaded" : "Załadowany plik został wysłany tylko częściowo.",
    "No file was uploaded" : "Nie wysłano żadnego pliku",
    "Missing a temporary folder" : "Brak katalogu tymczasowego",
    "Could not write file to disk" : "Nie można zapisać pliku na dysk",
    "A PHP extension stopped the file upload" : "Rozszerzenie PHP zatrzymało wysyłanie pliku",
    "No file uploaded or file size exceeds maximum of %s" : "Brak wysłanego pliku lub rozmiar pliku przekracza maksymalny limit %s",
    "This comment has more than %s characters.\nAdded as an attachment to the card with name %s.\nAccessible on URL: %s." : "Ten komentarz ma więcej niż %s znaków.\nDodany jako załącznik do karty o nazwie %s.\nDostępne pod adresem URL: %s.",
    "Card not found" : "Nie znaleziono karty",
    "Path is already shared with this card" : "Ścieżka jest już udostępniona dla tej karty",
    "Invalid date, date format must be YYYY-MM-DD" : "Nieprawidłowa data, format daty to RRRR-MM-DD",
    "Personal planning and team project organization" : "Indywidualne planowanie i organizacja projektu zespołowego",
    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in Markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your Markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Tablica to narzędzie organizacyjne w stylu kanban, którego celem jest osobiste planowanie i organizacja projektu dla zespołów zintegrowanych z Nextcloud.\n\n\n- 📥 Dodaj swoje zadania do kart i porządkuj je\n- 📄 Zapisuj dodatkowe notatki w Markdown\n- 🔖 Przypisuj etykiety dla jeszcze lepszej organizacji\n- 👥 Współdziel ze swoim zespołem, przyjaciółmi lub rodziną\n- 📎 Dołączaj pliki i umieszczaj je w opisie Markdown\n- 💬 Porozmawiaj ze swoim zespołem za pomocą komentarzy\n- ⚡ Śledź zmiany w strumieniu aktywności\n- 🚀 Organizuj swój projekt",
    "Card details" : "Szczegóły karty",
    "Add board" : "Dodaj tablicę",
    "Select the board to link to a project" : "Wybierz tablicę, aby połączyć się z projektem",
    "Search by board title" : "Szukaj według tytułu tablicy",
    "Select board" : "Wybierz tablicę",
    "Create a new card" : "Utwórz nową kartę",
    "Select a board" : "Wybierz tablicę",
    "Select a list" : "Wybierz listę",
    "Card title" : "Tytuł karty",
    "Cancel" : "Anuluj",
    "Creating the new card …" : "Tworzenie nowej karty…",
    "Card \"{card}\" was added to \"{board}\"" : "Karta \"{card}\" została dodana do \"{board}\"",
    "Open card" : "Otwórz kartę",
    "Close" : "Zamknij",
    "Create card" : "Utwórz kartę",
    "Select a card" : "Wybierz kartę",
    "Select the card to link to a project" : "Wybierz kartę, aby połączyć z projektem",
    "Link to card" : "Link do karty",
    "File already exists" : "Plik już istnieje",
    "A file with the name {filename} already exists." : "Plik o nazwie {filename} już istnieje.",
    "Do you want to overwrite it?" : "Czy chcesz go nadpisać?",
    "Overwrite file" : "Nadpisać plik",
    "Keep existing file" : "Zachowaj istniejący plik",
    "This board is read only" : "Ta tablica jest tylko do odczytu",
    "Drop your files to upload" : "Upuść swoje pliki do wysłania",
    "Add card" : "Dodaj kartę",
    "Archived cards" : "Zarchiwizowane karty",
    "Add list" : "Dodaj listę",
    "List name" : "Nazwa listy",
    "Active filters" : "Aktywne filtry",
    "Apply filter" : "Zastosuj filtr",
    "Filter by tag" : "Filtruj według etykiety",
    "Filter by assigned user" : "Filtruj według przydzielonego użytkownika",
    "Unassigned" : "Nieprzydzielone",
    "Filter by due date" : "Filtruj według terminu",
    "Overdue" : "Zaległe",
    "Next 24 hours" : "Następne 24 godziny",
    "Next 7 days" : "Następne 7 dni",
    "Next 30 days" : "Następne 30 dni",
    "No due date" : "Brak daty ważności",
    "Clear filter" : "Wyczyść filtr",
    "Hide archived cards" : "Ukryj zarchiwizowane karty",
    "Show archived cards" : "Pokaż zarchiwizowane karty",
    "Toggle compact mode" : "Przełącz w tryb kompaktowy",
    "Open details" : "Otwórz szczegóły",
    "Details" : "Szczegóły",
    "Loading board" : "Wczytywanie tablicy",
    "No lists available" : "Brak dostępnych list",
    "Create a new list to add cards to this board" : "Utwórz nową listę, aby dodać karty do tej tablicy",
    "Board not found" : "Nie znaleziono tablicy",
    "Sharing" : "Udostępnianie",
    "Tags" : "Etykiety",
    "Deleted items" : "Usunięte pozycje",
    "Timeline" : "Oś czasu",
    "Deleted lists" : "Usunięte listy",
    "Undo" : "Cofnij",
    "Deleted cards" : "Usunięte karty",
    "Share board with a user, group or circle …" : "Udostępnij tablicę użytkownikowi, grupie lub kręgowi…",
    "Searching for users, groups and circles …" : "Szukam użytkowników, grup i kręgów…",
    "No participants found" : "Nie znaleziono uczestników",
    "Board owner" : "Właściciel tablicy",
    "(Group)" : "(Grupa)",
    "(Circle)" : "(Krąg)",
    "Can edit" : "Może edytować",
    "Can share" : "Może udostępnić",
    "Can manage" : "Może zarządzać",
    "Owner" : "Właściciel",
    "Delete" : "Usuń",
    "Failed to create share with {displayName}" : "Nie udało się utworzyć udostępnienia dla {displayName}",
    "Are you sure you want to transfer the board {title} to {user}?" : "Czy na pewno chcesz przenieść tablicę {title} do {user}?",
    "Transfer the board." : "Przeniesienie tablicy.",
    "Transfer" : "Przenieś",
    "The board has been transferred to {user}" : "Tablica została przeniesiona do {user}",
    "Failed to transfer the board to {user}" : "Nie udało się przenieść tablicy do {user}",
    "Add a new list" : "Dodaj nową listę",
    "Archive all cards" : "Zarchiwizuj wszystkie karty",
    "Unarchive all cards" : "Przywróć wszystkie karty z archiwum",
    "Delete list" : "Usuń listę",
    "Archive all cards in this list" : "Zarchiwizuj wszystkie karty na tej liście",
    "Unarchive all cards in this list" : "Cofnij archiwizację wszystkich kart z tej listy",
    "Add a new card" : "Dodaj nową kartę",
    "Card name" : "Nazwa karty",
    "List deleted" : "Lista usunięta",
    "Edit" : "Edycja",
    "Add a new tag" : "Dodaj nową etykietę",
    "title and color value must be provided" : "należy podać tytuł i kolor",
    "Board name" : "Nazwa tablicy",
    "Members" : "Członkowie",
    "Upload new files" : "Wyślij nowe pliki",
    "Share from Files" : "Udostępnij z Plików",
    "Pending share" : "Oczekujące udostępnienie",
    "Add this attachment" : "Dodaj ten załącznik",
    "Show in Files" : "Pokaż w Plikach",
    "Download" : "Pobierz",
    "Remove attachment" : "Usuń załącznik",
    "Delete Attachment" : "Usuń załącznik",
    "Restore Attachment" : "Przywróć załącznik",
    "File to share" : "Plik do udostępnienia",
    "Invalid path selected" : "Wybrano nieprawidłową ścieżkę",
    "Open in sidebar view" : "Otwórz w widoku paska bocznego",
    "Open in bigger view" : "Otwórz w dużym widoku",
    "Attachments" : "Załączniki",
    "Comments" : "Komentarze",
    "Modified" : "Zmodyfikowany",
    "Created" : "Utworzono",
    "The title cannot be empty." : "Tytuł nie może być pusty.",
    "No comments yet. Begin the discussion!" : "Brak komentarzy. Rozpocznij dyskusję!",
    "Failed to load comments" : "Nie udało się wczytać komentarzy",
    "Assign a tag to this card…" : "Przypisz etykietę do tej karty…",
    "Assign to users" : "Przypisz do użytkowników",
    "Assign to users/groups/circles" : "Przypisz do użytkowników/grup/kręgów",
    "Assign a user to this card…" : "Przypisz użytkownika do tej karty…",
    "Due date" : "Data realizacji",
    "Set a due date" : "Ustaw termin",
    "Remove due date" : "Usuń datę realizacji",
    "Select Date" : "Wybierz datę",
    "Today" : "Dzisiaj",
    "Tomorrow" : "Jutro",
    "Next week" : "Następny tydzień",
    "Next month" : "Następny miesiąc",
    "Save" : "Zapisz",
    "The comment cannot be empty." : "Komentarz nie może być pusty.",
    "The comment cannot be longer than 1000 characters." : "Komentarz nie może być dłuższy niż 1000 znaków.",
    "In reply to" : "Odpowiedź na",
    "Cancel reply" : "Anuluj odpowiedź",
    "Reply" : "Odpowiedz",
    "Update" : "Aktualizuj",
    "Description" : "Opis",
    "(Unsaved)" : "(Niezapisane)",
    "(Saving…)" : "(Zapisywanie…)",
    "Formatting help" : "Pomoc przy formatowaniu",
    "Edit description" : "Edytuj opis",
    "View description" : "Zobacz opis",
    "Add Attachment" : "Dodaj załącznik",
    "Write a description …" : "Napisz opis…",
    "Choose attachment" : "Wybierz załącznik",
    "(group)" : "(grupa)",
    "Todo items" : "Do zrobienia",
    "{count} comments, {unread} unread" : "Komentarze: {count}, nieprzeczytane: {unread}",
    "Edit card title" : "Edytuj nazwę karty",
    "Assign to me" : "Przydziel do mnie",
    "Unassign myself" : "Cofnij moje przypisanie",
    "Move card" : "Przenieś kartę",
    "Unarchive card" : "Nie archiwizuj karty",
    "Archive card" : "Zarchiwizuj kartę",
    "Delete card" : "Usuń kartę",
    "Move card to another board" : "Przenieś kartę na inną tablicę",
    "List is empty" : "Lista jest pusta",
    "Card deleted" : "Karta usunięta",
    "seconds ago" : "przed chwilą",
    "All boards" : "Wszystkie tablice",
    "Archived boards" : "Zarchiwizowane tablice",
    "Shared with you" : "Udostępnione Tobie",
    "Deck settings" : "Ustawienia Tablicy",
    "Use bigger card view" : "Użyj większego widoku karty",
    "Show card ID badge" : "Pokaż ID karty",
    "Show boards in calendar/tasks" : "Pokaż tablice w kalendarzu/zadaniach",
    "Limit deck usage of groups" : "Ogranicz użycie tablic dla grup",
    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Ograniczenie Tablicy zablokuje użytkownikom z tych grup możliwość tworzenia własnych tablic. Użytkownicy nadal będą mogli pracować na tablicach, które zostały im udostępnione.",
    "Board details" : "Szczegóły tablicy",
    "Edit board" : "Edytuj tablicę",
    "Clone board" : "Klonuj tablicę",
    "Unarchive board" : "Przywróć tablicę",
    "Archive board" : "Zarchiwizuj tablicę",
    "Turn on due date reminders" : "Włącz przypomnienia o terminach",
    "Turn off due date reminders" : "Wyłącz przypomnienia o terminach",
    "Due date reminders" : "Przypomnienia o terminach",
    "All cards" : "Wszystkie karty",
    "Assigned cards" : "Przydzielone karty",
    "No notifications" : "Brak powiadomień",
    "Delete board" : "Usuń tablicę",
    "Board {0} deleted" : "Tablica {0} została usunięta",
    "Only assigned cards" : "Tylko przydzielone karty",
    "No reminder" : "Bez przypomnienia",
    "An error occurred" : "Wystąpił błąd",
    "Are you sure you want to delete the board {title}? This will delete all the data of this board including archived cards." : "Czy na pewno chcesz usunąć tablicę {title}? Spowoduje to usunięcie wszystkich danych z tej tablicy łącznie z zarchiwizowanymi kartami.",
    "Delete the board?" : "Usunąć tablicę?",
    "Loading filtered view" : "Wczytywanie przefiltrowanego widoku",
    "No due" : "Bez ważności",
    "Search for {searchQuery} in all boards" : "Wyszukaj dla {searchQuery} na wszystkich tablicach",
    "No results found" : "Nie znaleziono wyników",
    "{stack} in {board}" : "{stack} na {board}",
    "Click to expand description" : "Kliknij, aby rozwinąć opis",
    "* Created on {created}\n* Last modified on {lastMod}\n* {nbAttachments} attachments\n* {nbComments} comments" : "* Utworzono {created}\n* Ostatnia modyfikacja {lastMod}\n* Załączniki {nbAttachments}\n* Komentarze {nbComments}",
    "{nbCards} cards" : "Karty {nbCards}",
    "No upcoming cards" : "Brak nadchodzących kart",
    "upcoming cards" : "nadchodzące karty",
    "Due on {date}" : "Termin {date}",
    "Link to a board" : "Link do tablicy",
    "Link to a card" : "Link do karty",
    "Create a card" : "Utwórz kartę",
    "Message from {author} in {conversationName}" : "Wiadomość od {author} w {conversationName}",
    "Something went wrong" : "Coś poszło nie tak",
    "Failed to upload {name}" : "Nie udało się wysłać {name}",
    "Maximum file size of {size} exceeded" : "Przekroczono maksymalny rozmiar pliku {size}",
    "Error creating the share" : "Błąd podczas tworzenia udostępnienia",
    "Share with a Deck card" : "Udostępnij za pomocą karty Tablicy",
    "Share {file} with a Deck card" : "Udostępnij {file} za pomocą karty Tablicy",
    "Share" : "Udostępnianie",
    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Tablica to narzędzie organizacyjne w stylu kanban, którego celem jest osobiste planowanie i organizacja projektu dla zespołów zintegrowanych z Nextcloud.\n\n\n- 📥 Dodaj swoje zadania do kart i porządkuj je\n- 📄 Zapisuj dodatkowe notatki w Markdown\n- 🔖 Przypisuj etykiety dla jeszcze lepszej organizacji\n- 👥 Współdziel ze swoim zespołem, przyjaciółmi lub rodziną\n- 📎 Dołączaj pliki i umieszczaj je w opisie Markdown\n- 💬 Porozmawiaj ze swoim zespołem za pomocą komentarzy\n- ⚡ Śledź zmiany w strumieniu aktywności\n- 🚀 Organizuj swój projekt",
    "Are you sure you want to transfer the board {title} for {user} ?" : "Czy na pewno chcesz przenieść tablicę {title} dla {user}?",
    "Transfer the board for {user} successfully" : "Przeniesienie tablicy dla {user} pomyślne",
    "Failed to transfer the board for {user}" : "Nie udało się przenieść tablicy dla {user}",
    "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "Czy na pewno chcesz usunąć tablicę {title}? Spowoduje to usunięcie wszystkich danych z tej tablicy.",
    "This week" : "W tym tygodniu",
    "Are you sure you want to transfer the board {title} for {user}?" : "Czy na pewno chcesz przenieść tablicę {title} dla {user}?"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
