OC.L10N.register(
    "deck",
    {
    "Personal" : "Personal",
    "copy" : "copy",
    "Done" : "Done",
    "Cancel" : "Cancel",
    "Close" : "Close",
    "Details" : "Details",
    "Sharing" : "Ulashish",
    "Tags" : "Tags",
    "Can edit" : "Can edit",
    "Owner" : "Owner",
    "Delete" : "Delete",
    "Download" : "Download",
    "Comments" : "Comments",
    "Modified" : "Modified",
    "Today" : "Today",
    "Save" : "Save",
    "Update" : "Update",
    "seconds ago" : "seconds ago",
    "Shared with you" : "Shared with you",
    "This week" : "This week"
},
"nplurals=1; plural=0;");
