OC.L10N.register(
    "deck",
    {
    "You have created a new board {board}" : "Je creëerde een nieuw bord {board}",
    "{user} has created a new board {board}" : "{user} creëerde een nieuw bord {board}",
    "You have deleted the board {board}" : "Je verwijderde bord {board}",
    "{user} has deleted the board {board}" : "{user} verwijderde bord {board}",
    "You have restored the board {board}" : "Je herstelde bord {board}",
    "{user} has restored the board {board}" : "{user} herstelde bord {board}",
    "You have shared the board {board} with {acl}" : "Je deelde bord {board} met {acl}",
    "{user} has shared the board {board} with {acl}" : "{user} heeft een board {board} gedeeld met {acl}",
    "You have removed {acl} from the board {board}" : "Je verwijderde {acl} van bord {board}",
    "{user} has removed {acl} from the board {board}" : "{user} verwijderde {acl} van bord {board}",
    "You have renamed the board {before} to {board}" : "Je hernoemde bord {before} naar {board}",
    "{user} has renamed the board {before} to {board}" : "{user} hernoemde bord {before} naar {board}",
    "You have archived the board {board}" : "Je hebt bord {board} gearchiveerd",
    "{user} has archived the board {before}" : "{user} archiveerde bord {before}",
    "You have unarchived the board {board}" : "Je hebt bord {board} uit het archief opgehaald",
    "{user} has unarchived the board {before}" : "{user} heeft bord {before} uit het archief opgehaald",
    "You have created a new list {stack} on board {board}" : "Je hebt een nieuwe lijst {stack} op bord {board} gemaakt",
    "{user} has created a new list {stack} on board {board}" : "{user} heeft een nieuwe lijst {stack} op bord {board} gemaakt",
    "You have renamed list {before} to {stack} on board {board}" : "Je hebt de naam van lijst {before} gewijzigd in {stack} op bord van {board}",
    "{user} has renamed list {before} to {stack} on board {board}" : "{user} heeft de naam van lijst {before} gewijzigd in {stack} op bord van {board}",
    "You have deleted list {stack} on board {board}" : "Je hebt de lijst {stack} op bord {board} verwijderd",
    "{user} has deleted list {stack} on board {board}" : "{user} heeft lijst {stack} aan boord {board} verwijderd",
    "You have created card {card} in list {stack} on board {board}" : "Je hebt de kaart {card} gemaakt in lijst {stack} op bord {board}",
    "{user} has created card {card} in list {stack} on board {board}" : "{user} heeft kaart {card} gemaakt in lijst {stack} op bord {board}",
    "You have deleted card {card} in list {stack} on board {board}" : "Je hebt de kaart {card} verwijderd uit lijst {stack} op bord van {board}",
    "{user} has deleted card {card} in list {stack} on board {board}" : "{user} heeft kaart {card} verwijderd uit lijst {stack} op bord van {board}",
    "You have renamed the card {before} to {card}" : "Je hernoemde kaart {before} naar {card}",
    "{user} has renamed the card {before} to {card}" : "{user} hernoemde kaart {before} naar {card}",
    "You have added a description to card {card} in list {stack} on board {board}" : "Je hebt een beschrijving toegevoegd aan kaart {card} in lijst {stack} op bord {board}",
    "{user} has added a description to card {card} in list {stack} on board {board}" : "{user} heeft een beschrijving toegevoegd aan kaart {card} in lijst {stack} op bord {board}",
    "You have updated the description of card {card} in list {stack} on board {board}" : "Je hebt de beschrijving van kaart {card} in lijst {stack} op bord {board} bijgewerkt",
    "{user} has updated the description of the card {card} in list {stack} on board {board}" : "{user} heeft de beschrijving van de kaart {card} in lijst {stack} op bord {board} bijgewerkt",
    "You have archived card {card} in list {stack} on board {board}" : "Je hebt de kaart {card} gearchiveerd in lijst {stack} op bord {board}",
    "{user} has archived card {card} in list {stack} on board {board}" : "{user} heeft kaart {card} gearchiveerd in lijst {stack} op bord {board}",
    "You have unarchived card {card} in list {stack} on board {board}" : "Je hebt de kaart {card} in lijst {stack} op bord {board} uit het archief gehaald",
    "{user} has unarchived card {card} in list {stack} on board {board}" : "{user} heeft kaart {card} uit het archief verwijderd in lijst {stack} op bord {board}",
    "You have removed the due date of card {card}" : "Je verwijderde de vervaldatum van kaart {card}",
    "{user} has removed the due date of card {card}" : "{user} verwijderde de vervaldatum van kaart {card}",
    "You have set the due date of card {card} to {after}" : "Je stelde de vervaldatum van kaart {card} in op {after}",
    "{user} has set the due date of card {card} to {after}" : "{user} stelde de vervaldatum van kaart {card} in op {after}",
    "You have updated the due date of card {card} to {after}" : "Je werkte de vervaldatum van kaart {card} bij tot {after}",
    "{user} has updated the due date of card {card} to {after}" : "{user} werkte de vervaldatum van kaart {card} bij tot {after}",
    "You have added the tag {label} to card {card} in list {stack} on board {board}" : "Je hebt de tag {label} toegevoegd aan kaart {card} in lijst {stack} op bord {board}",
    "{user} has added the tag {label} to card {card} in list {stack} on board {board}" : "{user} heeft de tag {label} toegevoegd aan kaart {card} in lijst {stack} op bord {board}",
    "You have removed the tag {label} from card {card} in list {stack} on board {board}" : "Je hebt de tag {label} verwijderd van kaart {card} in lijst {stack} op bord {board}",
    "{user} has removed the tag {label} from card {card} in list {stack} on board {board}" : "{user} heeft de tag {label} verwijderd van kaart {card} in lijst {stack} op bord {board}",
    "You have assigned {assigneduser} to card {card} on board {board}" : "Je wees {assigneduser} toe aan kaart {card} op bord {board}",
    "{user} has assigned {assigneduser} to card {card} on board {board}" : "{user} wees {assigneduser} toe aan kaart {card} op bord {board}",
    "You have unassigned {assigneduser} from card {card} on board {board}" : "Je verwijderd {assigneduser} van kaart {card} op bord {board}",
    "{user} has unassigned {assigneduser} from card {card} on board {board}" : "{user} verwijderd {assigneduser} van kaart {card} op bord {board}",
    "You have moved the card {card} from list {stackBefore} to {stack}" : "Je hebt de kaart {card} verplaatst van lijst {stackBefore} naar {stack}",
    "{user} has moved the card {card} from list {stackBefore} to {stack}" : "{user} heeft de kaart {card} verplaatst van lijst {stackBefore} naar {stack}",
    "You have added the attachment {attachment} to card {card}" : "Je voegde bijlage {attachment} toe aan kaart {card}",
    "{user} has added the attachment {attachment} to card {card}" : "{user} voegde bijlage {attachment} toe aan kaart {card}",
    "You have updated the attachment {attachment} on card {card}" : "Je werkte bijlage {attachment} bij op kaart {card}",
    "{user} has updated the attachment {attachment} on card {card}" : "{user} werkte bijlage {attachment} bij op kaart {card}",
    "You have deleted the attachment {attachment} from card {card}" : "Je verwijderde bijlage {attachment} van kaart {card}",
    "{user} has deleted the attachment {attachment} from card {card}" : "{user} verwijderde bijlage {attachment} van kaart {card}",
    "You have restored the attachment {attachment} to card {card}" : "Je herstelde bijlage {attachment} bij kaart {card}",
    "{user} has restored the attachment {attachment} to card {card}" : "{user} herstelde bijlage {attachment} bij kaart {card}",
    "You have commented on card {card}" : "Je hebt gereageerd op kaart {card}",
    "{user} has commented on card {card}" : "{user} reageerde op kaart {card}",
    "A <strong>card description</strong> inside the Deck app has been changed" : "Een <strong>kaart beschrijving</strong> binnen de Deck app is gewijzigd",
    "Deck" : "Deck",
    "Changes in the <strong>Deck app</strong>" : "Wijzigingen in de <strong>Deck app</strong>",
    "A <strong>comment</strong> was created on a card" : "Er is <strong>commentaar </strong> gegeven op een card",
    "Upcoming cards" : "Aanstaande kaarten",
    "Load more" : "Laad meer",
    "Personal" : "Persoonlijk",
    "The card \"%s\" on \"%s\" has been assigned to you by %s." : "De kaart \"%s\" op \"%s\" is aan jou toegewezen door %s.",
    "{user} has assigned the card {deck-card} on {deck-board} to you." : "{user} heeft kaart {deck-card} op {deck-board} aan jou toegewezen.",
    "The card \"%s\" on \"%s\" has reached its due date." : "De kaart \"%s\" in \"%s\" heeft zijn vervaldatum bereikt.",
    "The card {deck-card} on {deck-board} has reached its due date." : "De kaart {deck-card} in {deck-board} heeft de vervaldatum bereikt.",
    "%s has mentioned you in a comment on \"%s\"." : "%s vermeldde je in een reactie op \"%s\".",
    "{user} has mentioned you in a comment on {deck-card}." : "{user} vermeldde je in een reactie op {deck-card}.",
    "The board \"%s\" has been shared with you by %s." : "Het bord \"%s\" is door %s met je gedeeld.",
    "{user} has shared {deck-board} with you." : "{user} heeft het bord {deck-board} met je gedeeld.",
    "Card comments" : "Kaart opmerkingen",
    "%s on %s" : "%s op %s",
    "No data was provided to create an attachment." : "Geen gegevens opgegeven voor het maken van een bijlage.",
    "Finished" : "Afgerond",
    "To review" : "Beoordelen",
    "Action needed" : "Actie benodigd",
    "Later" : "Later",
    "copy" : "kopiëren",
    "To do" : "Te doen",
    "Doing" : "Bezig",
    "Done" : "Klaar",
    "Example Task 3" : "Voorbeeld Taak 3",
    "Example Task 2" : "Voorbeeld Taak 2",
    "Example Task 1" : "Voorbeeld Taak 1",
    "The file was uploaded" : "Het bestand werd geüpload",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Het geüploade bestand overschrijdt de upload_max_filesize richtlijn in php.ini:",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Het bestand overschrijdt de MAX_FILE_SIZE instelling die is opgegeven in het HTML formulier",
    "The file was only partially uploaded" : "Het bestand is slechts gedeeltelijk geüpload",
    "No file was uploaded" : "Er is geen bestand geüpload",
    "Missing a temporary folder" : "Mist een tijdelijke map",
    "Could not write file to disk" : "Kon bestand niet naar schijf schrijven",
    "A PHP extension stopped the file upload" : "Een PHP-extensie blokkeerde de upload.",
    "No file uploaded or file size exceeds maximum of %s" : "Geen bestand geüpload of de grootte is meer dan het maximum van %s",
    "This comment has more than %s characters.\nAdded as an attachment to the card with name %s.\nAccessible on URL: %s." : "Deze opmerking heeft meer dan %s tekens.\nAls bijlage toegevoegd aan de kaart met naam %s.\nToegankelijk op URL: %s.",
    "Card not found" : "Kaart niet gevonden",
    "Path is already shared with this card" : "Pad is al gedeeld met deze kaart",
    "Invalid date, date format must be YYYY-MM-DD" : "Ongeldige datum, formaat is YYYY-MM-DD",
    "Personal planning and team project organization" : "Persoonlijke planning en inrichting voor teamproject",
    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in Markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your Markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Deck is een soort kanban organisatietool gericht op persoonlijke planning en projectorganisatie voor teams geïntegreerd in Nextcloud.\n\n\n- 📥 Voeg taken toe aan kaarten en sorteer ze\n- 📄 Schrijf extra notities in Markdown\n- 🔖 Ken labels toe voor betere organisatie\n- 👥 Deel met je team, vrienden of familie\n- 📎 Voeg bestanden toe en plaats ze in je Markdown beschrijving\n- 💬 Discussieer binnen je team met reacties\n- ⚡ Volg de wijzigingen in het activiteiten kanaal\n- 🚀 Organiseer je project",
    "Card details" : "Kaart details",
    "Add board" : "Toevoegen bord",
    "Select the board to link to a project" : "Kies het bord om met een project te verbinden",
    "Search by board title" : "Zoeken op bord-titel",
    "Select board" : "Selecteer bord",
    "Create a new card" : "Maak een nieuwe kaart aan",
    "Select a board" : "Selecteer een bord",
    "Select a list" : "Selecteer een lijst",
    "Card title" : "Kaarttitel",
    "Cancel" : "Annuleren",
    "Creating the new card …" : "Aanmaken nieuwe kaart...",
    "Card \"{card}\" was added to \"{board}\"" : "Kaart \"{card}\" is toegevoegd aan \"{board}\"",
    "Open card" : "Open kaard",
    "Close" : "Sluiten",
    "Create card" : "Aanmaken kaart",
    "Select a card" : "Selecteer een kaart",
    "Select the card to link to a project" : "Selecteer de kaart om met een project te koppelen",
    "Link to card" : "Koppelen met kaart",
    "File already exists" : "Bestand bestaat al",
    "A file with the name {filename} already exists." : "Er bestaat al een gebruiker met de naam {filename}.",
    "Do you want to overwrite it?" : "Wil je het overschrijven?",
    "Overwrite file" : "Overschrijven bestand",
    "Keep existing file" : "Bewaar het al bestaande bestand",
    "This board is read only" : "Dit bord is alleen-lezen",
    "Drop your files to upload" : "Zet je bestanden hier neer om te uploaden",
    "Add card" : "Toevoegen kaart",
    "Archived cards" : "Gearchiveerde kaarten",
    "Add list" : "Lijst toevoegen",
    "List name" : "Lijstnaam",
    "Apply filter" : "Filter toepassen",
    "Filter by tag" : "Filteren op label",
    "Filter by assigned user" : "Filter op toegewezen gebruiker",
    "Unassigned" : "Niet-toegewezen",
    "Filter by due date" : "Filter op vervaldatum",
    "Overdue" : "Vervallen",
    "Next 24 hours" : "Volgende 24 uur",
    "Next 7 days" : "Komende 7 dagen",
    "Next 30 days" : "Komende 30 dagen",
    "No due date" : "Geen vervaldatum",
    "Clear filter" : "Filter leegmaken",
    "Hide archived cards" : "Gearchiveerde kaarten verbergen",
    "Show archived cards" : "Gearchiveerde kaarten weergeven",
    "Toggle compact mode" : "Omschakelen compacte modus",
    "Open details" : "Details openen",
    "Details" : "Details",
    "Loading board" : "Bord laden",
    "No lists available" : "Geen lijsten beschikbaar",
    "Create a new list to add cards to this board" : "Maak een nieuwe lijst om kaarten aan dit bord toe te voegen",
    "Board not found" : "Bord niet gevonden",
    "Sharing" : "Delen",
    "Tags" : "Labels",
    "Deleted items" : "Verwijderde objecten",
    "Timeline" : "Tijdlijn",
    "Deleted lists" : "Verwijderde lijsten",
    "Undo" : "Ongedaan maken",
    "Deleted cards" : "Verwijderde kaarten",
    "Share board with a user, group or circle …" : "Deel bord met een gebruiker, groep of kring ...",
    "Searching for users, groups and circles …" : "Bezig met zoeken naar gebruikers, groepen en kringen ...",
    "No participants found" : "Geen deelnemers gevonden",
    "Board owner" : "Bordeigenaar",
    "(Group)" : "(groep)",
    "(Circle)" : "(Kring)",
    "Can edit" : "Kan bewerken",
    "Can share" : "Kan delen",
    "Can manage" : "Kan beheren",
    "Owner" : "Eigenaar",
    "Delete" : "Verwijderen",
    "Failed to create share with {displayName}" : "Delen met {displayName} mislukt",
    "Transfer" : "Overdracht",
    "Add a new list" : "Voeg een nieuwe lijst toe",
    "Archive all cards" : "Alle kaarten archiveren",
    "Delete list" : "Lijst verwijderen",
    "Archive all cards in this list" : "Alle kaarten in deze lijst archiveren",
    "Add a new card" : "Nieuwe kaart toevoegen",
    "Card name" : "Kaartnaam",
    "List deleted" : "Lijst verwijderd",
    "Edit" : "Bewerken",
    "Add a new tag" : "Nieuwe tag toevoegen",
    "title and color value must be provided" : "titel- en kleurwaarde moet gegeven worden",
    "Board name" : "Bordnaam",
    "Members" : "Leden",
    "Upload new files" : "Uploaden nieuwe bestanden",
    "Share from Files" : "Delen vanuit Bestanden",
    "Pending share" : "Share in afwachting",
    "Add this attachment" : "Voeg deze bijlage toe",
    "Show in Files" : "Tonen in Bestanden",
    "Download" : "Download",
    "Remove attachment" : "Bijlage verwijderen",
    "Delete Attachment" : "Verwijderen bijlage",
    "Restore Attachment" : "Herstellen bijlage",
    "File to share" : "Bestand om te delen",
    "Invalid path selected" : "Ongeldig pad geselecteerd",
    "Open in sidebar view" : "Open in zijbalk",
    "Open in bigger view" : "Open in grotere weergave",
    "Attachments" : "Bijlagen",
    "Comments" : "Reacties",
    "Modified" : "Aangepast",
    "Created" : "Gemaakt",
    "The title cannot be empty." : "De titel kan niet leeg zijn.",
    "No comments yet. Begin the discussion!" : "Nog geen reacties. Begin de discussie!",
    "Failed to load comments" : "Kon reacties niet laden.",
    "Assign a tag to this card…" : "Wijs een label toe aan deze kaart...",
    "Assign to users" : "Toewijzen aan gebruikers",
    "Assign to users/groups/circles" : "Toewijzen aan gebruikers/groepen/kringen",
    "Assign a user to this card…" : "Wijs een gebruiker toe aan deze kaart",
    "Due date" : "Vervaldatum",
    "Set a due date" : "Stel een vervaldatum in",
    "Remove due date" : "Verwijder vervaldatum",
    "Select Date" : "Selecteer datum",
    "Today" : "Vandaag",
    "Tomorrow" : "Morgen",
    "Next week" : "Volgende week",
    "Next month" : "Volgende maand",
    "Save" : "Opslaan",
    "The comment cannot be empty." : "De reactie kan niet leeg zijn.",
    "The comment cannot be longer than 1000 characters." : "De reactie kan niet langer dan 1000 tekens zijn.",
    "In reply to" : "Als antwoord op",
    "Cancel reply" : "Antwoord annuleren",
    "Reply" : "Antwoord",
    "Update" : "Bijwerken",
    "Description" : "Beschrijving",
    "(Unsaved)" : "(Niet opgeslagen)",
    "(Saving…)" : "(Opslaan…)",
    "Formatting help" : "Formatteringshulp",
    "Edit description" : "Bewerk beschrijving",
    "View description" : "Bekijk beschrijving",
    "Add Attachment" : "Toevoegen bijlage",
    "Write a description …" : "Voeg een beschrijving toe ...",
    "Choose attachment" : "Kies bijlage",
    "(group)" : "(groep)",
    "{count} comments, {unread} unread" : "{count} reacties, {unread} ongelezen",
    "Assign to me" : "Aan mij toewijzen",
    "Unassign myself" : "Eigen toewijzing opheffen",
    "Move card" : "Verplaats kaart",
    "Unarchive card" : "Terughalen kaart uit archief",
    "Archive card" : "Archiveer kaart",
    "Delete card" : "Verwijderen kaart",
    "Move card to another board" : "Verplaats kaart naar een ander bord",
    "List is empty" : "Lijst is leeg",
    "Card deleted" : "Kaart verwijderd",
    "seconds ago" : "seconden geleden",
    "All boards" : "Alle borden",
    "Archived boards" : "Gearchiveerde borden",
    "Shared with you" : "Deelde met jou",
    "Use bigger card view" : "Gebruik een grotere kaartweergave",
    "Show boards in calendar/tasks" : "Toon borden in agenda/taken",
    "Limit deck usage of groups" : "Beperk gebruik decks van groepen",
    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Het beperken van Deck verhindert dat gebruikers die niet lid zijn van die groepen hun eigen borden kunnen maken. gebruikers kunnen nog wel werken met de borden die met deze gebruikers zijn gedeeld.",
    "Board details" : "Bord details",
    "Edit board" : "Bewerk  bord",
    "Clone board" : "Dupliceer bord",
    "Unarchive board" : "De-archiveer bord",
    "Archive board" : "Archiveer bord",
    "Turn on due date reminders" : "Herinneringen voor vervaldatums aanzetten",
    "Turn off due date reminders" : "Herinneringen voor vervaldatums uitzetten",
    "Due date reminders" : "Herinneringen voor vervaldatums",
    "All cards" : "Alle kaarten",
    "Assigned cards" : "Toegewezen kaarten",
    "No notifications" : "Geen meldingen",
    "Delete board" : "Verwijder bord",
    "Board {0} deleted" : "Bord {0} verwijderd",
    "Only assigned cards" : "Uitsluitend toegewezen kaarten",
    "No reminder" : "Geen herinnering",
    "An error occurred" : "Er is een fout opgetreden",
    "Delete the board?" : "Bord verwijderen?",
    "Loading filtered view" : "Gefilterde weergave wordt geladen",
    "No due" : "Geen vervallen",
    "Search for {searchQuery} in all boards" : "Zoek naar {searchQuery} in alle borden",
    "No results found" : "Geen resultaten gevonden",
    "{stack} in {board}" : "{stack} in {board}",
    "No upcoming cards" : "Geen aanstaande kaarten",
    "upcoming cards" : "Aanstaande kaarten",
    "Link to a board" : "Verbind met een bord",
    "Link to a card" : "Koppel met een kaart",
    "Create a card" : "Maak een kaart aan",
    "Message from {author} in {conversationName}" : "Bericht van {author} in {conversationName}",
    "Something went wrong" : "Er ging iets verkeerd",
    "Failed to upload {name}" : "Kon {name} niet uploaden",
    "Maximum file size of {size} exceeded" : "Maximale bestandsomvang van {size} overschreden",
    "Error creating the share" : "Fout bij aanmaken share",
    "Share with a Deck card" : "Delen met een Deck kaart",
    "Share {file} with a Deck card" : "Delen {file} met een Deck kaart",
    "Share" : "Delen",
    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Deck is een soort kanban organisatietool gericht op persoonlijke planning en projectorganisatie voor teams geïntegreerd in Nextcloud.\n\n\n- 📥 Voeg taken toe aan kaarten en sorteer ze\n- 📄 Schrijf extra notities in markdown\n- 🔖 Ken labels toe voor betere organisatie\n- 👥 Deel met je team, vrienden of familie\n- 📎 Voeg bestanden toe en plaats ze in je markdown beschrijving\n- 💬 Discussieer binnen je team met reacties\n- ⚡ Volg de wijzigingen in het activiteiten kanaal\n- 🚀 Organiseer je project",
    "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "Weet je zeker dat je bord {title} met wilt verwijderen? Dit verwijderd alle informatie van dit bord.",
    "This week" : "Deze week"
},
"nplurals=2; plural=(n != 1);");
