OC.L10N.register(
    "deck",
    {
    "Done" : "Feito",
    "The file was uploaded" : "O fichero estió puyato",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "O fichero puyato sobrexe a directiva upload_max_filesize en php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "O fichero cargau supera a directiva MAX_FILE_SIZE que s'espezificó en o formulario HTML",
    "The file was only partially uploaded" : "O fichero nomás s'ha cargau parzialmén",
    "No file was uploaded" : "No s'ha cargau garra fichero",
    "Missing a temporary folder" : "Falta una carpeta temporal",
    "Could not write file to disk" : "No se podió escribir o fichero en o disco",
    "A PHP extension stopped the file upload" : "Una estensión de PHP aturó a carga de fichers",
    "Cancel" : "Canzelar",
    "Close" : "Zarrar",
    "Details" : "Detalles",
    "Tags" : "Etiquetas",
    "Delete" : "Borrar",
    "Download" : "Escargar",
    "Modified" : "Modificau",
    "Today" : "Hue",
    "Share" : "Compartir"
},
"nplurals=2; plural=(n != 1);");
