OC.L10N.register(
    "deck",
    {
    "You have created a new board {board}" : "Δημιουργήσατε νέο πίνακα {board}",
    "{user} has created a new board {board}" : "Ο/η {user} δημιούργησε νέο πίνακα {board}",
    "You have deleted the board {board}" : "Έχετε διαγράψει τον πίνακα {board}",
    "{user} has deleted the board {board}" : "Ο/η {user} διέγραψε τον πίνακα {board}",
    "You have restored the board {board}" : "Εχετε επαναφέρει τον πίνακα {board}",
    "{user} has restored the board {board}" : "Ο/η {user} επανέφερε τον πίνακα {board}",
    "You have shared the board {board} with {acl}" : "Εχετε διαμοιράσει τον πίνακα {board} με {acl}",
    "{user} has shared the board {board} with {acl}" : "Ο/η {user} διαμοίρασε τον πίνακα {board} με {acl}",
    "You have removed {acl} from the board {board}" : "Αφαιρέθηκε η {acl} από τον πίνακα {board}",
    "{user} has removed {acl} from the board {board}" : "Ο/η {user} αφαίρεσε την {acl} από τον πίνακα {board}",
    "You have renamed the board {before} to {board}" : "Μετονομάσατε τον πίνακα {before} σε {board}",
    "{user} has renamed the board {before} to {board}" : "Ο/η {user} μετονόμασε τον πίνακα {before} σε {board}",
    "You have archived the board {board}" : "Αρχειοθετήσατε τον πίνακα {board}",
    "{user} has archived the board {before}" : "Ο/η {user} αρχειοθέτησε τον πίνακα {before}",
    "You have unarchived the board {board}" : "Επαναφέρατε τον πίνακα {board} από το αρχείο",
    "{user} has unarchived the board {before}" : "Ο/η {user} επανέφερε τον πίνακα {before} από αρχείο",
    "You have created a new list {stack} on board {board}" : "Έχετε δημιουργήσει μια νέα λίστα {stack} στον πίνακα {board}",
    "{user} has created a new list {stack} on board {board}" : "Ο/η {user} δημιούργησε μια νέα λίστα {stack} στον πίνακα {board}",
    "You have renamed list {before} to {stack} on board {board}" : "Μετονομάσατε την λίστα {before} σε {stack} στον πίνακα {board}",
    "{user} has renamed list {before} to {stack} on board {board}" : "Ο/η {user} μετονόμασε την λίστα {before} σε {stack} στον πίνακα {board}",
    "You have deleted list {stack} on board {board}" : "Διαγράψατε την λίστα {stack} στον πίνακα {board}",
    "{user} has deleted list {stack} on board {board}" : "Ο/η {user} διέγραψε την λίστα {stack} στον πίνακα {board}",
    "You have created card {card} in list {stack} on board {board}" : "Δημιουργήσατε την καρτέλα {card} στην λίστα {stack} του πίνακα {board}",
    "{user} has created card {card} in list {stack} on board {board}" : "Ο/η {user} δημιούργησε την καρτέλα {card} στην λίστα {stack} του πίνακα {board}",
    "You have deleted card {card} in list {stack} on board {board}" : "Διαγράψατε την καρτέλα {card} στην λίστα {stack} του πίνακα {board}",
    "{user} has deleted card {card} in list {stack} on board {board}" : "Ο/η {user} διέγραψε την καρτέλα {card} στην λίστα {stack} του πίνακα {board}",
    "You have renamed the card {before} to {card}" : "Μετονομάσατε την καρτέλα {before} σε {card}",
    "{user} has renamed the card {before} to {card}" : "Ο/η {user} μετονόμασε την καρτέλα {before} σε {card}",
    "You have added a description to card {card} in list {stack} on board {board}" : "Προσθέσατε μια περιγραφή στην καρτέλα {card} της λίστας {stack} του πίνακα {board}",
    "{user} has added a description to card {card} in list {stack} on board {board}" : "Ο/η {user} πρόσθεσε μια περιγραφή στην καρτέλα {card} της λίστας {stack} του πίνακα {board} ",
    "You have updated the description of card {card} in list {stack} on board {board}" : "Ενημερώσατε την περιγραφή στην καρτέλα {card} της λίστας {stack} του πίνακα {board}",
    "{user} has updated the description of the card {card} in list {stack} on board {board}" : "Ο/η {user} ενημέρωσε την περιγραφή της καρτέλας {card} στη λίστα {stack} του πίνακα {board}",
    "You have archived card {card} in list {stack} on board {board}" : "Αρχειοθετήσατε την κάρτα {card} στην λίστα {stack} του πίνακα {board} ",
    "{user} has archived card {card} in list {stack} on board {board}" : "Ο/η {user} αρχειοθέτησε την κάρτα {card} στην λίστα {stack} του πίνακα {board} ",
    "You have unarchived card {card} in list {stack} on board {board}" : "Επαναφέρατε από το αρχείο την καρτέλα {card} της λίστας {stack} του πίνακα {board}",
    "{user} has unarchived card {card} in list {stack} on board {board}" : "Ο/η {user} επανέφερε από το αρχείο την κάρτα {card} της λίστας {stack} του πίνακα {board}",
    "You have removed the due date of card {card}" : "Καταργήσατε την ημερομηνία λήξης της καρτέλας {card}",
    "{user} has removed the due date of card {card}" : "Ο/η {user} κατάργησε την ημερομηνία λήξης της καρτέλας {card}",
    "You have set the due date of card {card} to {after}" : "Ορίσατε την ημερομηνία λήξης της καρτέλας {card} σε {after}",
    "{user} has set the due date of card {card} to {after}" : "Ο/η {user} όρισε την ημερομηνία λήξης της καρτέλας {card} σε {after} ",
    "You have updated the due date of card {card} to {after}" : "Ενημερώσατε την ημερομηνία λήξης της καρτέλας {card} σε {after}",
    "{user} has updated the due date of card {card} to {after}" : "Ο/η {user} ενημέρωσε την ημερομηνία λήξης της καρτέλας {card} σε {after}",
    "You have added the tag {label} to card {card} in list {stack} on board {board}" : "Προσθέσατε ετικέτα {label}  στην καρτέλα {card} της λίστας {stack} του πίνακα {board}",
    "{user} has added the tag {label} to card {card} in list {stack} on board {board}" : "Ο/η {user} πρόσθεσε ετικέτα {label} στην καρτέλα {card} της λίστας {stack} του πίνακα {board}",
    "You have removed the tag {label} from card {card} in list {stack} on board {board}" : "Αφαιρέσατε την ετικέτα {label} από την καρτέλα {card} της λίστας {stack} του πίνακα {board}",
    "{user} has removed the tag {label} from card {card} in list {stack} on board {board}" : "Ο/η {user} αφαίρεσε την ετικέτα {label}  της καρτέλας {card} της λίστας {stack} του πίνακα {board} ",
    "You have assigned {assigneduser} to card {card} on board {board}" : "Έχετε ορίσει τον {assigneduser} στην καρτέλα {card} στον πίνακα {board}",
    "{user} has assigned {assigneduser} to card {card} on board {board}" : "Ο/η {user} έχει ορισθεί {assigneduser} στην καρτέλα {card} του πίνακα {board}",
    "You have unassigned {assigneduser} from card {card} on board {board}" : "Έχετε αφαιρέσει {assigneduser} από την καρτέλα {card}  του πίνακα {board}",
    "{user} has unassigned {assigneduser} from card {card} on board {board}" : "Ο/η {user} έχει αφαιρεθεί {assigneduser} από την καρτέλα {card} του  πίνακα {board}",
    "You have moved the card {card} from list {stackBefore} to {stack}" : "Μετακινήσατε την καρτέλα {card} από την λίστα {stackBefore} στη {stack}",
    "{user} has moved the card {card} from list {stackBefore} to {stack}" : "Ο/η {user} μετακίνησε την καρτέλα {card} από την λίστα {stackBefore} στην {stack}",
    "You have added the attachment {attachment} to card {card}" : "Προσθέσατε το συνημμένο {attachment} στην καρτέλα {card}",
    "{user} has added the attachment {attachment} to card {card}" : "Ο/η {user} πρόσθεσε το συνημμένο {attachment} στην καρτέλα {card}",
    "You have updated the attachment {attachment} on card {card}" : "Ενημερώσατε το συνημμένο {attachment} της καρτέλας {card}",
    "{user} has updated the attachment {attachment} on card {card}" : "Ο/η {user} ενημέρωσε το συνημμένο {attachment} της καρτέλας {card}",
    "You have deleted the attachment {attachment} from card {card}" : "Διαγράψατε το συνημμένο {attachment} της καρτέλας {card}",
    "{user} has deleted the attachment {attachment} from card {card}" : "Ο/η {user} διέγραψε το συνημμένο {attachment} της καρτέλας {card}",
    "You have restored the attachment {attachment} to card {card}" : "Επαναφέρατε το συνημμένο {attachment} στην καρτέλα {card}",
    "{user} has restored the attachment {attachment} to card {card}" : "Ο/η {user} επανέφερε το συνημμένο {attachment} στην καρτέλα {card}",
    "You have commented on card {card}" : "Σχολιάσατε την καρτέλα {card}",
    "{user} has commented on card {card}" : "Ο/η {user} σχολίασε την καρτέλα {card}",
    "A <strong>card description</strong> inside the Deck app has been changed" : "Η <strong>περιγραφή καρτέλας </strong>στην εφαρμογή Deck άλλαξε",
    "Deck" : "Deck",
    "Changes in the <strong>Deck app</strong>" : "Αλλαγές στην <strong>εφαρμογή Deck</strong>",
    "A <strong>comment</strong> was created on a card" : "Ένα <strong>σχόλιο</strong> δημιουργήθηκε σε μια καρτέλα",
    "Upcoming cards" : "Επερχόμενες καρτέλες",
    "Load more" : "Φόρτωση περισσότερων",
    "Personal" : "Προσωπικά",
    "The card \"%s\" on \"%s\" has been assigned to you by %s." : "Η καρτέλα \"%s\" του \"%s\" ανατέθηκε σε εσάς από τον %s.",
    "{user} has assigned the card {deck-card} on {deck-board} to you." : "Ο/Η {user} έχει αναθέσει την καρτέλα {deck-card} του πίνακα {deck-board} σε εσάς.",
    "The card \"%s\" on \"%s\" has reached its due date." : "Η καρτέλα \"%s\" στο \"%s\" έχει λήξει.",
    "The card {deck-card} on {deck-board} has reached its due date." : "Η καρτέλα {deck-card} στο {deck-board} έχει λήξει.",
    "%s has mentioned you in a comment on \"%s\"." : "Ο/η%s σας ανέφερε σε σχόλιο στο \"%s\".",
    "{user} has mentioned you in a comment on {deck-card}." : "Ο/Η {user} σας ανέφερε σε ένα σχόλιο στο {deck-card}.",
    "The board \"%s\" has been shared with you by %s." : "Ο πίνακας \"%s\" είναι σε κοινή χρήση μαζί σας από %s.",
    "{user} has shared {deck-board} with you." : "Ο/Η διαμοιράστηκε μαζί σας το {deck-board}",
    "Card comments" : "Σχόλια καρτέλας",
    "%s on %s" : "%s στο %s",
    "No data was provided to create an attachment." : "Δεν δόθηκαν στοιχεία για δημιουργία συνημμένου.",
    "Finished" : "Ολοκληρώθηκε",
    "To review" : "Προς επισκόπηση",
    "Action needed" : "Απαιτείται ενέργεια",
    "Later" : "Αργότερα",
    "copy" : "Αντιγραφή",
    "To do" : "Προς Ενέργεια",
    "Doing" : "Σε εξέλιξη",
    "Done" : "Ολοκληρώθηκε",
    "Example Task 3" : "Παράδειγμα Εργασίας 3",
    "Example Task 2" : "Παράδειγμα Εργασίας 2",
    "Example Task 1" : "Παράδειγμα Εργασίας 1",
    "The file was uploaded" : "Το αρχείο μεταφορτώθηκε",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Το αρχείο που εστάλη υπερβαίνει την οδηγία μέγιστου επιτρεπτού μεγέθους \"upload_max_filesize\" του php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Το ανεβασμένο αρχείο υπερβαίνει το MAX_FILE_SIZE που ορίζεται στην  HTML φόρμα",
    "The file was only partially uploaded" : "Το αρχείο μεταφορτώθηκε εν μέρει",
    "No file was uploaded" : "Δεν μεταφορτώθηκε κάποιο αρχείο",
    "Missing a temporary folder" : "Λείπει κάποιος προσωρινός φάκελος",
    "Could not write file to disk" : "Αδυναμία εγγραφής αρχείου στον δίσκο",
    "A PHP extension stopped the file upload" : "Ένα πρόσθετο PHP διέκοψε την μεταφόρτωση του αρχείου",
    "No file uploaded or file size exceeds maximum of %s" : "Δεν μεταφορτώθηκε αρχείο ή το μέγεθος αρχείου υπερβαίνει το μέγιστο %s",
    "This comment has more than %s characters.\nAdded as an attachment to the card with name %s.\nAccessible on URL: %s." : "Αυτό το σχόλιο έχει περισσότερους από %s χαρακτήρες.\nΠροστέθηκε ως συνημμένο στην καρτέλα με όνομα %s .\nΠροσβάσιμο στη διεύθυνση URL: %s.",
    "Card not found" : "Η καρτέλα δεν βρέθηκε",
    "Path is already shared with this card" : "Η διαδρομή κοινοποιείται ήδη σε αυτήν την καρτέλα",
    "Invalid date, date format must be YYYY-MM-DD" : "Μη έγκυρη ημερομηνία, η μορφή ημερομηνίας πρέπει να είναι ΕΕΕΕ-ΜΜ-ΗΗ",
    "Personal planning and team project organization" : "Προσωπικός σχεδιασμός και οργάνωση ομαδικών έργων",
    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in Markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your Markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Το Deck είναι ένα εργαλείο οργάνωσης τύπου kanban με στόχο τον προσωπικό προγραμματισμό και την  οργάνωση έργων για ομάδες που έχουν ενσωματωθεί στο Nextcloud.\n\n\n- 📥 Προσθέστε τις εργασίες σας στις καρτέλες και βάλτε τες στη σειρά\n- 📄 Γράψτε τις πρόσθετες σημειώσεις\n- 🔖 Αντιστοιχίστε τις ετικέτες για ακόμη καλύτερη οργάνωση\n- 👥 Μοιραστείτε με την ομάδα, φίλους ή την οικογένειά σας\n- 📎 Επισυνάψτε αρχεία και ενσωματώστε τα στην περιγραφή\n- 💬 Συζητήστε με την ομάδα σας χρησιμοποιώντας σχόλια\n- ⚡ Παρακολουθήστε τις αλλαγές στη ροή δραστηριοτήτων\n- 🚀 Έχετε τα όλα οργανωμένα",
    "Card details" : "Λεπτομέρειες καρτέλας",
    "Add board" : "Προσθήκη πίνακα",
    "Select the board to link to a project" : "Επιλέξτε πίνακα και συνδέστε τον σε ένα έργο",
    "Search by board title" : "Αναζήτηση με το όνομα πίνακα",
    "Select board" : "Επιλογή πίνακα",
    "Create a new card" : "Δημιουργία νέας καρτέλας",
    "Select a board" : "Επιλογή ενός πίνακα",
    "Select a list" : "Επιλέξτε μια λίστα",
    "Card title" : "Τίτλος καρτέλας",
    "Cancel" : "Aκύρωση",
    "Creating the new card …" : "Γίνεται δημιουργία της νέας καρτέλας...",
    "Card \"{card}\" was added to \"{board}\"" : "Η καρτέλα \"{card}\" προστέθηκε στο \"{board}\"",
    "Open card" : "Άνοιγμα καρτέλας",
    "Close" : "Κλείσιμο",
    "Create card" : "Δημιουργία καρτέλας",
    "Select a card" : "Επιλογή μιας καρτέλας",
    "Select the card to link to a project" : "Επιλογή καρτέλας για σύνδεση στο έργο",
    "Link to card" : "Σύνδεσμος σε καρτέλα",
    "File already exists" : "Το αρχείο υπάρχει ήδη",
    "A file with the name {filename} already exists." : "Το αρχείο με όνομα {filename} υπάρχει ήδη.",
    "Do you want to overwrite it?" : "Επιθυμείτε να γίνει αντικατάσταση του?",
    "Overwrite file" : "Αντικατάσταση αρχείου",
    "Keep existing file" : "Διατήρηση υπάρχοντος αρχείου",
    "This board is read only" : "Ο πίνακας είναι μόνο για ανάγνωση",
    "Drop your files to upload" : "Αποθέστε τα αρχεία σας για ανέβασμα",
    "Add card" : "Προσθήκη καρτέλας",
    "Archived cards" : "Αρχειοθετημένες καρτέλες",
    "Add list" : "Προσθήκη λίστας",
    "List name" : "Όνομα λίστας",
    "Apply filter" : "Εφαρμογή φίλτρου",
    "Filter by tag" : "Φίλτρο ανά ετικέτα",
    "Filter by assigned user" : "Φίλτρο ανά χρήστη",
    "Unassigned" : "Χωρίς ανάθεση",
    "Filter by due date" : "Φίλτρο ανά ημερομηνία λήξης",
    "Overdue" : "Εκπρόθεσμες",
    "Next 24 hours" : "Επόμενες 24 ώρες",
    "Next 7 days" : "Επόμενες 7 ημέρες",
    "Next 30 days" : "Επόμενες 30 ημέρες",
    "No due date" : "Χωρίς ημερομηνία λήξης",
    "Clear filter" : "Εκκαθάριση φίλτρου",
    "Hide archived cards" : "Απόκρυψη καρτελών που αρχειοθετήθηκαν",
    "Show archived cards" : "Εμφάνιση καρτελών που αρχειοθετήθηκαν",
    "Toggle compact mode" : "Εναλλαγή λειτουργίας μικρού μεγέθους",
    "Open details" : "Άνοιγμα λεπτομερειών",
    "Details" : "Λεπτομέρειες",
    "Loading board" : "Φόρτωση πίνακα",
    "No lists available" : "Δεν υπάρχουν διαθέσιμες λίστες",
    "Create a new list to add cards to this board" : "Δημιουργήστε νέα λίστα για να προσθέσετε καρτέλες σε αυτό τον πίνακα.",
    "Board not found" : "Ο πίνακας δεν βρέθηκε",
    "Sharing" : "Διαμοιρασμός",
    "Tags" : "Ετικέτες",
    "Deleted items" : "Διαγραμμένα αντικείμενα",
    "Timeline" : "Χρονολόγιο",
    "Deleted lists" : "Διαγραμμένες λίστες",
    "Undo" : "Αναίρεση",
    "Deleted cards" : "Διαγραμμένες καρτέλες",
    "Share board with a user, group or circle …" : "Διαμοιράστε τον πίνακα με χρήστη, ομάδα ή κύκλο ...",
    "Searching for users, groups and circles …" : "Αναζήτηση χρηστών, ομάδων και κύκλων…",
    "No participants found" : "Δε βρέθηκαν συμμετέχοντες",
    "Board owner" : "Κάτοχος πίνακα",
    "(Group)" : "(Ομάδα)",
    "(Circle)" : "(Κύκλος)",
    "Can edit" : "Μπορεί να επεξεργαστεί",
    "Can share" : "Μπορεί να διαμοιράσει",
    "Can manage" : "Μπορεί να διαχειριστεί",
    "Owner" : "Κάτοχος",
    "Delete" : "Διαγραφή",
    "Failed to create share with {displayName}" : "Αποτυχία δημιουργίας κοινής χρήσης με το {displayName}",
    "Transfer" : "Μεταφορά",
    "Add a new list" : "Προσθήκη νέας λίστας",
    "Archive all cards" : "Αρχειοθέτηση όλων των καρτελών.",
    "Delete list" : "Διαγραφή λίστας",
    "Archive all cards in this list" : "Αρχειοθέτηση όλων των καρτελών σε αυτή τη λίστα.",
    "Add a new card" : "Προσθήκη νέας καρτέλας",
    "Card name" : "Όνομα καρτέλας",
    "List deleted" : "Η λίστα διαγράφηκε",
    "Edit" : "Επεξεργασία",
    "Add a new tag" : "Προσθήκη νέας ετικέτας",
    "title and color value must be provided" : "ο τίτλος και η τιμή χρώματος πρέπει να παρέχονται",
    "Board name" : "Όνομα πίνακα",
    "Members" : "Μέλη",
    "Upload new files" : "Ανεβάστε νέα αρχεία",
    "Share from Files" : "Κοινή χρήση από Αρχεία",
    "Pending share" : "Κοινή χρήση σε εκκρεμότητα",
    "Add this attachment" : "Προσθήκη αυτού του συνημμένου",
    "Show in Files" : "Εμφάνιση σε Αρχεία",
    "Download" : "Λήψη",
    "Remove attachment" : "Αφαίρεση συνημμένου",
    "Delete Attachment" : "Διαγραφή συνημμένου",
    "Restore Attachment" : "Επαναφορά συνημμένου",
    "File to share" : "Αρχείο για κοινή χρήση",
    "Invalid path selected" : "Επιλέχθηκε μη έγκυρη διαδρομή",
    "Open in sidebar view" : "Άνοιγμα σε προβολή πλευρικής στήλης",
    "Open in bigger view" : "Άνοιγμα σε μεγαλύτερη προβολή",
    "Attachments" : "Συνημμένα",
    "Comments" : "Σχόλια",
    "Modified" : "Τροποποιήθηκε",
    "Created" : "Δημιουργήθηκε",
    "The title cannot be empty." : "Ο τίτλος δεν μπορεί να είναι κενός.",
    "No comments yet. Begin the discussion!" : "Χωρίς σχόλια ακόμη. Ξεκινήστε την συζήτηση!",
    "Failed to load comments" : "Αποτυχία φόρτωσης σχολίων",
    "Assign a tag to this card…" : "Ορίστε μια ετικέτα σε αυτήν την καρτέλα...",
    "Assign to users" : "Ανάθεση σε χρήστες",
    "Assign to users/groups/circles" : "Ανάθεση σε χρήστες/ομάδες/κύκλους",
    "Assign a user to this card…" : "Ανάθεση χρήστη στην καρτέλα...",
    "Due date" : "Ημερομηνία λήξης",
    "Set a due date" : "Καθορίστε ημερομηνίας λήξης",
    "Remove due date" : "Αφαίρεση ημερομηνίας λήξης",
    "Select Date" : "Επιλέξτε ημερομηνία",
    "Today" : "Σήμερα",
    "Tomorrow" : "Αύριο",
    "Next week" : "Επόμενη εβδομάδα",
    "Next month" : "Επόμενος μήνας",
    "Save" : "Αποθήκευση",
    "The comment cannot be empty." : "Το σχόλιο δεν μπορεί να είναι κενό.",
    "The comment cannot be longer than 1000 characters." : "Το σχόλιο δεν μπορεί να έχι περισσότερους από 1000 χαρακτήρες.",
    "In reply to" : "Σε απάντηση σε",
    "Cancel reply" : "Ακύρωση απάντησης",
    "Reply" : "Απάντηση",
    "Update" : "Ενημέρωση",
    "Description" : "Περιγραφή",
    "(Unsaved)" : "(Δεν αποθηκεύτηκε)",
    "(Saving…)" : "(Αποθήκευση...)",
    "Formatting help" : "Βοήθεια μορφοποίησης",
    "Edit description" : "Επεξεργασία περιγραφής",
    "View description" : "Εμφάνιση περιγραφής",
    "Add Attachment" : "Προσθήκη συνημμένου",
    "Write a description …" : "Γράψτε μια περιγραφή…",
    "Choose attachment" : "Επιλογή συνημμένου",
    "(group)" : "(ομάδα)",
    "{count} comments, {unread} unread" : "{count} σχόλια, {unread} μη αναγνωσμένα",
    "Assign to me" : "Ανάθεση σε εμένα",
    "Unassign myself" : "Αποδέσμευσή μου",
    "Move card" : "Μετακίνηση καρτέλας",
    "Unarchive card" : "Αναίρεση αρχειοθέτησης καρτέλας",
    "Archive card" : "Αρχειοθέτηση καρτέλας",
    "Delete card" : "Διαγραφή καρτέλας",
    "Move card to another board" : "Μετακίνηση καρτέλας σε άλλο πίνακα",
    "List is empty" : "Η λίστα είναι άδεια.",
    "Card deleted" : "Η καρτέλα διαγράφηκε",
    "seconds ago" : " δευτερόλεπτα πριν ",
    "All boards" : "Όλοι οι πίνακες",
    "Archived boards" : "Αρχειοθέτηση πινάκων ",
    "Shared with you" : "Διαμοιρασμένα μαζί σας",
    "Use bigger card view" : "Χρησιμοποιήστε μεγαλύτερη προβολή καρτέλας",
    "Show boards in calendar/tasks" : "Εμφάνιση πινάκων στο ημερολόγιο / εργασίες",
    "Limit deck usage of groups" : "Περιορίστε τη χρήση της εφαρμογής deck σε ομάδες",
    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Ο περιορισμός του Deck θα εμποδίσει τους χρήστες που δεν είναι μέρος αυτών των ομάδων να δημιουργούν δικούς τους πίνακες. Οι χρήστες θα εξακολουθήσουν να εργάζονται σε πίνακες που έχουν διαμοιραστεί μαζί τους.",
    "Board details" : "Λεπτομέριες πίνακα",
    "Edit board" : "Επεξεργασία πίνακα",
    "Clone board" : "Κλώνος πίνακα",
    "Unarchive board" : "Κατάργηση αρχειοθέτησης πίνακα",
    "Archive board" : "Αρχειοθέτηση πίνακα",
    "Turn on due date reminders" : "Ενεργοποιήστε τις υπενθυμίσεις ημερομηνίας προθεσμίας",
    "Turn off due date reminders" : "Απενεργοποιήστε τις υπενθυμίσεις ημερομηνίας προθεσμίας",
    "Due date reminders" : "Υπενθυμίσεις ημερομηνίας προθεσμίας",
    "All cards" : "Όλες οι καρτέλες",
    "Assigned cards" : "Ανατεθειμένες καρτέλες",
    "No notifications" : "Δεν υπάρχουν ειδοποιήσεις",
    "Delete board" : "Διαγραφή πίνακα",
    "Board {0} deleted" : "Διαγράφηκε {0} πίνακας ",
    "Only assigned cards" : "Μόνο καρτέλες που έχουν ανατεθεί",
    "No reminder" : "Δεν υπάρχει υπενθύμιση",
    "An error occurred" : "Παρουσιάστηκε σφάλμα",
    "Delete the board?" : "Διαγραφή του πίνακα;",
    "Loading filtered view" : "Φόρτωση εμφάνισης με βάση το φίλτρο",
    "No due" : "Χωρίς λήξη",
    "Search for {searchQuery} in all boards" : "Αναζήτηση για {searchQuery} σε όλους τους πίνακες",
    "No results found" : "Δεν βρέθηκαν αποτελέσματα",
    "{stack} in {board}" : "{stack} στο {board}",
    "No upcoming cards" : "Δεν υπάρχουν επερχόμενες καρτέλες",
    "upcoming cards" : "επερχόμενες καρτέλες",
    "Link to a board" : "Σύνδεσμος στον πίνακα",
    "Link to a card" : "Σύνδεσμος σε καρτέλα",
    "Create a card" : "Δημιουργία καρτέλας",
    "Message from {author} in {conversationName}" : "Μήνυμα από {author} σε {conversationName}",
    "Something went wrong" : "Κάτι πήγε στραβά",
    "Failed to upload {name}" : "Αποτυχία μεταφόρτωσης {name}",
    "Maximum file size of {size} exceeded" : "Υπέρβαση επιτρεπόμενου μεγέθους αρχείου {size}",
    "Error creating the share" : "Σφάλμα κατά τη δημιουργία της κοινοποίησης",
    "Share with a Deck card" : "Μοιραστείτε με μια καρτέλα Deck",
    "Share {file} with a Deck card" : "Μοιραστείτε το {file} με μια καρτέλα Deck",
    "Share" : "Μοιραστείτε",
    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Το Deck είναι ένα εργαλείο οργάνωσης τύπου kanban με στόχο τον προσωπικό προγραμματισμό και την  οργάνωση έργων για ομάδες που έχουν ενσωματωθεί στο Nextcloud.\n\n\n- 📥 Προσθέστε τις εργασίες σας στις καρτέλες και βάλτε τες στη σειρά\n- 📄 Γράψτε τις πρόσθετες σημειώσεις\n- 🔖 Αντιστοιχίστε τις ετικέτες για ακόμη καλύτερη οργάνωση\n- 👥 Μοιραστείτε με την ομάδα, φίλους ή την οικογένειά σας\n- 📎 Συνδέστε αρχεία και ενσωματώστε τα στην περιγραφή\n- 💬 Συζητήστε με την ομάδα σας χρησιμοποιώντας σχόλια\n- ⚡ Παρακολουθήστε τις αλλαγές στη ροή δραστηριοτήτων\n- 🚀 Έχετε τα όλα οργανωμένα",
    "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "Είστε βέβαιοι ότι θέλετε να διαγράψετε τον πίνακα {title}; Θα διαγραφούν όλα τα δεδομένα.",
    "This week" : "Αυτή την εβδομάδα",
    "Are you sure you want to transfer the board {title} for {user}?" : "Είστε σίγουροι ότι θέλετε να μεταφέρετε τον πίνακα  {title} για {user}?  "
},
"nplurals=2; plural=(n != 1);");
