OC.L10N.register(
    "deck",
    {
    "Finished" : "Završeno",
    "copy" : "kopiraj",
    "Done" : "Done",
    "Add board" : "Dodaj tablu",
    "Cancel" : "Otkaži",
    "Close" : "Zatvori",
    "Add card" : "Dodaj karticu",
    "Details" : "Detalji",
    "Sharing" : "Deljenje",
    "Tags" : "Oznake",
    "Undo" : "Opozovi",
    "Can edit" : "Can edit",
    "Can share" : "Can share",
    "Owner" : "Vlasnik",
    "Delete" : "Obriši",
    "Edit" : "Uredi",
    "Download" : "Preuzmi",
    "Attachments" : "Prilozi",
    "Due date" : "Rok",
    "Today" : "Danas",
    "Save" : "Sačuvaj",
    "Reply" : "Odgovori",
    "Update" : "Ažuriraj",
    "Description" : "Opis",
    "Move card" : "Premesti karticu",
    "Archive card" : "Arhiviraj karticu",
    "Delete card" : "Obriši karticu",
    "seconds ago" : "pre nekoliko sekundi",
    "Shared with you" : "Shared with you",
    "Edit board" : "Izmeni tablu",
    "Archive board" : "Arhiviraj tablu",
    "No notifications" : "Nema obaveštenja",
    "Delete board" : "Izbriši tablu",
    "Share" : "Podeli",
    "This week" : "Ove sedmice"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
