OC.L10N.register(
    "deck",
    {
    "You have created a new board {board}" : "Du har opprettet ny tavle {board}",
    "{user} has created a new board {board}" : "{user} har opprettet tavle {board}",
    "You have deleted the board {board}" : "Du har slettet tavle {board}",
    "{user} has deleted the board {board}" : "{user} har slettet tavle {board}",
    "You have restored the board {board}" : "Du har gjennopprettet tavle {board}",
    "{user} has restored the board {board}" : "{user} har gjennopprettet tavle {board}",
    "You have shared the board {board} with {acl}" : "Du har delt tavle {board} med {acl}",
    "{user} has shared the board {board} with {acl}" : "{user} har delt table {board} med {acl}",
    "You have removed {acl} from the board {board}" : "Du har fjernet {acl} fra tavle {board}",
    "{user} has removed {acl} from the board {board}" : "{user} har fjernet {acl} fra tavle {board}",
    "You have renamed the board {before} to {board}" : "Du har endret navn på tavle {before} til {board}",
    "{user} has renamed the board {before} to {board}" : "{user} har endret navn på tavle {before} til {board}",
    "You have archived the board {board}" : "Du har arkivert tavle {board}",
    "{user} has archived the board {before}" : "{user} har arkivert tavle {board}",
    "You have unarchived the board {board}" : "Du har hentet tavle {board} fra arkiv",
    "{user} has unarchived the board {before}" : "{user} har hentet tavle {board} fra arkiv",
    "You have created a new list {stack} on board {board}" : "Du har opprettet en ny stabel {stack} på tavle {board}",
    "{user} has created a new list {stack} on board {board}" : "{user} har opprettet en ny stabel {stack} på tavle {board}",
    "You have renamed list {before} to {stack} on board {board}" : "Du har endret navn på stabel {before} til {stack} på tavle {board}",
    "{user} has renamed list {before} to {stack} on board {board}" : "{user} har endret navn på stabel {before} til {stack} på tavle {board}",
    "You have deleted list {stack} on board {board}" : "Du har slettet stabel {stack} på tavle {board}",
    "{user} has deleted list {stack} on board {board}" : "{user} har slettet stabel {stack} på tavle {board}",
    "You have created card {card} in list {stack} on board {board}" : "Du har opprettet kort {card} i stabel {stack} på tavle {board}",
    "{user} has created card {card} in list {stack} on board {board}" : "{user} har opprettet kort {card} i stabel {stack} på tavle {board}",
    "You have deleted card {card} in list {stack} on board {board}" : "Du har slettet kort {card} i stabel {stack} på tavle {board}",
    "{user} has deleted card {card} in list {stack} on board {board}" : "{user} har slettet kort {card} i stabel {stack} på tavle {board}",
    "You have renamed the card {before} to {card}" : "Du har endret navn fra {before} til {card}",
    "{user} has renamed the card {before} to {card}" : "{user} har endret navn fra {before} til {card}",
    "You have added a description to card {card} in list {stack} on board {board}" : "Du har lagt til beskrivelse på kort {card} i stable {stack} på table {board}",
    "{user} has added a description to card {card} in list {stack} on board {board}" : "{user} har lagt til beskrivelse på kort {card} i stabel {stack} på tavle {board}",
    "You have updated the description of card {card} in list {stack} on board {board}" : "Du har oppdatert beskrivelsen på kort {card} i stabel {stack} på tavle {board}",
    "{user} has updated the description of the card {card} in list {stack} on board {board}" : "{user} har oppdatert beskrivelsen på kort {card} i stabel {stack} på tavle {board}",
    "You have archived card {card} in list {stack} on board {board}" : "Du har arkivert kort {card} i stabel {stack} på tavle {board}",
    "{user} has archived card {card} in list {stack} on board {board}" : "{user} har arkivert kort {card} i stabel {stack} på tavle {board}",
    "You have unarchived card {card} in list {stack} on board {board}" : "Du har hentet arkivert kort {card} i stabel {stack} på tavle {board}",
    "{user} has unarchived card {card} in list {stack} on board {board}" : "{user} har hentet arkivert kort {card} i stabel {stack} på tavle {board}",
    "You have removed the due date of card {card}" : "Du har fjernet forfallsdato for kort {card}",
    "{user} has removed the due date of card {card}" : "{user} har fjernet forfallsdato for kort {card}",
    "You have set the due date of card {card} to {after}" : "Du har satt forfallsdato på kort {card} etter {after}",
    "{user} has set the due date of card {card} to {after}" : "{user} har satt forfallsdato på kort {card} etter {after}",
    "You have updated the due date of card {card} to {after}" : "Du har oppdatert forfallsdato på kort {card} etter {after}",
    "{user} has updated the due date of card {card} to {after}" : "{user} har oppdatert forfallsdato på kort {card} etter {after}",
    "You have added the tag {label} to card {card} in list {stack} on board {board}" : "Du har lagt til merke {label} til kort {card} i stabel {stack} på tavle {board}",
    "{user} has added the tag {label} to card {card} in list {stack} on board {board}" : "{user} har lagt til merke {label} til kort {card} i stabel {stack} på tavle {board}",
    "You have removed the tag {label} from card {card} in list {stack} on board {board}" : "Du har fjernet merke {label} fra kort {card} i stabel {stack} på tavle {board}",
    "{user} has removed the tag {label} from card {card} in list {stack} on board {board}" : "{user} har fjernet merke {label} fra kort {card} i stabel {stack} på tavle {board}",
    "You have assigned {assigneduser} to card {card} on board {board}" : "Du har tildelt {assigneduser} til kort {card} på tavle {board}",
    "{user} has assigned {assigneduser} to card {card} on board {board}" : "{user} har tildelt {assigneduser} til kort {card} på tavle {board}",
    "You have unassigned {assigneduser} from card {card} on board {board}" : "Du har fjernet {assigneduser} fra kort {card} på tavle {board}",
    "{user} has unassigned {assigneduser} from card {card} on board {board}" : "{user} har fjernet {assigneduser} fra kort {card} på tavle {board}",
    "You have moved the card {card} from list {stackBefore} to {stack}" : "Du har flyttet kort {card} fra stabel {stackBefore} til {stack}",
    "{user} has moved the card {card} from list {stackBefore} to {stack}" : "{user} har flyttet kort {card} fra stabel {stackBefore} til {stack}",
    "You have added the attachment {attachment} to card {card}" : "Du har lagt til vedlegget {attachment} ti kortet {card}",
    "{user} has added the attachment {attachment} to card {card}" : "{user} har lagt til vedlegget {attachment} på kortet {card}",
    "You have updated the attachment {attachment} on card {card}" : "Du har oppdatert vedlegget {attachment} på kortet {card}",
    "{user} has updated the attachment {attachment} on card {card}" : "{user} har oppdateret vedlegget {attachment} på kortet {card}",
    "You have deleted the attachment {attachment} from card {card}" : "Du har slettet vedlegget {attachment} på kortet {card}",
    "{user} has deleted the attachment {attachment} from card {card}" : "{user} har slettet vedlegget {attachment} fra kortet {card}",
    "You have restored the attachment {attachment} to card {card}" : "Du har gjennopprettet vedlegget {attachment} på kortet {card}",
    "{user} has restored the attachment {attachment} to card {card}" : "{user} har gjennopprettet vedlegget {attachment} på kortet {card}",
    "You have commented on card {card}" : "Du har kommetnert på kort {card}",
    "{user} has commented on card {card}" : "{user} har kommetnert på kort {card}",
    "A <strong>card description</strong> inside the Deck app has been changed" : "En <strong>kort beskrivelse</strong>i Stokk-appen er endret",
    "Deck" : "Stokk",
    "Changes in the <strong>Deck app</strong>" : "Endringer i <strong>Stokk-appen</strong>",
    "A <strong>comment</strong> was created on a card" : "En <strong>kommentar</strong> ble skrevet på kortet",
    "Upcoming cards" : "Kommende kort",
    "Load more" : "Last mer",
    "Personal" : "Personlig",
    "The card \"%s\" on \"%s\" has been assigned to you by %s." : "Kortet \"%s\" på \"%s\" er endret til deg av %s.",
    "{user} has assigned the card {deck-card} on {deck-board} to you." : "{user} har tildelt kortet {deck-card} på {deck-board} til deg.",
    "The card \"%s\" on \"%s\" has reached its due date." : "Kortet \"%s\" på \"%s\" har nådd sin utløpsdato.",
    "The card {deck-card} on {deck-board} has reached its due date." : "Kortet {deck-card} på {deck-board} har nådd sin utløpsdato.",
    "%s has mentioned you in a comment on \"%s\"." : "%shar nevnt deg i en kommentar på \"%s\".",
    "{user} has mentioned you in a comment on {deck-card}." : "{user} har nevnt deg i en kommentar på {deck-card}.",
    "The board \"%s\" has been shared with you by %s." : "Brettet \"%s\" har blitt delt med deg av %s.",
    "{user} has shared {deck-board} with you." : "{user} har delt brettet {deck-board} med deg.",
    "Card comments" : "Kommentarer på kortet",
    "%s on %s" : "%s på %s",
    "No data was provided to create an attachment." : "Ingen data for å opprette vedlegg.",
    "Finished" : "Fullført",
    "To review" : "Til gjennomlesning",
    "Action needed" : "Handling påkrevd",
    "Later" : "Senere",
    "copy" : "kopier",
    "To do" : "Å gjøre",
    "Doing" : "Pågår",
    "Done" : "Ferdig",
    "Example Task 3" : "Eksempel oppgave 3",
    "Example Task 2" : "Eksempel oppgave 2",
    "Example Task 1" : "Eksempel oppgave 1",
    "The file was uploaded" : "Filen er lastet opp",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Filen er større enn definert grense i upload_max_filesize direktiv i php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Filen er større enn definert grense i MAX_FILE_SIZE  direktiv i HTML formen.",
    "The file was only partially uploaded" : "Filen er delvis opplastet",
    "No file was uploaded" : "Ingen fil var lastet opp",
    "Missing a temporary folder" : "Mangler katalog for midlertidige filer",
    "Could not write file to disk" : "Kan ikke skrive til disk",
    "A PHP extension stopped the file upload" : "En PHP utvidelse stoppet når fil ble lastet opp",
    "No file uploaded or file size exceeds maximum of %s" : "Ingen fil lastet opp eller filen er større enn %s",
    "This comment has more than %s characters.\nAdded as an attachment to the card with name %s.\nAccessible on URL: %s." : "Denne kommentaren har enn %s tegn.\nLa til som vedlegg til kortet med navnet %s.\nTilgjengelig på URL: %s.",
    "Card not found" : "Kort ikke funnet",
    "Path is already shared with this card" : "Stien er allerede delt med dette kortet",
    "Invalid date, date format must be YYYY-MM-DD" : "Feil dato, dato må være i formatet YYYY-MM-DD",
    "Personal planning and team project organization" : "Personlig planlegging og organisering av prosjekter i team",
    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in Markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your Markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Stokk er et kanban inspirert verktøy for organisering for personlig planlegging og prosjekt organisering for team integrert med Nextcloud.\n\n\n- 📥 Legg til oppgaver på kort og hold orden på disse.\n- 📄 Legg til notater.\n- 🔖 Tildel merke for enda bedre organisering.\n- 👥 Del med team, venner eller familile.\n- 📎 Legg ved filer som kan integreres i beskrivelser.\n- 💬 Diskuter med ditt team ved å bruke kommentarer.\n- ⚡ Hold oversikt over endringer i aktivitetsstrøm.\n- 🚀 Få dine prosjekt organisert.",
    "Card details" : "Kort-detaljer",
    "Add board" : "Legg til tavle",
    "Select the board to link to a project" : "Velg tavle som skal lenkes til prosjekt",
    "Search by board title" : "Søk på tittel på tavle",
    "Select board" : "Velg tavle",
    "Create a new card" : "Opprett et nytt kort",
    "Select a board" : "Velg en tavle",
    "Select a list" : "Velg en stabel",
    "Card title" : "Kortittel",
    "Cancel" : "Avbryt",
    "Creating the new card …" : "Oppretter det nye kortet ...",
    "Card \"{card}\" was added to \"{board}\"" : "Kort \"{card}\" ble lagt til i \"{board}\"",
    "Open card" : "Åpne kort",
    "Close" : "Lukk",
    "Create card" : "Opprett kort",
    "Select a card" : "Velg et kort",
    "Select the card to link to a project" : "Velg kort som skal lenkes til prosjekt",
    "Link to card" : "Lenke til kort",
    "File already exists" : "Filen finnes allerede",
    "A file with the name {filename} already exists." : "En fil med navnet {filename} finnes allerede.",
    "Do you want to overwrite it?" : "Vil du overskrive?",
    "Overwrite file" : "Overskriv fil",
    "Keep existing file" : "Behold eksisterende fil",
    "This board is read only" : "Denne tavlen er kun lesbar",
    "Drop your files to upload" : "Dropp filer for å laste opp",
    "Add card" : "Legg til kort",
    "Archived cards" : "Arkiver tavle",
    "Add list" : "Legg til liste",
    "List name" : "Listenavn",
    "Active filters" : "Aktivt filter",
    "Apply filter" : "Aktiver filter",
    "Filter by tag" : "Filtrer på knagg",
    "Filter by assigned user" : "Filtrer på tildelt bruker",
    "Unassigned" : "Ikke tildelt",
    "Filter by due date" : "Filtrer på forfallsdato",
    "Overdue" : "Utløpt",
    "Next 24 hours" : "Neste 24 timer",
    "Next 7 days" : "Neste 7 dager",
    "Next 30 days" : "Neste 30 dager",
    "No due date" : "Ingen forfallsdato",
    "Clear filter" : "Tøm filter",
    "Hide archived cards" : "Skjul arkiverte kort",
    "Show archived cards" : "Vis arkiverkte kort",
    "Toggle compact mode" : "Endre kompakt modus",
    "Open details" : "Åpne detaljer",
    "Details" : "Detaljer",
    "Loading board" : "Laster tavle",
    "No lists available" : "Ingen stabler tilgjengelig",
    "Create a new list to add cards to this board" : "Lag en ny stabel for å legge til kort til denne tavlen",
    "Board not found" : "Tavle ikke funnet",
    "Sharing" : "Deling",
    "Tags" : "Merkelapper",
    "Deleted items" : "Slettede element",
    "Timeline" : "Tidslinje",
    "Deleted lists" : "Slettede stabler",
    "Undo" : "Angre",
    "Deleted cards" : "Slettede kort",
    "Share board with a user, group or circle …" : "Del tavle med bruker, gruppe eller sirkel",
    "Searching for users, groups and circles …" : "Søker etter brukere, grupper og sirkler ...",
    "No participants found" : "Ingen deltakere funnet",
    "Board owner" : "Tavle-eier",
    "(Group)" : "(Gruppe)",
    "(Circle)" : "(Sirkel)",
    "Can edit" : "Kan redigere",
    "Can share" : "Kan dele",
    "Can manage" : "Kan behandle",
    "Owner" : "Eier",
    "Delete" : "Slett",
    "Failed to create share with {displayName}" : "Klarte ikke å opprette deling med {displayName}",
    "Are you sure you want to transfer the board {title} to {user}?" : "Er du sikker på at du vil overføre tavlen {title} til {user}?",
    "Transfer the board." : "Overfør tavle.",
    "Transfer" : "Overfør",
    "The board has been transferred to {user}" : "Tavlen har blitt overført til {user}",
    "Failed to transfer the board to {user}" : "Klarte ikke overføre tavlen til {user}",
    "Add a new list" : "Legg til en ny stabel",
    "Archive all cards" : "Arkiver alle kort",
    "Delete list" : "Slett listen",
    "Archive all cards in this list" : "Arkiver alle kort i en stabel",
    "Add a new card" : "Legg til nytt kort",
    "Card name" : "Navn på kort",
    "List deleted" : "Stabel slettet",
    "Edit" : "Rediger",
    "Add a new tag" : "Legg til nytt merke",
    "title and color value must be provided" : "Du må oppgi verdier for tittel og farge",
    "Board name" : "Navn på tavle",
    "Members" : "Medlemmer",
    "Upload new files" : "Last opp nye filer",
    "Share from Files" : "Del fra Filer",
    "Pending share" : "Ventende deling",
    "Add this attachment" : "Legg til vedlegg",
    "Show in Files" : "Vis i Filer",
    "Download" : "Last ned",
    "Remove attachment" : "Fjern vedlegg",
    "Delete Attachment" : "Slett vedlegg",
    "Restore Attachment" : "Gjenopprett vedlegg",
    "File to share" : "Fil for deling",
    "Invalid path selected" : "Ugyldig angitt sti",
    "Open in sidebar view" : "Åpne med sidepanel",
    "Open in bigger view" : "Åpen i større visning",
    "Attachments" : "Vedlegg",
    "Comments" : "Kommentarer",
    "Modified" : "Endret",
    "Created" : "Opprettet",
    "The title cannot be empty." : "Tittel kan ikke være tom",
    "No comments yet. Begin the discussion!" : "Ingen kommentarer ennå. Start diskusjonen!",
    "Failed to load comments" : "Feil i lasting av kommentarer",
    "Assign a tag to this card…" : "Legg til et merke til dette kortet...",
    "Assign to users" : "Tildel brukere",
    "Assign to users/groups/circles" : "Tildel brukere/grupper/sirkler",
    "Assign a user to this card…" : "Tildel bruker til dette kortet...",
    "Due date" : "Forfallsdato",
    "Set a due date" : "Set forfallsdato",
    "Remove due date" : "Fjern forfallsdato",
    "Select Date" : "Velg dato",
    "Today" : "I dag",
    "Tomorrow" : "I morgen",
    "Next week" : "Neste uke",
    "Next month" : "Neste måned",
    "Save" : "Lagre",
    "The comment cannot be empty." : "Kommentaren kan ikke være tom.",
    "The comment cannot be longer than 1000 characters." : "Kommentaren kan ikke være lenger enn 1000 tegn.",
    "In reply to" : "Som svar på",
    "Cancel reply" : "Avbryt svar",
    "Reply" : "Svar",
    "Update" : "Oppdater",
    "Description" : "Beskrivelse",
    "(Unsaved)" : "(Ikke lagret)",
    "(Saving…)" : "(Lagrer...)",
    "Formatting help" : "Formateringshjelp",
    "Edit description" : "Rediger beskrivelse",
    "View description" : "Se beskrivelse",
    "Add Attachment" : "Legg til vedlegg",
    "Write a description …" : "Skriv en beskrivelse ...",
    "Choose attachment" : "Velg vedlegg",
    "(group)" : "(gruppe)",
    "Todo items" : "Gjøremålspunkter",
    "{count} comments, {unread} unread" : "{count} kommentarer, {unread} ulest",
    "Edit card title" : "Rediger korttittel",
    "Assign to me" : "Tildel meg",
    "Unassign myself" : "Fjern meg fra tildeling",
    "Move card" : "Flytt kort",
    "Unarchive card" : "Hent kort fra arkiv",
    "Archive card" : "Arkiver kort",
    "Delete card" : "Slett kort",
    "Move card to another board" : "Flytt kort til annen tavle",
    "List is empty" : "Stabel er tom",
    "Card deleted" : "Kort slettet",
    "seconds ago" : "sekunder siden",
    "All boards" : "Alle tabler",
    "Archived boards" : "Arkiverte tavler",
    "Shared with you" : "Delt med deg",
    "Deck settings" : "Innstillinger for Stokk",
    "Use bigger card view" : "Bruk større visning på kort",
    "Show boards in calendar/tasks" : "Vis tavler i kalender/oppgaver",
    "Limit deck usage of groups" : "Begrens stokk-bruk til grupper",
    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Begrensning av tavler vil hindre tilgang til de brukere som ikke er medlem av en gruppe fra å lage egne tavler. Bruker kan arbeide på de tavler som er delt med dem.",
    "Board details" : "Forumseksjonsdetaljer",
    "Edit board" : "Rediger tavle",
    "Clone board" : "Klon tavle",
    "Unarchive board" : "Aktiver tavle",
    "Archive board" : "Arkiver tavle",
    "Turn on due date reminders" : "Skru på påminnelser for forfallsdato",
    "Turn off due date reminders" : "Skru av påminnelser for forfallsdato",
    "Due date reminders" : "Påminnelser for forfallsdato",
    "All cards" : "Alle kort",
    "Assigned cards" : "Tildelte kort",
    "No notifications" : "Ingen varsler",
    "Delete board" : "Slett tavle",
    "Board {0} deleted" : "Tavle {0} slettet",
    "Only assigned cards" : "Kun tildelte kort",
    "No reminder" : "Ingen varsel",
    "An error occurred" : "En feil oppstod",
    "Are you sure you want to delete the board {title}? This will delete all the data of this board including archived cards." : "Are du sikker på sletting av tavlen {title}? Handlingen vil slette all data i denne tavlen, inkludert arkiverte kort.",
    "Delete the board?" : "Slett tavlen?",
    "Loading filtered view" : "Laster filtrert visning",
    "No due" : "Ingen forfall",
    "Search for {searchQuery} in all boards" : "Søk etter {searchQuery} i alle tavler",
    "No results found" : "Ingen resultater funnet",
    "{stack} in {board}" : "{stack} i {board}",
    "Click to expand description" : "Klikk for å utvide beskrivelsen",
    "* Created on {created}\n* Last modified on {lastMod}\n* {nbAttachments} attachments\n* {nbComments} comments" : "* Opprettet {created}\n* Sist endret {lastMod}\n* {nbAttachments} vedlegg\n* {nbComments} kommentarer",
    "{nbCards} cards" : "{nbCards} kort",
    "No upcoming cards" : "Ingen kommende kort",
    "upcoming cards" : "kommende kort",
    "Due on {date}" : "Utløper {date}",
    "Link to a board" : "Lenke til tavle",
    "Link to a card" : "Lenke til et kort",
    "Create a card" : "Opprett kort",
    "Message from {author} in {conversationName}" : "Melding fra {author} i {conversationName}",
    "Something went wrong" : "Noe gikk galt",
    "Failed to upload {name}" : "Klarte ikke laste opp {name}",
    "Maximum file size of {size} exceeded" : "Maksimal størrelse for filer på {size} er overskredet",
    "Error creating the share" : "Feil ved oppretting av deling",
    "Share with a Deck card" : "Del med et Stokk-kort",
    "Share {file} with a Deck card" : "Del {file} med et Stokk-kort",
    "Share" : "Del",
    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Stokk er et kanban inspirert verktøy for organisering for personlig planlegging og prosjekt organisering for team integrert med Nextcloud.\n\n\n- 📥 Legg til oppgaver på kort og hold orden på disse.\n- 📄 Legg til notater.\n- 🔖 Tildel merke for enda bedre organisering.\n- 👥 Del med team, venner eller familile.\n- 📎 Legg ved filer som kan integreres i beskrivelser.\n- 💬 Diskuter med ditt team ved å bruke kommentarer.\n- ⚡ Hold oversikt over endringer i aktivitetsstrøm.\n- 🚀 Få dine prosjekt organisert.",
    "Are you sure you want to transfer the board {title} for {user} ?" : "Er du sikker på at du vil overføre tavlen {title} for {user} ?",
    "Transfer the board for {user} successfully" : "Tavlen ble overført for {user}",
    "Failed to transfer the board for {user}" : "Klarte ikke overføre tavlen for {user}",
    "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "Er du sikker på sletting av tavlen {title}? Dette vil slette alt innholdet på denne tavlen.",
    "This week" : "Denne uken",
    "Are you sure you want to transfer the board {title} for {user}?" : "Er du sikker på at du vil overføre tavlen {title} for {user}?"
},
"nplurals=2; plural=(n != 1);");
