OC.L10N.register(
    "deck",
    {
    "You have created a new board {board}" : "لقد قمت بانشاء لوح جديد {board}",
    "{user} has created a new board {board}" : "{user} قام بانشاء لوح {board}",
    "You have deleted the board {board}" : "قمت بمسح اللوح {board}",
    "{user} has deleted the board {board}" : "{user} مَسحْ اللوح {board}",
    "You have restored the board {board}" : "لقد استعدت اللوح {board}",
    "{user} has restored the board {board}" : "{user} قام باسترجاع اللوح {board}",
    "You have shared the board {board} with {acl}" : "قمت بمشاركة اللوح {board} مع {acl}",
    "{user} has shared the board {board} with {acl}" : "{user} قام بمشاركة اللوح {board} مع {acl}",
    "You have removed {acl} from the board {board}" : "قمت بإزالة {acl} من اللوح {board}",
    "{user} has removed {acl} from the board {board}" : "{user} قام بازالة {acl} من اللوح {board}",
    "You have renamed the board {before} to {board}" : "قمت بإعادة تسمية اللوح من {before} الى {board}",
    "{user} has renamed the board {before} to {board}" : "{user} قام بإعادة تسمية اللوح من {before} الى {board}",
    "You have archived the board {board}" : "لقد ارشفت اللوح {board}",
    "{user} has archived the board {before}" : "{user} قام بأرشفة اللوح {before}",
    "You have unarchived the board {board}" : "قمت بالغاء ارشفة اللوح {board}",
    "{user} has unarchived the board {before}" : "{user} قام بالغاء ارشفة اللوح {before}",
    "You have created a new list {stack} on board {board}" : "لقد قمت بانشاء قائمة جديدة {stack} على اللوح {board}",
    "{user} has created a new list {stack} on board {board}" : "{user} قام بانشاء قائمة جديدة {stack} على اللوح {board}",
    "You have renamed list {before} to {stack} on board {board}" : "قمت باعادة تسمية القائمة من {before} إلى {stack} على اللوح {board}",
    "{user} has renamed list {before} to {stack} on board {board}" : "{user} قام باعادة تسمية القائمة {before} إلى {stack} على اللوح {board}",
    "You have deleted list {stack} on board {board}" : "قمت بمسح القائمة  {stack} على اللوح {board}",
    "{user} has deleted list {stack} on board {board}" : "{user} قام بمسح القائمة {stack} على اللوح {board}",
    "You have created card {card} in list {stack} on board {board}" : "لقد قمت بانشاء بطاقة {card} في القائمة {stack} على اللوح {board}",
    "{user} has created card {card} in list {stack} on board {board}" : "{user} قام بانشاء بطاقة {card} في القائمة {stack} على اللوح {board}",
    "You have deleted card {card} in list {stack} on board {board}" : "قمت بمسح بطاقة {card} في القائمة {stack} على اللوح {board}",
    "{user} has deleted card {card} in list {stack} on board {board}" : "{user} قام بحذف بطاقة {card} في القائمة {stack} على اللوح {board}",
    "You have renamed the card {before} to {card}" : "قمت بإعادة تسمية اللوح من {before} إلى {card}",
    "{user} has renamed the card {before} to {card}" : "{user} قام بإعادة تسمية اللوح من {before} إلى {card}",
    "You have added a description to card {card} in list {stack} on board {board}" : "قمت بإضافة وصف إلى البطاقة {card} في القائمة {stack} على اللوح {board}",
    "{user} has added a description to card {card} in list {stack} on board {board}" : "{user} قام بإضافة وصف إلى البطاقة {card} في القائمة {stack} على اللوح {board}",
    "You have updated the description of card {card} in list {stack} on board {board}" : "قمت بتحديث الوصف إلى البطاقة {card} في القائمة {stack} على اللوح {board}",
    "{user} has updated the description of the card {card} in list {stack} on board {board}" : "{user} قام بتحديث الوصف إلى البطاقة {card} في القائمة {stack} على اللوح {board}",
    "You have archived card {card} in list {stack} on board {board}" : "لقد قمت بأرشفة بطاقة {card} في القائمة {stack} على اللوح {board}",
    "{user} has archived card {card} in list {stack} on board {board}" : "{user} قام بأرشفة بطاقة {card} في القائمة {stack} على اللوح {board}",
    "You have unarchived card {card} in list {stack} on board {board}" : "لديك بطاقة غير مؤرشفة {card} في القائمة {stack} على اللوح {board}",
    "{user} has unarchived card {card} in list {stack} on board {board}" : "{user} لديه بطاقة غير مؤرشفة {card} في القائمة {stack} على اللوح {board}",
    "You have removed the due date of card {card}" : "قمت بإزالة التاريخ المحدد من البطاقة {card}",
    "{user} has removed the due date of card {card}" : "{user} قام بإزالة التاريخ المحدد من البطاقة {card}",
    "You have set the due date of card {card} to {after}" : "قمت بتعيين التاريخ المحدد للبطاقة {card} إلى {after}",
    "{user} has set the due date of card {card} to {after}" : "{user} قام بتعيين التاريخ المحدد للبطاقة {card} إلى {after}",
    "You have updated the due date of card {card} to {after}" : "قمت بتحديث التاريخ المحدد للبطاقة {card} إلى {after}",
    "{user} has updated the due date of card {card} to {after}" : "{user} قام بتحديث التاريخ المحدد للبطاقة {card} إلى {after}",
    "You have added the tag {label} to card {card} in list {stack} on board {board}" : "قمت بإضافة وسم {label} إلى البطاقة {card} في القائمة {stack} على اللوح {board}",
    "{user} has added the tag {label} to card {card} in list {stack} on board {board}" : "{user} قام بإضافة وسم {label} إلى البطاقة {card} في القائمة {stack} على اللوح {board}",
    "You have removed the tag {label} from card {card} in list {stack} on board {board}" : "قمت بإزالة وسم {label} من البطاقة {card} في القائمة {stack} على اللوح {board}",
    "{user} has removed the tag {label} from card {card} in list {stack} on board {board}" : "{user} قام بإزالة وسم {label} من البطاقة {card} في القائمة {stack} على اللوح {board}",
    "You have assigned {assigneduser} to card {card} on board {board}" : "قمت بتكليف {assigneduser} في بطاقة {card} على اللوح {board}",
    "{user} has assigned {assigneduser} to card {card} on board {board}" : "{user} قام بتكليف {assigneduser} في بطاقة {card} على اللوح {board}",
    "You have unassigned {assigneduser} from card {card} on board {board}" : "لقد إلغيت تكليف {assigneduser} من البطاقة {card} على اللوح {board}",
    "{user} has unassigned {assigneduser} from card {card} on board {board}" : "{user} الغى تكليف {assigneduser} من البطاقة {card} على اللوح {board}",
    "You have moved the card {card} from list {stackBefore} to {stack}" : " قمت بنقل البطاقة {card} من القائمة {stackBefore} إلى {stack}",
    "{user} has moved the card {card} from list {stackBefore} to {stack}" : "{user} قام بنقل البطاقة {card} من القائمة {stackBefore} إلى {stack}",
    "You have added the attachment {attachment} to card {card}" : "قمت بإضافة المرفق {attachment} إلى البطاقة {card}",
    "{user} has added the attachment {attachment} to card {card}" : "{user} قام بإضافة المرفق {attachment} إلى البطاقة {card}",
    "You have updated the attachment {attachment} on card {card}" : "قمت بتحديث المرفق {attachment} على البطاقة {card}",
    "{user} has updated the attachment {attachment} on card {card}" : "{user} قام بتحديث المرفق {attachment} على البطاقة {card}",
    "You have deleted the attachment {attachment} from card {card}" : "قمت بحذف المرفق {attachment} من البطاقة {card}",
    "{user} has deleted the attachment {attachment} from card {card}" : "{user} قام بحذف المرفق {attachment} من البطاقة {card}",
    "You have restored the attachment {attachment} to card {card}" : "قمت باسترجاع المرفق {attachment} إلى البطاقة {card}",
    "{user} has restored the attachment {attachment} to card {card}" : "{user} قام باسترجاع المرفق {attachment} إلى البطاقة {card}",
    "You have commented on card {card}" : "لقد علقت على البطاقة {بطاقة}",
    "{user} has commented on card {card}" : "{مستخدم} علق على بطاقة {بطاقة}",
    "A <strong>card description</strong> inside the Deck app has been changed" : "<strong>وصف البطاقة</strong>داخل تطبيق Deck قد تغيرت.",
    "Deck" : "Deck",
    "Changes in the <strong>Deck app</strong>" : "تغييرات في <strong>تطبيق Deck</strong> ",
    "A <strong>comment</strong> was created on a card" : "<strong>تعليق</strong> تم إنشاؤه على بطاقة",
    "Upcoming cards" : "البطاقات القادمة",
    "Personal" : "شخصي",
    "The card \"%s\" on \"%s\" has been assigned to you by %s." : "البطاقة \"%s\" على \"%s\" كُلفت بها من قبل %s.",
    "{user} has assigned the card {deck-card} on {deck-board} to you." : "{user} قام بتكليف البطاقة {deck-board} على {deck-board} لك",
    "The card \"%s\" on \"%s\" has reached its due date." : "وصلت بطاقة \"%s\" على %s\" الموعد المحدد ",
    "The card {deck-card} on {deck-board} has reached its due date." : "تجاوزت البطاقة {deck-card} على {deck-board} التاريخ المحدد.",
    "%s has mentioned you in a comment on \"%s\"." : "%s أشار إليك في تعليق على \"%s\".",
    "{user} has mentioned you in a comment on {deck-card}." : "{user} أشار إليك في تعليق على {deck-card}",
    "The board \"%s\" has been shared with you by %s." : "تمت مشاركة اللوح \"%s\" معك من قبل %s.",
    "{user} has shared {deck-board} with you." : "{user} قام بمشاركة {deck-board} معك.",
    "Card comments" : "تعليقات البطاقة ",
    "%s on %s" : "%s على %s",
    "No data was provided to create an attachment." : "لا بيانات تم تقديمها لانشاء مرفق",
    "Finished" : "اكتمل",
    "To review" : "لإعادة المراجعة",
    "Action needed" : "يحتاج إلى إجراء",
    "Later" : "لاحقا",
    "copy" : "نسخ",
    "To do" : "لفعله",
    "Doing" : "تحت العمل",
    "Done" : "أُنجز",
    "Example Task 3" : "مثال المهمة 3",
    "Example Task 2" : "مثال المهمة 2",
    "Example Task 1" : "مثال المهمة 1",
    "The file was uploaded" : "تم رفع الملف",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "حجم الملف المرفوع قد تجاوز  upload_max_filesize الموجودة في ملف php.ini ",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "حجم الملف الذي تريد رفعه أعلى من الحد المسموح به في واجهة ال HTML.",
    "The file was only partially uploaded" : "الملف قد رُفع جزءا منه فقط",
    "No file was uploaded" : "لم يتم رفع أي ملف",
    "Missing a temporary folder" : "المجلد المؤقت غير موجود",
    "Could not write file to disk" : "لم يستطع كتابة ملف للقرص",
    "A PHP extension stopped the file upload" : "إضافة البي اچ بي PHP أوقفت رفع الملف",
    "No file uploaded or file size exceeds maximum of %s" : "لم يتم تحميل أي ملف أو أن يتجاوز حجم الملف الحد الأقصى %s",
    "Card not found" : "لم يتم العثور على البطاقة ",
    "Path is already shared with this card" : "تم مشاركة المسار بالفعل مع هذه البطاقة ",
    "Invalid date, date format must be YYYY-MM-DD" : "تاريخ غير صحيح, يجب أن يكون تنسيق التاريخ YYYY-MM-DD",
    "Personal planning and team project organization" : "التخطيط الشخصي و تنظيم مشروع الفريق",
    "Card details" : "تفاصيل البطاقة",
    "Add board" : "إضافة لوح",
    "Select the board to link to a project" : "تحديد اللوح لربطه بمشروع",
    "Search by board title" : "بحث بواسطة عنوان اللوح",
    "Select board" : "حدد لوح",
    "Create a new card" : "أنشى بطاقة جديدة ",
    "Select a board" : "حدد لوح",
    "Select a list" : "اختر قائمة ",
    "Card title" : "عنوان البطاقة ",
    "Cancel" : "إلغاء",
    "Creating the new card …" : "أنشى البطاقة الجديدة ",
    "Card \"{card}\" was added to \"{board}\"" : "\"{بطاقة}\" تمت إضافتها في \"{اللوح}\"",
    "Open card" : "فتح البطاقة ",
    "Close" : "إغلاق",
    "Create card" : "أنشى بطاقة ",
    "Select a card" : "حدد بطاقة",
    "Select the card to link to a project" : "حدد البطاقة لربطها بمشروع",
    "Link to card" : "اربط بطاقة",
    "File already exists" : "الملف موجود مسبقاً",
    "A file with the name {filename} already exists." : "ملف باسم {اسم الملف} موجود مسبقًا ",
    "Do you want to overwrite it?" : "هل تريد تجاوزه؟",
    "Overwrite file" : "تجاوز ملف",
    "Keep existing file" : "ابقي الملف الموجود",
    "This board is read only" : "هذا اللوح بوضع القراءة فقط",
    "Drop your files to upload" : "افلت الملفات لرفعها",
    "Add card" : "إضافة بطاقة",
    "Archived cards" : "البطاقات المؤرشفة",
    "Add list" : "إضافة قائمة",
    "List name" : "قامة اسماء",
    "Apply filter" : "تطبيق التصفية",
    "Filter by tag" : "تصفية بواسطة الوسم",
    "Filter by assigned user" : "تصفية بواسطة المستخدم الموكل اليه",
    "Unassigned" : "غير معيين ",
    "Filter by due date" : "تصفية بواسطة تاريخ الإنجاز",
    "Overdue" : "تأخر",
    "Next 24 hours" : "ال 24 ساعة القادمة",
    "Next 7 days" : "ال 7 أيام القادمة",
    "Next 30 days" : "ال 30 يوم القادمة",
    "No due date" : "لا تاريخ إنجاز",
    "Clear filter" : "ازل التصفية",
    "Hide archived cards" : "إخفاء البطاقات المؤرشفة ",
    "Show archived cards" : "اظهر البطاقات المؤرشفة",
    "Toggle compact mode" : "تبديل النمط المضغوط",
    "Open details" : "افتح التفاصيل",
    "Details" : "التفاصيل",
    "Loading board" : "جارِ تحميل اللوح..",
    "No lists available" : "لا يوجد قائمة متاحه ",
    "Create a new list to add cards to this board" : "إنشاء قائمة جديدة لإضافة البطاقات على هذا اللوح",
    "Board not found" : "اللوح غير موجود",
    "Sharing" : "المشاركة",
    "Tags" : "الوسوم",
    "Deleted items" : "العناصر الممسوحة",
    "Timeline" : "الجدول الزمني",
    "Deleted lists" : "القوائم المحذوفة",
    "Undo" : "تراجع",
    "Deleted cards" : "البطاقات المحذوفة",
    "Share board with a user, group or circle …" : "مشاركة اللوح مع مستخدم،مجموعة أو دائرة ..",
    "Searching for users, groups and circles …" : "ابحث عن أعضاء، مجموعات أو حلقات ...",
    "No participants found" : "لم يتم العثور على مشاركين",
    "Board owner" : "منشئ اللوح",
    "(Group)" : "(مجموعة)",
    "(Circle)" : "(دائرة)",
    "Can edit" : "يمكن تعديله",
    "Can share" : "يمكن مشاركته",
    "Can manage" : "يمكن إدارته",
    "Owner" : "المالك",
    "Delete" : "حذف ",
    "Failed to create share with {displayName}" : "فشل في إنشاء المشاركة مع {displayName}",
    "Transfer" : "نقل",
    "Add a new list" : "اضف قائمة جديدة",
    "Archive all cards" : "أرشفة جميع البطاقات ",
    "Delete list" : "حذف القائمة",
    "Archive all cards in this list" : "أرشفة جميع البطاقات في القائمة ",
    "Add a new card" : "إضافة بطاقة جديدة",
    "Card name" : "اسم البطاقة ",
    "List deleted" : "القائمة حٌذفت ",
    "Edit" : "تعديل",
    "Add a new tag" : "إضافة وسم جديد",
    "title and color value must be provided" : "العنوان و قيمة اللون يجب تقديمها ",
    "Board name" : "اسم اللوح",
    "Members" : "الاعضاء",
    "Upload new files" : "رفع ملفات جديدة",
    "Share from Files" : "مشاركة من الملفات",
    "Add this attachment" : "إضافة هذا المرفق",
    "Show in Files" : "عرض في الملفات ",
    "Download" : "تنزيل",
    "Delete Attachment" : "مسح المرفق",
    "Restore Attachment" : "إستعادة المرفق",
    "File to share" : "ملف للمشاركة",
    "Invalid path selected" : "تم تحديد مسار غير صحيح",
    "Open in sidebar view" : "فتح في الشريط الجانبي ",
    "Open in bigger view" : "فتح في نافذة أكبر ",
    "Attachments" : "المرفقات",
    "Comments" : "تعليقات",
    "Modified" : "عُدل",
    "Created" : "أُنشئ",
    "The title cannot be empty." : "لا يمكن ترك العنوان فارغًا.",
    "No comments yet. Begin the discussion!" : "لا يوجد تعليقات بعد, ابدأ النقاش الآن!",
    "Failed to load comments" : "فشل في تحميل التعليقات ",
    "Assign a tag to this card…" : "انسب وسم الى هذه البطاقة..",
    "Assign to users" : "انسب الى المتسخدمين",
    "Assign to users/groups/circles" : "انسب الى المستخدمين،المجموعات،الدوائر",
    "Assign a user to this card…" : "انسب مستخدم الى هذه البطاقة..",
    "Due date" : "تاريخ الانجاز",
    "Set a due date" : "تعيين تاريخ الانجاز",
    "Remove due date" : "ازالة تاريخ الانجاز",
    "Select Date" : "اختر التاريخ ",
    "Today" : "اليوم",
    "Tomorrow" : "غدا",
    "Next week" : "الاسبوع القادم",
    "Next month" : "الشهر القادم",
    "Save" : "حفظ",
    "The comment cannot be empty." : "التعليق لايمكن ان يكون فارغا.",
    "The comment cannot be longer than 1000 characters." : "التعليق لا يمكن ان يكون اطول من 1000 حرف.",
    "In reply to" : "يقوم بالرد على",
    "Cancel reply" : "إلغاء الرد",
    "Reply" : "رد",
    "Update" : "تحديث",
    "Description" : "الوصف",
    "(Unsaved)" : "(غير محفوظ)",
    "(Saving…)" : "(يُحفظ..)",
    "Formatting help" : "مساعدة التنسيق",
    "Edit description" : "تعديل الوصف",
    "View description" : "إظهار الوصف",
    "Add Attachment" : "أضف ملحق",
    "Write a description …" : "كتابة وصف...",
    "Choose attachment" : "اختيار مرفق",
    "(group)" : "(مجموعة)",
    "{count} comments, {unread} unread" : "{عدد} التعليقات، {غير مقروءة} غير مقروءة",
    "Assign to me" : "ينسب لي",
    "Unassign myself" : "إلغاء تعييني ",
    "Move card" : "حرك البطاقة",
    "Unarchive card" : "إلغاء أرشفة البطاقة ",
    "Archive card" : "أرشفة البطاقة",
    "Delete card" : "حذف البطاقة",
    "Move card to another board" : "حرك البطاقة الى لوح اخر",
    "Card deleted" : "البطاقة حٌذفت ",
    "seconds ago" : "ثوانٍ مضت",
    "All boards" : "جميع الالواح",
    "Archived boards" : "الالواح المؤرشفة",
    "Shared with you" : "تم مشاركتها معك",
    "Use bigger card view" : "استخدام بطاقة عرض أكبر ",
    "Show boards in calendar/tasks" : "إظهار اللوح في التقويم/المهام",
    "Limit deck usage of groups" : "تقييد استخدام Deck  للمجموعات",
    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "سيؤدي تقييد Deck إلى منع المستخدمين الذين ليسوا جزءًا من تلك المجموعات من إنشاء لوحاتهم الخاصة. سيظل المستخدمون قادرين على العمل على اللوحات التي تمت مشاركتها معهم.",
    "Board details" : "تفاصيل لوح",
    "Edit board" : "تعديل اللوح",
    "Clone board" : "استنسخ اللوح",
    "Unarchive board" : "إلغاء أرشفة اللوح",
    "Archive board" : "أرشفة اللوح ",
    "Turn on due date reminders" : "تفعيل التذكيرات للموعد المحدد ",
    "Turn off due date reminders" : "إيقاف تشغيل التذكيرات للموعد المحددد",
    "Due date reminders" : "تذكيرات الموعد المحدد ",
    "All cards" : "جميع البطاقات ",
    "Assigned cards" : "البطاقات المخصصة",
    "No notifications" : "لا توجد إشعارات",
    "Delete board" : "مسح اللوح",
    "Board {0} deleted" : "اللوح {0} تم مسحه",
    "Only assigned cards" : "البطاقات المخصصة فقط",
    "No reminder" : "لا يوجد تذكير ",
    "An error occurred" : "حدث خطأ",
    "Delete the board?" : "مسح اللوح؟",
    "Loading filtered view" : "جارِ تحميل التصفية ",
    "No due" : "غير محدد",
    "Search for {searchQuery} in all boards" : "البحث عن {searchQuery} في جميع اللوح",
    "No results found" : "لا يتم العثور على أي نتائج ",
    "{stack} in {board}" : "{stack} في  {board}",
    "No upcoming cards" : "لا يوجد بطاقات قادمة ",
    "upcoming cards" : "البطاقات القادمة",
    "Link to a board" : "ربط بلوح",
    "Link to a card" : "ربط ببطاقة",
    "Create a card" : "أنشى بطاقة ",
    "Message from {author} in {conversationName}" : "رسالة من {author} في {conversationName}",
    "Something went wrong" : "حدث خطأ ما",
    "Failed to upload {name}" : "فشل في رفع {اسم}",
    "Maximum file size of {size} exceeded" : " تجاوز الملف الحد الاقصى {size} بالحجم المسموح ",
    "Error creating the share" : "خطأ في إنشاء المشاركة",
    "Share with a Deck card" : "مشاركة مع بطاقة Deck",
    "Share {file} with a Deck card" : "مشاركة الملف {file} مع بطاقة Deck",
    "Share" : "مشاركة ",
    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "دك (Deck) هو أداة تنظيم باسلوب كانبان (kanban) تهدف إلى التخطيط الشخصي وتنظيم المشروع للفرق مع نيكست كلاود (Nextcloud).\n- 📥 إضافة مهامك إلى البطاقات وترتيبها\n- 📄 كتابة ملاحظات إضافية  باستخدام مارك داون (markdown)\n- 🔖 تعيين تسميات لتنظيم أفضل\n- 👥 شارك مع فريقك أو أصدقائك أو عائلتك\n- 📎 إرفاق الملفات وتضمينها بالوصف المستخدم فيه مارك داون (markdown)\n- 💬 ناقش مع فريقك باستخدام التعليقات\n- ⚡ تتبع التغييرات في تيار النشاط\n- 🚀 اجعل مشروعك منظماً",
    "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "هل انت متأكد تريد مسح اللوح {title}؟ هذا سوف يمسح جميع بيانات هذا اللوح.",
    "This week" : "هذا الأسبوع"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
