OC.L10N.register(
    "deck",
    {
    "You have created a new board {board}" : "Você criou um novo painel {board}",
    "{user} has created a new board {board}" : "{user} criou um novo painel {board}",
    "You have deleted the board {board}" : "Você excluiu o painel {board}",
    "{user} has deleted the board {board}" : "{user} excluiu o painel {board}",
    "You have restored the board {board}" : "Você restaurou o painel {board}",
    "{user} has restored the board {board}" : "{user} restaurou o painel {board}",
    "You have shared the board {board} with {acl}" : "Você compartilhou o painel {board} com {acl}",
    "{user} has shared the board {board} with {acl}" : "{user} compartilhou o painel {board} com {acl}",
    "You have removed {acl} from the board {board}" : "Você excluiu {acl} do painel {board}",
    "{user} has removed {acl} from the board {board}" : "{user} excluiu {acl} do painel {board}",
    "You have renamed the board {before} to {board}" : "Você renomeou o painel {before} para {board}",
    "{user} has renamed the board {before} to {board}" : "{user} renomeou o painel {before} para {board}",
    "You have archived the board {board}" : "Você arquivou o painel {board}",
    "{user} has archived the board {before}" : "{user} arquivou o painel  {before}",
    "You have unarchived the board {board}" : "Você desarquivou o painel  {board}",
    "{user} has unarchived the board {before}" : "{user} desarquivou o painel {board}",
    "You have created a new list {stack} on board {board}" : "Você criou uma nova lista {stack} no painel {board}",
    "{user} has created a new list {stack} on board {board}" : "{user} criou uma nova lista {stack} no painel {board}",
    "You have renamed list {before} to {stack} on board {board}" : "Você renomeou a lista {before} para {stack} no painel {board}",
    "{user} has renamed list {before} to {stack} on board {board}" : "{user} renomeou a lista {before} para {stack} no painel {board}",
    "You have deleted list {stack} on board {board}" : "Você excluiu a lista {stack} do painel {board}",
    "{user} has deleted list {stack} on board {board}" : "{user} excluiu a lista {stack} do painel {board}",
    "You have created card {card} in list {stack} on board {board}" : "Você criou o cartão {card} na lista {stack} do painel {board}",
    "{user} has created card {card} in list {stack} on board {board}" : "{user} criou o cartão {card} na lista {stack} do painel {board}",
    "You have deleted card {card} in list {stack} on board {board}" : "Você excluiu o cartão {card} na lista {stack} do painel {board}",
    "{user} has deleted card {card} in list {stack} on board {board}" : "{user} excluiu o cartão {card} na lista {stack} do painel {board}",
    "You have renamed the card {before} to {card}" : "Você renomeou o cartão {before} para {card}",
    "{user} has renamed the card {before} to {card}" : "{user} renomeou o cartão {before} para {card}",
    "You have added a description to card {card} in list {stack} on board {board}" : "Você adicionou uma descrição ao cartão {card} na lista {stack} do painel {board}",
    "{user} has added a description to card {card} in list {stack} on board {board}" : "{user} adicionou uma descrição ao cartão {card} na lista {stack} do painel {board}",
    "You have updated the description of card {card} in list {stack} on board {board}" : "Você atualizou a descrição do cartão {card} na lista {stack} do painel {board}",
    "{user} has updated the description of the card {card} in list {stack} on board {board}" : "{user} atualizou a descrição do cartão {card} na lista {stack} do painel {board}",
    "You have archived card {card} in list {stack} on board {board}" : "Você arquivou o cartão {card} na lista {stack} do painel {board}",
    "{user} has archived card {card} in list {stack} on board {board}" : "{user} arquivou o cartão {card} na lista {stack} do painel {board}",
    "You have unarchived card {card} in list {stack} on board {board}" : "Você desarquivou o cartão {card} na lista {stack} do painel {board}",
    "{user} has unarchived card {card} in list {stack} on board {board}" : "{user} desarquivou o cartão {card} na lista {stack} do painel {board}",
    "You have removed the due date of card {card}" : "Você excluiu a data de vencimento do cartão {card}",
    "{user} has removed the due date of card {card}" : "{user} excluiu a data de vencimento do cartão {card}",
    "You have set the due date of card {card} to {after}" : "Você definiu a data de vencimento do cartão {card} para {after}",
    "{user} has set the due date of card {card} to {after}" : "{user} definiu a data de vencimento do cartão {card} para {after}",
    "You have updated the due date of card {card} to {after}" : "Você atualizou a data de vencimento do cartão {card} para {after}",
    "{user} has updated the due date of card {card} to {after}" : "{user} atualizou a data de vencimento do cartão {card} para {after}",
    "You have added the tag {label} to card {card} in list {stack} on board {board}" : "Você adicionou a etiqueta {label} ao cartão {card} na lista {stack} do painel {board}",
    "{user} has added the tag {label} to card {card} in list {stack} on board {board}" : "{user} adicionou a etiqueta {label} ao cartão {card} na lista {stack} do painel {board}",
    "You have removed the tag {label} from card {card} in list {stack} on board {board}" : "Você removeu a etiqueta {label} do cartão {card} na lista {stack} do painel {board}",
    "{user} has removed the tag {label} from card {card} in list {stack} on board {board}" : "{user} removeu a etiqueta {label} do cartão {card} na lista {stack} do painel {board}",
    "You have assigned {assigneduser} to card {card} on board {board}" : "Você vinculou {assigneduser} ao cartão {card} do painel {board}",
    "{user} has assigned {assigneduser} to card {card} on board {board}" : "{user} vinculou {assigneduser} ao cartão {card} do painel {board}",
    "You have unassigned {assigneduser} from card {card} on board {board}" : "Você desvinculou {assigneduser} do cartão {card} no painel {board}",
    "{user} has unassigned {assigneduser} from card {card} on board {board}" : "{user} desvinculou {assigneduser} do cartão {card} no painel {board}",
    "You have moved the card {card} from list {stackBefore} to {stack}" : "Você moveu o cartão {card} da lista {stackBefore} para {stack}",
    "{user} has moved the card {card} from list {stackBefore} to {stack}" : "{user} moveu o cartão {card} da lista {stackBefore} para {stack}",
    "You have added the attachment {attachment} to card {card}" : "Você adicionou o anexo {attachment} no cartão {card}",
    "{user} has added the attachment {attachment} to card {card}" : "{user} adicionou um anexo {attachment} ao cartão {card}",
    "You have updated the attachment {attachment} on card {card}" : "Você atualizou o anexo {attachment} do cartão {card}",
    "{user} has updated the attachment {attachment} on card {card}" : "{user} atualizou o anexo {attachment} no cartão {card}",
    "You have deleted the attachment {attachment} from card {card}" : "Você excluiu o anexo {attachment} do cartão {card}",
    "{user} has deleted the attachment {attachment} from card {card}" : "{user} excluiu o anexo {attachment} do cartão {card}",
    "You have restored the attachment {attachment} to card {card}" : "Você restaurou o anexo {attachment} do cartão {card}",
    "{user} has restored the attachment {attachment} to card {card}" : "{user} restaurou o anexo {attachment} do cartão {card}",
    "You have commented on card {card}" : "Você comentou no cartão {card}",
    "{user} has commented on card {card}" : "{user} comentou no cartão {card}",
    "A <strong>card description</strong> inside the Deck app has been changed" : "Uma <strong>descrição do cartão</strong> dentro do aplicativo Deck foi alterada",
    "Deck" : "Deck",
    "Changes in the <strong>Deck app</strong>" : "Mudanças no <strong>aplicativo Deck</strong>",
    "A <strong>comment</strong> was created on a card" : "Um <strong>comentário</strong> foi criado no cartão",
    "Upcoming cards" : "Próximos cartões",
    "Load more" : "Carregar mais",
    "Personal" : "Pessoal",
    "The card \"%s\" on \"%s\" has been assigned to you by %s." : "O cartão \"%s\" em \"%s\" foi vinculado com você por %s.",
    "{user} has assigned the card {deck-card} on {deck-board} to you." : "{usuário} atribuiu a carta {deck-card} no {deck-board} para você.",
    "The card \"%s\" on \"%s\" has reached its due date." : "O cartão \"%s\" em \"%s\" atingiu sua data de vencimento.",
    "The card {deck-card} on {deck-board} has reached its due date." : "A carta {deck-card} em {deck-board} atingiu sua data de vencimento.",
    "%s has mentioned you in a comment on \"%s\"." : "%s citou você num comentário em \"%s\".",
    "{user} has mentioned you in a comment on {deck-card}." : "{user} mencionou você em um comentário em {deck-card}.",
    "The board \"%s\" has been shared with you by %s." : "O painel \"%s\" foi compartilhado com você por %s.",
    "{user} has shared {deck-board} with you." : "{user} compartilhou {deck-board} com você.",
    "Card comments" : "Comentários nos Cards",
    "%s on %s" : "%s em %s",
    "No data was provided to create an attachment." : "Nenhum dado foi fornecido para criar um anexo.",
    "Finished" : "Terminado",
    "To review" : "Para revisão",
    "Action needed" : "Ação necessária",
    "Later" : "Depois",
    "copy" : "copiar",
    "To do" : "A fazer",
    "Doing" : "Fazendo",
    "Done" : "Concluído",
    "Example Task 3" : "Tarefa exemplo 3",
    "Example Task 2" : "Tarefa exemplo 2",
    "Example Task 1" : "Tarefa exemplo 1",
    "The file was uploaded" : "O arquivo foi enviado",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "O arquivo enviado excede a diretiva upload_max_filesize do php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "O arquivo enviado excede a diretiva MAX_FILE_SIZE especificada no formulário HTML",
    "The file was only partially uploaded" : "O arquivo foi parcialmente enviado",
    "No file was uploaded" : "Nenhum arquivo foi enviado",
    "Missing a temporary folder" : "Falta uma pasta temporária",
    "Could not write file to disk" : "Não foi possível escrever no disco",
    "A PHP extension stopped the file upload" : "Uma extensão PHP parou o envio do arquivo",
    "No file uploaded or file size exceeds maximum of %s" : "Nenhum arquivo enviado ou o tamanho excede o máximo de %s",
    "This comment has more than %s characters.\nAdded as an attachment to the card with name %s.\nAccessible on URL: %s." : "Este comentário tem mais de %s caracteres.\nAdicionado como um anexo ao cartão com o nome %s.\nAcessível no URL: %s.",
    "Card not found" : "Cartão não encontrado",
    "Path is already shared with this card" : "O caminho já é compartilhado com este cartão",
    "Invalid date, date format must be YYYY-MM-DD" : "Data inválida, o formato da data deve ser AAAA-MM-DD",
    "Personal planning and team project organization" : "Planejamento pessoal e organização de projetos em equipe",
    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in Markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your Markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Deck é uma ferramenta de organização do estilo kanban voltada para o planejamento pessoal e organização de projetos para equipes integradas ao Nextcloud.\n\n\n- 📥Adicione suas tarefas aos cartões e coloque-as em ordem\n- 📄 Escreva notas adicionais em Anotar \n- 🔖 Atribua rótulos para uma organização ainda melhor\n- 👥 Compartilhe com sua equipe, amigos ou família\n- 📎 Anexar arquivos e incorporá-los à descrição da Nota\n- 💬 Discuta com sua equipe usando comentários\n- ⚡ Acompanhe as mudanças no fluxo de atividades \n- 🚀 Organize seu projeto ",
    "Card details" : "Detalhes do cartão",
    "Add board" : "Adicionar painel",
    "Select the board to link to a project" : "Selecione o painel para vincular a um projeto",
    "Search by board title" : "Pesquisar pelo título do painel",
    "Select board" : "Selecionar painel",
    "Create a new card" : "Criar um novo cartão",
    "Select a board" : "Selecionar um painel",
    "Select a list" : "Selecione uma lista",
    "Card title" : "Título do cartão",
    "Cancel" : "Cancelar",
    "Creating the new card …" : "Criando o novo cartão …",
    "Card \"{card}\" was added to \"{board}\"" : "O cartão \"{card}\" foi adicionado a \"{board}\" ",
    "Open card" : "Abrir o cartão",
    "Close" : "Fechar",
    "Create card" : "Criar cartão",
    "Select a card" : "Selecionar um cartão",
    "Select the card to link to a project" : "Selecione o cartão para vincular a um projeto",
    "Link to card" : "Vincular ao cartão",
    "File already exists" : "Arquivo já existe",
    "A file with the name {filename} already exists." : "Um arquivo com o nome {filename} já existe.",
    "Do you want to overwrite it?" : "Quer sobrescrever?",
    "Overwrite file" : "Sobrescrever arquivo",
    "Keep existing file" : "Manter o arquivo existente",
    "This board is read only" : "Este painel é somente leitura",
    "Drop your files to upload" : "Arraste seus arquivos para enviar",
    "Add card" : "Adicionar cartão",
    "Archived cards" : "Cartões arquivados",
    "Add list" : "Adicionar lista",
    "List name" : "Nome da lista",
    "Active filters" : "Filtros ativos",
    "Apply filter" : "Aplicar filtro",
    "Filter by tag" : "Filtrar por etiqueta",
    "Filter by assigned user" : "Filtrar por usuário atribuído",
    "Unassigned" : "Não atribuído",
    "Filter by due date" : "Filtrar por data de vencimento",
    "Overdue" : "Vencidos",
    "Next 24 hours" : "Próximas 24 horas",
    "Next 7 days" : "Próximos 7 dias",
    "Next 30 days" : "Próximos 30 dias",
    "No due date" : "Sem data de vencimento",
    "Clear filter" : "Limpar filtro",
    "Hide archived cards" : "Ocultar cartões arquivados",
    "Show archived cards" : "Exibir cartões arquivados",
    "Toggle compact mode" : "Alternar para modo compacto",
    "Open details" : "Abrir detalhes",
    "Details" : "Detalhes",
    "Loading board" : "Carregando painel",
    "No lists available" : "Nenhuma lista disponível",
    "Create a new list to add cards to this board" : "Criar uma nova lista para adicionar cartões a este painel",
    "Board not found" : "Painel não encontrado",
    "Sharing" : "Compartilhando",
    "Tags" : "Etiquetas",
    "Deleted items" : "Itens excluídos",
    "Timeline" : "Linha do tempo",
    "Deleted lists" : "Listas excluídas",
    "Undo" : "Desfazer",
    "Deleted cards" : "Cartões excluídos",
    "Share board with a user, group or circle …" : "Compartilhar o painel com um usuário, grupo ou círculo...",
    "Searching for users, groups and circles …" : "Procurando usuários, grupos e círculos...",
    "No participants found" : "Nenhum participante encontrado",
    "Board owner" : "Proprietário do painel",
    "(Group)" : "(Grupo)",
    "(Circle)" : "(Círculo)",
    "Can edit" : "Pode editar",
    "Can share" : "Pode compartilhar",
    "Can manage" : "Pode gerenciar",
    "Owner" : "Proprietário",
    "Delete" : "Excluir",
    "Failed to create share with {displayName}" : "Falha ao criar compartilhamento com {displayName}",
    "Are you sure you want to transfer the board {title} to {user}?" : "Tem certeza de que deseja transferir o quadro {title} para {user}?",
    "Transfer the board." : "Transfira a reunião.",
    "Transfer" : "Transferir",
    "The board has been transferred to {user}" : "A quadro foi transferida para {user}",
    "Failed to transfer the board to {user}" : "Falha ao transferir o quadro para {user}",
    "Add a new list" : "Adicionar nova lista",
    "Archive all cards" : "Arquivar todos os cartões",
    "Delete list" : "Excluir lista",
    "Archive all cards in this list" : "Arquivar todos os cartões desta lista",
    "Add a new card" : "Adicionar um novo cartão",
    "Card name" : "Nome do cartão",
    "List deleted" : "Lista excluída",
    "Edit" : "Editar",
    "Add a new tag" : "Adicionar uma nova etiqueta",
    "title and color value must be provided" : "o título e o valor da cor devem ser fornecidos",
    "Board name" : "Nome do painel",
    "Members" : "Membros",
    "Upload new files" : "Enviar novos arquivos",
    "Share from Files" : "Compartilhar de Arquivos",
    "Pending share" : "Compartilhamento pendente",
    "Add this attachment" : "Adicionar este anexo",
    "Show in Files" : "Mostrar em Arquivos",
    "Download" : "Baixar",
    "Remove attachment" : "Remover anexo",
    "Delete Attachment" : "Excluir Anexo",
    "Restore Attachment" : "Restaurar Anexo",
    "File to share" : "Arquivo a compartilhar",
    "Invalid path selected" : "Caminho inválido selecionado",
    "Open in sidebar view" : "Abrir em visualização da barra lateral",
    "Open in bigger view" : "Abrir em  visualização ampliada",
    "Attachments" : "Anexos",
    "Comments" : "Comentários",
    "Modified" : "Modificado",
    "Created" : "Criado",
    "The title cannot be empty." : "O título não pode ficar em branco.",
    "No comments yet. Begin the discussion!" : "Nenhum comentário ainda. Inicie a conversa!",
    "Failed to load comments" : "Falha ao carregar comentários",
    "Assign a tag to this card…" : "Atribuir uma etiqueta a este cartão...",
    "Assign to users" : "Atribuir a usuários",
    "Assign to users/groups/circles" : "Atribuir a usuários/grupos/círculos",
    "Assign a user to this card…" : "Atribuir um usuário a este cartão...",
    "Due date" : "Data de vencimento",
    "Set a due date" : "Definir uma data de finalização",
    "Remove due date" : "Remover data de vencimento",
    "Select Date" : "Selecionar Data",
    "Today" : "Hoje",
    "Tomorrow" : "Amanhã",
    "Next week" : "Próxima semana",
    "Next month" : "Próximo mês",
    "Save" : "Salvar",
    "The comment cannot be empty." : "O comentário não pode zer vazio.",
    "The comment cannot be longer than 1000 characters." : "O comentário não pode ter mais que 1000 caracteres.",
    "In reply to" : "Em resposta para",
    "Cancel reply" : "Cancelar resposta",
    "Reply" : "Responder",
    "Update" : "Atualizar",
    "Description" : "Descrição",
    "(Unsaved)" : "(Não salvo)",
    "(Saving…)" : "(Salvando...)",
    "Formatting help" : "Formatando ajuda",
    "Edit description" : "Editar descrição",
    "View description" : "Exibir descrição",
    "Add Attachment" : "Adicionar anexo",
    "Write a description …" : "Escreva uma descrição...",
    "Choose attachment" : "Escolher anexo",
    "(group)" : "(grupo)",
    "Todo items" : "Itens para fazer",
    "{count} comments, {unread} unread" : "{count} comentários, {unread} não lidos",
    "Edit card title" : "Editar título do cartão",
    "Assign to me" : "Atribuir a mim",
    "Unassign myself" : "Desatribuir-me",
    "Move card" : "Mover cartão",
    "Unarchive card" : "Desarquivar cartão",
    "Archive card" : "Arquivar cartão",
    "Delete card" : "Excluir cartão",
    "Move card to another board" : "Mover o cartão para outro painel",
    "List is empty" : "A Lista está vazia",
    "Card deleted" : "Cartão excluído",
    "seconds ago" : "segundos atrás",
    "All boards" : "Todos os painéis",
    "Archived boards" : "Painéis arquivados",
    "Shared with you" : "Compartilhado com você",
    "Deck settings" : "Configurações do Deck",
    "Use bigger card view" : "Use uma exibição de cartão maior",
    "Show boards in calendar/tasks" : "Mostrar painéis em calendários/tarefas",
    "Limit deck usage of groups" : "Limitar o uso de grupos no deck",
    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Limitar o Deck impedirá que usuários que não fazem parte desses grupos criem seus próprios painéis. Os usuários ainda poderão trabalhar em pastas que foram compartilhadas com eles.",
    "Board details" : "Detalhes do painel",
    "Edit board" : "Editar painel",
    "Clone board" : "Clonar painel",
    "Unarchive board" : "Desarquivar painel",
    "Archive board" : "Arquivar painel",
    "Turn on due date reminders" : "Ativar lembretes de vencimento",
    "Turn off due date reminders" : "Desativar lembretes de vencimento",
    "Due date reminders" : "Lembretes de vencimento",
    "All cards" : "Todos os cartões",
    "Assigned cards" : "Cartões atribuídos",
    "No notifications" : "Sem notificações",
    "Delete board" : "Excluir painel",
    "Board {0} deleted" : "Painel {0} excluído",
    "Only assigned cards" : "Apenas cartões atribuídos",
    "No reminder" : "Nenhum lembrete",
    "An error occurred" : "Ocorreu um erro",
    "Are you sure you want to delete the board {title}? This will delete all the data of this board including archived cards." : "Tem certeza de que deseja excluir o quadro {title}? Isso excluirá todos os dados deste quadro, incluindo cartões arquivados.",
    "Delete the board?" : "Excluir o painel?",
    "Loading filtered view" : "Carregando exibição filtrada",
    "No due" : "Sem vencimento",
    "Search for {searchQuery} in all boards" : "Pesquisar por {searchQuery} em todos os painéis",
    "No results found" : "Nenhum resultado encontrado",
    "{stack} in {board}" : "{stack} de {board}",
    "Click to expand description" : "Clique para expandir a descrição",
    "* Created on {created}\n* Last modified on {lastMod}\n* {nbAttachments} attachments\n* {nbComments} comments" : "* Criado em {created}\n* Última modificação em {lastMod}\n* {nbAttachments} anexos\n* {nbComments} comentários",
    "{nbCards} cards" : "{nbCards} cartões",
    "No upcoming cards" : "Não há mais cartões",
    "upcoming cards" : "próximos cartões",
    "Due on {date}" : "Vencimento em {date}",
    "Link to a board" : "Linkar a um painel",
    "Link to a card" : "Vincular a um cartão",
    "Create a card" : "Criar um cartão",
    "Message from {author} in {conversationName}" : "Mensagem de {author} em {conversationName}",
    "Something went wrong" : "Algo deu errado",
    "Failed to upload {name}" : "Falha ao enviar {name}",
    "Maximum file size of {size} exceeded" : "Excedeu o tamanho máximo de arquivo de {size}",
    "Error creating the share" : "Erro ao criar o compartilhamento",
    "Share with a Deck card" : "Compartilhar com um cartão Deck",
    "Share {file} with a Deck card" : "Compartilhar {file} com um cartão Deck",
    "Share" : "Compartilhar",
    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Deck é uma ferramenta de organização de estilo kanban destinada ao planejamento pessoal e organização para equipes integradas com o Nextcloud.\n\n\n- 📥 Adicione suas tarefas aos cartões e coloque-os em ordem\n- 📄 Insira notas adicionais em markdown\n- 🔖 Atribua etiquetas para melhorar a organização\n- 👥 Compartilhe com sua equipe, amigos ou familiares\n- 📎 Anexe arquivos e incorpore-os em sua descrição no markdown\n- 💬 Discuta com sua equipe usando os comentários\n- ⚡ Acompanhe as alterações no fluxo de atividades\n- 🚀 Mantenha seu projeto organizado",
    "Are you sure you want to transfer the board {title} for {user} ?" : "Tem certeza de que deseja transferir o quadro {title} para {user}?",
    "Transfer the board for {user} successfully" : "Transferida a reunião para {user} com sucesso",
    "Failed to transfer the board for {user}" : "Falha ao transferir a reunião para {user}",
    "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "Deseja realmente excluir o painel {title}? Isto excluirá todos os dados deste painel.",
    "This week" : "Esta semana",
    "Are you sure you want to transfer the board {title} for {user}?" : "Tem certeza de que deseja transferir o quadro {title} para {user}?"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
