OC.L10N.register(
    "deck",
    {
    "Personal" : "ส่วนตัว",
    "copy" : "คัดลอก",
    "Done" : "Done",
    "The file was uploaded" : "ไฟล์อัปโหลดแล้ว",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "ขนาดไฟล์ที่อัปโหลดมีขนาดเกินค่า upload_max_filesize ที่ระบุไว้ใน php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "ไฟล์ที่อัพโหลดมีขนาดไฟล์ใหญ่เกินจำนวนที่กำหนดไว้ในคำสั่ง MAX_FILE_SIZE ที่ถูกระบุไว้ในรูปแบบของ HTML",
    "The file was only partially uploaded" : "ไฟล์ถูกอัปโหลดเพียงบางส่วน",
    "No file was uploaded" : "ไม่มีไฟล์ที่ถูกอัพโหลด",
    "Missing a temporary folder" : "โฟลเดอร์ชั่วคราวเกิดการสูญหาย",
    "Could not write file to disk" : "ไม่สามารถเขียนไฟล์ลงดิสก์",
    "A PHP extension stopped the file upload" : "ส่วนขยาย PHP ได้หยุดการอัปโหลดไฟล์",
    "Invalid date, date format must be YYYY-MM-DD" : "วันที่ไม่ถูกต้อง รูปแบบวันที่จะต้องเป็น YYYY-MM-DD",
    "Cancel" : "ยกเลิก",
    "Close" : "ปิด",
    "File already exists" : "ไฟล์นี้มีแล้ว",
    "Details" : "รายละเอียด",
    "Sharing" : "แชร์ข้อมูล",
    "Tags" : "ป้ายกำกับ",
    "Undo" : "เลิกทำ",
    "Can edit" : "Can edit",
    "Can share" : "Can share",
    "Owner" : "เจ้าของ",
    "Delete" : "ลบ",
    "Transfer" : "โอนย้าย",
    "Edit" : "แก้ไข",
    "Download" : "ดาวน์โหลด",
    "Invalid path selected" : "เลือกเส้นทางไม่ถูกต้อง",
    "Comments" : "ความคิดเห็น",
    "Modified" : "แก้ไขเมื่อ",
    "Due date" : "วันที่ครบกำหนด",
    "Today" : "วันนี้",
    "Tomorrow" : "วันพรุ่งนี้",
    "Save" : "บันทึก",
    "Reply" : "ตอบกลับ",
    "Update" : "อัพเดท",
    "Description" : "รายละเอียด",
    "(group)" : "(กลุ่ม)",
    "seconds ago" : "วินาที ก่อนหน้านี้",
    "Shared with you" : "Shared with you",
    "An error occurred" : "เกิดข้อผิดพลาด",
    "Share" : "แชร์",
    "This week" : "สัปดาห์นี้"
},
"nplurals=1; plural=0;");
