OC.L10N.register(
    "deck",
    {
    "Personal" : "Şəxsi",
    "Done" : "Done",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Yüklənilən faylın həcmi HTML formasinda olan MAX_FILE_SIZE direktivində təyin dilmiş həcmi aşır.",
    "No file was uploaded" : "Heç bir fayl yüklənilmədi",
    "Missing a temporary folder" : "Müvəqqəti qovluq çatışmır",
    "Cancel" : "Dayandır",
    "Close" : "Bağla",
    "Details" : "Detallar",
    "Sharing" : "Paylaşılır",
    "Tags" : "Işarələr",
    "Can edit" : "Can edit",
    "Can share" : "Can share",
    "Owner" : "Owner",
    "Delete" : "Sil",
    "Edit" : "Dəyişiklik et",
    "Download" : "Yüklə",
    "Modified" : "Dəyişdirildi",
    "Today" : "Bu gün",
    "Tomorrow" : "Sabah",
    "Save" : "Saxla",
    "Reply" : "Cavab",
    "Update" : "Yenilənmə",
    "Description" : "Açıqlanma",
    "(group)" : "(qrup)",
    "seconds ago" : "saniyələr öncə",
    "Shared with you" : "Shared with you",
    "Share" : "Paylaş"
},
"nplurals=2; plural=(n != 1);");
