OC.L10N.register(
    "deck",
    {
    "You have created a new board {board}" : "Has creado el tablero nuevo {board}",
    "{user} has created a new board {board}" : "{user} ha creado el tablero nuevo {board}",
    "You have deleted the board {board}" : "Has eliminado el tablero {board}",
    "{user} has deleted the board {board}" : "{user} ha eliminado el tablero {board}",
    "You have restored the board {board}" : "Has restaurado el tablero {board}",
    "{user} has restored the board {board}" : "{user} ha restaurado el tablero {board}",
    "You have shared the board {board} with {acl}" : "Has compartido el tablero {board} con {acl}",
    "{user} has shared the board {board} with {acl}" : "{user} ha compartido el tablero {board} con {acl}",
    "You have removed {acl} from the board {board}" : "Has eliminado a {acl} del tablero {board}",
    "{user} has removed {acl} from the board {board}" : "{user} ha elimiando a {acl} del tablero {board}",
    "You have renamed the board {before} to {board}" : "Has renombrado el tablero {before} como {board}",
    "{user} has renamed the board {before} to {board}" : "{user} ha renombrado el tablero {before} como {board}",
    "You have archived the board {board}" : "Has archivado el tablero {board}",
    "{user} has archived the board {before}" : "{user} ha archivado el tablero {board}",
    "You have unarchived the board {board}" : "Has desarchivado el tablero {board}",
    "{user} has unarchived the board {before}" : "{user} ha desarchivado el tablero {before}",
    "You have created a new list {stack} on board {board}" : "Has creado una nueva lista {stack} del tablero {board}",
    "{user} has created a new list {stack} on board {board}" : "{user} ha creado una nueva lista {stack} del tablero {board}",
    "You have renamed list {before} to {stack} on board {board}" : "Has renombrado la lista {before} a {stack} del tablero {board}",
    "{user} has renamed list {before} to {stack} on board {board}" : "{user} ha renombrado la lista {before} a {stack} del tablero {board}",
    "A <strong>card description</strong> inside the Deck app has been changed" : "Una <strong>descripción de tarjeta</strong> dentro de la app Deck ha cambiado",
    "Deck" : "Deck",
    "Changes in the <strong>Deck app</strong>" : "Cambios en la <strong>app Deck</strong>",
    "Personal" : "Personal",
    "{user} has assigned the card {deck-card} on {deck-board} to you." : "{user} te ha asigando la tarjeta {deck-card} de {deck-board} a ti.",
    "The card {deck-card} on {deck-board} has reached its due date." : "La tarjeta {deck-card} en {deck-board} ha alcanzado su fecha de caducidad.",
    "{user} has mentioned you in a comment on {deck-card}." : "{user} te ha mencionado en un comentario de {deck-card}.",
    "{user} has shared {deck-board} with you." : "{user} ha compartido {deck-board} contigo.",
    "Finished" : "Terminado",
    "To review" : "Para revisar",
    "Action needed" : "Acción requerida",
    "Later" : "Después",
    "copy" : "copiar",
    "Done" : "Hecho",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "El archivo subido sobrepasa el valor MAX_FILE_SIZE especificada en el formulario HTML",
    "No file was uploaded" : "No se subió ningún archivo ",
    "Missing a temporary folder" : "Falta un directorio temporal",
    "Card not found" : "Tarjeta no encontrada",
    "Invalid date, date format must be YYYY-MM-DD" : "La fecha es inválida, favor de seguir el formato AAAA-MM-DD",
    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in Markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your Markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Deck es una herramienta de organización de estilo kanban dirigida a la planificación personal y la organización de proyectos para equipos integrados con Nextcloud.\n\n\n- 📥 Agrega tus tareas a las tarjetas y ordénalas.\n- 📄 Escriba notas adicionales\n- 🔖 Asignar etiquetas para una organización mejor\n- 👥 Comparte con tu equipo, amigos o familia.\n- 📎 Adjuntar archivos e incrustarlos en su descripción\n- 💬 Discuta con su equipo usando comentarios.\n- ⚡ Mantenga un registro de los cambios en el flujo de actividad\n- 🚀 Organiza tu proyecto",
    "Card details" : "Detalles de la tarjeta",
    "Add board" : "Nuevo Tablero",
    "Search by board title" : "Buscar por título de tablero",
    "Select board" : "Selecciona tablero",
    "Create a new card" : "Crear una nueva tarjeta",
    "Select a board" : "Selecciona un tablero",
    "Select a list" : "Seleccionar una lista",
    "Card title" : "Título de la tarjeta",
    "Cancel" : "Cancelar",
    "Creating the new card …" : "Creando una nueva tarjeta …",
    "Card \"{card}\" was added to \"{board}\"" : "La tarjeta \"{card}\" fue añadida a \"{board}\"",
    "Close" : "Cerrar",
    "Create card" : "Crear tarjeta",
    "Select a card" : "Seleccionar una tarjeta",
    "Next 24 hours" : "Próximas 24 horas",
    "Next 7 days" : "Próximos 7 días",
    "Next 30 days" : "Próximos 30 días",
    "No due date" : "Sin fecha de vencimiento",
    "Hide archived cards" : "Ocultar tarjetas archivadas",
    "Show archived cards" : "Mostrar tarjetas archivadas",
    "Details" : "Detalles",
    "Sharing" : "Compartiendo",
    "Tags" : "Etiquetas",
    "Undo" : "Deshacer",
    "Can edit" : "Puede editar",
    "Can share" : "Puede compartir",
    "Owner" : "Dueño",
    "Delete" : "Eliminar",
    "Edit" : "Editar",
    "Members" : "Miembros",
    "Download" : "Descargar",
    "Attachments" : "Adjuntos",
    "Comments" : "Comentarios",
    "Modified" : "Modificado",
    "Created" : "Creado",
    "Due date" : "Fecha de vencimiento",
    "Select Date" : "Seleccionar fecha",
    "Today" : "Hoy",
    "Tomorrow" : "Mañana",
    "Next week" : "Proxima semana",
    "Next month" : "Proximo mes",
    "Save" : "Guardar",
    "Reply" : "Responder",
    "Update" : "Actualizar",
    "Description" : "Descripción",
    "Formatting help" : "Ayuda de formato",
    "(group)" : "(grupo)",
    "seconds ago" : "segundos",
    "All boards" : "Todos los Tableros",
    "Shared with you" : "Compartido con usted",
    "Deck settings" : "Configuración del Tablero",
    "Limit deck usage of groups" : "Limitar el uso del Tablero a grupos",
    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Limitar Tableros impedirá que usuarios que no formen parte de esos grupos creen sus propios tableros. Los usuarios todavía podrán trabajar en tableros que hayan sido compartidos con ellos.",
    "Board details" : "Detalles del tablero",
    "Edit board" : "Editar Tablero",
    "Clone board" : "Clonar Tablero",
    "No notifications" : "No hay notificaciones",
    "Delete board" : "Eliminar Tablero",
    "An error occurred" : "Ocurrió un error",
    "No due" : "Sin finalizar",
    "Share with a Deck card" : "Compartir con una tarjeta del Tablero",
    "Share {file} with a Deck card" : "Compartir {file} con una tarjeta del Tablero",
    "Share" : "Compartir",
    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Deck es una herramienta de organización de estilo kanban dirigida a la planificación personal y la organización de proyectos para equipos integrados con Nextcloud.\n\n\n- 📥 Agrega tus tareas a las tarjetas y ordénalas.\n- 📄 Escriba notas adicionales\n- 🔖 Asignar etiquetas para una organización mejor\n- 👥 Comparte con tu equipo, amigos o familia.\n- 📎 Adjuntar archivos e incrustarlos en su descripción\n- 💬 Discuta con su equipo usando comentarios.\n- ⚡ Mantenga un registro de los cambios en el flujo de actividad\n- 🚀 Organiza tu proyecto",
    "This week" : "Esta semana"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
