OC.L10N.register(
    "deck",
    {
    "You have created a new board {board}" : "Du har oprettet en ny tavle {board}",
    "{user} has created a new board {board}" : "{user} har oprettet en ny tavle {board}",
    "You have deleted the board {board}" : "Du har slettet tavlen {board}",
    "{user} has deleted the board {board}" : "{user} har slettet tavlen {board}",
    "You have restored the board {board}" : "Du har genskabt tavlen {board}",
    "{user} has restored the board {board}" : "{user} har genskabt tablen {board}",
    "You have shared the board {board} with {acl}" : "Du har delt tavlen {board} med {acl}",
    "{user} has shared the board {board} with {acl}" : "{user}  har delt tavlen {board} med {acl}",
    "You have removed {acl} from the board {board}" : "Du har fjernet {acl} fra tavlen {board}",
    "{user} has removed {acl} from the board {board}" : "{user} har fjernet {acl} fra tavlen {board}",
    "You have renamed the board {before} to {board}" : "Du har omdøbt tavlen {before} til {board}",
    "{user} has renamed the board {before} to {board}" : "{suer} har omdøbt tavlen {before} til {board}",
    "You have archived the board {board}" : "Du har arkiveret tavlen {board}",
    "{user} has archived the board {before}" : "{user} har arkiveret tavlen {before}",
    "You have unarchived the board {board}" : "Du har genskabt tavlen {board}",
    "{user} has unarchived the board {before}" : "{user} har genskabt tavlen {before}",
    "You have created a new list {stack} on board {board}" : "Du har oprettet en ny liste {stack} på tavlen {board}",
    "{user} has created a new list {stack} on board {board}" : "{user} har oprettet en ny kolonne {stack} på tavlen {board}",
    "You have renamed list {before} to {stack} on board {board}" : "Du har omdøbt kolonnen {before} til {stack} på tavlen {board}",
    "{user} has renamed list {before} to {stack} on board {board}" : "{user} har omdøbt kolonnen{before} til {stack} på tavlen {board}",
    "You have deleted list {stack} on board {board}" : "Du har slettet kolonnen {stack} på tavlen {board}",
    "{user} has deleted list {stack} on board {board}" : "{user} har slettet kolonnen {stack} på tavlen {board}",
    "You have created card {card} in list {stack} on board {board}" : "Du har oprettet kortet {card} i kolonnen {stack} på tavlen {board}",
    "{user} has created card {card} in list {stack} on board {board}" : "{user} har oprettet kortet {card} i kolonnen {stack} på tavlen {board}",
    "You have deleted card {card} in list {stack} on board {board}" : "Du har slettet kortet {card} i listen {stack} på tavlen {board}",
    "{user} has deleted card {card} in list {stack} on board {board}" : "{user} har slettet kortet {card} i listen {stack} på tavlen {board}",
    "You have renamed the card {before} to {card}" : "Du har omdøbt kortet {before} til {card}",
    "{user} has renamed the card {before} to {card}" : "{user} har omdøbt kortet {before} til {card}",
    "Deck" : "Deck",
    "Upcoming cards" : "Kommende kort",
    "Load more" : "Hent flere",
    "Personal" : "Personligt",
    "The card \"%s\" on \"%s\" has been assigned to you by %s." : "Kortet \"%s\" på \"%s\" er blevet tildelt dig af %s.",
    "The card \"%s\" on \"%s\" has reached its due date." : "Kortet \"%s\" på \"%s\" har nået sin forfaldsdato.",
    "%s has mentioned you in a comment on \"%s\"." : " %s har nævnt dig i en kommentar på \"%s\".",
    "The board \"%s\" has been shared with you by %s." : "Tavlen \"%s\" er blevet delt med dig af %s.",
    "No data was provided to create an attachment." : "Ingen data blev givet som kunne vedhæftes",
    "Finished" : "Færdiggjort",
    "To review" : "Til gennemgang",
    "Action needed" : "Handling påkrævet",
    "Later" : "Senere",
    "copy" : "kopiér",
    "To do" : "To do",
    "Doing" : "Igang",
    "Done" : "Afsluttet",
    "Example Task 3" : "Eksempel opgave 3",
    "Example Task 2" : "Eksempel opgave 2",
    "Example Task 1" : "Eksempel opgave 1",
    "The file was uploaded" : "Filen blev uploadet",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Den uploadede fil overstiger upload_max_filesize direktivet i php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Den uploadede fil overstiger MAX_FILE_SIZE indstilingen, som specificeret i HTML formularen",
    "The file was only partially uploaded" : "Filen blev kun delvist uploadet.",
    "No file was uploaded" : "Ingen fil uploadet",
    "Missing a temporary folder" : "Manglende midlertidig mappe.",
    "Could not write file to disk" : "Kunne ikke gemme filen",
    "A PHP extension stopped the file upload" : "En PHP udvidelse stoppede fil uploaden.",
    "No file uploaded or file size exceeds maximum of %s" : "Ingen fil blev uploadet eller fil størrelsen er større end det maksimale: %s.",
    "Card not found" : "Kort ikke fundet.",
    "Path is already shared with this card" : "Stien er allerede delt med dette kort.",
    "Invalid date, date format must be YYYY-MM-DD" : "Ikke gyldig dato - dato formatet skal være YYYY-MM-DD",
    "Personal planning and team project organization" : "Personlig planlægning og organisering af team projekter",
    "Card details" : "Kort detaljer",
    "Add board" : "Tilføj tavle",
    "Select the board to link to a project" : "Vælg en tavle at linke til et projekt",
    "Search by board title" : "Søg efter tavle titel",
    "Select board" : "Vælg tavle",
    "Select a board" : "Vælg én tavle",
    "Select a list" : "Vælg en kolonne",
    "Cancel" : "Annullér",
    "Close" : "Luk",
    "Create card" : "Opret kort",
    "Select a card" : "Vælg et kort",
    "Select the card to link to a project" : "Vælg et kort at linke til et projekt",
    "Link to card" : "Link til kort",
    "File already exists" : "Filen findes allerede",
    "A file with the name {filename} already exists." : "En fil med navnet {filename} already exists.",
    "Do you want to overwrite it?" : "Vil du overskrive?",
    "Overwrite file" : "Overskriv fil",
    "Keep existing file" : "Behold den eksisterende fil",
    "This board is read only" : "Denne tavle er skrivebeskyttet",
    "Drop your files to upload" : "Slip dine filer for at uploade",
    "Add card" : "Tilføj kort",
    "Archived cards" : "Arkiverede kort",
    "Add list" : "Tilføj kolonne",
    "List name" : "Kolonne navn",
    "Apply filter" : "Aktivér filter",
    "Filter by tag" : "Filtrer vha. mærkat",
    "Filter by assigned user" : "Filtrer vha. tildelt bruger",
    "Unassigned" : "Ikke tildelt",
    "Filter by due date" : "Filtrer vha. forfaldsdato",
    "Overdue" : "Overskredet",
    "Next 24 hours" : "De næste 24 timer",
    "Next 7 days" : "De næste 7 dage",
    "Next 30 days" : "De næste 30 dage",
    "No due date" : "Ingen forfaldsdato",
    "Clear filter" : "Ryd filter",
    "Hide archived cards" : "Skjul arkiverede kort",
    "Show archived cards" : "Vis arkiverede kort",
    "Toggle compact mode" : "Slå kompakt tilstand til/fra",
    "Open details" : "Mere information",
    "Details" : "Detaljer",
    "Loading board" : "Indlæser tavle",
    "No lists available" : "Ingen kolonner tilgængelige",
    "Create a new list to add cards to this board" : "Opret en ny kolonne for at tilføje kort til denne tavle ",
    "Board not found" : "Tavle ikke fundet.",
    "Sharing" : "Deling",
    "Tags" : "Mærkat",
    "Deleted items" : "Slettede objekter",
    "Timeline" : "Tidslinje",
    "Deleted lists" : "Slettede kolonner",
    "Undo" : "Fortryd",
    "Deleted cards" : "Sletttede kort",
    "Share board with a user, group or circle …" : "Del tavle med en bruger, gruppe eller cirkel ...",
    "Searching for users, groups and circles …" : "Leder efter brugere, grupper og cirkler ...",
    "No participants found" : "Ingen deltagere fundet",
    "Board owner" : "Ejer af tavlen",
    "(Group)" : "(Gruppe)",
    "(Circle)" : "(Cirkel)",
    "Can edit" : "Kan redigere",
    "Can share" : "Kan dele",
    "Can manage" : "Kan administrere",
    "Owner" : "Ejer",
    "Delete" : "Slet",
    "Failed to create share with {displayName}" : "Oprettelse af delt drev med {displayName} fejlede",
    "Transfer" : "Overførsel",
    "Add a new list" : "Tilføj en ny kolonne",
    "Archive all cards" : "Arkivér alle kort",
    "Delete list" : "Slet liste",
    "Archive all cards in this list" : "Arkivér alle kort i denne kolonne",
    "Add a new card" : "Tilføj et nyt kort",
    "Card name" : "Kort navn",
    "List deleted" : "Kolonne slettet",
    "Edit" : "Redigér",
    "Add a new tag" : "Opret et nyt mærkat",
    "title and color value must be provided" : "Titel og farve skal angives.",
    "Board name" : "Tavle navn",
    "Members" : "Medlemmer",
    "Upload new files" : "Upload nye filer",
    "Share from Files" : "Del fra Filer",
    "Add this attachment" : "Tilføj denne vedhæftning",
    "Show in Files" : "Vis i Filer",
    "Download" : "Download",
    "Delete Attachment" : "Slet vedhæftning",
    "Restore Attachment" : "Genskab vedhæftning",
    "File to share" : "Vælg fil til deling",
    "Invalid path selected" : "Ugyldig sti valgt.",
    "Open in sidebar view" : "Åben i sidekolonne",
    "Open in bigger view" : "Åben i større visning",
    "Attachments" : "Vedhæftede filer",
    "Comments" : "Kommentarer",
    "Modified" : "Ændret",
    "Created" : "Oprettet",
    "The title cannot be empty." : "Titlen kan ikke være tom",
    "No comments yet. Begin the discussion!" : "Ingen kommentarer endnu. Begynd diskussionen!",
    "Assign a tag to this card…" : "Tilføj et mærkat til dette kort ...",
    "Assign to users" : "Tildel til brugere",
    "Assign to users/groups/circles" : "Tildel til brugere/grupper/cirkler",
    "Assign a user to this card…" : "Tildel en bruger til dette kort",
    "Due date" : "Forfaldsdato",
    "Set a due date" : "Sæt en forfaldsdato",
    "Remove due date" : "Fjern forfaldsdato",
    "Select Date" : "Vælg dato",
    "Today" : "I dag",
    "Tomorrow" : "I morgen",
    "Next week" : "Næste uge",
    "Next month" : "Næste måned",
    "Save" : "Gem",
    "The comment cannot be empty." : "Kommentaren kan ikke være tom.",
    "The comment cannot be longer than 1000 characters." : "Kommentaren kan ikke være længere end 1000 tegn.",
    "In reply to" : "som svar til",
    "Reply" : "Besvar",
    "Update" : "Opdatér",
    "Description" : "Beskrivelse",
    "(Unsaved)" : "(Ikke gemt)",
    "(Saving…)" : "(Gemmer...)",
    "Formatting help" : "Hjælp til formatering",
    "Edit description" : "Redigér beskrivelse",
    "View description" : "Se beskrivelse",
    "Add Attachment" : "Tilføj vedhæftning",
    "Write a description …" : "Tilføj en beskrivelse...",
    "Choose attachment" : "Vælg en vedhæftning",
    "(group)" : "(gruppe)",
    "Assign to me" : "Tildel til mig",
    "Unassign myself" : "Fjern mig selv",
    "Move card" : "Flyt kort",
    "Unarchive card" : "Gen-aktivér kort",
    "Archive card" : "Arkivér kort",
    "Delete card" : "Slet kort",
    "Move card to another board" : "Flyt kort til en anden tavle",
    "Card deleted" : "Kort slettet",
    "seconds ago" : "sekunder siden",
    "All boards" : "Alle tavler",
    "Archived boards" : "Arkiverede lister",
    "Shared with you" : "Shared with you",
    "Use bigger card view" : "Brug større kort visning",
    "Show boards in calendar/tasks" : "Vis tavler i kalender/opgaver",
    "Limit deck usage of groups" : "Begræns Deck brug til grupper",
    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Begrænsning af Deck vil blokere brugere som ikke er en del af de valgte grupper fra at oprette deres egne tavler. Brugere vil stadig kunne arbejde på tavler der er blevet delt med dem. ",
    "Board details" : "Liste detaljer",
    "Edit board" : "Rediger liste",
    "Clone board" : "Klon tavle",
    "Unarchive board" : "Gen-aktivér tavle",
    "Archive board" : "Arkivér tavle",
    "Turn on due date reminders" : "Aktivér påmindelser om forfaldsdatoer",
    "Turn off due date reminders" : "Slå påmindelser om forfaldsdatoer fra",
    "Due date reminders" : "Påmindelser om forfaldsdatoer",
    "All cards" : "Alle kort",
    "Assigned cards" : "Tildelte kort",
    "No notifications" : "Ingen notifikationer",
    "Delete board" : "Slet tavle",
    "Board {0} deleted" : "Tavle {0} er slettet",
    "Only assigned cards" : "Kun tildelte kort",
    "No reminder" : "Ingen påmindelse",
    "An error occurred" : "Der var en fejl",
    "Delete the board?" : "Slet tavlen?",
    "Loading filtered view" : "Indlæser filtreret visning",
    "No due" : "Ikke forfalden",
    "No upcoming cards" : "Ingen kommende kort",
    "upcoming cards" : "kommende kort",
    "Link to a board" : "Link til tavle",
    "Link to a card" : "Link til et kort",
    "Message from {author} in {conversationName}" : "Besked fra {author} i {conversationName}",
    "Something went wrong" : "Noget gik galt",
    "Failed to upload {name}" : "Kunne ikke uploade {name}",
    "Maximum file size of {size} exceeded" : "Maksimal fil størrelse {size} overskredet",
    "Error creating the share" : "Fejl ved skabelse af delt drev",
    "Share with a Deck card" : "Del med et Deck kort",
    "Share {file} with a Deck card" : "Del {file} med et Deck kort",
    "Share" : "Del",
    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Deck er et kanban inspireret organisations værktøj rettet mod personlig planlægning og projekt organisering for teams integreret med Nextcloud.\n\n\n- 📥 Tilføj dine opgaver til kort og organisér dem\n- 📄 Tilføj noter til dine opgaver i markdown\n- 🔖 Tilføj mærkater for endnu bedre organisering\n- 👥 Del med dit team, dine venner eller familie\n- 📎 Vedhæft filer og indfør dem i din markdown beskrivelse\n- 💬 Diskutér med dit team ved hjælp af kommentarer\n- ⚡ Hold øje med ændringer i aktivitets strømmen\n- 🚀 Få dit projekt organiseret!",
    "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "Er du sikker på du vil slette tavlen {title}? Dette vil slette alt data på tavlen.",
    "This week" : "Denne uge"
},
"nplurals=2; plural=(n != 1);");
