OC.L10N.register(
    "deck",
    {
    "Personal" : "﻿ವೈಯಕ್ತಿಕ",
    "Done" : "Done",
    "No file was uploaded" : "ವರ್ಗಾವಣೆಗೆ ﻿ಯಾವುದೇ ಕಡತಗಳು ಕಂಡುಬಂದಿಲ್ಲ",
    "Missing a temporary folder" : "ತಾತ್ಕಾಲಿಕ ಕಡತಕೋಶ ದೊರೆಕುತ್ತಿಲ್ಲ",
    "Cancel" : "﻿ರದ್ದು",
    "Close" : "ಮುಚ್ಚು",
    "Sharing" : "﻿ಹಂಚಿಕೆ",
    "Can edit" : "Can edit",
    "Can share" : "Can share",
    "Owner" : "Owner",
    "Delete" : "﻿ಅಳಿಸಿ",
    "Edit" : "ಸಂಪಾದಿಸು",
    "Download" : "ಪ್ರತಿಯನ್ನು ಸ್ಥಳೀಯವಾಗಿ ಉಳಿಸಿಕೊಳ್ಳಿ",
    "Modified" : "﻿ಬದಲಾಯಿಸಿದ",
    "Today" : "Today",
    "Save" : "﻿ಉಳಿಸಿ",
    "Shared with you" : "Shared with you",
    "Share" : "﻿ಹಂಚಿಕೊಳ್ಳಿ"
},
"nplurals=2; plural=(n > 1);");
