OC.L10N.register(
    "deck",
    {
    "Personal" : "ব্যক্তিগত",
    "Done" : "Done",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "আপলোড করা ফাইলটি  HTML  ফর্মে উল্লিখিত MAX_FILE_SIZE নির্ধারিত ফাইলের সর্বোচ্চ আকার  অতিক্রম করতে চলেছে ",
    "No file was uploaded" : "কোন ফাইল আপলোড করা হয় নি",
    "Missing a temporary folder" : "অস্থায়ী ফোল্ডারটি হারানো গিয়েছে",
    "Cancel" : "বাতির",
    "Close" : "বন্ধ",
    "Details" : "বিসতারিত",
    "Sharing" : "ভাগাভাগিরত",
    "Tags" : "ট্যাগ",
    "Can edit" : "Can edit",
    "Can share" : "Can share",
    "Owner" : "Owner",
    "Delete" : "মুছে",
    "Edit" : "সম্পাদনা",
    "Download" : "ডাউনলোড",
    "Modified" : "পরিবর্তিত",
    "Today" : "আজ",
    "Tomorrow" : "আগামীকাল",
    "Save" : "সংরক্ষণ",
    "Reply" : "জবাব",
    "Update" : "পরিবর্ধন",
    "Description" : "বিবরণ",
    "(group)" : "(গোষ্ঠি)",
    "seconds ago" : "সেকেন্ড পূর্বে",
    "Shared with you" : "Shared with you",
    "Share" : "ভাগাভাগি কর"
},
"nplurals=2; plural=(n != 1);");
