OC.L10N.register(
    "deck",
    {
    "You have created a new board {board}" : "Du har skapat en ny tavla {board}",
    "{user} has created a new board {board}" : "{user} har skapat en ny tavla {board}",
    "You have deleted the board {board}" : "Du har raderat tavlan {board}",
    "{user} has deleted the board {board}" : "{user} har raderat tavlan {board}",
    "You have restored the board {board}" : "Du har återställt tavlan {board}",
    "{user} has restored the board {board}" : "{user} har återställt tavlan {board}",
    "You have shared the board {board} with {acl}" : "Du har delat tavlan {board} med {acl}",
    "{user} has shared the board {board} with {acl}" : "{user} har delat tavlan {board} med {acl}",
    "You have removed {acl} from the board {board}" : "Du har raderat {acl} från tavlan {board}",
    "{user} has removed {acl} from the board {board}" : "{user} har raderat {acl} från tavlan {board}",
    "You have renamed the board {before} to {board}" : "Du har bytt namn på tavlan {before} till {board}",
    "{user} has renamed the board {before} to {board}" : "{user} har bytt namn på tavlan {before} till {board}",
    "You have archived the board {board}" : "Du har arkiverat tavlan {board}",
    "{user} has archived the board {before}" : "{user} har arkiverat tavlan {before}",
    "You have unarchived the board {board}" : "Du har avarkiverat tavlan {board}",
    "{user} has unarchived the board {before}" : "{user} har avarkiverat tavlan {before}",
    "You have created a new list {stack} on board {board}" : "Du har skapat en ny lista {stack} på tavlan {board}",
    "{user} has created a new list {stack} on board {board}" : "{user} har skapat en ny lista {stack} på tavlan {board}",
    "You have renamed list {before} to {stack} on board {board}" : "Du har bytt namn på listan {before} till {stack} på tavlan {board}",
    "{user} has renamed list {before} to {stack} on board {board}" : "{user} har bytt namn på listan {before} till {stack} på tavlan {board}",
    "You have deleted list {stack} on board {board}" : "Du har raderat listan {stack} på tavlan {board}",
    "{user} has deleted list {stack} on board {board}" : "{user} har raderat listan {stack} på tavlan {board}",
    "You have created card {card} in list {stack} on board {board}" : "Du har skapat kortet {card} i listan {stack} på tavlan {board}",
    "{user} has created card {card} in list {stack} on board {board}" : "{user} har skapat kortet {card} i listan {stack} på tavlan {board}",
    "You have deleted card {card} in list {stack} on board {board}" : "Du har raderat kortet {card} i listan {stack} på tavlan {board}",
    "{user} has deleted card {card} in list {stack} on board {board}" : "{user} har raderat kortet {card} i listan {stack} på tavlan {board}",
    "You have renamed the card {before} to {card}" : "Du har bytt namn på kortet {before} till {card}",
    "{user} has renamed the card {before} to {card}" : "{user} har bytt namn på kortet {before} till {card}",
    "You have added a description to card {card} in list {stack} on board {board}" : "Du har lagt till en beskrivning till kortet {card} i listan {stack} på tavlan {board}",
    "{user} has added a description to card {card} in list {stack} on board {board}" : "{user} har lagt till en beskrivning till kortet {card} i listan {stack} på tavlan {board}",
    "You have updated the description of card {card} in list {stack} on board {board}" : "Du har uppdaterat beskrivningen för kortet {card} i listan {stack} på tavlan {board}",
    "{user} has updated the description of the card {card} in list {stack} on board {board}" : "{user} har uppdaterat beskrivningen för kortet {card} i listan {stack} på tavlan {board}",
    "You have archived card {card} in list {stack} on board {board}" : "Du har arkiverat kortet {card} i listan {stack} på tavlan {board}",
    "{user} has archived card {card} in list {stack} on board {board}" : "{user} har arkiverat kortet {card} i listan {stack} på tavlan {board}",
    "You have unarchived card {card} in list {stack} on board {board}" : "Du har avarkiverat kortet {card} i listan {stack} på tavlan {board}",
    "{user} has unarchived card {card} in list {stack} on board {board}" : "{user} har avarkiverat kortet {card} i listan {stack} på tavlan {board}",
    "You have removed the due date of card {card}" : "Du har tagit bort förfallodatum för kortet {card}",
    "{user} has removed the due date of card {card}" : "{user} tagit bort förfallodatum för kortet {card}",
    "You have set the due date of card {card} to {after}" : "Du har satt förfallodatum för kortet {card} till {after}",
    "{user} has set the due date of card {card} to {after}" : "{user} har satt förfallodatum för kortet {card} till {after}",
    "You have updated the due date of card {card} to {after}" : "Du har uppdaterat förfallodatum för kortet {card} till {after}",
    "{user} has updated the due date of card {card} to {after}" : "{user} har uppdaterat förfallodatum för kortet {card} till {after}",
    "You have added the tag {label} to card {card} in list {stack} on board {board}" : "Du har lagt till taggen {label} till kortet {card} i listan {stack} på tavlan {board}",
    "{user} has added the tag {label} to card {card} in list {stack} on board {board}" : "{user} har lagt till taggen {label} till kortet {card} i listan {stack} på tavlan {board}",
    "You have removed the tag {label} from card {card} in list {stack} on board {board}" : "Du har raderat taggen {label} från kortet {card} i listan {stack} på tavlan {board}",
    "{user} has removed the tag {label} from card {card} in list {stack} on board {board}" : "{user} har raderat taggen {label} från kortet {card} i listan {stack} på tavlan {board}",
    "You have assigned {assigneduser} to card {card} on board {board}" : "Du har tilldelat {assigneduser} till kortet {card} på tavlan {board}",
    "{user} has assigned {assigneduser} to card {card} on board {board}" : "{user} har tilldelat {assigneduser} till kortet {card} på tavlan {board}",
    "You have unassigned {assigneduser} from card {card} on board {board}" : "Du har tagit bort tilldelningen för {assigneduser} från kortet {card} på tavlan {board}",
    "{user} has unassigned {assigneduser} from card {card} on board {board}" : "{user} har tagit bort tilldelningen för {assigneduser} från kortet {card} på tavlan {board}",
    "You have moved the card {card} from list {stackBefore} to {stack}" : "Du har flyttat kortet {card} från listan {stackBefore} till {stack}",
    "{user} has moved the card {card} from list {stackBefore} to {stack}" : "{user} har flyttat kortet {card} från listan {stackBefore} till {stack}",
    "You have added the attachment {attachment} to card {card}" : "Du har lagt till bilagan {attachment} till kortet {card}",
    "{user} has added the attachment {attachment} to card {card}" : "{user} har lagt till bilagan {attachment} till kortet {card}",
    "You have updated the attachment {attachment} on card {card}" : "Du har uppdaterat bilagan {attachment} på kortet {card}",
    "{user} has updated the attachment {attachment} on card {card}" : "{user} har uppdaterat bilagan {attachment} på kortet {card}",
    "You have deleted the attachment {attachment} from card {card}" : "Du har raderat bilagan {attachment} från kortet {card}",
    "{user} has deleted the attachment {attachment} from card {card}" : "{user} har raderat bilagan {attachment} från kortet {card}",
    "You have restored the attachment {attachment} to card {card}" : "Du har återställt bilagan {attachment} till kortet {card}",
    "{user} has restored the attachment {attachment} to card {card}" : "{user} har återställt bilagan {attachment} till kortet {card}",
    "You have commented on card {card}" : "Du har kommenterat på kortet {card}",
    "{user} has commented on card {card}" : "{user} har kommenterat på kortet {card}",
    "A <strong>card description</strong> inside the Deck app has been changed" : "En <strong>kortbeskrivning</strong> i Deck-appen har ändrats",
    "Deck" : "Deck",
    "Changes in the <strong>Deck app</strong>" : "Ändringar i <strong>Deck-appen</strong>",
    "A <strong>comment</strong> was created on a card" : "En <strong>kommentar</strong> skapades på ett kort",
    "Upcoming cards" : "Kommande kort",
    "Load more" : "Ladda mer",
    "Personal" : "Personlig",
    "The card \"%s\" on \"%s\" has been assigned to you by %s." : "Kortet \"%s\" på \"%s\" har tilldelats dig av %s.",
    "{user} has assigned the card {deck-card} on {deck-board} to you." : "{user} har tilldelat kortet {deck-card} från {deck-board} till dig.",
    "The card \"%s\" on \"%s\" has reached its due date." : "Kortet \"%s\" på \"%s\" har nått sitt slutdatum.",
    "The card {deck-card} on {deck-board} has reached its due date." : "Kortet {deck-card} från {deck-board} har nått sitt slutdatum.",
    "%s has mentioned you in a comment on \"%s\"." : "%s har nämnt dig i en kommentar på \"%s\".",
    "{user} has mentioned you in a comment on {deck-card}." : "{user} har nämnt dig i en kommentar i {deck-card}.",
    "The board \"%s\" has been shared with you by %s." : "Tavlan \"%s\" har delats med dig av %s.",
    "{user} has shared {deck-board} with you." : "{user} har delat {deck-board} med dig.",
    "Card comments" : "Kort kommentarer",
    "%s on %s" : "%s på %s",
    "No data was provided to create an attachment." : "Inga data lämnades för att skapa en bilaga.",
    "Finished" : "Slutförd",
    "To review" : "Att granska",
    "Action needed" : "Åtgärd behövs",
    "Later" : "Senare",
    "copy" : "kopiera",
    "To do" : "Att göra",
    "Doing" : "Gör",
    "Done" : "Klart",
    "Example Task 3" : "Exempeluppgift 3",
    "Example Task 2" : "Exempeluppgift 2",
    "Example Task 1" : "Exempeluppgift 1",
    "The file was uploaded" : "Filen laddades upp",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Den uppladdade filen överstiger direktivet upload_max_filesize i php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Den uppladdade filen överstiger MAX_FILE_SIZE-direktivet som specificerades i HTML-formuläret",
    "The file was only partially uploaded" : "Filen var endast delvis uppladdad",
    "No file was uploaded" : "Ingen fil laddades upp",
    "Missing a temporary folder" : "Saknas en tillfällig mapp",
    "Could not write file to disk" : "Kunde inte skriva fil till disk",
    "A PHP extension stopped the file upload" : "Ett PHP-tillägg stoppade filuppladdningen",
    "No file uploaded or file size exceeds maximum of %s" : "Ingen fil uppladdad eller filstorleken överstiger max %s",
    "This comment has more than %s characters.\nAdded as an attachment to the card with name %s.\nAccessible on URL: %s." : "Den här kommentaren har mer än %s tecken.\nTillagd som en bilaga till kortet men namnet %s.\nÅtkomlig via URL: %s.",
    "Card not found" : "Kortet hittades inte",
    "Path is already shared with this card" : "Sökvägen är redan delad med detta kort",
    "Invalid date, date format must be YYYY-MM-DD" : "Ogiltigt datum, måste anges: ÅÅÅÅ-MM-DD",
    "Personal planning and team project organization" : "Personlig planering och projekthantering för teams",
    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in Markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your Markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Deck är en kanban-liknande organiseringsverktyg för personlig planering samt projektorganisering för  arbetsgrupper integrerade med Nextcloud.\n\n\n- 📥 Lägg till uppgifter på kort och lägg de i ordning\n- 📄 Skriv anteckningar i Markdown\n- 🔖 Tilldela etiketter för bättre organisering\n- 👥 Dela med arbetsgruppen, vänner eller familj\n- 📎 Bifoga filer och bädda in dem i Markdown-anteckningarna\n- 💬 Diskutera med arbetsgruppen med hjälp av kommentarer\n- ⚡ Håll koll på ändringar i aktivitetsflödet\n- 🚀 Få struktur på dina projekt",
    "Card details" : "Kortdetaljer",
    "Add board" : "Lägg till tavla",
    "Select the board to link to a project" : "Välj tavla att länka till ett projekt",
    "Search by board title" : "Sök efter namn på tavla",
    "Select board" : "Välj tavla",
    "Create a new card" : "Skapa ett nytt kort",
    "Select a board" : "Välj en tavla",
    "Select a list" : "Välj en lista",
    "Card title" : "Kort-titel",
    "Cancel" : "Avbryt",
    "Creating the new card …" : "Skapar det nya kortet ...",
    "Card \"{card}\" was added to \"{board}\"" : "kortet \"{card}\" lades till i \"{board}\"",
    "Open card" : "Öppna kort",
    "Close" : "Stäng",
    "Create card" : "Skapa kort",
    "Select a card" : "Välj ett kort",
    "Select the card to link to a project" : "Välj kort att länka till ett projekt",
    "Link to card" : "Länka till kort",
    "File already exists" : "Filen finns redan",
    "A file with the name {filename} already exists." : "En fil med namnet {filename} finns redan.",
    "Do you want to overwrite it?" : "Vill du skriva över det?",
    "Overwrite file" : "Skriv över filen",
    "Keep existing file" : "Behåll nuvarande fil",
    "This board is read only" : "Denna tavla är skrivskyddad",
    "Drop your files to upload" : "Släpp dina filer för att ladda upp",
    "Add card" : "Lägg till kort",
    "Archived cards" : "Arkiverade kort",
    "Add list" : "Lägg till lista...",
    "List name" : "Namn på lista",
    "Active filters" : "Aktiva filter",
    "Apply filter" : "Tillämpa filter",
    "Filter by tag" : "Filtrera efter tagg",
    "Filter by assigned user" : "Filtrera efter tilldelad användare",
    "Unassigned" : "Ej tilldelad",
    "Filter by due date" : "Filtrera efter förfallodatum",
    "Overdue" : "Förfallen",
    "Next 24 hours" : "Nästa 24 timmar",
    "Next 7 days" : "Nästa 7 dagar",
    "Next 30 days" : "Nästa 30 dagar",
    "No due date" : "Inget slutdatum",
    "Clear filter" : "Rensa filter",
    "Hide archived cards" : "Göm arkiverade kort",
    "Show archived cards" : "Visa arkiverade kort",
    "Toggle compact mode" : "Växla kompakt läge",
    "Open details" : "Öppna detaljer",
    "Details" : "Detaljer",
    "Loading board" : "Läser in tavla",
    "No lists available" : "Inga listor tillgängliga",
    "Create a new list to add cards to this board" : "Skapa en ny lista för att lägga till kort på denna tavla",
    "Board not found" : "Tavlan hittades inte",
    "Sharing" : "Delning",
    "Tags" : "Taggar",
    "Deleted items" : "Borttagna poster",
    "Timeline" : "Tidslinje",
    "Deleted lists" : "Borttagna listor",
    "Undo" : "Ångra",
    "Deleted cards" : "Ta bort kort",
    "Share board with a user, group or circle …" : "Dela en tavla med en användare, grupp eller cirkel ...",
    "Searching for users, groups and circles …" : "Söker efter användare, grupper och cirklar …",
    "No participants found" : "Inga deltagare hittades",
    "Board owner" : "Tavlans ägare",
    "(Group)" : "(Grupp)",
    "(Circle)" : "(Cirkel)",
    "Can edit" : "Kan redigera",
    "Can share" : "Kan dela",
    "Can manage" : "Kan hanter",
    "Owner" : "Ägare",
    "Delete" : "Ta bort",
    "Failed to create share with {displayName}" : "Kunde inte skapa delning med {displayName}",
    "Are you sure you want to transfer the board {title} to {user}?" : "Är du säker att du vill överföra tavlan {title} till {user}?",
    "Transfer the board." : "Överför tavlan.",
    "Transfer" : "Överför",
    "The board has been transferred to {user}" : "Tavlan har överförts till {user}",
    "Failed to transfer the board to {user}" : "Kunde inte överföra tavlan till {user}",
    "Add a new list" : "Lägg till en ny lista",
    "Archive all cards" : "Arkivera alla kort",
    "Unarchive all cards" : "Ta ut alla kort ur arkivet",
    "Delete list" : "Ta bort lista",
    "Archive all cards in this list" : "Arkivera alla kort i denna lista",
    "Unarchive all cards in this list" : "Ta ut alla kort i denna lista ur arkivet",
    "Add a new card" : "Lägg till ett nytt kort",
    "Card name" : "Kortets namn",
    "List deleted" : "Listan har raderats",
    "Edit" : "Redigera",
    "Add a new tag" : "Lägg till en ny tagg",
    "title and color value must be provided" : "titel och färg måste anges",
    "Board name" : "Tavlans namn",
    "Members" : "Medlemmar",
    "Upload new files" : "Ladda upp nya filer",
    "Share from Files" : "Dela från Filer",
    "Pending share" : "Väntande delning",
    "Add this attachment" : "Lägg till denna bilaga",
    "Show in Files" : "Visa i Filer",
    "Download" : "Ladda ner",
    "Remove attachment" : "Ta bort bilaga",
    "Delete Attachment" : "Ta bort bilaga",
    "Restore Attachment" : "Återställ bilaga",
    "File to share" : "Fil att dela",
    "Invalid path selected" : "Ogiltig sökväg vald",
    "Open in sidebar view" : "Öppna i sidofältet",
    "Open in bigger view" : "Öppna i större vy",
    "Attachments" : "Bilagor",
    "Comments" : "Kommentarer",
    "Modified" : "Ändrad",
    "Created" : "Skapat",
    "The title cannot be empty." : "Titeln får inte lämnas tom.",
    "No comments yet. Begin the discussion!" : "Inga kommentarer än. Börja diskussionen!",
    "Failed to load comments" : "Kunde inte ladda kommentarerna.",
    "Assign a tag to this card…" : "Tilldela en tagg till det här kortet ...",
    "Assign to users" : "Tilldela till användare",
    "Assign to users/groups/circles" : "Tilldela till användare/grupper/cirklar",
    "Assign a user to this card…" : "Tilldela en användare till det här kortet ...",
    "Due date" : "Slutdatum",
    "Set a due date" : "Sätt ett slutdatum",
    "Remove due date" : "Ta bort slutdatum",
    "Select Date" : "Välj datum",
    "Today" : "Idag",
    "Tomorrow" : "Imorgon",
    "Next week" : "Nästa vecka",
    "Next month" : "Nästa månad",
    "Save" : "Spara",
    "The comment cannot be empty." : "Kommentaren kan inte vara tom.",
    "The comment cannot be longer than 1000 characters." : "Kommentaren kan inte vara längre än 1000 tecken.",
    "In reply to" : "Som svar på",
    "Cancel reply" : "Avbryt svar",
    "Reply" : "Svara",
    "Update" : "Uppdatera",
    "Description" : "Beskrivning",
    "(Unsaved)" : "(Inte sparad)",
    "(Saving…)" : "(Sparar…)",
    "Formatting help" : "Formatteringshjälp",
    "Edit description" : "Ändra beskrivning",
    "View description" : "Visa beskrivning",
    "Add Attachment" : "Lägg till bilaga",
    "Write a description …" : "Ange en beskrivning ...",
    "Choose attachment" : "Välj bilaga",
    "(group)" : " (grupp)",
    "Todo items" : "Todo saker",
    "{count} comments, {unread} unread" : "{count} kommentarer, {unread} olästa",
    "Edit card title" : "Ändra korttitel",
    "Assign to me" : "Tilldela till mig",
    "Unassign myself" : "Ta bort från mig själv",
    "Move card" : "Flytta kort",
    "Unarchive card" : "Avarkivera kort",
    "Archive card" : "Arkivera kort",
    "Delete card" : "Ta bort kort",
    "Move card to another board" : "Flytta kort till en annan tavla",
    "List is empty" : "Listan är tom",
    "Card deleted" : "Kortet har raderats",
    "seconds ago" : "sekunder sedan",
    "All boards" : "Alla tavlor",
    "Archived boards" : "Arkiverade tavlor",
    "Shared with you" : "Delad med dig",
    "Deck settings" : "Deck-inställningar",
    "Use bigger card view" : "Visa större kort",
    "Show card ID badge" : "Visa kortets ID-märke",
    "Show boards in calendar/tasks" : "Visa tavlor i kalender / uppgifter",
    "Limit deck usage of groups" : "Begränsa användningen av grupper",
    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Begränsning av Deck blockerar användare som inte ingår i dessa grupper från att skapa egna tavlor. Användare kan dock fortfarande integrera med tavlor som har delats med dem.",
    "Board details" : "Taveldetaljer",
    "Edit board" : "Ändra tavla",
    "Clone board" : "Kopiera tavla",
    "Unarchive board" : "Ta bort tavlan ur arkivet",
    "Archive board" : "Arkivera tavla",
    "Turn on due date reminders" : "Aktivera påminnelser om förfallodatum",
    "Turn off due date reminders" : "Inaktivera påminnelser om förfallodatum",
    "Due date reminders" : "Påminnelser om förfallodatum",
    "All cards" : "Alla kort",
    "Assigned cards" : "Tilldelade kort",
    "No notifications" : "Inga aviseringar",
    "Delete board" : "Radera tavla",
    "Board {0} deleted" : "Tavla {0} raderad",
    "Only assigned cards" : "Bara tilldelade kort",
    "No reminder" : "Ingen påminnelse",
    "An error occurred" : "Ett fel uppstod",
    "Are you sure you want to delete the board {title}? This will delete all the data of this board including archived cards." : "Är du säker på att du vill radera brädet {title}? Detta kommer radera all data som tillhör brädet inklusive arkiverade kort.",
    "Delete the board?" : "Ta bort tavlan?",
    "Loading filtered view" : "Laddar filtrerad vy",
    "No due" : "Inget slut",
    "Search for {searchQuery} in all boards" : "Sök efter {searchQuery} i alla tavlor",
    "No results found" : "Inga resultat funna",
    "{stack} in {board}" : "{stack} i {board}",
    "Click to expand description" : "Klicka för att utöka beskrivningen",
    "* Created on {created}\n* Last modified on {lastMod}\n* {nbAttachments} attachments\n* {nbComments} comments" : "* Skapades {created}\n* Ändrades senast {lastMod}\n* {nbAttachments} bilagor\n* {nbComments} kommentarer",
    "{nbCards} cards" : "{nbCards} kort",
    "No upcoming cards" : "Inga kommande kort",
    "upcoming cards" : "kommande kort",
    "Due on {date}" : "Går ut {date}",
    "Link to a board" : "Länka till en tavla",
    "Link to a card" : "Länka till ett kort",
    "Create a card" : "Skapa ett kort",
    "Message from {author} in {conversationName}" : "Meddelande från {author} i {conversationName}",
    "Something went wrong" : "Något gick fel",
    "Failed to upload {name}" : "Kunde inte ladda upp {name}",
    "Maximum file size of {size} exceeded" : "Maximal filstorlek på {size} överskriden",
    "Error creating the share" : "Kunde inte skapa delning",
    "Share with a Deck card" : "Dela med ett Deck-kort",
    "Share {file} with a Deck card" : "Dela {file} med ett Deck-kort",
    "Share" : "Dela",
    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Deck är en kanban-liknande projekt- och organiseringsapp för arbetsgrupper i Nextcloud.\n\n\n- 📥 Lägg till uppgifter på kort och ordna dem\n- 📄 Skriv anteckningar i markdown\n- 🔖 Tilldela etiketter för organisering\n- 👥 Dela med arbetsgruppen, vänner eller familj\n- 📎 Bifoga filer och bädda in dem i markdown-anteckningarna\n- 💬 Diskutera i arbetsgruppen genom kommentarer\n- ⚡ Håll koll på ändringar i aktivitetsflödet\n- 🚀 Börja organisera din arbetsgrupp nu!",
    "Are you sure you want to transfer the board {title} for {user} ?" : "Är du säker på att du vill överföra brädet {title} för {user}?",
    "Transfer the board for {user} successfully" : "Överförde brädet för {user}",
    "Failed to transfer the board for {user}" : "Misslyckades med att överföra brädet för {user}",
    "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "Är du säker på att du vill radera tavla {title}? Detta kommer att radera all information från denna tavla.",
    "This week" : "Denna vecka",
    "Are you sure you want to transfer the board {title} for {user}?" : "Är du säker på att du vill överföra brädet {title} för {user}?"
},
"nplurals=2; plural=(n != 1);");
