OC.L10N.register(
    "deck",
    {
    "You have created a new board {board}" : "{board} taula berria sortu duzu",
    "{user} has created a new board {board}" : "{user} erabiltzaileak {board} taula berria sortu du",
    "You have deleted the board {board}" : "{board} taula ezabatu duzu",
    "{user} has deleted the board {board}" : "{user} erabiltzaileak {board} taula ezabatu du",
    "You have restored the board {board}" : "{board} taula leheneratu duzu",
    "{user} has restored the board {board}" : "{user} erabiltzaileak {board} taula leheneratu du",
    "You have shared the board {board} with {acl}" : "{board} taula {acl} erabiltzailearekin partekatu duzu",
    "{user} has shared the board {board} with {acl}" : "{user} erabiltzaileak {board} taula {acl} erabiltzailearekin partekatu du",
    "You have removed {acl} from the board {board}" : "{acl} erabiltzailea kendu duzu {board} taulatik",
    "{user} has removed {acl} from the board {board}" : "{user} erabiltzaileak {acl} erabiltzailea kendu du {board} taulatik",
    "You have renamed the board {before} to {board}" : "{before} taula zena {board} bezala berrizendatu duzu",
    "{user} has renamed the board {before} to {board}" : "{user} erabiltzaileak {before} taula zena {board} bezala berrizendatu du",
    "You have archived the board {board}" : "{board} taula artxibatu duzu",
    "{user} has archived the board {before}" : "{user} erabiltzaileak {before} taula artxibatu du",
    "You have unarchived the board {board}" : "{board} taula artxibotik berreskuratu duzu",
    "{user} has unarchived the board {before}" : "{user} erabiltzaileak {before} taula artxibotik kendu du",
    "You have created a new list {stack} on board {board}" : "{stack} zerrenda berria sortu duzu {board} taulan",
    "{user} has created a new list {stack} on board {board}" : "{user} erabiltzaileak {stack} zerrenda berria sortu du {board} taulan",
    "You have renamed list {before} to {stack} on board {board}" : "{before} zerrenda zena {stack} bezala berrizendatu duzu {board} taulan",
    "{user} has renamed list {before} to {stack} on board {board}" : "{user} erabiltzaileak {before} zerrenda zena {stack} bezala berrizendatu du {board} taulan",
    "You have deleted list {stack} on board {board}" : "{stack} zerrenda ezabatu duzu {board} taulan",
    "{user} has deleted list {stack} on board {board}" : "{user} erabiltzaileak {stack} zerrenda ezabatu du {board} taulan",
    "You have created card {card} in list {stack} on board {board}" : "{card} txartela sortu duzu {board} taulako {stack} zerrendan",
    "{user} has created card {card} in list {stack} on board {board}" : "{user} erabiltzaileak {card} txartela sortu du {board} taulako {stack} zerrendan",
    "You have deleted card {card} in list {stack} on board {board}" : "{card} txartela ezabatu duzu {board} taulako {stack} zerrendan",
    "{user} has deleted card {card} in list {stack} on board {board}" : "{user} erabiltzaileak {card} txartela ezabatu du {board} taulako {stack} zerrendan",
    "You have renamed the card {before} to {card}" : "{before} taula zena {card} bezala berrizendatu duzu",
    "{user} has renamed the card {before} to {card}" : "{user} erabiltzaileak {before} taula zena {card} bezala berrizendatu du",
    "You have added a description to card {card} in list {stack} on board {board}" : "{board} taulako {stack} zerrendako {card} txartelari deskripzioa gehitu diozu",
    "{user} has added a description to card {card} in list {stack} on board {board}" : "{user} erabiltzaileak {board} taulako {stack} zerrendako {card} txartelari deskripzioa gehitu dio",
    "You have updated the description of card {card} in list {stack} on board {board}" : "{board} taulako {stack} zerrendako {card} txartelaren deskripzioa eguneratu duzu",
    "{user} has updated the description of the card {card} in list {stack} on board {board}" : "{user} erabiltzaileak {board} taulako {stack} zerrendako {card} txartelaren deskripzioa eguneratu du",
    "You have archived card {card} in list {stack} on board {board}" : "{board} taulako {stack} zerrendako {card} txartela artxibatu duzu",
    "{user} has archived card {card} in list {stack} on board {board}" : "{user} erabiltzaileak {board} taulako {stack} zerrendako {card} txartela artxibatu du",
    "You have unarchived card {card} in list {stack} on board {board}" : "{board} taulako {stack} zerrendako {card} txartela berreskuratu duzu artxibotik",
    "{user} has unarchived card {card} in list {stack} on board {board}" : "{user} erabiltzaileak {board} taulako {stack} zerrendako {card} txartela berreskuratu du artxibotik",
    "You have removed the due date of card {card}" : "{card} txartelari epemuga kendu diozu",
    "{user} has removed the due date of card {card}" : "{user} erabiltzaileak {card} txartelari epemuga kendu dio",
    "You have set the due date of card {card} to {after}" : "{card} txartelari {after} epemuga ezarri diozu",
    "{user} has set the due date of card {card} to {after}" : "{user} erabiltzaileak {card} txartelari {after} epemuga ezarri dio",
    "You have updated the due date of card {card} to {after}" : "{card} txartelari epemuga eguneratu diozu: {after}",
    "{user} has updated the due date of card {card} to {after}" : "{user} erabiltzaileak {card} txartelari epemuga eguneratu dio: {after}",
    "You have added the tag {label} to card {card} in list {stack} on board {board}" : "{board} mahaiko {stack} zerrendako {card} txartelari {label} etiketa gehitu diozu",
    "{user} has added the tag {label} to card {card} in list {stack} on board {board}" : "{user} erabiltzaileak {board} taulako {stack} zerrendako {card} txartelari {label} etiketa gehitu dio",
    "You have removed the tag {label} from card {card} in list {stack} on board {board}" : "{board} taulako {stack} zerrendako {card} txartelari {label} etiketa kendu diozu",
    "{user} has removed the tag {label} from card {card} in list {stack} on board {board}" : "{user} erabiltzaileak {board} taulako {stack} zerrendako {card} txartelari {label} etiketa kendu dio",
    "You have assigned {assigneduser} to card {card} on board {board}" : "{board} taulako {card} txartela {assigneduser} erabiltzaileari esleitu diozu",
    "{user} has assigned {assigneduser} to card {card} on board {board}" : "{user} erabiltzaileak {board} taulako {card} txartela {assigneduser} erabiltzaileari esleitu dio",
    "You have unassigned {assigneduser} from card {card} on board {board}" : "{board} taulako {card} txartela {assigneduser} erabiltzaileari esleitzea ezeztatu duzu",
    "{user} has unassigned {assigneduser} from card {card} on board {board}" : "{user} erabiltzaileak {board} taulako {card} txartela {assigneduser} erabiltzaileari esleitzea ezeztatu du",
    "You have moved the card {card} from list {stackBefore} to {stack}" : "{card} txartela {stackBefore} zerrendatik {stack} zerrendara aldatu duzu",
    "{user} has moved the card {card} from list {stackBefore} to {stack}" : "{user} erabiltzaileak {card} txartela {stackBefore} zerrendatik {stack} zerrendara aldatu du",
    "You have added the attachment {attachment} to card {card}" : "{attachment} eranskina gehitu diozu {card} txartelari",
    "{user} has added the attachment {attachment} to card {card}" : "{user} erabiltzaileak {attachment} eranskina gehitu dio {card} txartelari",
    "You have updated the attachment {attachment} on card {card}" : "{card} txartelaren {attachment} eranskina eguneratu duzu",
    "{user} has updated the attachment {attachment} on card {card}" : "{user} erabiltzaileak {card} txartelaren {attachment} eranskina eguneratu du",
    "You have deleted the attachment {attachment} from card {card}" : "{card} txartelaren {attachment} eranskina ezabatu duzu",
    "{user} has deleted the attachment {attachment} from card {card}" : "{user} erabiltzaileak {card} txartelaren {attachment} eranskina ezabatu du",
    "You have restored the attachment {attachment} to card {card}" : "{card} txartelaren {attachment} eranskina leheneratu duzu",
    "{user} has restored the attachment {attachment} to card {card}" : "{user} erabiltzaileak {card} txartelaren {attachment} eranskina leheneratu du",
    "You have commented on card {card}" : "{card} txartela iruzkindu duzu",
    "{user} has commented on card {card}" : "{user} erabiltzaileak {card} txartela iruzkindu du",
    "A <strong>card description</strong> inside the Deck app has been changed" : "<strong>Txartel baten deskribapena</strong> aldatu da Deck aplikazioaren barruan",
    "Deck" : "Deck",
    "Changes in the <strong>Deck app</strong>" : "<strong>Deck</strong> aplikazioan aldaketak",
    "A <strong>comment</strong> was created on a card" : "<strong>Iruzkin bat</strong> sortu da txartel batean",
    "Upcoming cards" : "Hurrengo txartelak",
    "Load more" : "Kargatu gehiago",
    "Personal" : "Pertsonala",
    "The card \"%s\" on \"%s\" has been assigned to you by %s." : "\"%s\" txartela \"%s\"-n %sk esleitu zaizu.",
    "{user} has assigned the card {deck-card} on {deck-board} to you." : "{user}-k {deck-board}-ko  {deck-card} txartela esleitu dizu.",
    "The card \"%s\" on \"%s\" has reached its due date." : " \"%s\" txartela,  \"%s\" -n dagoena, epe-mugara ailegatu da.",
    "The card {deck-card} on {deck-board} has reached its due date." : " {deck-board}-ko {deck-card} txartela epe-mugara ailegatu da.",
    "%s has mentioned you in a comment on \"%s\"." : "%sk aipatu dizu \"%s\"-ri buruzko iruzkin batean.",
    "{user} has mentioned you in a comment on {deck-card}." : "{user}-k zure izena aipatu du {deck-card}-ko iruzkin batean.",
    "The board \"%s\" has been shared with you by %s." : "\"%s\" mahaia zurekin partekatu du %s-k",
    "{user} has shared {deck-board} with you." : "{user} erabiltzaileak {deck-board} partekatu du zurekin.",
    "Card comments" : "Txartelaren iruzkinak",
    "%s on %s" : "%s hemen: %s",
    "No data was provided to create an attachment." : "Ez da daturik eman eranskina sortzeko.",
    "Finished" : "Bukatuta",
    "To review" : "Errebisatzeko",
    "Action needed" : "Ekintza beharrezkoa",
    "Later" : "Beranduago",
    "copy" : "kopiatu",
    "To do" : "Egiteke",
    "Doing" : "Egiten",
    "Done" : "Egina",
    "Example Task 3" : "Adibidetarako ataza 3",
    "Example Task 2" : "Adibidetarako ataza 2",
    "Example Task 1" : "Adibidetarako ataza 1",
    "The file was uploaded" : "Fitxategia igo da",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Kargatutako fitxategiak php.ini fitxategiko upload_max_filesize direktiban zehazturikoa gainditzen du",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Kargatutako fitxategiak HTML formularioan ezarritako MAX_FILE_SIZE direktiban zehazturikoa gainditzen du",
    "The file was only partially uploaded" : "Fitxategia erdizka kargatu da",
    "No file was uploaded" : "Ez da fitxategirik kargatu",
    "Missing a temporary folder" : "Aldi baterako karpeta bat falta da",
    "Could not write file to disk" : "Ezin izan da fitxategia diskoan idatzi",
    "A PHP extension stopped the file upload" : "PHP hedapen batek fitxategiaren karga gelditu du",
    "No file uploaded or file size exceeds maximum of %s" : "Ez da fitxategirik kargatu edo fitxategi-tamainak gehienezko %s muga gainditzen du",
    "This comment has more than %s characters.\nAdded as an attachment to the card with name %s.\nAccessible on URL: %s." : "Iruzkin honek %s karaktere baino gehiago ditu.\n%s izena duen txartelari eranskin gisa gehitu da.\nURLan eskura daiteke: %s.",
    "Card not found" : "Txartela ez da aurkitu",
    "Path is already shared with this card" : "Bidea dagoeneko partekatu da txartel honekin",
    "Invalid date, date format must be YYYY-MM-DD" : "Data baliogabea, dataren formatuak UUUU-HH-EE izan behar du",
    "Personal planning and team project organization" : "Plangintza pertsonala eta talde proiektuen kudeaketa",
    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in Markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your Markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Deck aplikazioa plangintza pertsonalera eta proiektuen antolaketara zuzenduta dagoen Nextcloudekin integratutako kanban moduko tresna bat da.\n\n\n-📥 Gehitu atazak txarteletan eta ordenatu\n- 📄 Idatzi ohar gehigarriak Markdown erabiliz\n- 🔖 Esleitu etiketak antolaketa are gehiago hobetzeko\n- 👥 Partekatu zure talde, lagun edo familiarekin\n- 📎 Erantsi fitxategiak eta kapsulatu zure Markdown deskribapenean\n- 💬 Eztabaidatu zure taldearekin iruzkinak erabiliz\n- ⚡ Egin aldaketen jarraipena jarduera jarioa erabiliz\n- 🚀 Antolatu zure proiektua",
    "Card details" : "Txartelaren xehetasunak",
    "Add board" : "Gehitu mahaia",
    "Select the board to link to a project" : "Hautatu taula proiektu bati estekatzeko",
    "Search by board title" : "Bilatu taula izenez",
    "Select board" : "Hautatu taula",
    "Create a new card" : "Sortu txartel berri bat",
    "Select a board" : "Hautatu taula bat",
    "Select a list" : "Hautatu zerrenda bat",
    "Card title" : "Txartelaren izenburua",
    "Cancel" : "Utzi",
    "Creating the new card …" : "Txartel berria sortzen...",
    "Card \"{card}\" was added to \"{board}\"" : "\"{card}\" txartela \"{board}\"-ra gehitu da",
    "Open card" : "Ireki txartela",
    "Close" : "Itxi",
    "Create card" : "Sortu txartela",
    "Select a card" : "Hautatu txartel bat",
    "Select the card to link to a project" : "Hautatu proiektu bati estekatzeko txartela",
    "Link to card" : "Estekatu txartelera",
    "File already exists" : "Badago izen bereko fitxategi bat",
    "A file with the name {filename} already exists." : "{filename} izeneko fitxategia existitzen da dagoeneko.",
    "Do you want to overwrite it?" : "Gainidatzi nahi duzu?",
    "Overwrite file" : "Gainidatzi fitxategia",
    "Keep existing file" : "Mantendu dagoen fitxategia",
    "This board is read only" : "Mahai hau irakurtzeko soilik da",
    "Drop your files to upload" : "Jaregin zure fitxategiak kargatzeko",
    "Add card" : "Gehitu txartela",
    "Archived cards" : "Artxibatutako txartelak",
    "Add list" : "Gehitu zerrenda",
    "List name" : "Zerrendaren izena",
    "Active filters" : "Iragazki aktiboak",
    "Apply filter" : "Ezarri iragazkia",
    "Filter by tag" : "Iragazi etiketaz",
    "Filter by assigned user" : "Iragazi esleitutako erabiltzailez",
    "Unassigned" : "Esleitu gabea",
    "Filter by due date" : "Iragazi epe-mugaz",
    "Overdue" : "Atzeratuta",
    "Next 24 hours" : "Hurrengo 24 orduak",
    "Next 7 days" : "Hurrengo 7 egunetan",
    "Next 30 days" : "Hurrengo 30 egunetan",
    "No due date" : "Epe-mugarik gabe",
    "Clear filter" : "Garbitu iragazia",
    "Hide archived cards" : "Ezkutatu artxibatutako txartelak",
    "Show archived cards" : "Erakutsi artxibatutako txartelak",
    "Toggle compact mode" : "Txandakatu modu trinkoa",
    "Open details" : "Ireki xehetasunak",
    "Details" : "Xehetasunak",
    "Loading board" : "Taula kargatzen",
    "No lists available" : "Ez dago zerrendarik eskuragarri",
    "Create a new list to add cards to this board" : "Sortu zerrenda berria, taula honetan txartelak gehitzeko",
    "Board not found" : "Ez da taula aurkitu",
    "Sharing" : "Partekatzea",
    "Tags" : "Etiketak",
    "Deleted items" : "Ezabatutako elementuak",
    "Timeline" : "Denbora-lerroa",
    "Deleted lists" : "Ezabatutako zerrendak",
    "Undo" : "Desegin",
    "Deleted cards" : "Ezabatutako txartelak",
    "Share board with a user, group or circle …" : "Partekatu taula erabiltzaile, talde edo zirkulu batekin...",
    "Searching for users, groups and circles …" : "Erabiltzaileak, taldeak, zirkuluak... bilatzen",
    "No participants found" : "Ez da parte-hartzailerik aurkitu",
    "Board owner" : "Taularen jabea",
    "(Group)" : "(Taldea)",
    "(Circle)" : "(Zirkulua)",
    "Can edit" : "Editatu dezake",
    "Can share" : "Partekatu dezake",
    "Can manage" : "Kudeatu dezake",
    "Owner" : "Jabea",
    "Delete" : "Ezabatu",
    "Failed to create share with {displayName}" : "Ezin izan da {displayName}-(r)ekin partekatzea sortu",
    "Are you sure you want to transfer the board {title} to {user}?" : "Ziur {title} taula {user}-(a)ri transferitu nahi diozula?",
    "Transfer the board." : "Transferitu panela.",
    "Transfer" : "Transferitu",
    "The board has been transferred to {user}" : "Arbela {user}-(a)ri transferitu zaio",
    "Failed to transfer the board to {user}" : "Ezin izan zaio transferitu arbela {use}-(a)ri",
    "Add a new list" : "Gehitu zerrenda berria",
    "Archive all cards" : "Artxibatu txartel guztiak",
    "Delete list" : "Zerrenda ezabatu",
    "Archive all cards in this list" : "Artxibatu zerrenda honetako txartel guztiak",
    "Add a new card" : "Gehitu txartel berri bat",
    "Card name" : "Txartel izena",
    "List deleted" : "Zerrenda ezabatua",
    "Edit" : "Editatu",
    "Add a new tag" : "Gehitu etiketa berri bat",
    "title and color value must be provided" : "izenburu eta kolore balioak hornitu behar dira",
    "Board name" : "Taularen izena",
    "Members" : "Partaideak",
    "Upload new files" : "Kargatu fitxategi berriak",
    "Share from Files" : "Partekatu Fitxategiak-etik",
    "Pending share" : "Partekatzeko zain",
    "Add this attachment" : "Gehitu eranskin hau",
    "Show in Files" : "Erakutsi fitxategietan",
    "Download" : "Deskargatu",
    "Remove attachment" : "Kendu eranskina",
    "Delete Attachment" : "Ezabatu eranskina",
    "Restore Attachment" : "Berezarri eranskina",
    "File to share" : "Partekatzeko fitxategia",
    "Invalid path selected" : "Bide baliogabea hautatuta",
    "Open in sidebar view" : "Ireki alboko barraren ikuspegian",
    "Open in bigger view" : "Ireki ikuspegi handiago batean",
    "Attachments" : "Eranskinak",
    "Comments" : "Iruzkinak",
    "Modified" : "Aldatua",
    "Created" : "Sortua",
    "The title cannot be empty." : "Izenburua ezin da hutsik egon.",
    "No comments yet. Begin the discussion!" : "Ez dago iruzkinik oraindik. Hasi eztabaidatzen!",
    "Failed to load comments" : "Iruzkinen kargatzeak huts egin du.",
    "Assign a tag to this card…" : "Esleitu etiketa bat txartel honi...",
    "Assign to users" : "Esleitu erabiltzaileei",
    "Assign to users/groups/circles" : "Esleitu erabiltzaile/talde/zirkuluei",
    "Assign a user to this card…" : "Esleitu erabiltzaile bat txartel honi...",
    "Due date" : "Epe-muga",
    "Set a due date" : "Ezarri epe-muga",
    "Remove due date" : "Ezabatu epe-muga",
    "Select Date" : "Hautatu data",
    "Today" : "Gaur",
    "Tomorrow" : "Bihar",
    "Next week" : "Hurrengo astea",
    "Next month" : "Hurrengo hilabetea",
    "Save" : "Gorde",
    "The comment cannot be empty." : "Iruzkina ezin da hutsik egon.",
    "The comment cannot be longer than 1000 characters." : "Iruzkina ezin da 1000 karaktere baino luzeagoa izan.",
    "In reply to" : "Honi erantzunez",
    "Cancel reply" : "Utzi erantzuna bertan behera",
    "Reply" : "Erantzun",
    "Update" : "Eguneratu",
    "Description" : "Deskribapena",
    "(Unsaved)" : "(Gorde gabe)",
    "(Saving…)" : "(Gordetzen...)",
    "Formatting help" : "Formatua emateko laguntza",
    "Edit description" : "Editatu azalpena",
    "View description" : "Ikusi deskribapena",
    "Add Attachment" : "Gehitu eranskina",
    "Write a description …" : "Idatzi deskribapen bat ...",
    "Choose attachment" : "Aukeratu eranskina",
    "(group)" : "(taldea)",
    "Todo items" : "Elementuak egiteke",
    "{count} comments, {unread} unread" : "{count} iruzkin, {unread} irakurri gabe",
    "Edit card title" : "Editatu txartelaren izenburua",
    "Assign to me" : "Esleitu niri",
    "Unassign myself" : "Niri esleitzeari utzi",
    "Move card" : "Mugitu txartela",
    "Unarchive card" : "Berreskuratu txartela artxibotik",
    "Archive card" : "Artxibatu txartela",
    "Delete card" : "Ezabatu txartela",
    "Move card to another board" : "Mugitu txartela beste taula batera",
    "List is empty" : "Zerrenda hutsik dago",
    "Card deleted" : "Txartela ezabatuta",
    "seconds ago" : "segundo lehenago",
    "All boards" : "Taula guztiak",
    "Archived boards" : "Artxibatutako taulak",
    "Shared with you" : "Zurekin partekatua",
    "Deck settings" : "Deck ezarpenak",
    "Use bigger card view" : "Erabili txartel ikuspegi handiagoa",
    "Show boards in calendar/tasks" : "Erakutsi taulak egutegi/zereginetan",
    "Limit deck usage of groups" : "Mugatu taldeek Deck erabiltzeko aukera",
    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Deck mugatzeak taldeetako kide ez diren erabiltzaileei beren taula propioak sortzea eragotziko die. Erabiltzaileek beraiekin partekatu diren tauletan lan egin ahalko dute.",
    "Board details" : "Taularen xehetasunak",
    "Edit board" : "Editatu mahaia",
    "Clone board" : "Klonatu taula",
    "Unarchive board" : "Atera taula artxibotik",
    "Archive board" : "Artxibatu taula",
    "Turn on due date reminders" : "Aktibatu epemugako abisuak",
    "Turn off due date reminders" : "Desaktibatu epemugako abisuak",
    "Due date reminders" : "Epemugako abisuak",
    "All cards" : "Txartel guztiak",
    "Assigned cards" : "Esleitutako txartelak",
    "No notifications" : "Jakinarazpenik ez",
    "Delete board" : "Ezabatu taula",
    "Board {0} deleted" : "{0} taula ezabatu da",
    "Only assigned cards" : "Bakarrik esleitutako txartelak",
    "No reminder" : "Abisurik ez",
    "An error occurred" : "Errore bat gertatu da",
    "Are you sure you want to delete the board {title}? This will delete all the data of this board including archived cards." : "Ziur zaude {title} taula ezabatu nahi duzula? Honek taula honen datu guztiak ezabatuko ditu, artxibatutako kartak barne.",
    "Delete the board?" : "Taula ezabatu?",
    "Loading filtered view" : "Kargatzen iragazitako ikuspegia",
    "No due" : "Epemugarik ez",
    "Search for {searchQuery} in all boards" : "Bilatu {searchQuery} taula guztietan",
    "No results found" : "Ez da emaitzarik aurkitu",
    "{stack} in {board}" : "{stack} {board}-(e)n",
    "Click to expand description" : "Egin klik deskribapena handitzeko",
    "* Created on {created}\n* Last modified on {lastMod}\n* {nbAttachments} attachments\n* {nbComments} comments" : "* Sorrera-data {created}\n* Azken aldaketa data {lastMod}\n* {nbAttachments} eranskin\n* {nbComments} iruzkin",
    "{nbCards} cards" : "{nbCards} karta",
    "No upcoming cards" : "Ez dago hurrengo txartelik",
    "upcoming cards" : "hurrengo txartelak",
    "Due on {date}" : "Iraungitze-data {date}",
    "Link to a board" : "Estekatu taula batera",
    "Link to a card" : "Estekatu txartel batera",
    "Create a card" : "Sortu txartela",
    "Message from {author} in {conversationName}" : "{author} erabiltzailearen mezua {conversationName}-an",
    "Something went wrong" : "Zerbait gaizki joan da",
    "Failed to upload {name}" : "{name} kargatzeak huts egin du",
    "Maximum file size of {size} exceeded" : "Fitxategiaren gehienezko {size} tamaina gainditu da",
    "Error creating the share" : "Errorea partekatzea sortzean",
    "Share with a Deck card" : "Partekatu Deck txartel baten bidez",
    "Share {file} with a Deck card" : "Partekatu {file} Deck txartel baten bidez",
    "Share" : "Partekatu",
    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Deck aplikazioa plangintza pertsonalera eta proiektuen antolaketara zuzenduta dagoen Nextcloudekin integratutako kanban moduko tresna bat da.\n\n\n- 📥 Gehitu atazak txarteletan eta ordenatu\n- 📄 Idatzi ohar gehigarriak markdown erabiliz\n- 🔖 Esleitu etiketak antolaketa are gehiago hobetzeko\n- 👥 Partekatu zure talde, lagun edo familiarekin\n- 📎 Erantsi fitxategiak eta kapsulatu zure markdown deskribapenean\n- 💬 Eztabaidatu zure taldearekin iruzkinak erabiliz\n- ⚡ Egin aldaketen jarraipena jarduera jarioa erabiliz\n- 🚀 Antolatu zure proiektua",
    "Are you sure you want to transfer the board {title} for {user} ?" : "Ziur {title} transferitu nahi duzula {user}-en panela ?",
    "Transfer the board for {user} successfully" : "Transferitu {user}-ren panela behar bezala",
    "Failed to transfer the board for {user}" : "Ezin izan da transferitu {user}-ren panela",
    "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "Ziur zaude «{title}» taula ezabatu nahi duzula? Honek taula honen datu guztiak ezabatuko ditu.",
    "This week" : "Aste honetan",
    "Are you sure you want to transfer the board {title} for {user}?" : "Ziur {title} taula transferitu nahi duzula {user}?"
},
"nplurals=2; plural=(n != 1);");
