OC.L10N.register(
    "deck",
    {
    "You have created a new board {board}" : "새로운 보드{board}를 만들었습니다.",
    "Deck" : "덱",
    "Upcoming cards" : "다음 카드들",
    "Load more" : "더 불러오기",
    "Personal" : "개인",
    "The card \"%s\" on \"%s\" has reached its due date." : "카드 \"%s\"(\"%s\"에 있음)의 만료 날짜가 다가왔습니다.",
    "The board \"%s\" has been shared with you by %s." : "\"%s\" 게시판을 %s 님이 공유했습니다.",
    "%s on %s" : "%s(%s의)",
    "Finished" : "완료됨",
    "To review" : "리뷰할 항목",
    "Action needed" : "동작 필요",
    "Later" : "나중에",
    "copy" : "복사",
    "To do" : "할 일",
    "Done" : "완료",
    "Example Task 3" : "작업 예제 3",
    "Example Task 2" : "작업 예제 2",
    "Example Task 1" : "작업 예제 1",
    "The file was uploaded" : "파일을 업로드함",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "업로드한 파일의 크기가 php.ini의 upload_max_filesize를 초과함",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "업로드한 파일의 크기가 HTML 폼에 지정한 MAX_FILE_SIZE를 초과함",
    "The file was only partially uploaded" : "파일이 일부분만 업로드됨",
    "No file was uploaded" : "업로드한 파일 없음",
    "Missing a temporary folder" : "임시 폴더 없음",
    "Could not write file to disk" : "디스크에 파일을 쓸 수 없음",
    "A PHP extension stopped the file upload" : "PHP 확장 기능에서 파일 업로드를 차단함",
    "Card not found" : "카드 없음",
    "Invalid date, date format must be YYYY-MM-DD" : "잘못된 날짜, YYYY-MM-DD 형식이어야 합니다",
    "Card details" : "카드 세부사항",
    "Add board" : "보드 추가",
    "Search by board title" : "보드 제목으로 검색",
    "Select board" : "보드 선택",
    "Select a board" : "보드 선택",
    "Cancel" : "취소",
    "Close" : "닫기",
    "Create card" : "크레딧 카드",
    "Select a card" : "카드 선택",
    "Select the card to link to a project" : "카드를 선택해 프로젝트에 연결",
    "File already exists" : "파일이 이미 존재함",
    "A file with the name {filename} already exists." : "이미 존재하는  파일이름 {filename} ",
    "Do you want to overwrite it?" : "덮어쓰시겠습니까?",
    "Overwrite file" : "덮어쓰기",
    "Keep existing file" : "기존 파일 보존",
    "This board is read only" : "읽기 전용 보드",
    "Drop your files to upload" : "업로드를 하려면 파일을 올리시오.",
    "Add card" : "카드 추가",
    "Archived cards" : "보관된 카드들",
    "Add list" : "목록 추가",
    "List name" : "리스트 추가",
    "Apply filter" : "필터링 적용",
    "Filter by tag" : "태그로 필터링",
    "Filter by assigned user" : "지정된 사용자로 필터링",
    "Unassigned" : "할당되지 않음",
    "Filter by due date" : "기한으로 필터링",
    "Overdue" : "기한 넘김",
    "Next 24 hours" : "다음 24시간",
    "Next 7 days" : "다음 7일 동안",
    "Next 30 days" : "다음 30일 동안",
    "No due date" : "기한 없음",
    "Hide archived cards" : "보관된 카드 숨기기",
    "Show archived cards" : "보관된 카드 보기",
    "Open details" : "자세한 정보 열기",
    "Details" : "세부사항",
    "Sharing" : "공유",
    "Tags" : "태그",
    "Deleted items" : "삭제된 항목",
    "Timeline" : "타임라인",
    "Undo" : "실행 취소",
    "No participants found" : "참여자를 찾을 수 없음",
    "(Group)" : "(그룹)",
    "Can edit" : "편집할 수 있음",
    "Can share" : "공유할 수 있음",
    "Owner" : "소유자",
    "Delete" : "삭제",
    "Transfer" : "전송",
    "Delete list" : "목록 지우기",
    "Edit" : "편집",
    "Members" : "구성원",
    "Upload new files" : "새로운 파일 업로드",
    "Share from Files" : "파일 공유",
    "Download" : "다운로드",
    "File to share" : "공유할 파일",
    "Invalid path selected" : "잘못된 경로가 선택됨",
    "Attachments" : "첨부파일",
    "Comments" : "댓글",
    "Modified" : "수정한 날짜",
    "Created" : "생성됨",
    "Due date" : "만료 날짜",
    "Remove due date" : "만료 날짜 삭제",
    "Select Date" : "날짜 선택",
    "Today" : "오늘",
    "Tomorrow" : "내일",
    "Next week" : "다음주",
    "Next month" : "다음달",
    "Save" : "저장",
    "Reply" : "답장",
    "Update" : "업데이트",
    "Description" : "설명",
    "Formatting help" : "서식 도움말",
    "Edit description" : "설명 편집",
    "(group)" : "(그룹)",
    "Move card" : "카드 이동",
    "Archive card" : "보관 카드",
    "Delete card" : "카드 삭제",
    "List is empty" : "목록이 비어 있음",
    "seconds ago" : "초 전",
    "All boards" : "모든 보드",
    "Archived boards" : "보관된 게시판",
    "Shared with you" : "나와 공유됨",
    "Board details" : "게시판 정보",
    "Edit board" : "게시판 편집",
    "Clone board" : "게시판 복제",
    "Unarchive board" : "게시판 보관 해제",
    "Archive board" : "게시판 보관",
    "No notifications" : "알림 없음",
    "Delete board" : "게시판 삭제",
    "No reminder" : "알림 없음",
    "An error occurred" : "오류가 발생함",
    "Delete the board?" : "보드를 삭제합니까?",
    "No results found" : "결과 없음",
    "Something went wrong" : "잘못된 접근",
    "Share" : "공유",
    "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "정말로 보드 {title}을 지우시겠습니까? 보드의 모든 데이터가 삭제됩니다.",
    "This week" : "이번 주"
},
"nplurals=1; plural=0;");
