OC.L10N.register(
    "deck",
    {
    "Personal" : "Perséinlech",
    "Done" : "Done",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Déi ropgelueden Datei ass méi grouss wei d'MAX_FILE_SIZE Eegenschaft déi an der HTML form uginn ass",
    "No file was uploaded" : "Et ass kee Fichier ropgeluede ginn",
    "Missing a temporary folder" : "Et feelt en temporären Dossier",
    "Cancel" : "Ofbriechen",
    "Close" : "Zoumaachen",
    "Details" : "Detailer",
    "Sharing" : "Gedeelt",
    "Tags" : "Tags",
    "Can edit" : "Can edit",
    "Can share" : "Can share",
    "Owner" : "Owner",
    "Delete" : "Läschen",
    "Edit" : "Änneren",
    "Download" : "Eroflueden",
    "Comments" : "Kommentarer",
    "Modified" : "Geännert",
    "Today" : "Haut",
    "Tomorrow" : "Muer",
    "Save" : "Späicheren",
    "Reply" : "Äntwerten",
    "Update" : "Update",
    "Description" : "Beschreiwung",
    "seconds ago" : "Sekonnen hier",
    "Shared with you" : "Mat dir gedeelt",
    "Share" : "Deelen"
},
"nplurals=2; plural=(n != 1);");
