OC.L10N.register(
    "deck",
    {
    "Deck" : "Deck",
    "Personal" : "Personal",
    "The card \"%s\" on \"%s\" has reached its due date." : "The card \"%s\" on \"%s\" has reached its due date.",
    "The board \"%s\" has been shared with you by %s." : "The board \"%s\" has been shared with you by %s.",
    "%s on %s" : "%s on %s",
    "Finished" : "Finished",
    "To review" : "To review",
    "Action needed" : "Action needed",
    "Later" : "Later",
    "copy" : "copy",
    "Done" : "Done",
    "The file was uploaded" : "The file was uploaded",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "The uploaded file exceeds the upload_max_filesize directive in php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form",
    "The file was only partially uploaded" : "The file was only partially uploaded",
    "No file was uploaded" : "No file was uploaded",
    "Missing a temporary folder" : "Missing a temporary folder",
    "Could not write file to disk" : "Could not write file to disk",
    "A PHP extension stopped the file upload" : "A PHP extension stopped the file upload",
    "Card not found" : "Card not found",
    "Invalid date, date format must be YYYY-MM-DD" : "Invalid date, date format must be YYYY-MM-DD",
    "Add board" : "Add board",
    "Cancel" : "Cancel",
    "Close" : "Close",
    "Create card" : "Create card",
    "File already exists" : "File already exists",
    "Do you want to overwrite it?" : "Do you want to overwrite it?",
    "Add card" : "Add card",
    "Add list" : "Add list",
    "Filter by tag" : "Filter by tag",
    "Unassigned" : "Unassigned",
    "Overdue" : "Overdue",
    "Hide archived cards" : "Hide archived cards",
    "Show archived cards" : "Show archived cards",
    "Open details" : "Open details",
    "Details" : "Details",
    "Sharing" : "Sharing",
    "Tags" : "Tags",
    "Undo" : "Undo",
    "Can edit" : "Can edit",
    "Can share" : "Can share",
    "Owner" : "Owner",
    "Delete" : "Delete",
    "Transfer" : "Transfer",
    "Delete list" : "Delete list",
    "Edit" : "Edit",
    "Members" : "Members",
    "Download" : "Download",
    "Attachments" : "Attachments",
    "Comments" : "Comments",
    "Modified" : "Modified",
    "Created" : "Created",
    "Due date" : "Due date",
    "Remove due date" : "Remove due date",
    "Today" : "Today",
    "Tomorrow" : "Tomorrow",
    "Next week" : "Next week",
    "Next month" : "Next month",
    "Save" : "Save",
    "Reply" : "Reply",
    "Update" : "Update",
    "Description" : "Description",
    "Formatting help" : "Formatting help",
    "(group)" : "(group)",
    "Archive card" : "Archive card",
    "Delete card" : "Delete card",
    "seconds ago" : "seconds ago",
    "Archived boards" : "Archived boards",
    "Shared with you" : "Shared with you",
    "Board details" : "Board details",
    "Edit board" : "Edit board",
    "Unarchive board" : "Unarchive board",
    "Archive board" : "Archive board",
    "No notifications" : "No notifications",
    "Delete board" : "Delete board",
    "Share" : "Share",
    "This week" : "This week"
},
"nplurals=2; plural=(n != 1);");
