OC.L10N.register(
    "deck",
    {
    "You have created a new board {board}" : "Vostede creou o novo taboleiro {board}",
    "{user} has created a new board {board}" : "{user}  creou o novo taboleiro {board}",
    "You have deleted the board {board}" : "Vostede eliminou o taboleiro {board}",
    "{user} has deleted the board {board}" : "{user} eliminou o taboleiro {board}",
    "You have restored the board {board}" : "Vostede restaurou o taboleiro {board}",
    "{user} has restored the board {board}" : "{user} restaurou o taboleiro {board}",
    "You have shared the board {board} with {acl}" : "Vostede compartiu o taboleiro {board} con {acl}",
    "{user} has shared the board {board} with {acl}" : "{user} compartiu o taboleiro {board} con {acl}",
    "You have removed {acl} from the board {board}" : "Vostede retirou a {acl} do taboleiro {board}",
    "{user} has removed {acl} from the board {board}" : "{user} retirou a {acl} do taboleiro {board}",
    "You have renamed the board {before} to {board}" : "Vostede renomeou o taboleiro {before} como {board}",
    "{user} has renamed the board {before} to {board}" : "{user} renomeou o taboleiro {before} como {board}",
    "You have archived the board {board}" : "Vostede arquivou o taboleiro {board}",
    "{user} has archived the board {before}" : "{user} arquivou o taboleiro {before}",
    "You have unarchived the board {board}" : "Vostede desarquivou o taboleiro {board}",
    "{user} has unarchived the board {before}" : "{user} desarquivou o taboleiro {before}",
    "You have created a new list {stack} on board {board}" : "Vostede creou unha nova lista {stack} no taboleiro {board}",
    "{user} has created a new list {stack} on board {board}" : "{user} creou unha nova lista {stack} no taboleiro {board}",
    "You have renamed list {before} to {stack} on board {board}" : "Vostede renomeou a lista {before} no taboleiro {board}",
    "{user} has renamed list {before} to {stack} on board {board}" : "{user} renomeou a lista {before} como {stack} no taboleiro {board}",
    "You have deleted list {stack} on board {board}" : "Vostede eliminou a lista {stack} do taboleiro {board}",
    "{user} has deleted list {stack} on board {board}" : "{user} eliminou a lista {stack} do taboleiro {board}",
    "You have created card {card} in list {stack} on board {board}" : "Vostede creou a tarxeta {card} na lista {stack} no taboleiro {board}",
    "{user} has created card {card} in list {stack} on board {board}" : "{user} creou a tarxeta {card} na lista {stack} no taboleiro {board}",
    "You have deleted card {card} in list {stack} on board {board}" : "Vostede eliminou a tarxeta {card} na lista {stack} no taboleiro {board}",
    "{user} has deleted card {card} in list {stack} on board {board}" : "{user} eliminou a tarxeta {card} na lista {stack} no taboleiro {board}",
    "You have renamed the card {before} to {card}" : "Renomeou a tarxeta {before} a {card}",
    "{user} has renamed the card {before} to {card}" : "{user} renomeou a tarxeta {before} a {card}",
    "You have added a description to card {card} in list {stack} on board {board}" : "Vostede engadiu a descrición á tarxeta {card} na lista {stack} no taboleiro {board}",
    "{user} has added a description to card {card} in list {stack} on board {board}" : "{user} engadiu a descrición á tarxeta {card} na lista {stack} no taboleiro {board}",
    "You have updated the description of card {card} in list {stack} on board {board}" : "Vostede actualizou a descrición da tarxeta {card} na lista {stack} no taboleiro {board}",
    "{user} has updated the description of the card {card} in list {stack} on board {board}" : "{user} actualizou a descrición da tarxeta {card} na lista {stack} no taboleiro {board}",
    "You have archived card {card} in list {stack} on board {board}" : "Vostede arquivou a tarxeta {card} na lista {stack} no taboleiro {board}",
    "{user} has archived card {card} in list {stack} on board {board}" : "{user} arquivou a tarxeta {card} na lista {stack} no taboleiro {board}",
    "You have unarchived card {card} in list {stack} on board {board}" : "Vostede desarquivou a tarxeta {card} na lista {stack} no taboleiro {board}",
    "{user} has unarchived card {card} in list {stack} on board {board}" : "{user} desarquivou a tarxeta {card} na lista {stack} no taboleiro {board}",
    "You have removed the due date of card {card}" : "Vostede retirou a caducidade da tarxeta {card}",
    "{user} has removed the due date of card {card}" : "{user} retirou a caducidade da tarxeta {card}",
    "You have set the due date of card {card} to {after}" : "Vostede estabeleceu a caducidade da tarxeta {card} a {after}",
    "{user} has set the due date of card {card} to {after}" : "{user} estabeleceu a caducidade da tarxeta {card} a {after}",
    "You have updated the due date of card {card} to {after}" : "Vostede actualizou a caducidade da tarxeta {card} a {after}",
    "{user} has updated the due date of card {card} to {after}" : "{user} actualizou a caducidade da tarxeta {card} a {after}",
    "You have added the tag {label} to card {card} in list {stack} on board {board}" : "Vostede engadiu a etiqueta {label} á tarxeta {card} na lista {stack} no taboleiro {board}",
    "{user} has added the tag {label} to card {card} in list {stack} on board {board}" : "{user} engadiu a etiqueta {label} á tarxeta {card} na lista {stack} no taboleiro {board}",
    "You have removed the tag {label} from card {card} in list {stack} on board {board}" : "Vostede retirou a etiqueta {label} da tarxeta {card} na lista {stack} no taboleiro {board}",
    "{user} has removed the tag {label} from card {card} in list {stack} on board {board}" : "{user} retirou a etiqueta {label} da tarxeta {card} na lista {stack} no taboleiro {board}",
    "You have assigned {assigneduser} to card {card} on board {board}" : "Vostede asignou a {assigneduser} á tarxeta {card} no taboleiro {board}",
    "{user} has assigned {assigneduser} to card {card} on board {board}" : "{user} asignou a {assigneduser} á tarxeta {card} no taboleiro {board}",
    "You have unassigned {assigneduser} from card {card} on board {board}" : "Vostede desasignou a {assigneduser} da tarxeta {card} no taboleiro {board}",
    "{user} has unassigned {assigneduser} from card {card} on board {board}" : "{user} desasignou a {assigneduser} da tarxeta {card} no taboleiro {board}",
    "You have moved the card {card} from list {stackBefore} to {stack}" : "Vostede moveu a tarxeta {card} dende a lista {stackBefore} cara a lista {stack}",
    "{user} has moved the card {card} from list {stackBefore} to {stack}" : "{user} moveu a tarxeta {card} dende a lista {stackBefore} cara a lista {stack}",
    "You have added the attachment {attachment} to card {card}" : "Vostede engadiu o anexo  {attachment} na tarxeta {card}",
    "{user} has added the attachment {attachment} to card {card}" : "{user} engadiu o anexo {attachment} na tarxeta {card}",
    "You have updated the attachment {attachment} on card {card}" : "Vostede actualizou o anexo  {attachment} na tarxeta {card}",
    "{user} has updated the attachment {attachment} on card {card}" : "{user} actualizou o anexo {attachment} na tarxeta {card}",
    "You have deleted the attachment {attachment} from card {card}" : "Vostede eliminou o anexo  {attachment} da tarxeta {card}",
    "{user} has deleted the attachment {attachment} from card {card}" : "{user} eliminou o anexo {attachment} da tarxeta {card}",
    "You have restored the attachment {attachment} to card {card}" : "Vostede restaurou o anexo  {attachment} na tarxeta {card}",
    "{user} has restored the attachment {attachment} to card {card}" : "{user} restaurou o anexo {attachment} da tarxeta {card}",
    "You have commented on card {card}" : "Vostede comentou na tarxeta {card}",
    "{user} has commented on card {card}" : "{user} comentou na tarxeta {card}",
    "A <strong>card description</strong> inside the Deck app has been changed" : "Cambiouse a <strong>descripción da tarxeta</strong> dentro da aplicación Deck",
    "Deck" : "Deck",
    "Changes in the <strong>Deck app</strong>" : "Cambios na <strong>aplicación Deck</strong>",
    "A <strong>comment</strong> was created on a card" : "Creouse un <strong>comentario</strong> nunha tarxeta",
    "Upcoming cards" : "Tarxetas próximas",
    "Load more" : "Cargar máis",
    "Personal" : "Persoal",
    "The card \"%s\" on \"%s\" has been assigned to you by %s." : "A tarxeta «%s» en «%s» foi asignada a vostede por %s.",
    "The card \"%s\" on \"%s\" has reached its due date." : "A tarxeta «%s» en «%s» chegou á súa data de caducidade.",
    "%s has mentioned you in a comment on \"%s\"." : "%s mencionouno a vostede nun comentario en «%s».",
    "The board \"%s\" has been shared with you by %s." : "O taboleiro «%s» foi compartido con vostede por %s.",
    "Card comments" : "Comentarios da tarxeta",
    "%s on %s" : "%s en %s",
    "No data was provided to create an attachment." : "Non se forneceu ningún dato para crear un anexo.",
    "Finished" : "Rematado",
    "To review" : "Para revisar",
    "Action needed" : "Necesita unha acción",
    "Later" : "Despois",
    "copy" : "copiar",
    "To do" : "Para facer",
    "Doing" : "Facendo",
    "Done" : "Feito",
    "Example Task 3" : "Tarefa de exemplo 3",
    "Example Task 2" : "Tarefa de exemplo 2",
    "Example Task 1" : "Tarefa de exemplo 1",
    "The file was uploaded" : "O ficheiro foi enviado",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "O ficheiro enviado excede a directiva indicada por upload_max_filesize de php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "O ficheiro enviado excede da directiva MAX_FILE_SIZE especificada no formulario HTML",
    "The file was only partially uploaded" : "O ficheiro só foi parcialmente enviado",
    "No file was uploaded" : "Non se enviou ningún ficheiro",
    "Missing a temporary folder" : "Falta un cartafol temporal",
    "Could not write file to disk" : "Non foi posíbel escribir o ficheiro no disco",
    "A PHP extension stopped the file upload" : "Unha extensión PHP detivo o envío de ficheiros",
    "No file uploaded or file size exceeds maximum of %s" : "Non se enviou ningún ficheiro ou o tamaño do ficheiro supera o máximo de %s",
    "Card not found" : "Non se atopou a tarxeta",
    "Path is already shared with this card" : "A ruta xa está compartida con esta tarxeta",
    "Invalid date, date format must be YYYY-MM-DD" : "Data incorrecta, o formato da date debe ser AAAA-MM-DD",
    "Personal planning and team project organization" : "Planificación persoal e organización de proxectos de equipo",
    "Card details" : "Detalles da tarxeta",
    "Add board" : "Engadir taboleiro",
    "Select the board to link to a project" : "Seleccione o taboleiro para ligar a un proxecto",
    "Search by board title" : "Buscar polo título do taboleiro",
    "Select board" : "Seleccionar taboleiro",
    "Create a new card" : "Crear unha nova tarxeta",
    "Select a board" : "Seleccione un taboleiro",
    "Select a list" : "Seleccionar unha lista",
    "Card title" : "Título da tarxeta",
    "Cancel" : "Cancelar",
    "Open card" : "Abrir a tarxeta",
    "Close" : "Pechar",
    "Create card" : "Crear tarxeta",
    "Select a card" : "Seleccione unha tarxeta",
    "Select the card to link to a project" : "Seleccione a tarxeta para ligar a un proxecto",
    "Link to card" : "Ligar á tarxeta",
    "File already exists" : "O ficheiro xa existe",
    "A file with the name {filename} already exists." : "Xa existe un ficheiro co nome {filename}.",
    "Do you want to overwrite it?" : "Quere sobrescribilo?",
    "Overwrite file" : "Sobrescribir o ficheiro",
    "Keep existing file" : "Conservar o ficheiro existente",
    "This board is read only" : "Este taboleiro é só de lectura",
    "Drop your files to upload" : "Arrastre os seus ficheiros para envialos",
    "Add card" : "Engadir tarxeta",
    "Archived cards" : "Tarxetas arquivadas",
    "Add list" : "Engadir unha lista",
    "List name" : "Nome da lista",
    "Apply filter" : "Aplicar filtro",
    "Filter by tag" : "Filtrar pola etiqueta",
    "Filter by assigned user" : "Filtrar polo usuario asignado",
    "Unassigned" : "Sen asignar",
    "Filter by due date" : "Filtrar pola data de caducidade",
    "Overdue" : "Caducado",
    "Next 24 hours" : "Próximas 24 horas",
    "Next 7 days" : "Próximos 7 días",
    "Next 30 days" : "Próximos 30 días",
    "No due date" : "Sen data de caducidade",
    "Clear filter" : "Limpar o filtro",
    "Hide archived cards" : "Agochar as tarxetas arquivadas",
    "Show archived cards" : "Amosar as tarxetas arquivadas",
    "Toggle compact mode" : "Alternar o modo compacto",
    "Open details" : "Abrir detalles",
    "Details" : "Detalles",
    "Loading board" : "Cargando o taboleiro",
    "No lists available" : "Non hai listas dispoñíbeis",
    "Create a new list to add cards to this board" : "Crear unha nova lista para engadir tarxetas a este taboleiro",
    "Board not found" : "Non se atopou o taboleiro",
    "Sharing" : "Compartindo",
    "Tags" : "Etiquetas",
    "Deleted items" : "Elementos eliminados",
    "Timeline" : "Liña temporal",
    "Deleted lists" : "Listas eliminadas",
    "Undo" : "Desfacer",
    "Deleted cards" : "Eliminar tarxetas",
    "Share board with a user, group or circle …" : "Compartir taboleiro cun usuario, grupo ou círculo…",
    "Searching for users, groups and circles …" : "Buscando por usuarios, grupos e círculos…",
    "No participants found" : "Non se atoparon participantes",
    "Board owner" : "Propietariio do taboleiro",
    "(Group)" : "(grupo)",
    "(Circle)" : "(Círculo)",
    "Can edit" : "Pode editar",
    "Can share" : "Pode compartir",
    "Can manage" : "Pode xestionar",
    "Owner" : "Propietario",
    "Delete" : "Eliminar",
    "Failed to create share with {displayName}" : "Produciuse un fallo ao crear o uso compartido con {displayName}",
    "Transfer" : "Transferencia",
    "Add a new list" : "Engadir unha lista nova",
    "Archive all cards" : "Arquivar todas as tarxetas",
    "Delete list" : "Eliminar lista",
    "Archive all cards in this list" : "Arquivar todas as tarxetas desta lista",
    "Add a new card" : "Engadir unha nova tarxeta",
    "Card name" : "Nome da tarxeta",
    "List deleted" : "Lista eliminada",
    "Edit" : "Editar",
    "Add a new tag" : "Engadir unha nova etiqueta",
    "title and color value must be provided" : "debe indicar o título e o valor da cor",
    "Board name" : "Nome do taboleiro",
    "Members" : "Membros",
    "Upload new files" : "Enviar novos ficheiros",
    "Share from Files" : "Compartir dende «Ficheiros»",
    "Add this attachment" : "Engadir este anexo",
    "Show in Files" : "Amosar en Ficheiros",
    "Download" : "Descargar",
    "Delete Attachment" : "Eliminar o anexo",
    "Restore Attachment" : "Restaurar o anexo",
    "File to share" : "Ficheiro para compartir",
    "Invalid path selected" : "Seleccionou unha ruta incorrecta.",
    "Open in sidebar view" : "Abrir na vista da barra lateral",
    "Open in bigger view" : "Abrir nunha vista máis grande",
    "Attachments" : "Anexos",
    "Comments" : "Comentarios",
    "Modified" : "Modificado",
    "Created" : "Creado",
    "The title cannot be empty." : "O título non pode estar baleiro.",
    "No comments yet. Begin the discussion!" : "Aínda non hai comentarios. Comece o debate!",
    "Assign a tag to this card…" : "Asignar unha etiqueta a esta tarxeta…",
    "Assign to users" : "Asignar a usuarios",
    "Assign to users/groups/circles" : "Asignar a usuarios/grupos/círculos",
    "Assign a user to this card…" : "Asigna un usuario a esta tarxeta…",
    "Due date" : "Data de caducidade",
    "Set a due date" : "Estabelecer a data de caducidade",
    "Remove due date" : "Retirar a data de caducidade",
    "Select Date" : "Seleccione a data",
    "Today" : "Hoxe",
    "Tomorrow" : "Mañá",
    "Next week" : "Semana seguinte",
    "Next month" : "Mes seguinte",
    "Save" : "Gardar",
    "The comment cannot be empty." : "O comentario non pode estar baleiro",
    "The comment cannot be longer than 1000 characters." : "O comentario non pode ter máis de 1000 caracteres.",
    "In reply to" : "En resposta a",
    "Reply" : "Responder",
    "Update" : "Actualizar",
    "Description" : "Descrición",
    "(Unsaved)" : "(Sen gardar)",
    "(Saving…)" : "(Gardando…)",
    "Formatting help" : "Axuda de formatado",
    "Edit description" : "Editar a descrición",
    "View description" : "Ver a descrición",
    "Add Attachment" : "Engadir o anexo",
    "Write a description …" : "Escriba unha descrición…",
    "Choose attachment" : "Escoller o anexo",
    "(group)" : "(grupo)",
    "Assign to me" : "Asignarme",
    "Unassign myself" : "Desasignarme",
    "Move card" : "Mover a tarxeta",
    "Unarchive card" : "Desarquivar a tarxeta",
    "Archive card" : "Arquivar a tarxeta",
    "Delete card" : "Eliminar tarxeta",
    "Move card to another board" : "Mover a tarxeta a outro taboleiro",
    "List is empty" : "A lista está baleira",
    "Card deleted" : "Tarxeta eliminada",
    "seconds ago" : "hai uns segundos",
    "All boards" : "Todos os taboleiros",
    "Archived boards" : "Taboleiros arquivados",
    "Shared with you" : "Compartido con vostede",
    "Use bigger card view" : "Usa a vista de tarxeta máis grande",
    "Show boards in calendar/tasks" : "Amosar taboleiros no calendario/tarefas",
    "Limit deck usage of groups" : "Limitar o uso da plataforma a grupos",
    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Limitando Deck bloqueará os usuarios que non formen parte destes grupos, para crear os seus propios taboleiros. Os usuarios aínda así poderán traballar en taboleiros compartidos con eles.",
    "Board details" : "Detalles do taboleiro",
    "Edit board" : "Editar taboleiro",
    "Clone board" : "Clonar taboleiro",
    "Unarchive board" : "Desarquivar taboleiro",
    "Archive board" : "Arquivar taboleiro",
    "Turn on due date reminders" : "Activar os lembretes de data de caducidade",
    "Turn off due date reminders" : "Desctivar os lembretes de data de caducidade",
    "Due date reminders" : "Lembretes de data de caducidade",
    "All cards" : "Todas as tarxeta",
    "Assigned cards" : "Tarxetas asignadas",
    "No notifications" : "Non hai notificacións",
    "Delete board" : "Eliminar taboleiro",
    "Board {0} deleted" : "Eliminouse o taboleiro {0}",
    "Only assigned cards" : "Só as tarxetas asignadas",
    "No reminder" : "Non hai lembretes",
    "An error occurred" : "Produciuse un erro",
    "Delete the board?" : "Eliminar o taboleiro?",
    "Loading filtered view" : "Cargando a vista filtrada",
    "No due" : "Sen caducidade",
    "Search for {searchQuery} in all boards" : "Resultados de busca para {searchQuery} en todos os taboleiros",
    "No results found" : "Non se atoparon resultados",
    "{stack} in {board}" : "{stack} en {board}",
    "No upcoming cards" : "Non hai tarxetas próximas",
    "upcoming cards" : "tarxetas próximas",
    "Link to a board" : "Ligar a un taboleiro",
    "Link to a card" : "Ligar a unha tarxeta",
    "Create a card" : "Crear unha tarxeta",
    "Message from {author} in {conversationName}" : "Mensaxe de {author} en {conversationName}",
    "Something went wrong" : "Algo foi mal",
    "Failed to upload {name}" : "Produciuse un fallo ao actualizar {name}",
    "Maximum file size of {size} exceeded" : "Excedeuse o tamaño máximo de ficheiro de {size}",
    "Error creating the share" : "Produciuse un erro ao crear a compartición",
    "Share with a Deck card" : "Compartir cunha tarxeta Deck",
    "Share {file} with a Deck card" : "Compartir {file} cunha tarxeta Deck",
    "Share" : "Compartir",
    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Deck é unha ferramenta de organización de estilo kanban dirixida a planificación persoal e organización de proxectos para equipos integrados con Nextcloud. \n\n\n- 📥 Engada as súas tarefas ás tarxetas e fagas ordenadas\n- 📄 Escriba notas adicionais en markdown\n- 🔖 Asigne etiquetas para unha mellor organización\n- 👥 Comparta co seu equipo, amigos ou a súa familia\n- 📎 Anexe ficheiros e insíraos na súa descrición de markdown\n- 💬 Debata co seu equipo usando os comentarios\n- ⚡ Faga un seguimento dos cambios no fluxo de actividade\n- 🚀 Teña o seu proxecto organizado",
    "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "Confirma que quere eliminar o taboleiro {title}? Isto eliminará todos os datos deste taboleiro.",
    "This week" : "Esta semana"
},
"nplurals=2; plural=(n != 1);");
