OC.L10N.register(
    "deck",
    {
    "Personal" : "Peribadi",
    "Done" : "Done",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Saiz fail yang dimuatnaik melebihi MAX_FILE_SIZE yang ditetapkan dalam borang HTML",
    "No file was uploaded" : "Tiada fail dimuatnaik",
    "Missing a temporary folder" : "Direktori sementara hilang",
    "Cancel" : "Batal",
    "Close" : "Tutup",
    "Can edit" : "Can edit",
    "Can share" : "Can share",
    "Owner" : "Owner",
    "Delete" : "Padam",
    "Edit" : "Sunting",
    "Download" : "Muat turun",
    "Modified" : "Dimodifikasi",
    "Today" : "Hari ini",
    "Save" : "Simpan",
    "Update" : "Kemaskini",
    "Description" : "Keterangan",
    "Shared with you" : "Shared with you",
    "Share" : "Kongsi"
},
"nplurals=1; plural=0;");
