OC.L10N.register(
    "deck",
    {
    "You have created a new board {board}" : "Stvorili ste novu ploču {board}",
    "{user} has created a new board {board}" : "{user} je stvorio novu ploču {board}",
    "You have deleted the board {board}" : "Izbrisali ste ploču {board}",
    "{user} has deleted the board {board}" : "{user} je izbrisao ploču {board}",
    "You have restored the board {board}" : "Vratili ste ploču {board}",
    "{user} has restored the board {board}" : "{user} je vratio ploču {board}",
    "You have shared the board {board} with {acl}" : "Podijelili ste ploču {board} s {acl}",
    "{user} has shared the board {board} with {acl}" : "{user} je podijelio ploču {board} s {acl}",
    "You have removed {acl} from the board {board}" : "Uklonili ste {acl} s ploče {board}",
    "{user} has removed {acl} from the board {board}" : "{user} je uklonio {acl} s ploče {board}",
    "You have renamed the board {before} to {board}" : "Preimenovali ste ploču {before} u {board}",
    "{user} has renamed the board {before} to {board}" : "{user} je preimenovao ploču {before} u {board}",
    "You have archived the board {board}" : "Arhivirali ste ploču {board}",
    "{user} has archived the board {before}" : "{user} je arhivirao ploču {before}",
    "You have unarchived the board {board}" : "Dearhivirali ste ploču {board}",
    "{user} has unarchived the board {before}" : "{user} je dearhivirao ploču {before}",
    "You have created a new list {stack} on board {board}" : "Stvorili ste novi popis {stack} na ploči {board}",
    "{user} has created a new list {stack} on board {board}" : "{user} je stvorio novi popis {stack} na ploči {board}",
    "You have renamed list {before} to {stack} on board {board}" : "Preimenovali ste popis {before} u {stack} na ploči {board}",
    "{user} has renamed list {before} to {stack} on board {board}" : "{user} je preimenovao popis {before} u {stack} na ploči {board}",
    "You have deleted list {stack} on board {board}" : "Izbrisali ste popis {stack} na ploči {board}",
    "{user} has deleted list {stack} on board {board}" : "{user} je izbrisao popis {stack} na ploči {board}",
    "You have created card {card} in list {stack} on board {board}" : "Stvorili ste karticu {card} u popisu {stack} na ploči {board}",
    "{user} has created card {card} in list {stack} on board {board}" : "{user} je stvorio karticu {card} u popisu {stack} na ploči {board}",
    "You have deleted card {card} in list {stack} on board {board}" : "Izbrisali ste karticu {card} u popisu {stack} na ploči {board}",
    "{user} has deleted card {card} in list {stack} on board {board}" : "{user} je izbrisao karticu {card} u popisu {stack} na ploči {board}",
    "You have renamed the card {before} to {card}" : "Preimenovali ste karticu {before} u {card}",
    "{user} has renamed the card {before} to {card}" : "{user} je preimenovao karticu {before} u {card}",
    "You have added a description to card {card} in list {stack} on board {board}" : "Dodali ste opis kartici {card} u popisu {stack} na ploči {board}",
    "{user} has added a description to card {card} in list {stack} on board {board}" : "{user} je dodao opis kartici {card} u popisu {stack} na ploči {board}",
    "You have updated the description of card {card} in list {stack} on board {board}" : "Ažurirali ste opis kartice {card} u popisu {stack} na ploči {board}",
    "{user} has updated the description of the card {card} in list {stack} on board {board}" : "{user} je ažurirao opis kartice {card} u popisu {stack} na ploči {board}",
    "You have archived card {card} in list {stack} on board {board}" : "Arhivirali ste karticu {card} u popisu {stack} na ploči {board}",
    "{user} has archived card {card} in list {stack} on board {board}" : "{user} je arhivirao karticu {card} u popisu {stack} na ploči {board}",
    "You have unarchived card {card} in list {stack} on board {board}" : "Dearhivirali ste karticu {card} u popisu {stack} na ploči {board}",
    "{user} has unarchived card {card} in list {stack} on board {board}" : "{user} je dearhivirao karticu {card} u popisu {stack} na ploči {board}",
    "You have removed the due date of card {card}" : "Uklonili ste datum dospijeća kartice {card}",
    "{user} has removed the due date of card {card}" : "{user} je uklonio datum dospijeća kartice {card}",
    "You have set the due date of card {card} to {after}" : "Postavili ste datum dospijeća kartice {card} na {after}",
    "{user} has set the due date of card {card} to {after}" : "{user} je postavio datum dospijeća kartice {card} na {after}",
    "You have updated the due date of card {card} to {after}" : "Ažurirali ste datum dospijeća kartice {card} na {after}",
    "{user} has updated the due date of card {card} to {after}" : "{user} je ažurirao datum dospijeća kartice {card} na {after}",
    "You have added the tag {label} to card {card} in list {stack} on board {board}" : "Dodali ste oznaku {label} na karticu {card} u popisu {stack} na ploči {board}",
    "{user} has added the tag {label} to card {card} in list {stack} on board {board}" : "{user} je dodao oznaku {label} na karticu {card} u popisu {stack} na ploči {board}",
    "You have removed the tag {label} from card {card} in list {stack} on board {board}" : "Uklonili ste oznaku {label} s kartice {card} u popisu {stack} na ploči {board}",
    "{user} has removed the tag {label} from card {card} in list {stack} on board {board}" : "{user} je uklonio oznaku {label} s kartice {card} u popisu {stack} na ploči {board}",
    "You have assigned {assigneduser} to card {card} on board {board}" : "Dodijelili ste {assigneduser} kartici {card} na ploči {board}",
    "{user} has assigned {assigneduser} to card {card} on board {board}" : "{user} je dodijelio {assigneduser} kartici {card} na ploči {board}",
    "You have unassigned {assigneduser} from card {card} on board {board}" : "Uklonili ste {assigneduser} s kartice {card} na ploči {board}",
    "{user} has unassigned {assigneduser} from card {card} on board {board}" : "{user} je uklonio {assigneduser} s kartice {card} na ploči {board}",
    "You have moved the card {card} from list {stackBefore} to {stack}" : "Premjestili ste karticu {card} iz popisa {stackBefore} u {stack}",
    "{user} has moved the card {card} from list {stackBefore} to {stack}" : "{user} je premjestio karticu {card} iz popisa {stackBefore} u {stack}",
    "You have added the attachment {attachment} to card {card}" : "Dodali ste privitak {attachment} kartici {card}",
    "{user} has added the attachment {attachment} to card {card}" : "{user} je dodao privitak {attachment} kartici {card}",
    "You have updated the attachment {attachment} on card {card}" : "Ažurirali ste privitak {attachment} na kartici {card}",
    "{user} has updated the attachment {attachment} on card {card}" : "{user} je ažurirao privitak {attachment} na kartici {card}",
    "You have deleted the attachment {attachment} from card {card}" : "Izbrisali ste privitak {attachment} s kartice {card}",
    "{user} has deleted the attachment {attachment} from card {card}" : "{user} je izbrisao privitak {attachment} s kartice {card}",
    "You have restored the attachment {attachment} to card {card}" : "Vratili ste privitak {attachment} na karticu {card}",
    "{user} has restored the attachment {attachment} to card {card}" : "{user} je vratio privitak {attachment} na karticu {card}",
    "You have commented on card {card}" : "Komentirali ste karticu {card}",
    "{user} has commented on card {card}" : "{user} je komentirao karticu {card}",
    "A <strong>card description</strong> inside the Deck app has been changed" : "Promijenjen je <strong>opis kartice</strong> u aplikaciji Deck",
    "Deck" : "Deck",
    "Changes in the <strong>Deck app</strong>" : "Promjene u <strong>aplikaciji Deck</strong>",
    "A <strong>comment</strong> was created on a card" : "Na kartici je stvoren <strong>komentar</strong>",
    "Upcoming cards" : "Nadolazeće kartice",
    "Load more" : "Učitaj više",
    "Personal" : "Osobno",
    "The card \"%s\" on \"%s\" has been assigned to you by %s." : "Karticu „%s” na „%s” dodijelio vam je %s.",
    "{user} has assigned the card {deck-card} on {deck-board} to you." : "{user} vam je dodijelio karticu {deck-card} na {deck-board}.",
    "The card \"%s\" on \"%s\" has reached its due date." : "Kartica „%s” na „%s” dosegla je datum dospijeća.",
    "The card {deck-card} on {deck-board} has reached its due date." : "Kartica {deck-card} na {deck-board} dosegla je datum dospijeća.",
    "%s has mentioned you in a comment on \"%s\"." : "%s vas spominje u komentaru na „%s”.",
    "{user} has mentioned you in a comment on {deck-card}." : "{user} vas je spomenuo u komentaru na {deck-card}.",
    "The board \"%s\" has been shared with you by %s." : "Ploču „%s” je s vama podijelio %s.",
    "{user} has shared {deck-board} with you." : "{user} s vama dijeli {deck-board}.",
    "Card comments" : "Komentari o kartici",
    "%s on %s" : "%s na %s",
    "No data was provided to create an attachment." : "Nema podataka za izradu privitka.",
    "Finished" : "Završeno",
    "To review" : "Provjeriti",
    "Action needed" : "Potrebna radnja",
    "Later" : "Kasnije",
    "copy" : "kopiraj",
    "To do" : "Zadatak",
    "Doing" : "U postupku",
    "Done" : "Gotovo",
    "Example Task 3" : "Primjer zadatka 3.",
    "Example Task 2" : "Primjer zadatka 2.",
    "Example Task 1" : "Primjer zadatka 1.",
    "The file was uploaded" : "Datoteka je otpremljena",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Otpremljena datoteka premašuje postavku upload_max_filesize u datoteci php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Otpremljena datoteka premašuje postavku MAX_FILE_SIZE koja je navedena u obrascu HTML-a",
    "The file was only partially uploaded" : "Datoteka je samo djelomično otpremljena",
    "No file was uploaded" : "Nije otpremljena nijedna datoteka",
    "Missing a temporary folder" : "Nedostaje privremena mapa",
    "Could not write file to disk" : "Nije moguće zapisati datoteku na disk",
    "A PHP extension stopped the file upload" : "Proširenje PHP-a zaustavilo je otpremanje datoteke",
    "No file uploaded or file size exceeds maximum of %s" : "Nijedna datoteka nije otpremljena ili veličina datoteke premašuje maksimalnu veličinu od %s",
    "Card not found" : "Kartica nije pronađena",
    "Path is already shared with this card" : "Put je već podijeljen s ovom karticom",
    "Invalid date, date format must be YYYY-MM-DD" : "Nevažeći datum, oblik datuma mora biti GGGG-MM-DD",
    "Personal planning and team project organization" : "Osobno planiranje i organizacija timskih projekata",
    "Card details" : "Pojedinosti o kartici",
    "Add board" : "Dodaj ploču",
    "Select the board to link to a project" : "Odaberite ploču za povezivanje s projektom",
    "Search by board title" : "Traži po naslovu ploče",
    "Select board" : "Odaberi ploču",
    "Create a new card" : "Stvori novu karticu",
    "Select a board" : "Odaberite ploču",
    "Select a list" : "Odaberi popis",
    "Card title" : "Naslov kartice",
    "Cancel" : "Odustani",
    "Creating the new card …" : "Stvaranje nove kartice…",
    "Card \"{card}\" was added to \"{board}\"" : "Kartica „{card}” je dodana na „{board}”",
    "Open card" : "Otvori karticu",
    "Close" : "Zatvori",
    "Create card" : "Stvori karticu",
    "Select a card" : "Odaberite karticu",
    "Select the card to link to a project" : "Odaberite karticu za povezivanje s projektom",
    "Link to card" : "Poveznica na karticu",
    "File already exists" : "Datoteka već postoji",
    "A file with the name {filename} already exists." : "Datoteka s nazivom {filename} već postoji.",
    "Do you want to overwrite it?" : "Želite li prepisati?",
    "Overwrite file" : "Prepiši datoteku",
    "Keep existing file" : "Zadrži postojeću datoteku",
    "This board is read only" : "Ova je ploča samo za čitanje",
    "Drop your files to upload" : "Ispustite datoteke za otpremu",
    "Add card" : "Dodaj karticu",
    "Archived cards" : "Arhivirane kartice",
    "Add list" : "Dodaj popis",
    "List name" : "Naziv popisa",
    "Apply filter" : "Primijeni filtar",
    "Filter by tag" : "Filtriraj prema oznaci",
    "Filter by assigned user" : "Filtriraj prema dodijeljenom korisniku",
    "Unassigned" : "Nedodijeljeno",
    "Filter by due date" : "Filtriraj prema datumu dospijeća",
    "Overdue" : "Kasni",
    "Next 24 hours" : "Sljedeća 24 sata",
    "Next 7 days" : "Sljedećih 7 dana",
    "Next 30 days" : "Sljedećih 30 dana",
    "No due date" : "Nema datuma dospijeća",
    "Clear filter" : "Ukloni filtar",
    "Hide archived cards" : "Sakrij arhivirane kartice",
    "Show archived cards" : "Prikaži arhivirane kartice",
    "Toggle compact mode" : "Prebaci u kompaktni način rada",
    "Open details" : "Otvori pojedinosti",
    "Details" : "Pojedinosti",
    "Loading board" : "Učitavanje ploče",
    "No lists available" : "Nema dostupnih popisa",
    "Create a new list to add cards to this board" : "Stvorite novi popis kako biste dodali kartice na ovu ploču",
    "Board not found" : "Ploča nije pronađena",
    "Sharing" : "Dijeljenje",
    "Tags" : "Oznake",
    "Deleted items" : "Izbrisane stavke",
    "Timeline" : "Vremenska crta",
    "Deleted lists" : "Izbrisani popisi",
    "Undo" : "Poništi",
    "Deleted cards" : "Izbrisane kartice",
    "Share board with a user, group or circle …" : "Dijelite ploču s korisnikom, grupom ili krugom...",
    "Searching for users, groups and circles …" : "Traženje korisnika, grupa i krugova...",
    "No participants found" : "Nije pronađen nijedan sudionik",
    "Board owner" : "Vlasnik ploče",
    "(Group)" : "(Grupa)",
    "(Circle)" : "(Krug)",
    "Can edit" : "Uređivanje moguće",
    "Can share" : "Dijeljenje moguće",
    "Can manage" : "Upravljanje moguće",
    "Owner" : "Vlasnik",
    "Delete" : "Izbriši",
    "Failed to create share with {displayName}" : "Dijeljenje s {displayName} nije uspjelo",
    "Transfer" : "Prijenos",
    "Add a new list" : "Dodaj novi popis",
    "Archive all cards" : "Arhiviraj sve kartice",
    "Delete list" : "Izbriši popis",
    "Archive all cards in this list" : "Arhiviraj sve kartice s ovog popisa",
    "Add a new card" : "Dodaj novu karticu",
    "Card name" : "Naziv kartice",
    "List deleted" : "Popis je izbrisan",
    "Edit" : "Uredi",
    "Add a new tag" : "Dodaj novu oznaku",
    "title and color value must be provided" : "potrebno je odabrati naziv i vrijednost boje",
    "Board name" : "Naziv ploče",
    "Members" : "Članovi",
    "Upload new files" : "Otpremi nove datoteke",
    "Share from Files" : "Dijeli iz datoteka",
    "Add this attachment" : "Dodajte ovaj privitak",
    "Show in Files" : "Prikaži u datotekama",
    "Download" : "Preuzmi",
    "Delete Attachment" : "Izbriši privitak",
    "Restore Attachment" : "Vrati privitak",
    "File to share" : "Datoteka za dijeljenje",
    "Invalid path selected" : "Odabran nevažeći put",
    "Open in sidebar view" : "Otvori u bočnom prikazu",
    "Open in bigger view" : "Otvori u većem prikazu",
    "Attachments" : "Privici",
    "Comments" : "Komentari",
    "Modified" : "Promijenjeno",
    "Created" : "Stvoreno",
    "The title cannot be empty." : "Naslov ne može biti prazan.",
    "No comments yet. Begin the discussion!" : "Nema komentara. Započnite raspravu!",
    "Failed to load comments" : "Učitavanje komentara nije uspjelo",
    "Assign a tag to this card…" : "Dodijeli oznaku ovoj kartici...",
    "Assign to users" : "Dodijeli korisnicima",
    "Assign to users/groups/circles" : "Dodijeli korisnicima/grupama/krugovima",
    "Assign a user to this card…" : "Dodijeli korisnika ovoj kartici...",
    "Due date" : "Datum dospijeća",
    "Set a due date" : "Postavi datum dospijeća",
    "Remove due date" : "Ukloni datum dospijeća",
    "Select Date" : "Odaberi datum",
    "Today" : "Danas",
    "Tomorrow" : "Sutra",
    "Next week" : "Sljedeći tjedan",
    "Next month" : "Sljedeći mjesec",
    "Save" : "Spremi",
    "The comment cannot be empty." : "Komentar ne može biti prazan.",
    "The comment cannot be longer than 1000 characters." : "Komentar ne može duži od 1000 znakova.",
    "In reply to" : "Kao odgovor",
    "Cancel reply" : "Prekini odgovor",
    "Reply" : "Odgovori",
    "Update" : "Ažuriraj",
    "Description" : "Opis",
    "(Unsaved)" : "(Nije spremljeno)",
    "(Saving…)" : "(Spremanje…)",
    "Formatting help" : "Pomoć pri oblikovanju",
    "Edit description" : "Uredi opis",
    "View description" : "Prikaži opis",
    "Add Attachment" : "Dodaj privitak",
    "Write a description …" : "Napišite opis...",
    "Choose attachment" : "Odaberi privitak",
    "(group)" : "(grupa)",
    "{count} comments, {unread} unread" : "{count} komentara, {unread} nepročitanih",
    "Assign to me" : "Dodijeli meni",
    "Unassign myself" : "Ukloni sebe",
    "Move card" : "Premjesti karticu",
    "Unarchive card" : "Dearhiviraj karticu",
    "Archive card" : "Arhiviraj karticu",
    "Delete card" : "Izbriši karticu",
    "Move card to another board" : "Premjesti karticu na drugu ploču",
    "List is empty" : "Popis je prazan",
    "Card deleted" : "Kartica je izbrisana",
    "seconds ago" : "prije nekoliko sekundi",
    "All boards" : "Sve ploče",
    "Archived boards" : "Arhivirane ploče",
    "Shared with you" : "Podijeljeno s vama",
    "Use bigger card view" : "Prikaži veće kartice",
    "Show boards in calendar/tasks" : "Prikaži ploče u kalendaru/zadacima",
    "Limit deck usage of groups" : "Ograniči uporabu decka grupama",
    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Ograničenjem Decka možete spriječiti korisnike koji ne sudjeluju u tim grupama da stvaraju vlastite ploče. Korisnici će i dalje moći raditi na pločama koje su dijeljene s njima.",
    "Board details" : "Pojedinosti o ploči",
    "Edit board" : "Uredi ploču",
    "Clone board" : "Kloniraj ploču",
    "Unarchive board" : "Dearhiviraj ploču",
    "Archive board" : "Arhiviraj ploču",
    "Turn on due date reminders" : "Uključi podsjetnike datuma dospijeća",
    "Turn off due date reminders" : "Isključi podsjetnike datuma dospijeća",
    "Due date reminders" : "Podsjetnici datuma dospijeća",
    "All cards" : "Sve kartice",
    "Assigned cards" : "Dodijeljene kartice",
    "No notifications" : "Nema obavijesti",
    "Delete board" : "Izbriši ploču",
    "Board {0} deleted" : "Ploča {0} je izbrisana",
    "Only assigned cards" : "Samo dodijeljene kartice",
    "No reminder" : "Nema podsjetnika",
    "An error occurred" : "Došlo je do pogreške",
    "Delete the board?" : "Želite li izbrisati ploču?",
    "Loading filtered view" : "Učitavanje filtriranog prikaza",
    "No due" : "Nema nezavršenih",
    "Search for {searchQuery} in all boards" : "Traži {searchQuery} na svim pločama",
    "No results found" : "Nema rezultata",
    "{stack} in {board}" : "{stack} u {board}",
    "No upcoming cards" : "Nema nadolazećih kartica",
    "upcoming cards" : "nadolazeće kartice",
    "Link to a board" : "Poveznica na ploču",
    "Link to a card" : "Poveznica na karticu",
    "Create a card" : "Stvori karticu",
    "Message from {author} in {conversationName}" : "Poruka od {author} u {conversationName}",
    "Something went wrong" : "Nešto je pošlo po krivu",
    "Failed to upload {name}" : "Neuspješno otpremanje {name}",
    "Maximum file size of {size} exceeded" : "Prekoračena je maksimalna veličina datoteke od {size}",
    "Error creating the share" : "Pogreška pri stvaranju dijeljenja",
    "Share with a Deck card" : "Dijeli s Deck karticom",
    "Share {file} with a Deck card" : "Dijeli {file} s Deck karticom",
    "Share" : "Dijeli",
    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Deck je organizacijski alat za kanban projekte usmjeren na osobno planiranje i organizaciju projekta za timove integrirane s Nextcloudom.\n\n\n- 📥 Dodajte svoje zadatke na kartice i poredajte ih po želji\n- 📄 Zapišite dodatne bilješke u markdown\n- 🔖 Dodijelite oznake za još bolju organizaciju\n- 👥 Dijelite sa svojim timom, prijateljima ili obitelji\n- 📎 Priložite datoteke i ugradite ih u svoj markdown opis\n- 💬 Raspravljajte sa svojim timom putem komentara\n- ⚡ Pratite promjene u strujanju aktivnosti\n- 🚀 Organizirajte svoj projekt",
    "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "Jeste li sigurni da želite izbrisati ploču {title}? Time ćete izbrisati sve podatke ploče.",
    "This week" : "Ovaj tjedan"
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
