OC.L10N.register(
    "deck",
    {
    "You have created a new board {board}" : "Vous avez créé un nouveau tableau {board}",
    "{user} has created a new board {board}" : "{user} a créé un nouveau tableau {board}",
    "You have deleted the board {board}" : "Vous avez supprimé le tableau {board}",
    "{user} has deleted the board {board}" : "{user} a supprimé le tableau {board}",
    "You have restored the board {board}" : "Vous avez restauré le tableau {board}",
    "{user} has restored the board {board}" : "{user} a restauré le tableau {board}",
    "You have shared the board {board} with {acl}" : "Vous avez partagé le tableau {board} avec {acl}",
    "{user} has shared the board {board} with {acl}" : "{user} a partagé le tableau {board} en {acl}",
    "You have removed {acl} from the board {board}" : "Vous avez supprimé {acl} du tableau {board}",
    "{user} has removed {acl} from the board {board}" : "{user} a supprimé {acl} du tableau {board}",
    "You have renamed the board {before} to {board}" : "Vous avez renommé le tableau {before} en {board}",
    "{user} has renamed the board {before} to {board}" : "{user} a renommé le tableau {before} en {board}",
    "You have archived the board {board}" : "Vous avez archivé le tableau {board}",
    "{user} has archived the board {before}" : "{user} a archivé le tableau {before}",
    "You have unarchived the board {board}" : "Vous avez désarchivé le tableau {board}",
    "{user} has unarchived the board {before}" : "{user} a désarchivé le tableau {before}",
    "You have created a new list {stack} on board {board}" : "Vous avez créé une nouvelle liste {stack} sur le tableau {board}",
    "{user} has created a new list {stack} on board {board}" : "{user} a créé une nouvelle liste {stack} sur le tableau {board}",
    "You have renamed list {before} to {stack} on board {board}" : "Vous avez renommé la liste {before} en {stack} sur le tableau {board}",
    "{user} has renamed list {before} to {stack} on board {board}" : "{user} a renommé la liste {before} en {stack} sur le tableau {board}",
    "You have deleted list {stack} on board {board}" : "Vous avez supprimé la liste {stack} sur le tableau {board}",
    "{user} has deleted list {stack} on board {board}" : "{user} a supprimé la liste {stack} sur le tableau {board}",
    "You have created card {card} in list {stack} on board {board}" : "Vous avez créé la carte {card} dans la liste {stack} du tableau {board}",
    "{user} has created card {card} in list {stack} on board {board}" : "{user} a créé la carte {card} dans la liste {stack} du tableau {board}",
    "You have deleted card {card} in list {stack} on board {board}" : "Vous avez supprimé la carte {card} de la liste {stack} du tableau {board}",
    "{user} has deleted card {card} in list {stack} on board {board}" : "{user} a supprimé la carte {card} de la liste {stack} du tableau {board}",
    "You have renamed the card {before} to {card}" : "Vous avez renommé la carte {before} en {card}",
    "{user} has renamed the card {before} to {card}" : "{user} a renommé la carte {before} en {card}",
    "You have added a description to card {card} in list {stack} on board {board}" : "Vous avez ajouté une description à la carte {card} de la liste {stack} du tableau {board}",
    "{user} has added a description to card {card} in list {stack} on board {board}" : "{user} a ajouté une description à la carte {card} de la liste {stack} du tableau {board}",
    "You have updated the description of card {card} in list {stack} on board {board}" : "Vous avez mis à jour la description de la carte {card} de la liste {stack} du tableau {board}",
    "{user} has updated the description of the card {card} in list {stack} on board {board}" : "{user} a mis à jour la description de la carte {card} de la liste {stack} du tableau {board}",
    "You have archived card {card} in list {stack} on board {board}" : "Vous avez archivé la carte {card} de la liste {stack} du tableau {board}",
    "{user} has archived card {card} in list {stack} on board {board}" : "{user} a archivé la carte {card} de la liste {stack} du tableau {board}",
    "You have unarchived card {card} in list {stack} on board {board}" : "Vous avez désarchivé la carte {card} de la liste {stack} du tableau {board}",
    "{user} has unarchived card {card} in list {stack} on board {board}" : "{user} a désarchivé la carte {card} de la liste {stack} du tableau {board}",
    "You have removed the due date of card {card}" : "Vous avez supprimé la date d'échéance de la carte {card}",
    "{user} has removed the due date of card {card}" : "{user} a supprimé la date d'échéance de la carte {card}",
    "You have set the due date of card {card} to {after}" : "Vous avez établi la date d'échéance de la carte {card} à {after}",
    "{user} has set the due date of card {card} to {after}" : "{user} a établi la date d'échéance de la carte {card} à {after}",
    "You have updated the due date of card {card} to {after}" : "Vous avez mis à jour la date d'échéance de la carte {card} à {after}",
    "{user} has updated the due date of card {card} to {after}" : "{user} a mis à jour la date d'échéance de la carte {card} à {after}",
    "You have added the tag {label} to card {card} in list {stack} on board {board}" : "Vous avez ajouté l'étiquette {label} à la carte {card} de la liste {stack} du tableau {board}",
    "{user} has added the tag {label} to card {card} in list {stack} on board {board}" : "{user} a ajouté l'étiquette {label} à la carte {card} de la liste {stack} du tableau {board}",
    "You have removed the tag {label} from card {card} in list {stack} on board {board}" : "Vous avez supprimé l'étiquette {label} de la carte {card} de la liste {stack} du tableau {board}",
    "{user} has removed the tag {label} from card {card} in list {stack} on board {board}" : "{user} a supprimé l'étiquette {label} de la carte {card} de la liste {stack} du tableau {board}",
    "You have assigned {assigneduser} to card {card} on board {board}" : "Vous avez assigné {assigneduser} à la carte {card} du tableau {board}",
    "{user} has assigned {assigneduser} to card {card} on board {board}" : "{user} a assigné {assigneduser} à la carte {card} du tableau {board}",
    "You have unassigned {assigneduser} from card {card} on board {board}" : "Vous avez retiré {assigneduser} de la carte {card} du tableau {board}",
    "{user} has unassigned {assigneduser} from card {card} on board {board}" : "{user} a retiré {assigneduser} de la carte {card} du tableau {board}",
    "You have moved the card {card} from list {stackBefore} to {stack}" : "Vous avez déplacé la carte {card} de la liste {stackBefore} vers {stack}",
    "{user} has moved the card {card} from list {stackBefore} to {stack}" : "{user} a déplacé la carte {card} de la liste {stackBefore} vers {stack}",
    "You have added the attachment {attachment} to card {card}" : "Vous avez ajouté la pièce jointe {attachment} à la carte {card}",
    "{user} has added the attachment {attachment} to card {card}" : "{user} a ajouté la pièce jointe {attachment} à la carte {card}",
    "You have updated the attachment {attachment} on card {card}" : "Vous avez mis à jour la pièce jointe {attachment} de la carte {card}",
    "{user} has updated the attachment {attachment} on card {card}" : "{user} a mis à jour la pièce jointe {attachment} de la carte {card}",
    "You have deleted the attachment {attachment} from card {card}" : "Vous avez supprimé la pièce jointe {attachment} de la carte {card}",
    "{user} has deleted the attachment {attachment} from card {card}" : "{user} a supprimé la pièce jointe {attachment} de la carte {card}",
    "You have restored the attachment {attachment} to card {card}" : "Vous avez restauré la pièce jointe {attachment} de la carte {card}",
    "{user} has restored the attachment {attachment} to card {card}" : "{user} a restauré la pièce jointe {attachment} de la carte {card}",
    "You have commented on card {card}" : "Vous avez commenté la carte {card}",
    "{user} has commented on card {card}" : "{user} a commenté la carte {card}",
    "A <strong>card description</strong> inside the Deck app has been changed" : "La <strong>description de la carte</strong> présente dans l'application Deck a été modifiée",
    "Deck" : "Deck",
    "Changes in the <strong>Deck app</strong>" : "Modifications dans <strong>Deck app</strong>",
    "A <strong>comment</strong> was created on a card" : "Un  <strong>commentaire</strong> a été créé sur une carte",
    "Upcoming cards" : "Cartes à venir",
    "Load more" : "Charger d'avantage",
    "Personal" : "Personnel",
    "The card \"%s\" on \"%s\" has been assigned to you by %s." : "La carte \"%s\" de \"%s\" vous a été assignée par %s.",
    "{user} has assigned the card {deck-card} on {deck-board} to you." : "{user} vous a attribué la carte {deck-card} du tableau {deck-board}.",
    "The card \"%s\" on \"%s\" has reached its due date." : "La date d'échéance de la carte \"%s\" de \"%s\" a été atteinte.",
    "The card {deck-card} on {deck-board} has reached its due date." : "La carte {deck-card} sur {deck-board} a atteint sa date d'échéance.",
    "%s has mentioned you in a comment on \"%s\"." : "%s vous a mentionné dans un commentaire sur \"%s\".",
    "{user} has mentioned you in a comment on {deck-card}." : "{user} vous a cité dans un commentaire sur {deck-card}.",
    "The board \"%s\" has been shared with you by %s." : "Le tableau \"%s\" a été partagé avec vous par %s.",
    "{user} has shared {deck-board} with you." : "{user} vous a partagé le tableau {deck-board}.",
    "Card comments" : "Commentaires de la carte",
    "%s on %s" : "%s sur %s",
    "No data was provided to create an attachment." : "Aucune donnée n'a été fournie pour créer une pièce jointe.",
    "Finished" : "Terminé",
    "To review" : "A réviser",
    "Action needed" : "Action requise",
    "Later" : "Plus tard",
    "copy" : "copie",
    "To do" : "À faire",
    "Doing" : "En cours",
    "Done" : "Terminé",
    "Example Task 3" : "Exemple de tâche 3",
    "Example Task 2" : "Exemple de tâche 2",
    "Example Task 1" : "Exemple de tâche 1",
    "The file was uploaded" : "Le fichier a été envoyé",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Le fichier envoyé dépasse la valeur upload_max_filesize spécifiée dans php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Le fichier envoyé dépasse la valeur MAX_FILE_SIZE spécifiée dans le formulaire HTML",
    "The file was only partially uploaded" : "Le fichier n'a été que partiellement envoyé",
    "No file was uploaded" : "Aucun fichier n'a été envoyé",
    "Missing a temporary folder" : "Absence de dossier temporaire",
    "Could not write file to disk" : "Impossible d'écrire le fichier sur le disque",
    "A PHP extension stopped the file upload" : "Une extension PHP a arrêté l'envoi du fichier",
    "No file uploaded or file size exceeds maximum of %s" : "Aucun fichier envoyé ou la taille du fichier dépasse le maximum de %s",
    "This comment has more than %s characters.\nAdded as an attachment to the card with name %s.\nAccessible on URL: %s." : "Ce commentaire comporte plus de %s caractères.\nAjouté en pièce jointe à la carte intitulée %s.\nAccessible depuis l'URL: %s.",
    "Card not found" : "Carte introuvable",
    "Path is already shared with this card" : "Le chemin est déjà partagé avec cette carte",
    "Invalid date, date format must be YYYY-MM-DD" : "Date non valable, le format de la date doit être AAAA-MM-JJ",
    "Personal planning and team project organization" : "Agenda personnel et organisation projet",
    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in Markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your Markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Deck est un outil d'organisation de style kanban destiné à la planification personnelle et à l'organisation de projets pour les équipes intégrées à Nextcloud.\n\n\n- 📥 Ajoutez vos tâches à des cartes et organisez-les\n- 📄 Écrivez des notes supplémentaires en Markdown\n- 🔖 Affectez des étiquettes pour une organisation encore meilleure\n- 👥 Partagez avec votre équipe, vos amis ou votre famille\n- 📎 Attachez des fichiers et utilisez les dans vos descriptions en Markdown\n- 💬 Échangez avec votre équipe grâce aux commentaires\n- ⚡ Gardez un œil sur les modifications dans le flux d'activité\n- 🚀 Organisez vos projets",
    "Card details" : "Détails de la carte",
    "Add board" : "Ajouter un tableau",
    "Select the board to link to a project" : "Sélection le tableau pour faire le lien avec un projet.",
    "Search by board title" : "Rechercher par titre du tableau",
    "Select board" : "Sélectionner le tableau",
    "Create a new card" : "Créer une nouvelle carte",
    "Select a board" : "Sélectionner un tableau",
    "Select a list" : "Sélectionner une liste",
    "Card title" : "Titre de la carte",
    "Cancel" : "Annuler",
    "Creating the new card …" : "Création de la nouvelle carte…",
    "Card \"{card}\" was added to \"{board}\"" : "La carte \"{card}\" a été ajoutée au tableau \"{board}\"",
    "Open card" : "Ouvrir la carte",
    "Close" : "Fermer",
    "Create card" : "Créer une carte",
    "Select a card" : "Sélectionnez une carte",
    "Select the card to link to a project" : "Sélectionner la carte à relier à un projet",
    "Link to card" : "Relier à une carte",
    "File already exists" : "Le fichier existe déjà",
    "A file with the name {filename} already exists." : "Un fichier avec le nom {filename} existe déjà.",
    "Do you want to overwrite it?" : "Souhaitez-vous l'écraser ?",
    "Overwrite file" : "Remplacer le fichier",
    "Keep existing file" : "Conserver le fichier existant",
    "This board is read only" : "Ce tableau est en lecture seule",
    "Drop your files to upload" : "Glissez vos fichiers pour les envoyer",
    "Add card" : "Ajouter une carte",
    "Archived cards" : "Cartes archivées",
    "Add list" : "Ajouter une liste",
    "List name" : "Nom de la liste",
    "Active filters" : "Filtres actifs",
    "Apply filter" : "Filtrer",
    "Filter by tag" : "Filtrer par étiquette",
    "Filter by assigned user" : "Filtrer par utilisateur",
    "Unassigned" : "Non attribué",
    "Filter by due date" : "Filtrer par échéance",
    "Overdue" : "En retard",
    "Next 24 hours" : "prochaines 24 heures",
    "Next 7 days" : "7 prochains jours",
    "Next 30 days" : "30 prochains jours",
    "No due date" : "Sans échéance",
    "Clear filter" : "Supprimer le filtre",
    "Hide archived cards" : "Masquer les cartes archivées",
    "Show archived cards" : "Afficher les cartes archivées",
    "Toggle compact mode" : "Activer/Désactiver l'affichage compact",
    "Open details" : "Ouvrir les détails",
    "Details" : "Détails",
    "Loading board" : "Chargement du tableau…",
    "No lists available" : "Aucune liste disponible",
    "Create a new list to add cards to this board" : "Créer une nouvelle liste pour ajouter des cartes à ce tableau",
    "Board not found" : "Tableau non trouvé",
    "Sharing" : "Partagé",
    "Tags" : "Étiquettes",
    "Deleted items" : "Éléments supprimés",
    "Timeline" : "Chronologie",
    "Deleted lists" : "Listes supprimées",
    "Undo" : "Annuler",
    "Deleted cards" : "Cartes supprimées",
    "Share board with a user, group or circle …" : "Partager le tableau avec un utilisateur, un groupe ou un cercle…",
    "Searching for users, groups and circles …" : "Recherche d'utilisateurs, de groupes et de cercles ...",
    "No participants found" : "Aucun participant trouvé",
    "Board owner" : "Propriétaire du tableau",
    "(Group)" : "(Groupe)",
    "(Circle)" : "(Cercle)",
    "Can edit" : "Peut modifier",
    "Can share" : "Peut partager",
    "Can manage" : "Peut gérer",
    "Owner" : "Propriétaire",
    "Delete" : "Supprimer",
    "Failed to create share with {displayName}" : "Échec de la création du partage avec {displayName}",
    "Are you sure you want to transfer the board {title} to {user}?" : "Êtes-vous sûr de vouloir transférer le tableau {title} à {user} ?",
    "Transfer the board." : "Transférer le tableau",
    "Transfer" : "Transférer",
    "The board has been transferred to {user}" : "Le tableau a été transféré à {user}",
    "Failed to transfer the board to {user}" : "Échec du transfert du tableau à {user}",
    "Add a new list" : "Ajouter une nouvelle liste",
    "Archive all cards" : "Archiver toutes les cartes",
    "Unarchive all cards" : "Désarchiver toutes les cartes",
    "Delete list" : "Supprimer la liste",
    "Archive all cards in this list" : "Archiver toutes les cartes de cette liste",
    "Unarchive all cards in this list" : "Désarchiver toutes les cartes de cette liste",
    "Add a new card" : "Ajouter une nouvelle carte",
    "Card name" : "Nom de la carte",
    "List deleted" : "Liste supprimée",
    "Edit" : "Modifier",
    "Add a new tag" : "Ajouter une nouvelle étiquette",
    "title and color value must be provided" : "Le titre et la couleur doivent être renseignés",
    "Board name" : "Nom du tableau",
    "Members" : "Membres",
    "Upload new files" : "Téléverser de nouveaux fichiers",
    "Share from Files" : "Choisir depuis Fichiers",
    "Pending share" : "Partage en attente",
    "Add this attachment" : "Ajouter cette pièce jointe",
    "Show in Files" : "Afficher dans Fichiers",
    "Download" : "Télécharger",
    "Remove attachment" : "Supprimer la pièce jointe",
    "Delete Attachment" : "Supprimer la pièce jointe",
    "Restore Attachment" : "Restaurer la pièce jointe",
    "File to share" : "Fichier à partager",
    "Invalid path selected" : "Chemin sélectionné non valide",
    "Open in sidebar view" : "Ouvrir dans le panneau latéral",
    "Open in bigger view" : "Ouvrir dans la vue principale",
    "Attachments" : "Pièces jointes",
    "Comments" : "Commentaires",
    "Modified" : "Modifiée",
    "Created" : "Créée",
    "The title cannot be empty." : "Le titre ne peut pas être vide.",
    "No comments yet. Begin the discussion!" : "Aucun commentaire pour l'instant, démarrez la discussion !",
    "Failed to load comments" : "Échec du chargement des commentaires",
    "Assign a tag to this card…" : "Associer une étiquette à cette carte…",
    "Assign to users" : "Attribuer aux utilisateurs",
    "Assign to users/groups/circles" : "Attribuer à des utilisateurs / groupes / cercles",
    "Assign a user to this card…" : "Attribuer cette carte à un utilisateur…",
    "Due date" : "Date d'échéance",
    "Set a due date" : "Définir une date d'échéance",
    "Remove due date" : "Supprimer la date d'échéance",
    "Select Date" : "Sélectionnez une date",
    "Today" : "Aujourd'hui",
    "Tomorrow" : "Demain",
    "Next week" : "Semaine suivante",
    "Next month" : "Mois suivant",
    "Save" : "Enregistrer",
    "The comment cannot be empty." : "Un commentaire ne peut pas être vide.",
    "The comment cannot be longer than 1000 characters." : "Un commentaire est limité à 1 000 caractères.",
    "In reply to" : "En réponse à",
    "Cancel reply" : "Annuler la réponse",
    "Reply" : "Répondre",
    "Update" : "Mettre à jour",
    "Description" : "Description",
    "(Unsaved)" : "(Non enregistré)",
    "(Saving…)" : "(Enregistrement ...)",
    "Formatting help" : "Aide sur la mise en forme",
    "Edit description" : "Modifier la description",
    "View description" : "Afficher la description",
    "Add Attachment" : "Ajouter une pièce jointe",
    "Write a description …" : "Écrire une description…",
    "Choose attachment" : "Choisir une pièce jointe",
    "(group)" : "(groupe)",
    "Todo items" : "À faire",
    "{count} comments, {unread} unread" : "{count} commentaires, {unread} non lus",
    "Edit card title" : "Modifier le titre de la carte",
    "Assign to me" : "Me l'assigner",
    "Unassign myself" : "Me désassigner",
    "Move card" : "Déplacer la carte",
    "Unarchive card" : "Sortir la carte des archives",
    "Archive card" : "Archiver la carte",
    "Delete card" : "Supprimer la carte",
    "Move card to another board" : "Déplacer la carte vers un autre tableau ",
    "List is empty" : "La liste est vide",
    "Card deleted" : "Carte supprimée",
    "seconds ago" : "à l'instant",
    "All boards" : "Tous les tableaux",
    "Archived boards" : "Tableaux archivés",
    "Shared with you" : "Partagés avec vous",
    "Deck settings" : "Paramètres de Deck",
    "Use bigger card view" : "Utiliser la vue large des cartes",
    "Show card ID badge" : "Afficher la carte d'identité du badge",
    "Show boards in calendar/tasks" : "Afficher les tableaux dans les agendas/tâches",
    "Limit deck usage of groups" : "Limiter l'utilisation du tableau aux groupes",
    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Limiter Deck empêchera les utilisateurs ne faisant pas partie de ces groupes de créer leurs propres tableaux. Ces utilisateurs pourront toujours travailler sur les tableaux qui ont été partagés avec eux.",
    "Board details" : "Détails du tableau",
    "Edit board" : "Renommer le tableau",
    "Clone board" : "Dupliquer le tableau",
    "Unarchive board" : "Désarchiver le tableau",
    "Archive board" : "Archiver le tableau",
    "Turn on due date reminders" : "Activer les rappels",
    "Turn off due date reminders" : "Désactiver les rappels",
    "Due date reminders" : "Rappels",
    "All cards" : "Toutes les cartes",
    "Assigned cards" : "Cartes assignées",
    "No notifications" : "Aucune notification",
    "Delete board" : "Supprimer le tableau",
    "Board {0} deleted" : "Tableau {0} supprimé",
    "Only assigned cards" : "Uniquement les cartes assignées",
    "No reminder" : "Aucun rappel",
    "An error occurred" : "Une erreur est survenue",
    "Are you sure you want to delete the board {title}? This will delete all the data of this board including archived cards." : "Êtes-vous sûr de vouloir supprimer le tableau {titre} ? Cela supprimera toutes les données de ce tableau, y compris les cartes archivées.",
    "Delete the board?" : "Supprimer le tableau ?",
    "Loading filtered view" : "Chargement de la vue filtrée",
    "No due" : "Sans échéance",
    "Search for {searchQuery} in all boards" : "Rechercher {searchQuery} dans tous les tableaux",
    "No results found" : "Aucun résultat",
    "{stack} in {board}" : "{stack} dans {board}",
    "Click to expand description" : "Cliquer pour visualiser la description",
    "* Created on {created}\n* Last modified on {lastMod}\n* {nbAttachments} attachments\n* {nbComments} comments" : "* Créée le {created}\n* Dernière modification le {lastMod}\n* {nbAttachments} pièces jointes\n* {nbComments} commentaires",
    "{nbCards} cards" : "{nbCards} cartes",
    "No upcoming cards" : "Pas de cartes à venir",
    "upcoming cards" : "cartes à venir",
    "Due on {date}" : "Échéance le {date}",
    "Link to a board" : "Relier à un tableau",
    "Link to a card" : "Relier à une carte",
    "Create a card" : "Créer une carte",
    "Message from {author} in {conversationName}" : "Message de {author} dans {conversationName}",
    "Something went wrong" : "Quelque chose s'est mal passé",
    "Failed to upload {name}" : "Échec d'envoi de {name}",
    "Maximum file size of {size} exceeded" : "Taille de fichier maximale de {size} dépassée",
    "Error creating the share" : "Erreur lors de la création du partage",
    "Share with a Deck card" : "Partager avec Deck en tant que carte",
    "Share {file} with a Deck card" : "Partager {file} avec Deck en tant que carte",
    "Share" : "Partager",
    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Deck est un outil d'organisation de style kanban destiné à la planification personnelle et à l'organisation de projets pour les équipes intégrées à Nextcloud.\n\n\n- 📥 Ajoutez vos tâches à des cartes et organisez-les\n- 📄 Écrivez des notes supplémentaires en Markdown\n- 🔖 Affectez des étiquettes pour une organisation encore meilleure\n- 👥 Partagez avec votre équipe, vos amis ou votre famille\n- 📎 Attachez des fichiers et utilisez les dans vos descriptions en Markdown\n- 💬 Échangez avec votre équipe grâce aux commentaires\n- ⚡ Gardez un œil sur les modifications dans le flux d'activité\n- 🚀 Organisez vos projets",
    "Are you sure you want to transfer the board {title} for {user} ?" : "Êtes-vous sûr de vouloir transférer le tableau {title} pour {user} ?",
    "Transfer the board for {user} successfully" : "Transfert du tableau pour {user} avec succès",
    "Failed to transfer the board for {user}" : "Échec du transfert du tableau pour {user}",
    "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "Êtes-vous certain de vouloir supprimer le tableau {title} ? Cela supprimera l'ensemble des données de ce tableau.",
    "This week" : "Cette semaine",
    "Are you sure you want to transfer the board {title} for {user}?" : "Êtes-vous sûr de vouloir transférer le tableau {title} pour {user} ?"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
