OC.L10N.register(
    "deck",
    {
    "You have created a new board {board}" : "Направили сте нову таблу {board}",
    "{user} has created a new board {board}" : "{user} направи нову таблу {board}",
    "You have deleted the board {board}" : "Обрисали сте таблу {board}",
    "{user} has deleted the board {board}" : "{user} је обрисао таблу {board}",
    "You have restored the board {board}" : "Повратили сте таблу {board}",
    "{user} has restored the board {board}" : "{user} је повратио таблу {board}",
    "You have shared the board {board} with {acl}" : "Поделили сте таблу {board} са {acl}",
    "{user} has shared the board {board} with {acl}" : "{user} је поделио таблу {board} са {acl}",
    "You have removed {acl} from the board {board}" : "Уклонили сте {acl} са табле {board}",
    "{user} has removed {acl} from the board {board}" : "{user} је уклонио {acl} са табле {board}",
    "You have renamed the board {before} to {board}" : "Преименовали сте таблу {before} у {board}",
    "{user} has renamed the board {before} to {board}" : "{user} је преименовао таблу {before} у {board}",
    "You have archived the board {board}" : "Архивирали сте таблу {board}",
    "{user} has archived the board {before}" : "{user} је архивирао таблу {before}",
    "You have unarchived the board {board}" : "Вратили сте таблу {board} из архиве",
    "{user} has unarchived the board {before}" : "{user} је вратио таблу {before} из архиве",
    "You have created a new list {stack} on board {board}" : "Направили сте нови списак {stack} на табли {board}",
    "{user} has created a new list {stack} on board {board}" : "{user} је направио нови списак {stack} на табли {board}",
    "You have renamed list {before} to {stack} on board {board}" : "Преименовали сте списак {before} у {stack} на табли {board}",
    "{user} has renamed list {before} to {stack} on board {board}" : "{user} је преименовао списак {before} у {stack} на табли {board}",
    "You have deleted list {stack} on board {board}" : "Обрисали сте списак {stack} са табле {board}",
    "{user} has deleted list {stack} on board {board}" : "{user} је обрисао списак {stack} са табле {board}",
    "You have created card {card} in list {stack} on board {board}" : "Направили сте картицу {card} на списку {stack} у табли {board}",
    "{user} has created card {card} in list {stack} on board {board}" : "{user} је направио картицу {card} на списку {stack} у табли {board}",
    "You have deleted card {card} in list {stack} on board {board}" : "Обрисали сте картицу {card} са списка {stack} у табли {board}",
    "{user} has deleted card {card} in list {stack} on board {board}" : "{user} је обрисао картицу {card} са списка {stack} у табли {board}",
    "You have renamed the card {before} to {card}" : "Преименовали сте картицу {before} као картицу {card}",
    "{user} has renamed the card {before} to {card}" : "{user} је преименовао картицу {before} као картицу {card}",
    "You have added a description to card {card} in list {stack} on board {board}" : "Додали сте опис картици {card} са списка {stack} на табли {board}",
    "{user} has added a description to card {card} in list {stack} on board {board}" : "{user} је додао опис картици {card} са списка {stack} на табли {board}",
    "You have updated the description of card {card} in list {stack} on board {board}" : "Ажурирали сте опис картице {card} са списка {stack} на табли {board}",
    "{user} has updated the description of the card {card} in list {stack} on board {board}" : "Корисник {user} је ажурирао опис картице {card} са списка {stack} на табли {board}",
    "You have archived card {card} in list {stack} on board {board}" : "Архивирали сте картицу {card} са списка {stack} на табли {board}",
    "{user} has archived card {card} in list {stack} on board {board}" : "{user} је архивирао картицу {card} са списка {stack} на табли {board}",
    "You have unarchived card {card} in list {stack} on board {board}" : "Вратили сте из архиве картицу {card} са списка {stack} у табли {board}",
    "{user} has unarchived card {card} in list {stack} on board {board}" : "{user} је вратио из архиве картицу {card} са списка {stack} у табли {board}",
    "You have removed the due date of card {card}" : "Уклонили сте рок са картице {card}",
    "{user} has removed the due date of card {card}" : "{user} је уклонио рок са картице {card}",
    "You have set the due date of card {card} to {after}" : "Поставили сте рок {after} на картици {card}",
    "{user} has set the due date of card {card} to {after}" : "{user} је поставио рок {after} на картици {card}",
    "You have updated the due date of card {card} to {after}" : "Ажурирали сте рок на {after} на картици {card}",
    "{user} has updated the due date of card {card} to {after}" : "{user} је ажурирао рок на {after} на картици {card}",
    "You have added the tag {label} to card {card} in list {stack} on board {board}" : "Додали сте ознаку {label} на картицу {card} са списка {stack} у табли {board}",
    "{user} has added the tag {label} to card {card} in list {stack} on board {board}" : "{user} је додао ознаку {label} на картицу {card} са списка {stack} у табли {board}",
    "You have removed the tag {label} from card {card} in list {stack} on board {board}" : "Уклонили сте ознаку {label} са картице {card} са списка {stack} у табли {board}",
    "{user} has removed the tag {label} from card {card} in list {stack} on board {board}" : "{user} је уклонио ознаку {label} са картице {card} са списка {stack} у табли {board}",
    "You have assigned {assigneduser} to card {card} on board {board}" : "Доделили сте корисника {assigneduser} картици {card} са табле {board}",
    "{user} has assigned {assigneduser} to card {card} on board {board}" : "{user} је доделио корисника {assigneduser} картици {card} са табле {board}",
    "You have unassigned {assigneduser} from card {card} on board {board}" : "Раздужили сте корисника {assigneduser} с картице {card} на табли {board}",
    "{user} has unassigned {assigneduser} from card {card} on board {board}" : "{user} раздужи корисника {assigneduser} с картице {card} на табли {board}",
    "You have moved the card {card} from list {stackBefore} to {stack}" : "Померили сте картицу {card} са списка {stackBefore} на списак {stack}",
    "{user} has moved the card {card} from list {stackBefore} to {stack}" : "{user} је померио картицу {card} са списка {stackBefore} на списак {stack}",
    "You have added the attachment {attachment} to card {card}" : "Додали сте прилог {attachment} на картицу {card}",
    "{user} has added the attachment {attachment} to card {card}" : "{user} је додао прилог {attachment} на картицу {card}",
    "You have updated the attachment {attachment} on card {card}" : "Ажурирали сте прилог {attachment} на картици {card}",
    "{user} has updated the attachment {attachment} on card {card}" : "{user} је ажурирао прилог {attachment} на картици {card}",
    "You have deleted the attachment {attachment} from card {card}" : "Обрисали сте прилог {attachment} са картице {card}",
    "{user} has deleted the attachment {attachment} from card {card}" : "{user} је обрисао прилог {attachment} са картице {card}",
    "You have restored the attachment {attachment} to card {card}" : "Повратили сте прилог {attachment} на картицу {card}",
    "{user} has restored the attachment {attachment} to card {card}" : "{user} је повратио прилог {attachment} на картицу {card}",
    "You have commented on card {card}" : "Оставили сте коментар на картици {card}",
    "{user} has commented on card {card}" : "{user} је оставио коментар на картици {card}",
    "A <strong>card description</strong> inside the Deck app has been changed" : "<strong>Опис картице</strong> унутар Deck апликације је промењен",
    "Deck" : "Deck",
    "Changes in the <strong>Deck app</strong>" : "Измене у <strong>Deck апликацији</strong>",
    "A <strong>comment</strong> was created on a card" : "Направљен је <strong>коментар</strong> на картици",
    "Upcoming cards" : "Предстојеће картице",
    "Load more" : "Учитај још",
    "Personal" : "Лично",
    "The card \"%s\" on \"%s\" has been assigned to you by %s." : "Корисник %s Вам је доделио картицу „%s“ са табле „%s“.",
    "The card \"%s\" on \"%s\" has reached its due date." : "Картици „%s“ на табли „%s“ је истекао рок.",
    "%s has mentioned you in a comment on \"%s\"." : "%s Вас је поменуо у коментару на „%s“.",
    "The board \"%s\" has been shared with you by %s." : "Корисник „%s“ је поделио са Вама таблу „%s“.",
    "%s on %s" : "%s на %s",
    "No data was provided to create an attachment." : "Нису дати подаци за креирање прилога.",
    "Finished" : "Завршено",
    "To review" : "Треба прегледати",
    "Action needed" : "Потребна акција",
    "Later" : "После",
    "copy" : "копирај",
    "To do" : "За урадити",
    "Doing" : "Ради се",
    "Done" : "Готово",
    "Example Task 3" : "Пример задатка 3",
    "Example Task 2" : "Пример задатка 2",
    "Example Task 1" : "Пример задатка 1",
    "The file was uploaded" : "Фајл је отпремљен",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Фајл за отпремање премашује upload_max_filesize директиву у php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Фајл за отпремање премашује MAX_FILE_SIZE директиву наведену у HTML форми",
    "The file was only partially uploaded" : "Фајл је парцијално отпремљен",
    "No file was uploaded" : "Ниједан фајл није отпремљен",
    "Missing a temporary folder" : "Недостаје привремена фасцикла",
    "Could not write file to disk" : "Не могу да пишем на диск",
    "A PHP extension stopped the file upload" : "PHP екстензија је зауставила отпремање фајла",
    "No file uploaded or file size exceeds maximum of %s" : "Ниједан фајл није отпремљен или величина фајла премашује максимум од %s",
    "Card not found" : "Картица није нађена",
    "Invalid date, date format must be YYYY-MM-DD" : "Неисправан датим, формат датума мора бити ГГГГ-ММ-ДД",
    "Personal planning and team project organization" : "Лични планер и организатор тимског пројекта",
    "Card details" : "Детаљи картице",
    "Add board" : "Додај таблу",
    "Select the board to link to a project" : "Одаберите таблу да је повежете са пројектом",
    "Search by board title" : "Претражи по наслову табле",
    "Select board" : "Одаберите таблу",
    "Select a board" : "Изаберите таблу",
    "Select a list" : "Одабери списак",
    "Cancel" : "Одустани",
    "Close" : "Затвори",
    "Create card" : "Направите картицу",
    "Select a card" : "Изаберите картицу",
    "Select the card to link to a project" : "Изаберите картицу да повежете на пројекат",
    "Link to card" : "Повежи са картицом",
    "File already exists" : "Фајл већ постоји",
    "A file with the name {filename} already exists." : "Фајл {filename} већ постоји.",
    "Do you want to overwrite it?" : "Да ли желите да га препишете?",
    "Overwrite file" : "Препиши фајл",
    "Keep existing file" : "Задржи постојећи фајл",
    "This board is read only" : "Табла је само за читање",
    "Drop your files to upload" : "Отпустите фајлове за отпремање",
    "Add card" : "Додај картицу",
    "Archived cards" : "Архивиране картице",
    "Add list" : "Додај списак",
    "List name" : "Назив листе",
    "Apply filter" : "Примени филтер",
    "Filter by tag" : "Филтрирај по ознаци",
    "Filter by assigned user" : "Филтрирај по додељеном кориснику",
    "Unassigned" : "Недодељен",
    "Filter by due date" : "Филтрирај по року",
    "Overdue" : "Прошао рок",
    "Next 24 hours" : "Наредна 24 сата",
    "Next 7 days" : "Следећих 7 дана",
    "Next 30 days" : "Следећих 30 дана",
    "No due date" : "Без рока",
    "Clear filter" : "Очисти филтер",
    "Hide archived cards" : "Сакриј архивиране картице",
    "Show archived cards" : "Прикажи архивиране картице",
    "Toggle compact mode" : "Укључи/искључи компактни режим",
    "Open details" : "Отвори детаље",
    "Details" : "Детаљи",
    "Loading board" : "Учитавам таблу",
    "No lists available" : "Нема доступних спискова",
    "Create a new list to add cards to this board" : "Направите нови списак да додате картице на ову таблу",
    "Board not found" : "Табла није нађена",
    "Sharing" : "Дељење",
    "Tags" : "Ознаке",
    "Deleted items" : "Обрисане ставке",
    "Timeline" : "Временска оса",
    "Deleted lists" : "Обрисани спискови",
    "Undo" : "Опозови",
    "Deleted cards" : "Обрисане картице",
    "Share board with a user, group or circle …" : "Подели таблу са корисником, групом или кругом…",
    "No participants found" : "Нема нађених учесника",
    "Board owner" : "Власник табле",
    "(Group)" : "(група)",
    "(Circle)" : "(Круг)",
    "Can edit" : "Може да мења",
    "Can share" : "Може да дели",
    "Can manage" : "Може да управља",
    "Owner" : "Власник",
    "Delete" : "Избриши",
    "Failed to create share with {displayName}" : "Грешка у прављењу дељења са {displayName}",
    "Transfer" : "Пренеси",
    "Add a new list" : "Додај нови списак",
    "Archive all cards" : "Архивирај све картице",
    "Delete list" : "Обриши списак",
    "Archive all cards in this list" : "Архивирај све картице са овог списка",
    "Add a new card" : "Додај нову картицу",
    "Card name" : "Име картице",
    "List deleted" : "Листа обрисана",
    "Edit" : "Измени",
    "Add a new tag" : "Додај нову ознаку",
    "title and color value must be provided" : "морају се дати вредности за наслов и боју",
    "Board name" : "Име табле",
    "Members" : "Чланови",
    "Add this attachment" : "Додај овај прилог",
    "Download" : "Преузми",
    "Delete Attachment" : "Обриши прилог",
    "Restore Attachment" : "Поврати прилог",
    "File to share" : "Фајл за дељење",
    "Invalid path selected" : "Одабрана неисправна путања",
    "Open in sidebar view" : "Отвори у бочном прегледу",
    "Open in bigger view" : "Отвори на већем приказу",
    "Attachments" : "Прилози",
    "Comments" : "Коментари",
    "Modified" : "Измењен",
    "Created" : "Направљен",
    "The title cannot be empty." : "Наслов не може бити празан.",
    "No comments yet. Begin the discussion!" : "Нема још коментара. Започните дискусију!",
    "Assign a tag to this card…" : "Додели ознаку овој картици…",
    "Assign to users" : "Додели корисницима",
    "Assign to users/groups/circles" : "Додели корисницима/групама/круговима",
    "Assign a user to this card…" : "Додели корисника овој картици…",
    "Due date" : "Рок",
    "Set a due date" : "Постави рок",
    "Remove due date" : "Уклони рок",
    "Select Date" : "Одаберите датум",
    "Today" : "Данас",
    "Tomorrow" : "сутра",
    "Save" : "Сачувај",
    "The comment cannot be empty." : "Коментар не може да буде празан.",
    "The comment cannot be longer than 1000 characters." : "Коментар не може да има преко 1000 карактера.",
    "In reply to" : "Као одговор на",
    "Reply" : "Одговори",
    "Update" : "Ажурирај",
    "Description" : "Опис",
    "(Unsaved)" : "(несачуван)",
    "(Saving…)" : "(чувам…)",
    "Formatting help" : "Помоћ око форматирања",
    "Edit description" : "Измени опис",
    "View description" : "Погледај опис",
    "Add Attachment" : "Додај прилог",
    "Choose attachment" : "Одабери прилог",
    "(group)" : "(група)",
    "Assign to me" : "Додели мени",
    "Unassign myself" : "Склони са мене",
    "Move card" : "Премести картицу",
    "Unarchive card" : "Врати картицу из архиве",
    "Archive card" : "Архивирај картицу",
    "Delete card" : "Обриши картицу",
    "Move card to another board" : "Помери картицу на другу таблу",
    "List is empty" : "Списак је празан",
    "Card deleted" : "Картица обрисана",
    "seconds ago" : "пре неколико секунди",
    "All boards" : "Све табле",
    "Archived boards" : "Архивиране табле",
    "Shared with you" : "Дељено са Вама",
    "Show boards in calendar/tasks" : "Прикажи табле у календару/задацима",
    "Limit deck usage of groups" : "Ограничи употребу шпила на групе",
    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Ограничавање Deck апликације ће блокирати кориснике који нису део одабраних група да креирају своје табле. Корисници ће и даље моћи да раде на таблама које су подељене са њима.",
    "Board details" : "Детаљи табле",
    "Edit board" : "Измени таблу",
    "Clone board" : "Клонирај таблу",
    "Unarchive board" : "Врати таблу из архиве",
    "Archive board" : "Архивирај таблу",
    "No notifications" : "Нема обавештења",
    "Delete board" : "Избриши таблу",
    "Board {0} deleted" : "Табла {0} обрисана",
    "An error occurred" : "Догодила се грешка",
    "Delete the board?" : "Обрисати таблу?",
    "Loading filtered view" : "Учитам филтрирани преглед",
    "No due" : "Нема рокова",
    "No results found" : "Нема пронађених резултата",
    "No upcoming cards" : "Нема предстојећих картица",
    "upcoming cards" : "предстојеће картице",
    "Link to a board" : "Веза ка табли",
    "Link to a card" : "Веза ка картици",
    "Something went wrong" : "Нешто је пошло наопако",
    "Maximum file size of {size} exceeded" : "Премашена максимална величина фајла од {size}",
    "Error creating the share" : "Грешка при прављењу дељења",
    "Share" : "Подели",
    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Deck је алатка канбан организационог стила намењена за лично планирање и организацију пројеката за тимове интегрисане са Некстклаудом.\n\n\n- 📥 Додајте Ваше задатке на картице и распоређујте их како желите\n- 📄 Допишите додатне белешке markdown синтаксом\n- 🔖 Додељујте ознаке за још боље организовање\n- 👥 Делите са Вашим тимом, пријатељима или породицом\n- 📎 Качите фајлове и уградите их у Ваш markdown опис\n- 💬 Дискутујте са тимом преко коментара\n- ⚡ Пазите на промене коришћењем тока активности\n- 🚀 Организујте Ваше пројекте",
    "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "Да ли стварно желите да обришете таблу {title}? Овим ћете обрисати све податке са табле.",
    "This week" : "Ове недеље"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
