OC.L10N.register(
    "deck",
    {
    "You have created a new board {board}" : "تختهٔ جدیدی به نام {board} ایجاد کردید",
    "{user} has created a new board {board}" : "{user} یک تخته جدیدی به نام {board} ایجاد کرد",
    "You have deleted the board {board}" : "تختهٔ {board} را حذف کردید",
    "{user} has deleted the board {board}" : "{user} تختهٔ {board} را حذف کرد",
    "You have restored the board {board}" : "تختهٔ {board} را بازیابی کردید",
    "{user} has restored the board {board}" : "{user} تختهٔ {board} را بازیابی کرد",
    "You have shared the board {board} with {acl}" : "تختهٔ {board} را با {acl} هم‌رسانی کردید",
    "{user} has shared the board {board} with {acl}" : "{user} تختهٔ {board} را با {acl} هم‌رسانی کرد",
    "You have removed {acl} from the board {board}" : "شما {acl} را از تختهٔ {board} حذف کردید",
    "{user} has removed {acl} from the board {board}" : "{user} اقدام به حذف {acl} از تختهٔ {board} کرد",
    "You have renamed the board {before} to {board}" : "نام تخته را از {before} به {board} تغییر دادید",
    "{user} has renamed the board {before} to {board}" : "{user} نام تخته را از {before} به {board} تغییر داد",
    "You have archived the board {board}" : "تختهٔ {board} را بایگانی کردید",
    "{user} has archived the board {before}" : "{user} تختهٔ {board} را بایگانی کرد",
    "You have unarchived the board {board}" : "تختهٔ {board} را از بایگانی خارج کردید",
    "{user} has unarchived the board {before}" : "{user} تختهٔ {board} را از بایگانی خارج کرد",
    "You have created a new list {stack} on board {board}" : "شما فهرست جدید {stack} را در تخته {board} ایجاد کرده‌اید",
    "{user} has created a new list {stack} on board {board}" : "{user} فهرست جدید {stack} را در تخته {board} ایجاد کرده است",
    "You have renamed list {before} to {stack} on board {board}" : "شما فهرست {before} را به {stack} در تخته {board} تغییر نام داده‌اید",
    "{user} has renamed list {before} to {stack} on board {board}" : "{user} فهرست {before} را به {stack} در تخته {board} تغییر نام داده است",
    "You have deleted list {stack} on board {board}" : "شما فهرست {stack} را در تخته {board} حذف کرده اید",
    "{user} has deleted list {stack} on board {board}" : "{user} فهرست {stack} را در تخته {board} حذف کرده است",
    "You have created card {card} in list {stack} on board {board}" : "شما برگه {card} را در فهرست {stack} در تخته {board} ایجاد کرده اید",
    "{user} has created card {card} in list {stack} on board {board}" : "ٰ{user} برگه {card} را در فهرست {stack} در تخته {board} ایجاد کرده است",
    "You have deleted card {card} in list {stack} on board {board}" : "شما برگه {card} را در فهرست {stack} در تخته {board} حذف کرده اید",
    "{user} has deleted card {card} in list {stack} on board {board}" : "{user} برگه {card} را در فهرست {stack} در تخته {board} حذف کرده است",
    "You have renamed the card {before} to {card}" : "شما نام برگه را {پیش از} به {card} تغییر داده اید",
    "{user} has renamed the card {before} to {card}" : "{user} نام برگه را {پیش از} به {card} تغییر داده است",
    "You have added a description to card {card} in list {stack} on board {board}" : "شما یک توضیح به برگه {card} در فهرست {stack} در تخته {board} اضافه کرده اید",
    "{user} has added a description to card {card} in list {stack} on board {board}" : "{user} توضیحاتی را به برگه {card} در فهرست {stack} on board {board} اضافه کرده است.",
    "You have updated the description of card {card} in list {stack} on board {board}" : "شما شرح برگه {card} را در فهرست {stack} در تخته {board} به روز کرده اید.",
    "{user} has updated the description of the card {card} in list {stack} on board {board}" : "{user} توضیحات برگه {card} را در فهرست {stack} on board {board} به روز کرده است.",
    "You have archived card {card} in list {stack} on board {board}" : "شما برگه {card} را در فهرست {stack} در تخته {board} بایگانی کرده اید",
    "{user} has archived card {card} in list {stack} on board {board}" : "{user} برگه {card} را در فهرست {stack} در تخته {board} بایگانی کرده است",
    "You have unarchived card {card} in list {stack} on board {board}" : "شما برگه {card} را در فهرست {stack} در تخته {board} از بایگانی خارج کرده‌اید.",
    "{user} has unarchived card {card} in list {stack} on board {board}" : "{user} برگه {card} را در فهرست {stack} در تخته {board} از بایگانی خارج کرده است",
    "You have removed the due date of card {card}" : "شما تاریخ سررسید برگه {card} را حذف کرده اید",
    "{user} has removed the due date of card {card}" : "{user} تاریخ سررسید برگه {card} را حذف کرده است",
    "You have set the due date of card {card} to {after}" : "شما تاریخ سررسید برگه {card} را روی {after} تنظیم کرده اید",
    "{user} has set the due date of card {card} to {after}" : "{user} تاریخ سررسید برگه {card} را روی {after} قرار داده است",
    "You have updated the due date of card {card} to {after}" : "شما تاریخ سررسید برگه {card} را به {after} به روز کرده اید",
    "{user} has updated the due date of card {card} to {after}" : "{user} تاریخ سررسید برگه {card} را به {after} به روز کرده است",
    "You have added the tag {label} to card {card} in list {stack} on board {board}" : "شما برچسب {label} را به برگه {card} در فهرست {stack} در تخته {board} اضافه کرده‌اید.",
    "{user} has added the tag {label} to card {card} in list {stack} on board {board}" : "{user} برچسب {label} را بهبرگه {card} در فهرست {stack} در تخته {board} اضافه کرده است.",
    "You have removed the tag {label} from card {card} in list {stack} on board {board}" : "شما برچسب {label} را از برگه {card} در فهرست {stack} در تخته {board} حذف کردید.",
    "{user} has removed the tag {label} from card {card} in list {stack} on board {board}" : "{user} برچسب {label} را از برگه {card} در فهرست {stack} در تخته {board} حذف کرده است.",
    "You have assigned {assigneduser} to card {card} on board {board}" : "شما {کاربر اختصاص یافته} را به برگه {card} در تخته {board} اختصاص داده‌اید.",
    "{user} has assigned {assigneduser} to card {card} on board {board}" : "{user} {assigneduser} را به برگه {card} در تخته {board} اختصاص داده است",
    "You have unassigned {assigneduser} from card {card} on board {board}" : "شما {تخصیص کاربر} را از برگه {card} در تخته {board} لغو کرده‌اید.",
    "{user} has unassigned {assigneduser} from card {card} on board {board}" : "{user} تخصیص {assigneduser} را از برگه {card} در تخته لغو کرده است",
    "You have moved the card {card} from list {stackBefore} to {stack}" : "شما برگه {card} را از فهرست {stackBefore} به {stack} منتقل کرده اید",
    "{user} has moved the card {card} from list {stackBefore} to {stack}" : "{user} برگه {card} را از فهرست {stackBefore} به {stack} منتقل کرده است",
    "You have added the attachment {attachment} to card {card}" : "شما پیوست {attachment} را به برگه {card} اضافه کرده‌اید.",
    "{user} has added the attachment {attachment} to card {card}" : "{user} پیوست {attachment} را به برگه {card} اضافه کرده است",
    "You have updated the attachment {attachment} on card {card}" : "شما پیوست {attachment} را در برگه {card} به روز کرده اید",
    "{user} has updated the attachment {attachment} on card {card}" : "{user} پیوست {attachment} را در برگه {card} به روز کرده است",
    "You have deleted the attachment {attachment} from card {card}" : "شما پیوست {attachment} را از برگه {card} حذف کرده اید",
    "{user} has deleted the attachment {attachment} from card {card}" : "{user} پیوست {attachment} را ازبرگه {card} حذف کرده است",
    "You have restored the attachment {attachment} to card {card}" : "شما پیوست {attachment} را به برگه {card} بازیابی کرده اید",
    "{user} has restored the attachment {attachment} to card {card}" : "{user} پیوست {attachment} را به برگه {card} بازیابی کرده است",
    "You have commented on card {card}" : "شما در مورد برگه {card} نظر داده اید",
    "{user} has commented on card {card}" : "{user} روی برگه {card} نظر داده است",
    "A <strong>card description</strong> inside the Deck app has been changed" : "شرح برگه در برگه‌دان تغییر کرده است",
    "Deck" : "برگه‌دان",
    "Changes in the <strong>Deck app</strong>" : "تغییرات در برگه‌دان",
    "A <strong>comment</strong> was created on a card" : "یک نظر روی یک برگه ایجاد شد",
    "Upcoming cards" : "برگه‌های آینده",
    "Personal" : "شخصی",
    "{user} has assigned the card {deck-card} on {deck-board} to you." : "{user} برگه {deck-card} در {deck-board} را به شما اختصاص داده است.",
    "The card {deck-card} on {deck-board} has reached its due date." : "برگه {deck-card} در {deck-board} به تاریخ سررسید خود رسیده است.",
    "{user} has mentioned you in a comment on {deck-card}." : "{user} از شما در نظری در {deck-card} نام برده است.",
    "{user} has shared {deck-board} with you." : "{user} {deck-board} را با شما به اشتراک گذاشته است.",
    "Card comments" : "دیدگاه‌های برگه",
    "No data was provided to create an attachment." : "هیچ داده ای برای ایجاد پیوست ارائه نشد.",
    "Finished" : "تمام شده",
    "To review" : "برای بازبینی",
    "Action needed" : "نیازمند اقدام",
    "Later" : "بعدا",
    "copy" : "کپی",
    "To do" : "برای انجام",
    "Doing" : "در حال انجام",
    "Done" : "انجام شد",
    "Example Task 3" : "نمونه کار ۳",
    "Example Task 2" : "نمونه کار ۲",
    "Example Task 1" : "نمونه کار ۱",
    "The file was uploaded" : "پرونده بارگذاری شد",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "حجم پرونده بارگذاری شده بیشتر از تنظیمات upload_max_filesize در پرونده php.ini است",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "حداکثر حجم قابل بار گذاری از طریق HTML MAX_FILE_SIZE است",
    "The file was only partially uploaded" : "پرونده فقط به صورت جزئی و ناقص بارگذاری شد",
    "No file was uploaded" : "هیچ پرونده‌ای بارگذاری نشد",
    "Missing a temporary folder" : "یک پوشه موقت گم شده",
    "Could not write file to disk" : "عدم موفقیت در نوشتن پرونده روی حافظه",
    "A PHP extension stopped the file upload" : "یک افزونه پی‌اچ‌پی مانع بارگذاری پرونده شد",
    "No file uploaded or file size exceeds maximum of %s" : "پرونده‌ای بارگذاری نشد و یا حجم پرونده بیش از بیشینه مجاز %s بود",
    "Card not found" : "برگه یافت نشد",
    "Path is already shared with this card" : "مسیر قبلاً با این برگه به اشتراک گذاشته شده است",
    "Invalid date, date format must be YYYY-MM-DD" : "تاریخ نامعتبر است، قالب تاریخ باید YYYY-MM-DD باشد",
    "Personal planning and team project organization" : "برنامه‌ریزی شخصی و سازمان‌دهی کار گروهی",
    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in Markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your Markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "برگه‌دان یک ابزار سازمان‌دهی سبک کانبان است که هدف آن برنامه‌ریزی شخصی و سازمان‌دهی پروژه برای گروه‌های مرتبط با Nextcloud است.\n\n\n- 📥 وظایف خود را به برگه‌ها اضافه کنید و آن‌ها را مرتب کنید\n- 📄 یادداشت‌های اضافی را در Markdown یادداشت کنید\n- 🔖 برچسب‌هایی را برای سازمان‌دهی بهتر اختصاص دهید\n- 👥 با گروه، دوستان یا خانوادهٔ خود به اشتراک بگذارید\n- 📎 فایل‌ها را ضمیمه کنید و آنها را در توضیحات Markdown خود قرار دهید\n- 💬 با استفاده از نظرات با تیم خود بحث کنید\n- ⚡ تغییرات در جریان فعالیت را پیگیری کنید\n- 🚀 پروژه خود را سازمان‌دهی کنید",
    "Card details" : "جزئیات برگه",
    "Add board" : "افزودن تخته",
    "Select the board to link to a project" : "تخته‌ای را برای ایجاد پیوند با یک پروژه انتخاب کنید",
    "Search by board title" : "جستجو بر اساس عنوان تخته",
    "Select board" : "انتخاب تخته",
    "Create a new card" : "یک برگهٔ جدید بسازید",
    "Select a board" : "انتخاب یک تخته",
    "Select a list" : "یک فهرست برگزینید",
    "Card title" : "عنوان برگه",
    "Cancel" : "لغو",
    "Creating the new card …" : "ساختن برگهٔ جدید ...",
    "Card \"{card}\" was added to \"{board}\"" : "برگه \"{card}\" به \"{board}\" اضافه شد",
    "Open card" : "بازکردن برگه",
    "Close" : "بسته",
    "Create card" : "ایجاد برگه",
    "Select a card" : "انتخاب یک برگه",
    "Select the card to link to a project" : "برگه‌ای را برای ایجاد پیوند با یک پروژه انتخاب کنید",
    "Link to card" : "پیوند به برگه",
    "File already exists" : "پرونده از قبل موجود است",
    "A file with the name {filename} already exists." : "پرونده‌ای با نام {filename} از قبل موجود است.",
    "Do you want to overwrite it?" : "می‌خواهید روی آن بازنویسی شود؟",
    "Overwrite file" : "بازنویسی پرونده",
    "Keep existing file" : "پرونده موجود حفظ شود",
    "This board is read only" : "تخته، فقط خواندنی است",
    "Drop your files to upload" : "برای بارگذاری، پرونده‌ها را اینجا رها کنید",
    "Add card" : "افزودن برگه",
    "Archived cards" : "کارت‌های بایگانی‌شده",
    "Add list" : "افزودن فهرست",
    "List name" : "نام فهرست",
    "Apply filter" : "اعمال پالایه",
    "Filter by tag" : "پالایش برحسب برچسب",
    "Filter by assigned user" : "فیلتر بر اساس کاربر اختصاص داده شده",
    "Unassigned" : "اختصاص داده نشده است",
    "Filter by due date" : "فیلتر بر اساس تاریخ مقرر",
    "Overdue" : "تاریخ گذشته",
    "Next 24 hours" : "۲۴ ساعت آینده",
    "Next 7 days" : "۷ روز آینده",
    "Next 30 days" : "۳۰ روز آینده",
    "No due date" : "بدون تاریخ سررسید",
    "Clear filter" : "پاک کردن پالایه",
    "Hide archived cards" : "برگه‌های بایگانی شده را مخفی کنید",
    "Show archived cards" : "نمایش کارت‌های بایگانی شده",
    "Toggle compact mode" : "تغییر حالت فشرده",
    "Details" : "جزئیات",
    "Loading board" : "بارکردن تخته",
    "No lists available" : "هیچ فهرستی در دسترس نیست",
    "Create a new list to add cards to this board" : "یک فهرست جدید برای افزود برگه به این تابلو ایجاد کنید",
    "Board not found" : "تخته یافت نشد",
    "Sharing" : "هم‌رسانی",
    "Tags" : "برچسب‌ها",
    "Deleted items" : "موارد حذف شده",
    "Timeline" : "خط زمانی",
    "Deleted lists" : "فهرست‌های پاک شده",
    "Undo" : "برگرداندن",
    "Deleted cards" : "کارت‌های پاک شده",
    "Share board with a user, group or circle …" : "هم‌رسانی تخته با کاربر، گروه یا حلقه...",
    "Searching for users, groups and circles …" : "جستجوی کاربران، گروه‌ها و حلقه‌ها…",
    "No participants found" : "هیچ شرکتی پیدا نشد",
    "Board owner" : "مالک تخته",
    "(Group)" : "(گروه)",
    "(Circle)" : "(حلقه)",
    "Can edit" : "می‌تواند ویرایش کند",
    "Can share" : "می‌تواند هم‌رسانی کند",
    "Can manage" : "می‌تواند مدیریت کند",
    "Owner" : "مالک",
    "Delete" : "حذف",
    "Failed to create share with {displayName}" : "اشتراک‌گذاری با {displayName} ایجاد نشد",
    "Transfer" : "انتقال",
    "Add a new list" : "فهرست جدید بیفزایید!",
    "Archive all cards" : "همهٔ برگه‌ها را بایگانی کنید!",
    "Delete list" : "حذف فهرست",
    "Archive all cards in this list" : "تمام برگه‌های موجود در این فهرست را بایگانی کنید",
    "Add a new card" : "افزودن یک کارت جدید",
    "Card name" : "نام برگه",
    "List deleted" : "فهرست پاک شد",
    "Edit" : "ویرایش",
    "Add a new tag" : "افزودن یک برچسب جدید",
    "title and color value must be provided" : "نام و رنگ باید مشخص شود",
    "Board name" : "نامِ تخته",
    "Members" : "اعضا",
    "Upload new files" : "فایل‌های جدید را آپلود کنید",
    "Share from Files" : "اشتراک‌گذاری از فایل‌ها",
    "Pending share" : "سهم معلق",
    "Add this attachment" : "افزودن این پیوست",
    "Show in Files" : "نمایش در فایل‌ها",
    "Download" : "بارگیری",
    "Remove attachment" : "حذف پیوست",
    "Delete Attachment" : "حذف پیوست",
    "Restore Attachment" : "بازیابی پیوست",
    "File to share" : "فایل برای اشتراک‌گذاری",
    "Invalid path selected" : "مسیر نامعتبر انتخاب شده است",
    "Open in sidebar view" : "در نمای نوار کناری باز کنید",
    "Open in bigger view" : "در نمای بزرگتر باز کنید",
    "Attachments" : "پیوست‌ها",
    "Comments" : "نظرات",
    "Modified" : "تغییر یافته",
    "Created" : "ایجاد شده",
    "The title cannot be empty." : "عنوان نمی‌تواند خالی باشد.",
    "No comments yet. Begin the discussion!" : "هنوز نظری وجود ندارد. بحثی را آغاز کنید!",
    "Failed to load comments" : "نظرات بارگیری نشد",
    "Assign a tag to this card…" : "یک برچسب به این برگه اختصاص دهید…",
    "Assign to users" : "به کاربران اختصاص دهید",
    "Assign to users/groups/circles" : "به کاربران/ گروه‌ها/ حلقه‌ها اختصاص دهید",
    "Assign a user to this card…" : "اختصاص یک کاربر به این برگه…",
    "Due date" : "موعد مقرر",
    "Set a due date" : "تاریخ سررسید را تعیین کنید",
    "Remove due date" : "تاریخ سررسید را حذف کنید",
    "Select Date" : "تاریخ را انتخاب کنید",
    "Today" : "Today",
    "Tomorrow" : "فردا",
    "Next week" : "هفتهٔ بعد",
    "Next month" : "ماه بعد",
    "Save" : "ذخیره",
    "The comment cannot be empty." : "نظر نمی‌تواند خالی باشد.",
    "The comment cannot be longer than 1000 characters." : "نظر نمی‌تواند طولانی‌تر از ۱۰۰۰ حرف باشد.",
    "In reply to" : "در پاسخ به",
    "Cancel reply" : "لغو پاسخ",
    "Reply" : "پاسخ",
    "Update" : "به‌روزرسانی",
    "Description" : "توضیحات",
    "(Unsaved)" : "(ذخیره نشده)",
    "(Saving…)" : "(در حال ذخیره...)",
    "Formatting help" : "راهنمای قالب‌بندی",
    "Edit description" : "ویرایش توضیحات",
    "View description" : "نمایش توضیحات",
    "Add Attachment" : "افزودن پیوست",
    "Write a description …" : "توضیح بنویس…",
    "Choose attachment" : "انتخاب پیوست",
    "(group)" : "(گروه)",
    "{count} comments, {unread} unread" : "{count} نظر، { خوانده نشده} خوانده نشده",
    "Assign to me" : "به من اختصاص دهید",
    "Unassign myself" : "واگذاری به خودم را لغو می‌کنم",
    "Move card" : "انتقال برگه",
    "Unarchive card" : "برگه را از بایگانی خارج کنید",
    "Archive card" : "بایگانی برگه",
    "Delete card" : "حذف برگه",
    "Move card to another board" : "انتقال برگه به تخته‌ای دیگر",
    "List is empty" : "فهرست خالی است",
    "Card deleted" : "برگه پاک شد",
    "seconds ago" : "ثانیه‌هایی پیش",
    "All boards" : "همه تخته‌ها",
    "Archived boards" : "تخته‌های بایگانی شده",
    "Shared with you" : "با شما به اشتراک گذاشته شده است",
    "Use bigger card view" : "از نمای برگهٔ بزرگتر استفاده کنید",
    "Show boards in calendar/tasks" : "نمایش تابلوها در تقویم/ وظایف",
    "Limit deck usage of groups" : "استفاده از برگه‌دان گروه‌ها را محدود کنید",
    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "محدودکردن برگه‌دان  باعث می‌شود تا کاربرانی که جزو آن گروه‌ها نیستند، تابلوهای خود را ایجاد کنند. کاربران همچنان می‌توانند روی تابلوهایی کار کنند که با آنها به اشتراک گذاشته شده است.",
    "Edit board" : "ویرایش تخته",
    "Clone board" : "تخته شبیه‌سازی",
    "Archive board" : "تخته",
    "No notifications" : "بدون اعلان",
    "Delete board" : "حذف تهته",
    "An error occurred" : "خطایی روی داد",
    "No results found" : "هیچ نتیجه ای یافت نشد",
    "Error creating the share" : "خطایی در ایجاد اشتراک",
    "Share" : "هم‌رسانی",
    "This week" : "این هفته"
},
"nplurals=2; plural=(n > 1);");
