OC.L10N.register(
    "deck",
    {
    "Personal" : "Անձնական",
    "Done" : "Done",
    "Cancel" : "ընդհատել",
    "Close" : "Փակել",
    "Details" : "Մանրամասներ",
    "Can edit" : "Can edit",
    "Can share" : "Can share",
    "Owner" : "Owner",
    "Delete" : "հեռացնել",
    "Edit" : "մշակել",
    "Download" : "Ներբեռնել",
    "Comments" : "Կարծիքներ",
    "Modified" : "Փոփոխված",
    "Today" : "այսօր",
    "Save" : "Պահպանել",
    "Update" : "Թարմացնել",
    "Description" : "Նկարագրություն",
    "seconds ago" : "վրկ. առաջ",
    "Shared with you" : "Shared with you",
    "Share" : "Կիսվել",
    "This week" : "այս շաբաթ"
},
"nplurals=2; plural=(n != 1);");
