OC.L10N.register(
    "deck",
    {
    "You have created a new board {board}" : "Vytvorili ste novú nástenku {board}",
    "{user} has created a new board {board}" : "Používateľ {user} vytvoril novú nástenku {board}",
    "You have deleted the board {board}" : "Vymazali ste nástenku {board}",
    "{user} has deleted the board {board}" : "Používateľ {user} vymazal nástenku {board}",
    "You have restored the board {board}" : "Obnovili ste nástenku {board}",
    "{user} has restored the board {board}" : "Používateľ {user} obnovil nástenku {board}",
    "You have shared the board {board} with {acl}" : "Sprístupnili ste nástenku {board} s {acl}",
    "{user} has shared the board {board} with {acl}" : "Používateľ {user} sprístupnil nástenku {board} pre {acl}",
    "You have removed {acl} from the board {board}" : "Odobrali ste {acl} z nástenky {board}",
    "{user} has removed {acl} from the board {board}" : "Používateľ {user} odobral {acl} z nástenky {board}",
    "You have renamed the board {before} to {board}" : "Premenovali ste nástenku {before} na {board}",
    "{user} has renamed the board {before} to {board}" : "Používateľ {user} premenoval nástenku {before} na {board}",
    "You have archived the board {board}" : "Archivovali ste nástenku {board}",
    "{user} has archived the board {before}" : "Používateľ {user} archivoval nástenku {board}",
    "You have unarchived the board {board}" : "Zrušili ste archiváciu nástenky {board}",
    "{user} has unarchived the board {before}" : "Používateľ {user} zrušil archiváciu nástenky {before}",
    "You have created a new list {stack} on board {board}" : "Vytvorili ste nový zoznam {stack} na nástenke {board}",
    "{user} has created a new list {stack} on board {board}" : "{user} vytvoril nový zoznam {stack} na nástenke {board}",
    "You have renamed list {before} to {stack} on board {board}" : "Premenovali ste zoznam {before} na {stack} na nástenke {board}",
    "{user} has renamed list {before} to {stack} on board {board}" : "{user} premenoval zoznam {before} na {stack} na nástenke {board}",
    "You have deleted list {stack} on board {board}" : "Odstránili ste {stack} z nástenky {board}",
    "{user} has deleted list {stack} on board {board}" : "{user} odstránil zoznam {stack} z nástenky {board}",
    "You have created card {card} in list {stack} on board {board}" : "Vytvorili ste kartu {card} v zozname {stack} na nástenke {board}",
    "{user} has created card {card} in list {stack} on board {board}" : "{user} vytvoril kartu {card} v zozname {stack} na nástenke {board}",
    "You have deleted card {card} in list {stack} on board {board}" : "Odstránili ste kartu {card} zo zoznamu {stack} na nástenke {board}",
    "{user} has deleted card {card} in list {stack} on board {board}" : "{user} odstránil kartu {card} zo zoznamu {stack} na nástenke {board}",
    "You have renamed the card {before} to {card}" : "Premenovali ste kartu {before} na {card}",
    "{user} has renamed the card {before} to {card}" : "Používateľ {user} premenoval kartu {before} na {card}",
    "You have added a description to card {card} in list {stack} on board {board}" : "Pridali ste popis na kartu {card} v zozname {stack} na nástenke {board}",
    "{user} has added a description to card {card} in list {stack} on board {board}" : "{user} pridal popis na kartu {card} v zozname {stack} na nástenke {board}",
    "You have updated the description of card {card} in list {stack} on board {board}" : "Aktualizovali ste popis na karte {card} v zozname {stack} na nástenke {board}",
    "{user} has updated the description of the card {card} in list {stack} on board {board}" : "{user} aktualizoval popis na karte {card} v zozname {stack} na nástenke {board}",
    "You have archived card {card} in list {stack} on board {board}" : "Archivovali ste kartu {card} v zozname {stack} na nástenke {board}",
    "{user} has archived card {card} in list {stack} on board {board}" : "{user} archivoval kartu {card} v zozname {stack} na nástenke {board}",
    "You have unarchived card {card} in list {stack} on board {board}" : "Zrušili ste archiváciu karty {card} v zozname {stack} na nástenke {board}",
    "{user} has unarchived card {card} in list {stack} on board {board}" : "{user} zrušil archiváciu karty {card} v zozname {stack} na nástenke {board}",
    "You have removed the due date of card {card}" : "Odobrali ste termín dokončenia z karty {card}",
    "{user} has removed the due date of card {card}" : "Používateľ {user} odobral termín dokončenia z karty {card}",
    "You have set the due date of card {card} to {after}" : "Nastavili ste termín dokončenia pre kartu {card} na {after}",
    "{user} has set the due date of card {card} to {after}" : "Používateľ {user} nastavil termín dokončenia karty {card} na {after}",
    "You have updated the due date of card {card} to {after}" : "Zmenili ste termín dokončenia karty {card} na {after}",
    "{user} has updated the due date of card {card} to {after}" : "Používateľ {user} aktualizoval termín dokončenia karty {card} na {after}",
    "You have added the tag {label} to card {card} in list {stack} on board {board}" : "Pridali ste štítok {label} ku karte {card} v zozname {stack} na nástenke {board}",
    "{user} has added the tag {label} to card {card} in list {stack} on board {board}" : "{user} pridal štítok {label} ku karte {card} v zozname {stack} na nástenke {board}",
    "You have removed the tag {label} from card {card} in list {stack} on board {board}" : "Odstránili ste štítok {label} karty {card} v zozname {stack} na nástenke {board}",
    "{user} has removed the tag {label} from card {card} in list {stack} on board {board}" : "{user} odstránil štítok {label} karty {card} v zozname {stack} na nástenke {board}",
    "You have assigned {assigneduser} to card {card} on board {board}" : "Priradili ste používateľa {assigneduser} ku karte {card} na nástenke {board}",
    "{user} has assigned {assigneduser} to card {card} on board {board}" : "Používateľ {user} priradil používateľa {assigneduser} ku karte {card} na nástenke {board}",
    "You have unassigned {assigneduser} from card {card} on board {board}" : "Vyradili ste priradenie používateľa {assigneduser} z karty {card} na nástenke {board}",
    "{user} has unassigned {assigneduser} from card {card} on board {board}" : "Používateľ {user} vyradil používateľa {assigneduser} z karty {card} na nástenke {board}",
    "You have moved the card {card} from list {stackBefore} to {stack}" : "Presunuli ste kartu {card} zo zoznamu {stackBefore} na {stack}",
    "{user} has moved the card {card} from list {stackBefore} to {stack}" : "{user} presunul kartu {card} zo zoznamu {stackBefore} na {stack}",
    "You have added the attachment {attachment} to card {card}" : "Pridali ste prílohu {attachment} ku karte {card}",
    "{user} has added the attachment {attachment} to card {card}" : "Používateľ {user} pridal prílohu {attachment} ku karte {card}",
    "You have updated the attachment {attachment} on card {card}" : "Aktualizovali ste prílohu {attachment} na karte {card}",
    "{user} has updated the attachment {attachment} on card {card}" : "Používateľ {user} aktualizoval prílohu {attachment} na karte {card}",
    "You have deleted the attachment {attachment} from card {card}" : "Vymazali ste prílohu {attachment} na karte {card}",
    "{user} has deleted the attachment {attachment} from card {card}" : "Používateľ {user} vymazal prílohu {attachment} na karte {card}",
    "You have restored the attachment {attachment} to card {card}" : "Obnovili ste prílohu {attachment} na karte {card}",
    "{user} has restored the attachment {attachment} to card {card}" : "Používateľ {user} obnovil prílohu {attachment} na karte {card}",
    "You have commented on card {card}" : "Komentovali ste kartu {card}",
    "{user} has commented on card {card}" : "{user} komentoval(a) kartu {card}",
    "A <strong>card description</strong> inside the Deck app has been changed" : "V apke Nástenka sa zmenil <strong>Popis karty</strong>",
    "Deck" : "Nástenka",
    "Changes in the <strong>Deck app</strong>" : "Zmeny v apke <strong>Nástenka</strong>",
    "A <strong>comment</strong> was created on a card" : "Na karte bol vytvorený <strong>komentár</strong>. ",
    "Upcoming cards" : "Nadchádzajúce karty",
    "Load more" : "Načítať viac",
    "Personal" : "Osobné",
    "The card \"%s\" on \"%s\" has been assigned to you by %s." : "Používateľ %s vám priradil kartu „%s“ na „%s“.",
    "{user} has assigned the card {deck-card} on {deck-board} to you." : "{user} vám priradil kartu {deck-card} na {deck-board}.",
    "The card \"%s\" on \"%s\" has reached its due date." : "Karta \"%s\" na nástenke \"%s\" dosiahla termín dokončenia.",
    "The card {deck-card} on {deck-board} has reached its due date." : "Karta {deck-card} na {deck-board} dosiahla termín dokončenia.",
    "%s has mentioned you in a comment on \"%s\"." : "Používateľ %s vás zmienil v komentári ku „%s“.",
    "{user} has mentioned you in a comment on {deck-card}." : "{user} vás spomenul v komentári v {deck-card}.",
    "The board \"%s\" has been shared with you by %s." : "Používateľ %s vám sprístupnil nástenku \"%s\".",
    "{user} has shared {deck-board} with you." : "{user} zdieľa {deck-board} s vami.",
    "Card comments" : "Komentáre karty",
    "%s on %s" : "%s na %s",
    "No data was provided to create an attachment." : "Neboli poskytnuté dáta pre vytvorenie prílohy.",
    "Finished" : "Ukončené",
    "To review" : "Na posúdenie",
    "Action needed" : "Potrebná akcia",
    "Later" : "Neskôr",
    "copy" : "kopírovať",
    "To do" : "Urobiť",
    "Doing" : "Prebieha",
    "Done" : "Hotové",
    "Example Task 3" : "Príklad úlohy 3",
    "Example Task 2" : "Príklad úlohy 2",
    "Example Task 1" : "Príklad úlohy 1",
    "The file was uploaded" : "Súbor bol nahraný",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Nahraný súbor prekročil limit nastavený v upload_max_filesize v súbore php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Ukladaný súbor prekračuje nastavenie MAX_FILE_SIZE z volieb HTML formulára.",
    "The file was only partially uploaded" : "Súbor bol nahraný iba čiastočne",
    "No file was uploaded" : "Nenahral sa žiadny súbor",
    "Missing a temporary folder" : "Chýba priečinok pre dočasné súbory",
    "Could not write file to disk" : "Nepodarilo sa zapísať súbor na disk",
    "A PHP extension stopped the file upload" : "Rozšírenie PHP zastavilo nahrávanie súboru",
    "No file uploaded or file size exceeds maximum of %s" : "Nenahral sa žiadny súbor alebo jeho veľkosť presiahla %s",
    "This comment has more than %s characters.\nAdded as an attachment to the card with name %s.\nAccessible on URL: %s." : "Tento komentár má viac než %s znakov.\nPridané ako príloha ku karte s názvom %s.\nDostupné na URL: %s.",
    "Card not found" : "Karta nebola nájdená",
    "Path is already shared with this card" : "Cesta je už zdieľaná s touto kartou",
    "Invalid date, date format must be YYYY-MM-DD" : "Neplatný dátum, formát musí byť v tvare YYYY-MM-DD",
    "Personal planning and team project organization" : "Osobné plánovanie a organizácia tímových projektov",
    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in Markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your Markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Deck je organizačný nástroj typu kanban zameraný na osobné plánovanie a organizáciu projektov pre tímy integrované s Nextcloud.\n\n\n- 📥 Pridajte svoje úlohy na karty a usporiadajte ich\n- 📄 Zapíšte si ďalšie poznámky v Markdown\n- 🔖 Priraďte štítky pre ešte lepšiu organizáciu\n- 👥 Zdieľajte so svojím tímom, priateľmi alebo rodinou\n- 📎 Pripojte súbory a vložte ich do popisu Markdown\n- 💬 Diskutujte so svojím tímom pomocou komentárov\n- ⚡ Sledujte zmeny v prúde aktivít\n- 🚀 Zorganizujte si svoj projekt",
    "Card details" : "Podrobnosti o karte",
    "Add board" : "Pridať nástenk",
    "Select the board to link to a project" : "Vybrať nástenku na vytvorenie odkazu ku projektu",
    "Search by board title" : "Vyhľadávanie podľa názvu nástenky",
    "Select board" : "Vybrať nástenku",
    "Create a new card" : "Vytvoriť novú kartu",
    "Select a board" : "Vyberte nástenku",
    "Select a list" : "Vybrať zoznam",
    "Card title" : "Meno karty",
    "Cancel" : "Zrušiť",
    "Creating the new card …" : "Vytváram novú kartu ...",
    "Card \"{card}\" was added to \"{board}\"" : "Karta \"{card}\" bola pridaná na \"{board}\"",
    "Open card" : "Otvoriť kartu",
    "Close" : "Zatvoriť",
    "Create card" : "Vytvoriť kartu",
    "Select a card" : "Vyberte kartu",
    "Select the card to link to a project" : "Vyberte kartu, ktorú chcete prepojiť s projektom",
    "Link to card" : "Prepojiť s kartou",
    "File already exists" : "Súbor už existuje",
    "A file with the name {filename} already exists." : "Súbor s názvom {filename} už existuje.",
    "Do you want to overwrite it?" : "Chcete ho prepísať?",
    "Overwrite file" : "Prepísať súbor",
    "Keep existing file" : "Ponechať existujúci súbor",
    "This board is read only" : "Táto nástenka je iba na čítanie",
    "Drop your files to upload" : "Pretiahnite sem súbory, ktoré chcete nahrať",
    "Add card" : "Pridať kartu",
    "Archived cards" : "Archivované karty",
    "Add list" : "Pridať zoznam",
    "List name" : "Názov zoznamu",
    "Active filters" : "Aktívne filtre",
    "Apply filter" : "Uplatniť filter",
    "Filter by tag" : "Filtrovať podľa štítkov",
    "Filter by assigned user" : "Filtrovať podľa priradeného používateľa",
    "Unassigned" : "Nepriradený",
    "Filter by due date" : "Filtrovať podľa termínu",
    "Overdue" : "Po termíne",
    "Next 24 hours" : "Ďalších 24 hodín",
    "Next 7 days" : "Následujúcich 7 dní",
    "Next 30 days" : "Následujúcich 30 dní",
    "No due date" : "Bez termínu",
    "Clear filter" : "Vyčistiť filter",
    "Hide archived cards" : "Skryť archivované karty",
    "Show archived cards" : "Zobraziť archivované karty",
    "Toggle compact mode" : "Vyp/zap. kompaktný režim",
    "Open details" : "Otvoriť detaily",
    "Details" : "Podrobnosti",
    "Loading board" : "Načítanie nástenky",
    "No lists available" : "Nie sú k dispozícii žiadne zoznamy",
    "Create a new list to add cards to this board" : "Pre pridanie kariet na túto tabuľu vytvorte nový zoznam",
    "Board not found" : "Nástenka nebola nájdená",
    "Sharing" : "Sprístupnenie",
    "Tags" : "Štítky",
    "Deleted items" : "Zmazané položky",
    "Timeline" : "Časová os",
    "Deleted lists" : "Vymazané zoznamy",
    "Undo" : "Odvolať",
    "Deleted cards" : "Odstránené karty",
    "Share board with a user, group or circle …" : "Zdieľanie nástenky s použivateľom, skupinou alebo okruhom…",
    "Searching for users, groups and circles …" : "Vyhľadávanie v používateľoch, skupinách a kruhoch...",
    "No participants found" : "Nenašli sa žiadni účastníci",
    "Board owner" : "Vlastník nástenky",
    "(Group)" : "(Skupina)",
    "(Circle)" : "(Okruh)",
    "Can edit" : "Môže upravovať",
    "Can share" : "Môže sprístupniť",
    "Can manage" : "Môže spravovať",
    "Owner" : "Vlastník",
    "Delete" : "Zmazať",
    "Failed to create share with {displayName}" : "Nepodarilo sa vytvoriť sprístupnenie pre {displayName}",
    "Are you sure you want to transfer the board {title} to {user}?" : "Naozaj chcete preniesť nástenku {title} na užívateľa {user}?",
    "Transfer the board." : "Prenos nástenky.",
    "Transfer" : "Prenos",
    "The board has been transferred to {user}" : "Nástenka bola presunutá na {user}",
    "Failed to transfer the board to {user}" : "Chyba pri presune nástenky na {user}",
    "Add a new list" : "Pridať nový zoznam",
    "Archive all cards" : "Archivovať všetky karty",
    "Unarchive all cards" : "Zrušiť archiváciu všetkých kariet",
    "Delete list" : "Vymazať zoznam",
    "Archive all cards in this list" : "Archivovať všetky karty v tomto zozname",
    "Unarchive all cards in this list" : "Zrušiť archiváciu všetkých kariet v tomto zozname",
    "Add a new card" : "Pridať novú kartu",
    "Card name" : "Názov karty",
    "List deleted" : "Zoznam bol vymazaný",
    "Edit" : "Upraviť",
    "Add a new tag" : "Pridať nový štítok",
    "title and color value must be provided" : "je potrebné zadať nadpis a vybrať farbu",
    "Board name" : "Názov nástenky",
    "Members" : "Členovia",
    "Upload new files" : "Nahrať nové súbory",
    "Share from Files" : "Zdieľať zo Súborov",
    "Pending share" : "Čakajúce zdeľanie",
    "Add this attachment" : "Pridať túto prílohu",
    "Show in Files" : "Zobraziť v Súboroch",
    "Download" : "Sťahovanie",
    "Remove attachment" : "Odstrániť prílohu",
    "Delete Attachment" : "Odstrániť prílohu",
    "Restore Attachment" : "Obnoviť prílohu",
    "File to share" : "Súbor na zdieľanie",
    "Invalid path selected" : "Bola vybraná neplatná cesta",
    "Open in sidebar view" : "Otvoriť v zobrazení v bočnom paneli",
    "Open in bigger view" : "Otvoriť vo väčšom zobrazení",
    "Attachments" : "Prílohy",
    "Comments" : "Komentáre",
    "Modified" : "Upravené",
    "Created" : "Vytvorené",
    "The title cannot be empty." : "Nadpis nemôže byť prázdny.",
    "No comments yet. Begin the discussion!" : "Zatiaľ bez komentárov. Začnite diskusiu!",
    "Failed to load comments" : "Nepodarilo sa načítať komentáre",
    "Assign a tag to this card…" : "Tejto karte priradiť štítok…",
    "Assign to users" : "Priradiť používateľom",
    "Assign to users/groups/circles" : "Priradiť používateľom/skupinám/okruhom",
    "Assign a user to this card…" : "Priradiť používateľa k tejto karte…",
    "Due date" : "Termín dokončenia",
    "Set a due date" : "Nastaviť termín",
    "Remove due date" : "Odstrániť termín dokončenia",
    "Select Date" : "Vybrať dátum",
    "Today" : "Dnes",
    "Tomorrow" : "Zajtra",
    "Next week" : "Nasledujúci týždeň",
    "Next month" : "Nasledujúci mesiac",
    "Save" : "Uložiť",
    "The comment cannot be empty." : "Komentár nemôže byť prázdny.",
    "The comment cannot be longer than 1000 characters." : "Komentár nemôže byť dlhší ako 1000 znakov.",
    "In reply to" : "Odpoveď na",
    "Cancel reply" : "Zrušiť odpoveď",
    "Reply" : "Odpoveď",
    "Update" : "Aktualizovať",
    "Description" : "Popis",
    "(Unsaved)" : "(Neuložené)",
    "(Saving…)" : "(Ukladanie…)",
    "Formatting help" : "Pomoc pri formátovaní",
    "Edit description" : "Upraviť popis",
    "View description" : "Zobraziť popis",
    "Add Attachment" : "Pridať prílohu",
    "Write a description …" : "Napíšte popis...",
    "Choose attachment" : "Vybrať prílohu",
    "(group)" : "(skupina)",
    "Todo items" : "Položky úloh",
    "{count} comments, {unread} unread" : "{count} komentárov, {unread} neprečítaných",
    "Edit card title" : "Upraviť názov karty",
    "Assign to me" : "Priradiť mne",
    "Unassign myself" : "Zrušiť priradenie mne",
    "Move card" : "Presunúť kartu",
    "Unarchive card" : "Zrušiť archiváciu karty",
    "Archive card" : "Archivovať kartu",
    "Delete card" : "Zmazať kartu",
    "Move card to another board" : "Presunúť kartu na inú nástenku",
    "List is empty" : "Zoznam je prázdny",
    "Card deleted" : "Karta bola vymazaná",
    "seconds ago" : "pred niekoľkými sekundami",
    "All boards" : "Všetky nástenky",
    "Archived boards" : "Archivované nástenky",
    "Shared with you" : "Vám sprístupnené",
    "Deck settings" : "Nastavenia paluby",
    "Use bigger card view" : "Použiť väčšie zobrazenie karty",
    "Show card ID badge" : "Ukázať ID karty",
    "Show boards in calendar/tasks" : "Zobrazovať nástenky v kalendári/úlohách",
    "Limit deck usage of groups" : "Obmedziť použitie Deck na skupiny",
    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Obmedzenie Násteniek bráni používateľom, ktorí nie sú súčasťou týchto skupín, aby si vytvárali vlastné nástenky. Môžu však stále pracovať na nástenkách, ktoré im niekto sprístupní.",
    "Board details" : "Podrobnosti o nástenke",
    "Edit board" : "Upraviť nástenku",
    "Clone board" : "Duplikovať nástenku",
    "Unarchive board" : "Zrušiť archiváciu nástenky",
    "Archive board" : "Archivovať nástenku",
    "Turn on due date reminders" : "Zapnúť pripomienky na termín dokončenia",
    "Turn off due date reminders" : "Vypnúť pripomienky na termín dokončenia",
    "Due date reminders" : "Pripomienky termínu dokončenia",
    "All cards" : "Všetky karty",
    "Assigned cards" : "Priradené karty",
    "No notifications" : "Žiadne upozornenia",
    "Delete board" : "Vymazať nástenku",
    "Board {0} deleted" : "Nástenka {0} vymazaná",
    "Only assigned cards" : "Len priradené karty",
    "No reminder" : "Žiadna pripomienka",
    "An error occurred" : "Vyskytla sa chyba",
    "Are you sure you want to delete the board {title}? This will delete all the data of this board including archived cards." : "Naozaj chcete chcete vymazať nástenku {title}? Toto zmaže všetky údaje o tejto nástenke vrátane archivovaných kariet.",
    "Delete the board?" : "Vymazať nástenku?",
    "Loading filtered view" : "Načítavanie filtrovaného pohľadu",
    "No due" : "Žiadny termín dokončenia",
    "Search for {searchQuery} in all boards" : "Vyhľadať {searchQuery} na všetkých plochách",
    "No results found" : "Neboli nájdené žiadne výsledky",
    "{stack} in {board}" : "{stack} v {board}",
    "Click to expand description" : "Kliknite pre rozšírenie popisu",
    "* Created on {created}\n* Last modified on {lastMod}\n* {nbAttachments} attachments\n* {nbComments} comments" : "* Vytvorené dňa {created}\n* Naposledy upravené {lastMod}\n* {nbAttachments} príloh\n* Komentáre: {nbComments}",
    "{nbCards} cards" : "{nbCards} kariet",
    "No upcoming cards" : "Žiadne nadchádzajúce karty",
    "upcoming cards" : "nadchádzajúce karty",
    "Due on {date}" : "Platné do {date}",
    "Link to a board" : "Odkaz na nástenku",
    "Link to a card" : "Prepojiť s kartou",
    "Create a card" : "Vytvoriť kartu",
    "Message from {author} in {conversationName}" : "Správa od {author} v {conversationName}",
    "Something went wrong" : "Niečo sa pokazilo",
    "Failed to upload {name}" : "Zlyhalo nahrávanie {name}",
    "Maximum file size of {size} exceeded" : "Bola prekročená maximálna veľkosť súboru {size}",
    "Error creating the share" : "Chyba pri vytváraní zdieľania",
    "Share with a Deck card" : "Zdieľať s kartou Deck",
    "Share {file} with a Deck card" : "Zdieľať {file} s kartou Deck",
    "Share" : "Zdieľať",
    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Karty sú nástroj zacielený na osobné alebo projektové plánovanie tímov v štýle Kanban integrovaný do Nextcloud.\n\n\n- 📥 Zadávajte a usporadúvajte svoje úlohy do kariet\n- 📄 Zapisujte si dodatočné poznámky\n- 🔖 Priraďujte štítky pre ešte lepšiu organizáciu\n- 👥 Zdieľajte so svojim tímom, priateľmi alebo rodinou\n- 🚀 Dostaňte svoj projekt pod kontrolu",
    "Are you sure you want to transfer the board {title} for {user} ?" : "Naozaj chcete preniesť nástenku {title} na užívateľa {user} ?",
    "Transfer the board for {user} successfully" : "Presun nástenky na  {user} bolo úspešné",
    "Failed to transfer the board for {user}" : "Chyba pri presune nástenky na {user}",
    "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "Naozaj chcete chcete vymazať nástenku {title}? Toto zmaže všetky údaje o tejto nástenke.",
    "This week" : "Tento týždeň",
    "Are you sure you want to transfer the board {title} for {user}?" : "Naozaj chcete preniesť nástenku {title} na užívateľa {user}?"
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
