OC.L10N.register(
    "deck",
    {
    "You have created a new board {board}" : "Þú hefur búið til nýja borðið {board}",
    "{user} has created a new board {board}" : "{user} hefur búið til nýja borðið {board}",
    "You have deleted the board {board}" : "Þú hefur eytt borðinu {board}",
    "{user} has deleted the board {board}" : "{user} hefur eytt borðinu {board}",
    "You have restored the board {board}" : "Þú hefur endurheimt borðið {board}",
    "{user} has restored the board {board}" : "{user} hefur endurheimt borðið {board}",
    "You have shared the board {board} with {acl}" : "Þú hefur deilt borðinu {board} með {acl}",
    "{user} has shared the board {board} with {acl}" : "{user} hefur deilt borðinu {board} með {acl}",
    "You have removed {acl} from the board {board}" : "Þú fjarlægðir {acl} af borðinu {board}",
    "{user} has removed {acl} from the board {board}" : "{user} fjarlægði {acl} af borðinu {board}",
    "You have renamed the board {before} to {board}" : "Þú hefur endurnefnt borðið {before} sem {board}",
    "{user} has renamed the board {before} to {board}" : "{user} hefur endurnefnt borðið {before} sem {board}",
    "You have archived the board {board}" : "Þú settir borðið {board} í geymslu",
    "{user} has archived the board {before}" : "{user} setti borðið {before} í geymslu",
    "You have unarchived the board {board}" : "Þú tókst borðið {board} úr geymslu",
    "{user} has unarchived the board {before}" : "{user} tók borðið {before} úr geymslu",
    "You have renamed the card {before} to {card}" : "Þú hefur endurnefnt spjaldið {before} sem {card}",
    "{user} has renamed the card {before} to {card}" : "{user} hefur endurnefnt spjaldið {before} sem {card}",
    "You have removed the due date of card {card}" : "Þú fjarlægðir gildistíma af spjaldinu {card}",
    "{user} has removed the due date of card {card}" : "{user} fjarlægði gildistíma af spjaldinu {card}",
    "You have set the due date of card {card} to {after}" : "Þú settir gildistíma spjaldsins {card} á {after}",
    "{user} has set the due date of card {card} to {after}" : "{user} setti gildistíma spjaldsins {card} á {after}",
    "You have updated the due date of card {card} to {after}" : "Þú uppfærðir gildistíma spjaldsins {card} á {after}",
    "{user} has updated the due date of card {card} to {after}" : "{user} uppfærði gildistíma spjaldsins {card} á {after}",
    "You have assigned {assigneduser} to card {card} on board {board}" : "Þú úthlutaðir {assigneduser} á spjaldið {card} á borðinu {board}",
    "{user} has assigned {assigneduser} to card {card} on board {board}" : "{user} úthlutaði {assigneduser} á spjaldið {card} á borðinu {board}",
    "You have unassigned {assigneduser} from card {card} on board {board}" : "Þú hefur afturkallað úthlutun {assigneduser} á spjaldið {card} á borðinu {board}",
    "{user} has unassigned {assigneduser} from card {card} on board {board}" : "{user} hefur afturkallað úthlutun {assigneduser} á spjaldið {card} á borðinu {board}",
    "You have added the attachment {attachment} to card {card}" : "Þú bættir viðhenginu {attachment} við spjaldið {card}",
    "{user} has added the attachment {attachment} to card {card}" : "{user} bætti viðhenginu {attachment} við spjaldið {card}",
    "You have updated the attachment {attachment} on card {card}" : "Þú uppfærðir viðhengið {attachment} á spjaldinu {card}",
    "{user} has updated the attachment {attachment} on card {card}" : "{user} uppfærði viðhengið {attachment} á spjaldinu {card}",
    "You have deleted the attachment {attachment} from card {card}" : "Þú eyddir viðhenginu {attachment} af spjaldinu {card}",
    "{user} has deleted the attachment {attachment} from card {card}" : "{user} eyddi viðhenginu {attachment} af spjaldinu {card}",
    "You have restored the attachment {attachment} to card {card}" : "Þú endurheimtir viðhengið {attachment} á spjaldinu {card}",
    "{user} has restored the attachment {attachment} to card {card}" : "{user} endurheimti viðhengið {attachment} á spjaldinu {card}",
    "You have commented on card {card}" : "Þú settir inn athugasemd við spjaldið {card}",
    "{user} has commented on card {card}" : "{user} setti inn athugasemd við spjaldið {card}",
    "A <strong>card description</strong> inside the Deck app has been changed" : "<strong>Lýsingu á spjaldi</strong> inni í Deck-spjaldaforritinu hefur verið breytt",
    "Deck" : "Dekk",
    "Changes in the <strong>Deck app</strong>" : "Breytingar í <strong>Deck spjaldaforritinu</strong>",
    "A <strong>comment</strong> was created on a card" : "<strong>Athugasemd</strong> var gerð á spjaldi",
    "Load more" : "Hlaða inn meira",
    "Personal" : "Einka",
    "The card \"%s\" on \"%s\" has been assigned to you by %s." : "Spjaldinu \"%s\" á \"%s\" hefur verið úthlutað til þín af %s.",
    "The card \"%s\" on \"%s\" has reached its due date." : "Spjaldið \"%s\" á \"%s\" er komið fram yfir lokadagsetningu.",
    "%s has mentioned you in a comment on \"%s\"." : "%s minntist á þig í athugasemd við \"%s\".",
    "The board \"%s\" has been shared with you by %s." : "Borðinu \"%s\" hefur verið deilt með þér af %s.",
    "%s on %s" : "%s á %s",
    "No data was provided to create an attachment." : "Engin gögn voru gefin til að útbúa viðhengi.",
    "Finished" : "Lokið",
    "To review" : "Til að yfirfara",
    "Action needed" : "Aðgerðar krafist",
    "Later" : "Seinna",
    "copy" : "afrita",
    "To do" : "Verkefni",
    "Doing" : "Er að gera",
    "Done" : "Lokið",
    "Example Task 3" : "Dæmi um verkefni 3",
    "Example Task 2" : "Dæmi um verkefni 2",
    "Example Task 1" : "Dæmi um verkefni 1",
    "The file was uploaded" : "Skráin var send inn",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Innsend skrá er stærri en upload_max stillingin í php.ini:",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Innsenda skráin er stærri en MAX_FILE_SIZE sem skilgreint er í HTML sniðinu.",
    "The file was only partially uploaded" : "Einungis hluti af innsendri skrá skilaði sér",
    "No file was uploaded" : "Engin skrá skilaði sér",
    "Missing a temporary folder" : "Vantar bráðabirgðamöppu",
    "Could not write file to disk" : "Tókst ekki að skrifa skrá á disk.",
    "A PHP extension stopped the file upload" : "PHP-viðbót stöðvaði innsendingu skráar",
    "No file uploaded or file size exceeds maximum of %s" : "Engin innsend skrá eða að skráarstærð fór fram úr hámarksstæðinni %s",
    "Invalid date, date format must be YYYY-MM-DD" : "Ógild dagsetning, dagsetningasniðið verður að vera ÁÁÁÁ-MM-DD",
    "Personal planning and team project organization" : "Persónuleg áætlanagerð og skipulag verkefnisvinnu",
    "Card details" : "Nánar um spjald",
    "Add board" : "Bæta við borði",
    "Select the board to link to a project" : "Veldu borðið sem á að tengja við verkefnið",
    "Select board" : "Veldu borð",
    "Select a board" : "Veldu borð",
    "Cancel" : "Hætta við",
    "Close" : "Loka",
    "Create card" : "Búa til spjald",
    "Select a card" : "Veldu spjald",
    "Select the card to link to a project" : "Veldu spjaldið sem á að tengja við verkefnið",
    "Link to card" : "Tengill á spjald",
    "File already exists" : "Skrá er þegar til",
    "Do you want to overwrite it?" : "Viltu skrifa yfir það?",
    "Add card" : "Bæta við spjaldi",
    "Archived cards" : "Spjöld í geymslu",
    "Add list" : "Bæta við lista",
    "List name" : "Heiti á lista",
    "Apply filter" : "Beita síu",
    "Filter by tag" : "Sía eftir merki",
    "Filter by assigned user" : "Sía eftir úthlutuðum notanda",
    "Unassigned" : "Ekki úthlutað",
    "Filter by due date" : "Sía eftir lokadagsetningu",
    "Overdue" : "Fram yfir tímamörk",
    "Next 7 days" : "Næstu 7 daga",
    "Next 30 days" : "Næstu 30 daga",
    "No due date" : "Enginn lokadagur",
    "Hide archived cards" : "Fela spjöld í geymslu",
    "Show archived cards" : "Sýna spjöld í geymslu",
    "Toggle compact mode" : "Víxla þjöppuðum ham af/á",
    "Open details" : "Opna nánari upplýsingar",
    "Details" : "Details",
    "Loading board" : "Hleð inn borði",
    "Board not found" : "Borð fannst ekki",
    "Sharing" : "Deiling",
    "Tags" : "Merki",
    "Deleted items" : "Eydd atriði",
    "Timeline" : "Tímalína",
    "Undo" : "Afturkalla",
    "Deleted cards" : "Eydd spjöld",
    "Share board with a user, group or circle …" : "Deila borði með notanda, hóp eða hring …",
    "No participants found" : "No participants found",
    "Board owner" : "Eigandi borðs",
    "(Group)" : "(Hópur)",
    "(Circle)" : "(hringur)",
    "Can edit" : "Getur breytt",
    "Can share" : "Getur deilt",
    "Can manage" : "Gerur sýslað með",
    "Owner" : "Eigandi",
    "Delete" : "Eyða",
    "Transfer" : "Færa",
    "Delete list" : "Eyða lista",
    "Add a new card" : "Bæta við nýju spjaldi",
    "Edit" : "Breyta",
    "title and color value must be provided" : "titill og litgildi verða að vera til staðar",
    "Members" : "Meðlimir",
    "Download" : "Sækja",
    "File to share" : "Skrá til að deila",
    "Invalid path selected" : "Ógild slóð valin",
    "Attachments" : "Viðhengi",
    "Comments" : "Athugasemdir",
    "Modified" : "Breytt",
    "Created" : "Búið til þann",
    "No comments yet. Begin the discussion!" : "Engar athugasemdir ennþá. Byrjaðu umræðuna!",
    "Assign a tag to this card…" : "Úthluta merki á þetta spjald",
    "Assign to users" : "Úthluta á notendur",
    "Assign a user to this card…" : "Úthluta notanda á þetta spjald",
    "Due date" : "Skiladagur",
    "Set a due date" : "Setja lokadag",
    "Remove due date" : "Fjarlægja skiladag",
    "Select Date" : "Veldu dag",
    "Today" : "Í dag",
    "Tomorrow" : "Á morgun",
    "Next week" : "Næsta viku",
    "Next month" : "Næsti mánuður",
    "Save" : "Vista",
    "The comment cannot be empty." : "Athugasemdin má ekki vera tóm.",
    "The comment cannot be longer than 1000 characters." : "Athugasemdin má ekki vera lengri en 1000 stafir.",
    "Reply" : "Svara",
    "Update" : "Uppfæra",
    "Description" : "Lýsing",
    "Formatting help" : "Hjálp við að sníða",
    "(group)" : "(hópur)",
    "Assign to me" : "Úthluta mér",
    "Move card" : "Færa spjald",
    "Unarchive card" : "Taka spjald úr geymslu",
    "Archive card" : "Setja spjald í geymslu",
    "Delete card" : "Eyða spjaldi",
    "seconds ago" : "sekúndum síðan",
    "All boards" : "Öll borð",
    "Archived boards" : "Borð í geymslu",
    "Shared with you" : "Deilt með þér",
    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Takmörkun í  Deck spjaldaforritinu mun loka notendur sem tilheyra ekki þessum hópum frá því að útbúa sín eigin borð. Notendurnir munu samt geta áfram unnið með borð sem hefur verið deilt til þeirra.",
    "Board details" : "Nánar um borð",
    "Edit board" : "Breyta borði",
    "Clone board" : "Klóna borð",
    "Unarchive board" : "Taka borð úr geymslu",
    "Archive board" : "Setja borð í geymslu",
    "No notifications" : "Engar tilkynningar",
    "Delete board" : "Eyða borði",
    "No reminder" : "Engin áminning",
    "An error occurred" : "Villa kom upp",
    "No results found" : "Engar niðurstöður fundust",
    "Link to a board" : "Tengill við borð",
    "Link to a card" : "Tengja við spjald",
    "Something went wrong" : "Eitthvað fór úrskeiðis",
    "Maximum file size of {size} exceeded" : "Fór yfir hámarks skráarstærð {size}",
    "Share" : "Deila",
    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Dekk (e. Deck) er skipulagningartól í kanban-stíl sem ætlað er fyrir verkefna- og persónuupplýsingastjórnun hópvinnuteyma innan Nextcloud.\n\n\n- 📥 Settu verkefnin þín á spjöld of raðaðu þeim á ýmsa vegu\n- 📄 Skrifaðu niður minnispunkta í markdown-kóða\n- 🔖 Úthlutaðu merkjum/skýringum til að bæta skipulagninguna\n- 👥 Deildu með vinnuhópnum, vinum eða fjölskyldu\n- 📎 Hengdu við skrár og ívefðu þær í lýsinguna með markdown-kóða\n- 💬 Ræddu málin við hópinn þinn með athugasemdum\n- ⚡ Haltu utan um breytingar í virknistreyminu\n- 🚀 Haltu verkefnunum þínum skipulögðum",
    "This week" : "Í þessari viku"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
