OC.L10N.register(
    "deck",
    {
    "You have created a new board {board}" : "Vytvořili jste tabuli {board}",
    "{user} has created a new board {board}" : "{user} vytvořil(a) novou tabuli {board}",
    "You have deleted the board {board}" : "Smazali jste tabuli {board}",
    "{user} has deleted the board {board}" : "{user} smazal(a) tabuli {board}",
    "You have restored the board {board}" : "Obnovili jste tabuli {board}",
    "{user} has restored the board {board}" : "{user} obnovil(a) tabuli {board}",
    "You have shared the board {board} with {acl}" : "Nasdíleli jste tabuli {board} s {acl}",
    "{user} has shared the board {board} with {acl}" : "{user} nasdílel(a) tabuli {board} s {acl}",
    "You have removed {acl} from the board {board}" : "Odebrali jste {acl} z tabule {board}",
    "{user} has removed {acl} from the board {board}" : "{user} odebral(a) {acl} z tabule {board}",
    "You have renamed the board {before} to {board}" : "Přejmenovali jste tabuli {before} na {board}",
    "{user} has renamed the board {before} to {board}" : "{user} přejmenoval(a) tabuli {before} na {board}",
    "You have archived the board {board}" : "Zaarchivovali jste tabuli {board}",
    "{user} has archived the board {before}" : "{user} zaarchivoval(a) tabuli {before}",
    "You have unarchived the board {board}" : "Vrátili jste zpět z archivace tabuli {board}",
    "{user} has unarchived the board {before}" : "{user} vrátil(a) tabuli {before} zpět z archivace",
    "You have created a new list {stack} on board {board}" : "Vytvořili jste nový sloupec {stack} na tabuli {board}",
    "{user} has created a new list {stack} on board {board}" : "{user} vytvořil(a) nový sloupec {stack} na tabuli {board}",
    "You have renamed list {before} to {stack} on board {board}" : "Přejmenovali jste sloupec {before} na {stack} na tabuli {board}",
    "{user} has renamed list {before} to {stack} on board {board}" : "{user} přejmenoval(a) sloupec {before} na {stack} na tabuli {board}",
    "You have deleted list {stack} on board {board}" : "Smazali jste sloupec {stack} na tabuli {board}",
    "{user} has deleted list {stack} on board {board}" : "{user} smazal(a) sloupec {stack} na tabuli {board}",
    "You have created card {card} in list {stack} on board {board}" : "Vytvořili jste kartu {card} ve sloupci {stack} na tabuli {board}",
    "{user} has created card {card} in list {stack} on board {board}" : "{user} vytvořil(a) kartu {card} ve sloupci {stack} na tabuli {board}",
    "You have deleted card {card} in list {stack} on board {board}" : "Smazali jste kartu {card} ve sloupci {stack} na tabuli {board}",
    "{user} has deleted card {card} in list {stack} on board {board}" : "{user} smazal(a) kartu {card} ve sloupci {board} na tabuli {board}",
    "You have renamed the card {before} to {card}" : "Přejmenovali jste kartu {before} na {card}",
    "{user} has renamed the card {before} to {card}" : "{user} přejmenoval(a) kartu {before} na {card}",
    "You have added a description to card {card} in list {stack} on board {board}" : "Přidali jste popis ke kartě {card} ve sloupci {stack} na tabuli {board}",
    "{user} has added a description to card {card} in list {stack} on board {board}" : "{user} přidal(a) popis ke kartě {card} ve sloupci {stack} na tabuli {board}",
    "You have updated the description of card {card} in list {stack} on board {board}" : "Aktualizovali jste popis karty {card} ve sloupci {stack} na tabuli {board}",
    "{user} has updated the description of the card {card} in list {stack} on board {board}" : "{user} aktualizoval(a) popis karty {card} ve sloupci {stack} na tabuli {board}",
    "You have archived card {card} in list {stack} on board {board}" : "Zaarchivovali kartu {card} ve sloupci {stack} na tabuli {board}",
    "{user} has archived card {card} in list {stack} on board {board}" : "{user} zaarchivoval(a) kartu {card} ve sloupci {stack} na tabuli {board}",
    "You have unarchived card {card} in list {stack} on board {board}" : "Zrušili jste archivacii karty {card} ve sloupci {stack} na tabuli {board}",
    "{user} has unarchived card {card} in list {stack} on board {board}" : "{user} zrušil(a) archivaci karty {card} ve sloupci {stack} na tabuli {board}",
    "You have removed the due date of card {card}" : "Odebrali jste termín u karty {card}",
    "{user} has removed the due date of card {card}" : "{user} odebral(a) termín u karty {card}",
    "You have set the due date of card {card} to {after}" : "Nastavili jste termín u karty {card} na {after}",
    "{user} has set the due date of card {card} to {after}" : "{user} nastavil(a) termín u karty {card} na {after}",
    "You have updated the due date of card {card} to {after}" : "Změnili jste termín u karty {card} na {after}",
    "{user} has updated the due date of card {card} to {after}" : "{user} aktualizoval(a) termín u karty {card} na {after}",
    "You have added the tag {label} to card {card} in list {stack} on board {board}" : "Přidali jste štítek {label} kartě {card} ve sloupci {stack} na tabuli {board}",
    "{user} has added the tag {label} to card {card} in list {stack} on board {board}" : "{user} přidal(a) štítek {label} ke kartě {card} ve sloupci {stack} na tabuli {board}",
    "You have removed the tag {label} from card {card} in list {stack} on board {board}" : "Odebrali jste štítek {label} z karty {card} ve sloupci {stack} na tabuli {board}",
    "{user} has removed the tag {label} from card {card} in list {stack} on board {board}" : "{user} odebral(a) štítek {label} z karty {card} ve sloupci {stack} na tabuli {board}",
    "You have assigned {assigneduser} to card {card} on board {board}" : "Přiřadili jste {assigneduser} ke kartě {card} na tabuli {board}",
    "{user} has assigned {assigneduser} to card {card} on board {board}" : "{user} přiřadil(a) {assigneduser} ke kartě {card} na tabuli {board}",
    "You have unassigned {assigneduser} from card {card} on board {board}" : "Zrušili jste přiřazení {assigneduser} u karty {card} na tabuli {board}",
    "{user} has unassigned {assigneduser} from card {card} on board {board}" : "{user} zrušil(a) přiřazení {assigneduser} z karty {card} na tabuli {board}",
    "You have moved the card {card} from list {stackBefore} to {stack}" : "Přesunuli jste kartu {card} ze sloupce {stackBefore} do {stack}",
    "{user} has moved the card {card} from list {stackBefore} to {stack}" : "{user} přesunul(a) kartu {card} ze sloupce {stackBefore} do {stack}",
    "You have added the attachment {attachment} to card {card}" : "Přidali jste přílohu {attachment} ke kartě {card}",
    "{user} has added the attachment {attachment} to card {card}" : "{user} přidal(a) přílohu {attachment} ke kartě {card}",
    "You have updated the attachment {attachment} on card {card}" : "Aktualizovali jste přílohu {attachment} u karty {card}",
    "{user} has updated the attachment {attachment} on card {card}" : "{user} aktualizoval(a) přílohu {attachment} u karty {card}",
    "You have deleted the attachment {attachment} from card {card}" : "Smazali jste přílohu {attachment} u karty {card}",
    "{user} has deleted the attachment {attachment} from card {card}" : "{user} smazal(a) přílohu {attachment} u karty {card}",
    "You have restored the attachment {attachment} to card {card}" : "Obnovili jste přílohu {attachment} ke kartě {card}",
    "{user} has restored the attachment {attachment} to card {card}" : "{user} obnovil(a) přílohu {attachment} ke kartě {card}",
    "You have commented on card {card}" : "Přidali jste komentář na kartě {card}",
    "{user} has commented on card {card}" : "{user} přidal(a) komentář na kartě {card}",
    "A <strong>card description</strong> inside the Deck app has been changed" : "<strong>Popis karty</strong> v aplikaci Deck byl změněn",
    "Deck" : "Deck",
    "Changes in the <strong>Deck app</strong>" : "Změny v <strong>aplikaci Deck</strong>",
    "A <strong>comment</strong> was created on a card" : "Na kartě byl vytvořen <strong>komentář</strong>",
    "Upcoming cards" : "Nadcházející karty",
    "Load more" : "Načíst více",
    "Personal" : "Osobní",
    "The card \"%s\" on \"%s\" has been assigned to you by %s." : "Kartu „%s“ na „%s“ vám přiřadil(a) %s.",
    "{user} has assigned the card {deck-card} on {deck-board} to you." : "{user} vám přiřadil(a) kartu {deck-card} na tabuli {deck-board}.",
    "The card \"%s\" on \"%s\" has reached its due date." : "U karty „%s“ z tabule „%s“ nastalo plánované datum dokončení.",
    "The card {deck-card} on {deck-board} has reached its due date." : "Karta {deck-card} na tabuli {deck-board} dosáhla data plánovaného dokončení.",
    "%s has mentioned you in a comment on \"%s\"." : "%s vás zmínil(a) v komentáři k „%s“.",
    "{user} has mentioned you in a comment on {deck-card}." : "{user} vás zmínil(a) v komentáři na kartě {deck-card}.",
    "The board \"%s\" has been shared with you by %s." : "Uživatel %s vám nasdílel(a) tabuli „%s“.",
    "{user} has shared {deck-board} with you." : "{user} vám nasdílel(a) tabuli {deck-board}.",
    "Card comments" : "Komentáře v kartách",
    "%s on %s" : "%s na %s",
    "No data was provided to create an attachment." : "Nebyla poskytnuta žádná data pro vytvoření přílohy.",
    "Finished" : "Dokončeno",
    "To review" : "K revizi",
    "Action needed" : "Nutná akce",
    "Later" : "Později",
    "copy" : "kopie",
    "To do" : "Zbývá udělat",
    "Doing" : "Provádí se",
    "Done" : "Hotovo",
    "Example Task 3" : "Třetí úkol pro ukázku",
    "Example Task 2" : "Druhý úkol pro ukázku",
    "Example Task 1" : "První úkol pro ukázku",
    "The file was uploaded" : "Soubor byl nahrán",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Velikost nahrávaného souboru překračuje limit nastavení direktivou upload_max_filesize v php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Nahrávaný soubor přesáhl svou velikostí hodnotu direktivy MAX_FILE_SIZE, určenou v HTML formuláři",
    "The file was only partially uploaded" : "Soubor byl nahrán pouze z části",
    "No file was uploaded" : "Nebyl nahrán žádný soubor",
    "Missing a temporary folder" : "Chybí složka pro dočasné soubory",
    "Could not write file to disk" : "Soubor se nedaří se zapsat na úložiště",
    "A PHP extension stopped the file upload" : "PHP rozšíření zastavilo nahrávání souboru.",
    "No file uploaded or file size exceeds maximum of %s" : "Nebyl nahrán žádný soubor nebo jeho velikost přesáhla %s",
    "This comment has more than %s characters.\nAdded as an attachment to the card with name %s.\nAccessible on URL: %s." : "Tento komentář je delší než %s znaků.\nPřidán jako příloha ke kartě nazvané %s.\nDostupné na URL: %s.",
    "Card not found" : "Karta nebyla nalezena",
    "Path is already shared with this card" : "Popis umístění už je touto kartou sdíleno",
    "Invalid date, date format must be YYYY-MM-DD" : "Neplatné datum – je třeba, aby formát data byl RRRR-MM-DD",
    "Personal planning and team project organization" : "Osobní plánování a organizování týmového projektu",
    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in Markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your Markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Deck je nástroj cílený na osobní nebo projektové plánování týmů v Kanban stylu, napojený do Nextcloud.\n\n\n- 📥 Zadávejte a uspořádávejte své úkoly do karet\n- 📄 Zapisujte si dodatečné poznámky (v Markdown) \n- 🔖 Přiřazujte štítky pro ještě lepší uspořádání\n- 👥 Sdílejte se svým týmem, přáteli nebo rodinou\n- 📎 Připojte soubory a vložte je do (Markdown) popisu \n- 💬 Diskutujte se svým týmem prostřednictvím komentářů\n- ⚡ Udržte si přehled o změnách prostřednictvím sledování proudu aktivit\n- 🚀 Dostaňte svůj projekt pod kontrolu",
    "Card details" : "Podrobnosti o kartě",
    "Add board" : "Přidat tabuli",
    "Select the board to link to a project" : "Vyberte tabuli kterou propojit s projektem",
    "Search by board title" : "Hledat podle názvu tabule",
    "Select board" : "Vybrat tabuli",
    "Create a new card" : "Vytvořit novou kartu",
    "Select a board" : "Vybrat tabuli",
    "Select a list" : "Vyberte sloupec",
    "Card title" : "Název karty",
    "Cancel" : "Storno",
    "Creating the new card …" : "Vytváření nové karty…",
    "Card \"{card}\" was added to \"{board}\"" : "Karta „{card}“ byla přidána na „{board}“",
    "Open card" : "Otevřít kartu",
    "Close" : "Zavřít",
    "Create card" : "Vytvořit kartu",
    "Select a card" : "Vybrat kartu",
    "Select the card to link to a project" : "Vyberte kartu kterou propojit s projektem",
    "Link to card" : "Propojit s kartou",
    "File already exists" : "Soubor už existuje",
    "A file with the name {filename} already exists." : "Soubor nazvaný {filename} už existuje.",
    "Do you want to overwrite it?" : "Chcete položku přepsat?",
    "Overwrite file" : "Přepsat soubor",
    "Keep existing file" : "Ponechat existující soubor",
    "This board is read only" : "Tato tabule je pouze pro čtení",
    "Drop your files to upload" : "Přetáhněte sem soubory, které chcete nahrát",
    "Add card" : "Přidat kartu",
    "Archived cards" : "Archivované karty",
    "Add list" : "Přidat seznam",
    "List name" : "Název seznamu",
    "Active filters" : "Zapnuté filtry",
    "Apply filter" : "Uplatnit filtr",
    "Filter by tag" : "Filtrovat podle štítku",
    "Filter by assigned user" : "Filtrovat podle uživatele, který je úkolem pověřen",
    "Unassigned" : "Nepřiřazeno",
    "Filter by due date" : "Filtrovat podle termínu",
    "Overdue" : "Po termínu",
    "Next 24 hours" : "Následujících 24 hodin",
    "Next 7 days" : "Příštích 7 dnů",
    "Next 30 days" : "Příštích 30 dnů",
    "No due date" : "Žádný termín",
    "Clear filter" : "Vyčistit filtr",
    "Hide archived cards" : "Skrýt archivované karty",
    "Show archived cards" : "Zobrazit archivované karty",
    "Toggle compact mode" : "Vyp/zap. kompaktní režim",
    "Open details" : "Otevřít podorobnosti",
    "Details" : "Podrobnosti",
    "Loading board" : "Načítání tabule",
    "No lists available" : "Nejsou k dispozici žádné seznamy",
    "Create a new list to add cards to this board" : "Pro přidání karet na tuto tabuli vytvořte nový seznam",
    "Board not found" : "Tabule nenalezena",
    "Sharing" : "Sdílení",
    "Tags" : "Štítky",
    "Deleted items" : "Smazané položky",
    "Timeline" : "Časová osa",
    "Deleted lists" : "Smazané seznamy",
    "Undo" : "Vrátit zpět",
    "Deleted cards" : "Smazané karty",
    "Share board with a user, group or circle …" : "Sdílet tabuli s uživatelem, skupinou nebo okruhem…",
    "Searching for users, groups and circles …" : "Hledání v uživatelích, skupinách a okruzích…",
    "No participants found" : "Nenalezeni žádní účastníci",
    "Board owner" : "Vlastník tabule",
    "(Group)" : "(Skupina)",
    "(Circle)" : "(Okruh)",
    "Can edit" : "Může upravovat",
    "Can share" : "Může sdílet",
    "Can manage" : "Může spravovat",
    "Owner" : "Vlastník",
    "Delete" : "Smazat",
    "Failed to create share with {displayName}" : "Nepodařilo se vytvořit sdílení s {displayName}",
    "Are you sure you want to transfer the board {title} to {user}?" : "Opravdu chcete předat vlastnictví tabule {title} uživateli {user}?",
    "Transfer the board." : "Předat vlastnictví tabule.",
    "Transfer" : "Předat vlastnictví",
    "The board has been transferred to {user}" : "Vlastnictví tabule bylo předáno uživateli {user}",
    "Failed to transfer the board to {user}" : "Nepodařilo se předat vlastnictví tabule uživateli {user}",
    "Add a new list" : "Přidat nový sloupec",
    "Archive all cards" : "Archivovat všechny karty",
    "Unarchive all cards" : "Zrušit archivaci všech karet",
    "Delete list" : "Smazat seznam",
    "Archive all cards in this list" : "Archivovat všechny karty v tomto seznamu",
    "Unarchive all cards in this list" : "Zrušit archivaci všech karet v tomto seznamu",
    "Add a new card" : "Přidat novou kartu",
    "Card name" : "Název karty",
    "List deleted" : "Seznam smazán",
    "Edit" : "Upravit",
    "Add a new tag" : "Přidat nový štítek",
    "title and color value must be provided" : "je třeba zadat nadpis a zvolit barvu",
    "Board name" : "Název tabule",
    "Members" : "Členové",
    "Upload new files" : "Nahrát nové soubory",
    "Share from Files" : "Sdílet ze Souborů",
    "Pending share" : "Čekající sdílení",
    "Add this attachment" : "Přidat tuto přílohu",
    "Show in Files" : "Zobrazit v Souborech",
    "Download" : "Stáhnout",
    "Remove attachment" : "Odebrat přílohu",
    "Delete Attachment" : "Smazat přílohu",
    "Restore Attachment" : "Obnovit přílohu",
    "File to share" : "Soubor ke sdílení",
    "Invalid path selected" : "Je vybrán neplatný popis umístění",
    "Open in sidebar view" : "Otevřít v zobrazení v postranním panelu",
    "Open in bigger view" : "Otevřít ve větším zobrazení",
    "Attachments" : "Přílohy",
    "Comments" : "Komentáře",
    "Modified" : "Změněno",
    "Created" : "Vytvořeno",
    "The title cannot be empty." : "Nadpis je třeba vyplnit.",
    "No comments yet. Begin the discussion!" : "Zatím bez komentářů. Zahajte diskuzi!",
    "Failed to load comments" : "Načtení komentářů se nezdařilo",
    "Assign a tag to this card…" : "Přiřadit této kartě štítek…",
    "Assign to users" : "Přiřadit k uživatelům",
    "Assign to users/groups/circles" : "Přiřadit uživatelům/skupinám/okruhům",
    "Assign a user to this card…" : "Přiřadit uživatele k této kartě…",
    "Due date" : "Termín",
    "Set a due date" : "Vybrat termín",
    "Remove due date" : "Odstranit termín",
    "Select Date" : "Vybrat datum",
    "Today" : "Dnes",
    "Tomorrow" : "Zítra",
    "Next week" : "Příští týden",
    "Next month" : "Příští měsíc",
    "Save" : "Uložit",
    "The comment cannot be empty." : "Komentář je třeba vyplnit.",
    "The comment cannot be longer than 1000 characters." : "Délka komentáře může být nejvýše 1 000 znaků.",
    "In reply to" : "V odpověď na",
    "Cancel reply" : "Zrušit odpověď",
    "Reply" : "Odpovědět",
    "Update" : "Aktualizovat",
    "Description" : "Popis",
    "(Unsaved)" : "(Neuloženo)",
    "(Saving…)" : "(Ukládání…)",
    "Formatting help" : "Nápověda k formátování",
    "Edit description" : "Upravit popis",
    "View description" : "Zobrazit popis",
    "Add Attachment" : "Přidat přílohu",
    "Write a description …" : "Zadejte popis…",
    "Choose attachment" : "Zvolte přílohu",
    "(group)" : "(skupina)",
    "Todo items" : "Položky k udělání",
    "{count} comments, {unread} unread" : "{count} komentářů, {unread} nepřečtených",
    "Edit card title" : "Upravit nadpis karty",
    "Assign to me" : "Přiřadit mě",
    "Unassign myself" : "Zrušit přiřazení sobě",
    "Move card" : "Přesunout kartu",
    "Unarchive card" : "Zrušit archivaci karty",
    "Archive card" : "Archivovat kartu",
    "Delete card" : "Smazat kartu",
    "Move card to another board" : "Přesunout kartu na jinou tabuli",
    "List is empty" : "Seznam je prázdný",
    "Card deleted" : "Karta smazána",
    "seconds ago" : "před několika sekundami",
    "All boards" : "Všechny tabule",
    "Archived boards" : "Archivované tabule",
    "Shared with you" : "Sdíleno s vámi",
    "Deck settings" : "Nastavení pro Deck",
    "Use bigger card view" : "Použít větší zobrazení karet",
    "Show card ID badge" : "Zobrazit odznáček s identifikátorem karty",
    "Show boards in calendar/tasks" : "Zobrazit tabule v kalendáři/úkolech",
    "Limit deck usage of groups" : "Omezit využití deck na skupiny",
    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Omezení nastavené pro Deck brání uživatelům, kteří nejsou součástí těchto skupin, ve vytváření vlastních tabulí. Nicméně i tak ale pořád budou moci pracovat na tabulích, které jsou jim nasdíleny.",
    "Board details" : "Podrobnosti o tabuli",
    "Edit board" : "Upravit tabuli",
    "Clone board" : "Klonovat tabuli",
    "Unarchive board" : "Vrátit tabuli zpět z archivu",
    "Archive board" : "Archivovat tabuli",
    "Turn on due date reminders" : "Zapnout upomínky termínů",
    "Turn off due date reminders" : "Vypnout upomínky termínů",
    "Due date reminders" : "Upomínky termínů",
    "All cards" : "Všechny karty",
    "Assigned cards" : "Přiřazené karty",
    "No notifications" : "Žádná upozornění",
    "Delete board" : "Smazat tabuli",
    "Board {0} deleted" : "Tabule {0} smazána",
    "Only assigned cards" : "Pouze přiřazené karty",
    "No reminder" : "Bez připomínky",
    "An error occurred" : "Došlo k chybě",
    "Are you sure you want to delete the board {title}? This will delete all the data of this board including archived cards." : "Opravdu chcete tabuli {title} smazat? Toto smaže veškerá data této tabule, včetně archivovaných karet.",
    "Delete the board?" : "Smazat tabuli?",
    "Loading filtered view" : "Načítání filtrovaného pohledu",
    "No due" : "Žádný termín",
    "Search for {searchQuery} in all boards" : "Hledat {searchQuery} na všech tabulích",
    "No results found" : "Nenalezeny žádné výsledky",
    "{stack} in {board}" : "{stack} v {board}",
    "Click to expand description" : "Popis rozbalíte kliknutím",
    "* Created on {created}\n* Last modified on {lastMod}\n* {nbAttachments} attachments\n* {nbComments} comments" : "* Vytvořeno {created}\n* Naposledy upraveno {lastMod}\n* {nbAttachments} příloh\n* {nbComments} komentářů",
    "{nbCards} cards" : "{nbCards} karet",
    "No upcoming cards" : "Žádné nadcházející karty",
    "upcoming cards" : "nadcházející karty",
    "Due on {date}" : "Termín {date}",
    "Link to a board" : "Propojit s tabulí",
    "Link to a card" : "Propojit s kartou",
    "Create a card" : "Vytvořit kartu",
    "Message from {author} in {conversationName}" : "Zpráva od {author} v {conversationName}",
    "Something went wrong" : "Něco se pokazilo",
    "Failed to upload {name}" : "Nepodařilo se nahrát {name}",
    "Maximum file size of {size} exceeded" : "Překročena nejvyšší umožněná velikost souboru {size}",
    "Error creating the share" : "Chyba při vytváření sdílení",
    "Share with a Deck card" : "Sdílet s kartou aplikace Deck",
    "Share {file} with a Deck card" : "Sdílet {file} s kartou aplikace Deck",
    "Share" : "Sdílet",
    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Deck je nástroj cílený na osobní nebo projektové plánování týmů v Kanban stylu, vestavěný v Nextcloud.\n\n\n- 📥 Zadávejte a uspořádávejte své úkoly do karet\n- 📄 Zapisujte si dodatečné poznámky \n- 🔖 Přiřazujte štítky pro ještě lepší organizaci\n- 👥 Sdílejte se svým týmem, přáteli nebo rodinou\n- 🚀 Dostaňte svůj projekt pod kontrolu",
    "Are you sure you want to transfer the board {title} for {user} ?" : "Opravdu chcete předat vlastnictví tabule {title} uživateli {user}?",
    "Transfer the board for {user} successfully" : "Předání vlastnictví tabule uživateli {user} úspěšné",
    "Failed to transfer the board for {user}" : "Nepodařilo se předat vlastnictví tabule uživateli {user}",
    "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "Opravdu chcete tabuly {title} smazat? Toto smaže veškerá data této tabule.",
    "This week" : "Tento týden",
    "Are you sure you want to transfer the board {title} for {user}?" : "Opravdu chcete předat vlastnictví tabule {title} uživateli {user}?"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
