OC.L10N.register(
    "deck",
    {
    "Personal" : "شخصی",
    "Done" : "Done",
    "Cancel" : "منسوخ کریں",
    "Close" : "بند ",
    "Can edit" : "Can edit",
    "Can share" : "Can share",
    "Owner" : "Owner",
    "Delete" : "حذف کریں",
    "Edit" : "تدوین کریں",
    "Download" : "ڈاؤن لوڈ",
    "Today" : "آج",
    "Save" : "حفظ",
    "Reply" : "جواب",
    "Description" : "تصریح",
    "seconds ago" : "سیکنڈز پہلے",
    "Shared with you" : "Shared with you",
    "Share" : "تقسیم"
},
"nplurals=2; plural=(n != 1);");
