OC.L10N.register(
    "deck",
    {
    "You have created a new board {board}" : "Heu creat el nou tauler {board}",
    "{user} has created a new board {board}" : "{user} ha creat el nou tauler {board}",
    "You have deleted the board {board}" : "Heu suprimit el tauler {board}",
    "{user} has deleted the board {board}" : "{user} ha suprimit el tauler {board}",
    "You have restored the board {board}" : "Heu restaurat el tauler {board}",
    "{user} has restored the board {board}" : "{user} ha restaurat el tauler {board}",
    "You have shared the board {board} with {acl}" : "Heu compartit el tauler {board} amb {acl}",
    "{user} has shared the board {board} with {acl}" : "{user} ha compartit el tauler {board} amb {acl}",
    "You have removed {acl} from the board {board}" : "Heu suprimit {acl} del tauler {board}",
    "{user} has removed {acl} from the board {board}" : "{user} ha suprimit {acl} del tauler {board}",
    "You have renamed the board {before} to {board}" : "Heu reanomenat el tauler {before} a {board}",
    "{user} has renamed the board {before} to {board}" : "{user} ha reanomenat el tauler {before} a {board}",
    "You have archived the board {board}" : "Heu arxivat el tauler {board}",
    "{user} has archived the board {before}" : "{user} ha arxivat el tauler {before}",
    "You have unarchived the board {board}" : "Heu desarxivat el tauler {board}",
    "{user} has unarchived the board {before}" : "{user} ha desarxivat el tauler {before}",
    "You have created a new list {stack} on board {board}" : "Heu creat una llista nova {stack} al tauler {board}",
    "{user} has created a new list {stack} on board {board}" : "{user} ha creat una nova llista {stack} al tauler {board}",
    "You have renamed list {before} to {stack} on board {board}" : "Heu canviat el nom de la llista {before} a {stack} al tauler {board}",
    "{user} has renamed list {before} to {stack} on board {board}" : "{user} ha canviat el nom de la llista {before} a {stack} al tauler {board}",
    "You have deleted list {stack} on board {board}" : "Heu suprimit la llista {stack} al tauler {board}",
    "{user} has deleted list {stack} on board {board}" : "{user} ha suprimit la llista {stack} al tauler {board}",
    "You have created card {card} in list {stack} on board {board}" : "Heu creat la targeta {card} a la llista {stack} al tauler {board}",
    "{user} has created card {card} in list {stack} on board {board}" : "{user} ha creat la targeta {card} a la llista {stack} al tauler {board}",
    "You have deleted card {card} in list {stack} on board {board}" : "Heu suprimit la targeta {card} a la llista {stack} al tauler {board}",
    "{user} has deleted card {card} in list {stack} on board {board}" : "{user} ha suprimit la targeta {card} a la llista {stack} al tauler {board}",
    "You have renamed the card {before} to {card}" : "Heu reanomenat la targeta {before} a {card}",
    "{user} has renamed the card {before} to {card}" : "{user} ha reanomenat la targeta {before} a {card}",
    "You have added a description to card {card} in list {stack} on board {board}" : "Heu afegit una descripció a la targeta {card} a la llista {stack} al tauler {board}",
    "{user} has added a description to card {card} in list {stack} on board {board}" : "{user} ha afegit una descripció a la targeta {card} a la llista {stack} al tauler {board}",
    "You have updated the description of card {card} in list {stack} on board {board}" : "Heu actualitzat la descripció de la targeta {card} a la llista {stack} al tauler {board}",
    "{user} has updated the description of the card {card} in list {stack} on board {board}" : "{user} ha actualitzat la descripció de la targeta {card} a la llista {stack} al tauler {board}",
    "You have archived card {card} in list {stack} on board {board}" : "Teniu la targeta arxivada {card} a la llista {stack} al tauler {board}",
    "{user} has archived card {card} in list {stack} on board {board}" : "{user} té la targeta arxivada {card} a la llista {stack} al tauler {board}",
    "You have unarchived card {card} in list {stack} on board {board}" : "Teniu una targeta no-arxchivada {card} a la llista {stack} al tauler {board}",
    "{user} has unarchived card {card} in list {stack} on board {board}" : "{user} té una targeta no-arxivada {card} a la llista {stack} al tauler {board}",
    "You have removed the due date of card {card}" : "Heu suprimit la data de venciment de la targeta {targeta}",
    "{user} has removed the due date of card {card}" : "{user} ha suprimit la data de venciment de la targeta {targeta}",
    "You have set the due date of card {card} to {after}" : "Heu establert la data de venciment de la targeta {card} a {after}",
    "{user} has set the due date of card {card} to {after}" : "{user} ha establert la data de venciment de la targeta {card} a {after}",
    "You have updated the due date of card {card} to {after}" : "Heu actualitzat la data de venciment de la targeta {card} a {after}",
    "{user} has updated the due date of card {card} to {after}" : "{user} ha actualitzat la data de venciment de la targeta {card} a {after}",
    "You have added the tag {label} to card {card} in list {stack} on board {board}" : "Heu afegit l'etiqueta {label} a la targeta {card} a la llista {stack} al tauler {board}",
    "{user} has added the tag {label} to card {card} in list {stack} on board {board}" : "{user} ha afegit l'etiqueta {label} a la targeta {card} a la llista {stack} al tauler {board}",
    "You have removed the tag {label} from card {card} in list {stack} on board {board}" : "Heu eliminat l'etiqueta {label} de la targeta {card} a la llista {stack} al tauler {board}",
    "{user} has removed the tag {label} from card {card} in list {stack} on board {board}" : "{user} ha eliminat l'etiqueta {label} de la targeta {card} a la llista {stack} al tauler {board}",
    "You have assigned {assigneduser} to card {card} on board {board}" : "Heu assignat a {assigneduser} a la targeta {card} al tauler {board}",
    "{user} has assigned {assigneduser} to card {card} on board {board}" : "{user} ha assignat a {assigneduser} la targeta {card} del tauler {board}",
    "You have unassigned {assigneduser} from card {card} on board {board}" : "Heu desassignat {assigneduser} de la targeta {card} al tauler {board}",
    "{user} has unassigned {assigneduser} from card {card} on board {board}" : "{user} ha desassignat {assigneduser} de la targeta {card} al tauler {board}",
    "You have moved the card {card} from list {stackBefore} to {stack}" : "Heu mogut la targeta {card} de la llista {stackBefore} a {stack}",
    "{user} has moved the card {card} from list {stackBefore} to {stack}" : "{user} ha mogut la targeta {card} de la llista {stackBefore} a {stack}",
    "You have added the attachment {attachment} to card {card}" : "Heu afegit l'adjunt {attachment} a la targeta {card}",
    "{user} has added the attachment {attachment} to card {card}" : "{user} ha afegit l'adjunt {attachment} a la targeta {card}",
    "You have updated the attachment {attachment} on card {card}" : "Heu actualitzat l'adjunt {attachment} a la targeta {card}",
    "{user} has updated the attachment {attachment} on card {card}" : "{user} ha actualitzat l’adjunt {attachment} a la targeta {card}",
    "You have deleted the attachment {attachment} from card {card}" : "Heu suprimit l'adjunt {attachment} de la targeta {card}",
    "{user} has deleted the attachment {attachment} from card {card}" : "{user} ha suprimit l'adjunt {attachment} de la targeta {card}",
    "You have restored the attachment {attachment} to card {card}" : "Heu restaurat l'adjunt {attachment} a la targeta {card}",
    "{user} has restored the attachment {attachment} to card {card}" : "{user} ha restaurat l'adjunt {attachment} a la targeta {card}",
    "You have commented on card {card}" : "Heu comentat la targeta {card}",
    "{user} has commented on card {card}" : "{user} ha comentat la targeta {card}",
    "A <strong>card description</strong> inside the Deck app has been changed" : "S'ha canviat una <strong>descripció de targeta</strong> a l'aplicació Tauler",
    "Deck" : "Targetes",
    "Changes in the <strong>Deck app</strong>" : "Canvis a l'<strong>aplicació Targetes</strong>",
    "A <strong>comment</strong> was created on a card" : "S'ha afegit un <strong>comentari</strong> a una targeta",
    "Upcoming cards" : "Pròximes targetes",
    "Load more" : "Carrega'n més",
    "Personal" : "Personal",
    "The card \"%s\" on \"%s\" has been assigned to you by %s." : "La targeta \"%s\" sobre \"%s\" se us ha assignat per %s.",
    "{user} has assigned the card {deck-card} on {deck-board} to you." : "{user} us ha assignat la targeta {deck-card} a {deck-board}.",
    "The card \"%s\" on \"%s\" has reached its due date." : "La targeta \"%s\" sobre \"%s\" ha assolit la seva data de venciment.",
    "The card {deck-card} on {deck-board} has reached its due date." : "La targeta {deck-card} a {deck-board} ha assolit la seva data de caducitat.",
    "%s has mentioned you in a comment on \"%s\"." : "%s us ha anomenat en un comentari sobre \"%s\".",
    "{user} has mentioned you in a comment on {deck-card}." : "{user} us ha mencionat en un comentari a {deck-card}.",
    "The board \"%s\" has been shared with you by %s." : "El tauler \"%s\" se us ha compartit per %s.",
    "{user} has shared {deck-board} with you." : "{user} us ha compartit {board}.",
    "Card comments" : "Comentaris de la targeta",
    "%s on %s" : "%s a %s",
    "No data was provided to create an attachment." : "No s’ha proporcionat cap dada per crear un fitxer adjunt.",
    "Finished" : "Acabat",
    "To review" : "Per revisar",
    "Action needed" : "Acció necessària",
    "Later" : "Més tard",
    "copy" : "còpia",
    "To do" : "Pendent",
    "Doing" : "En procés",
    "Done" : "Finalitzat",
    "Example Task 3" : "Tasca d'exemple 3",
    "Example Task 2" : "Tasca d'exemple 2",
    "Example Task 1" : "Tasca d'exemple 1",
    "The file was uploaded" : "S'ha pujat el fitxer",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "El fitxer carregat excedeix la directiva upload_max_filesize dins de php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "El fitxer carregat excedeix la directiva MAX_FILE_SIZE que hi ha especificada al formulari d'HTML",
    "The file was only partially uploaded" : "El fitxer s'ha carregat només parcialment",
    "No file was uploaded" : "No s'ha pujat cap fitxer",
    "Missing a temporary folder" : "Falta una carpeta temporal",
    "Could not write file to disk" : "No s’ha pogut escriure el fitxer al disc",
    "A PHP extension stopped the file upload" : "Una extensió del PHP ha aturat la carregada del fitxer",
    "No file uploaded or file size exceeds maximum of %s" : "No s'ha carregat cap fitxer o la mida del fitxer sobrepassa el màxim de %s",
    "This comment has more than %s characters.\nAdded as an attachment to the card with name %s.\nAccessible on URL: %s." : "Aquest comentari té més de %s caràcters.\nS'ha afegit com a fitxer adjunt a la targeta amb el nom %s.\nAccessible a l'URL: %s.",
    "Card not found" : "No s'ha trobat la targeta",
    "Path is already shared with this card" : "Aquesta ruta ja ha estat compartida amb aquesta targeta",
    "Invalid date, date format must be YYYY-MM-DD" : "La data no és vàlida, el format de la data ha de ser YYYY-MM-DD",
    "Personal planning and team project organization" : "Planificació personal i organització de projectes en equip",
    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in Markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your Markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Tauler és una eina d'organització a l'estil kanban dirigida a la planificació personal i a l'organització de projectes per equips integrada a Nextcloud.\n\n\n- 📥 Afegiu les tasques en targetes i poseu-les en ordre\n- 📄 Apunteu notes addicionals en format Markdown\n- 🔖 Assigneu etiquetes per una millor organització\n- 👥 Compartiu amb el vostre equip, família o amics\n- 📎 Adjunteu fitxers i encasteu-los en la descripció en markdown\n- 💬 Converses amb el vostre equip fent servir comentaris\n- ⚡ Mantingueu el seguiment de canvis al flux d'activitat\n- 🚀 Tingueu el vostre projecte organitzat",
    "Card details" : "Detalls de la targeta",
    "Add board" : "Afegeix un tauler",
    "Select the board to link to a project" : "Selecciona el tauler per enllaçar a un projecte",
    "Search by board title" : "Cerca per títol del tauler",
    "Select board" : "Selecciona un tauler",
    "Create a new card" : "Crea una nova targeta",
    "Select a board" : "Selecciona un tauler",
    "Select a list" : "Seleccioneu una llista",
    "Card title" : "Títol de la targeta",
    "Cancel" : "Cancel·la",
    "Creating the new card …" : "Creant la nova targeta …",
    "Card \"{card}\" was added to \"{board}\"" : "La targeta \"{card}\" s'ha afegit a \"{board}\"",
    "Open card" : "Obre la targeta",
    "Close" : "Tanca",
    "Create card" : "Crea una targeta",
    "Select a card" : "Selecciona una targeta",
    "Select the card to link to a project" : "Selecciona la targeta per enllaçar a un projecte",
    "Link to card" : "Enllaç a la targeta",
    "File already exists" : "El fitxer ja existeix",
    "A file with the name {filename} already exists." : "Ja existeix un fitxer amb el nom {filename}.",
    "Do you want to overwrite it?" : "Voleu sobre-escriure'l?",
    "Overwrite file" : "Sobreescriu el fitxer",
    "Keep existing file" : "Mantén el fitxer existent",
    "This board is read only" : "Aquest tauler és només de lectura",
    "Drop your files to upload" : "Deixeu anar els fitxers per penjar-los",
    "Add card" : "Afegeix una targeta",
    "Archived cards" : "Targetes arxivades",
    "Add list" : "Afegeix una llista",
    "List name" : "Nom de la llista",
    "Active filters" : "Filtres actius",
    "Apply filter" : "Aplica el filtre",
    "Filter by tag" : "Filtra per etiqueta",
    "Filter by assigned user" : "Filtra per usuari assignat",
    "Unassigned" : "Sense assignar",
    "Filter by due date" : "Filtra per data de venciment",
    "Overdue" : "Endarrerit",
    "Next 24 hours" : "Pròximes 24 hores",
    "Next 7 days" : "Pròxims 7 dies",
    "Next 30 days" : "Pròxims 30 dies",
    "No due date" : "Sense venciment",
    "Clear filter" : "Esborra el filtre",
    "Hide archived cards" : "Amaga les targetes arxivades",
    "Show archived cards" : "Mostra les targetes arxivades",
    "Toggle compact mode" : "Commuta el mode compacte",
    "Open details" : "Obre els detalls",
    "Details" : "Detalls",
    "Loading board" : "S'està carregant el tauler",
    "No lists available" : "No hi ha cap llista disponible",
    "Create a new list to add cards to this board" : "Crea una llista nova per afegir targetes a aquest tauler",
    "Board not found" : "Tauler no trobat",
    "Sharing" : "Compartició",
    "Tags" : "Etiquetes",
    "Deleted items" : "Elements suprimits",
    "Timeline" : "Línia de temps",
    "Deleted lists" : "Llistes suprimides",
    "Undo" : "Desfés",
    "Deleted cards" : "Targetes suprimides",
    "Share board with a user, group or circle …" : "Compartir tauler amb un usuari, grup o cercle …",
    "Searching for users, groups and circles …" : "Buscant usuaris, grups i cercles …",
    "No participants found" : "No s'han trobat participants",
    "Board owner" : "Propietari del tauler",
    "(Group)" : "(Grup)",
    "(Circle)" : "(Cercle)",
    "Can edit" : "Pot editar",
    "Can share" : "Pot compartir",
    "Can manage" : "Pot gestionar",
    "Owner" : "Propietari",
    "Delete" : "Eliminar",
    "Failed to create share with {displayName}" : "Ha fallat la creació de la compartició amb {displayName}",
    "Are you sure you want to transfer the board {title} to {user}?" : "Esteu segur que voleu transferir el tauler {title} a {user}?",
    "Transfer the board." : "Transfereix el tauler.",
    "Transfer" : "Transferència",
    "The board has been transferred to {user}" : "El tauler s'ha transferit a {user}",
    "Failed to transfer the board to {user}" : "No s'ha pogut transferir el tauler a {user}",
    "Add a new list" : "Afegir una llista nova",
    "Archive all cards" : "Arxiva totes les targetes",
    "Delete list" : "Suprimeix la llista",
    "Archive all cards in this list" : "Arxiva totes les targetes d'aquesta llista",
    "Add a new card" : "Afegir una nova targeta",
    "Card name" : "Nom de la targeta",
    "List deleted" : "Llista suprimida",
    "Edit" : "Edita",
    "Add a new tag" : "Afegir una etiqueta nova",
    "title and color value must be provided" : "s’ha de proporcionar el valor del títol i del color",
    "Board name" : "Nom del taulell",
    "Members" : "Membres",
    "Upload new files" : "Puja nous fitxers",
    "Share from Files" : "Comparteix des de Fitxers",
    "Pending share" : "Compartició pendent",
    "Add this attachment" : "Afegeix aquest adjunt",
    "Show in Files" : "Mostra a Fitxers",
    "Download" : "Baixa",
    "Remove attachment" : "Treu l'adjunt",
    "Delete Attachment" : "Suprimeix l’adjunt",
    "Restore Attachment" : "Restaura l'adjunt",
    "File to share" : "Fitxer a compartir",
    "Invalid path selected" : "S'ha seleccionat una ruta invàlida",
    "Open in sidebar view" : "Obre a la vista de la barra lateral",
    "Open in bigger view" : "Obre a la vista més gran",
    "Attachments" : "Adjunts",
    "Comments" : "Comentaris",
    "Modified" : "Darrera modificació",
    "Created" : "Creat",
    "The title cannot be empty." : "El títol no pot estar buit.",
    "No comments yet. Begin the discussion!" : "No hi ha comentaris encara. Començar la discussió!",
    "Failed to load comments" : "No s'han pogut carregar els comentaris",
    "Assign a tag to this card…" : "Assigna una etiqueta a aquesta targeta…",
    "Assign to users" : "Assigna als usuaris",
    "Assign to users/groups/circles" : "Assigna a usuaris/grups/cercles",
    "Assign a user to this card…" : "Assigneu un usuari a aquesta targeta…",
    "Due date" : "Per la data",
    "Set a due date" : "Definir una data de venciment",
    "Remove due date" : "Elimina la data de venciment",
    "Select Date" : "Selecciona la data",
    "Today" : "Avui",
    "Tomorrow" : "Demà",
    "Next week" : "Setmana següent",
    "Next month" : "Mes següent",
    "Save" : "Desa",
    "The comment cannot be empty." : "El comentari no pot estar buit.",
    "The comment cannot be longer than 1000 characters." : "El comentari no pot ser més llarg que 1000 caràcters.",
    "In reply to" : "En resposta a",
    "Cancel reply" : "Cancel·la la resposta",
    "Reply" : "Respon",
    "Update" : "Actualitza",
    "Description" : "Descripció",
    "(Unsaved)" : "(No desat)",
    "(Saving…)" : "(Desant…)",
    "Formatting help" : "Format d'ajuda",
    "Edit description" : "Edita descripció",
    "View description" : "Veure descripció",
    "Add Attachment" : "Afegeix un adjunt",
    "Write a description …" : "Escriviu una descripció …",
    "Choose attachment" : "Triar adjunt",
    "(group)" : "(grup)",
    "Todo items" : "Elements pendents",
    "{count} comments, {unread} unread" : "{count} comentaris, {unread} no llegits",
    "Edit card title" : "Edita el títol de la targeta",
    "Assign to me" : "Assigna'm a mi",
    "Unassign myself" : "Desasignar a mi mateix",
    "Move card" : "Mou la targeta",
    "Unarchive card" : "Desarxiva targeta",
    "Archive card" : "Arxiva la targeta",
    "Delete card" : "Suprimeix targeta",
    "Move card to another board" : "Mou la targeta a un altre tauler",
    "List is empty" : "La llista és buida",
    "Card deleted" : "Targeta suprimida",
    "seconds ago" : "fa uns segons",
    "All boards" : "Tots els taulers",
    "Archived boards" : "Taulers arxivats",
    "Shared with you" : "Us han compartit",
    "Deck settings" : "Configuració del Tauler",
    "Use bigger card view" : "Utilitza la visualització de targetes més gran",
    "Show boards in calendar/tasks" : "Mostra els taulers al calendari/tasques",
    "Limit deck usage of groups" : "Limitar l'ús del tauler de grups",
    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Limitant el Tauler bloquejarà la creació de taulers als usuaris que no són part d'aquests grups. Els usuaris podran seguir treballant en els taulers que hagin estat compartits amb ells.",
    "Board details" : "Detalls del tauler",
    "Edit board" : "Edita el tauler",
    "Clone board" : "Clonar tauler",
    "Unarchive board" : "Desarxiva el tauler",
    "Archive board" : "Arxiva el tauler",
    "Turn on due date reminders" : "Activa els recordatoris de data de venciment",
    "Turn off due date reminders" : "Desactiva els recordatoris de data de venciment",
    "Due date reminders" : "Recordatoris de data de venciment",
    "All cards" : "Totes les targetes",
    "Assigned cards" : "Targetes assignades",
    "No notifications" : "No hi ha notificacions",
    "Delete board" : "Suprimeix el tauler",
    "Board {0} deleted" : "S’ha suprimit el tauler {0}",
    "Only assigned cards" : "Només les targetes assignades",
    "No reminder" : "Sense recordatoris",
    "An error occurred" : "S'ha produït un error",
    "Are you sure you want to delete the board {title}? This will delete all the data of this board including archived cards." : "Esteu segur que voleu suprimir el tauler {title}? Això suprimirà totes les dades d'aquest tauler, incloses les targetes arxivades.",
    "Delete the board?" : "Voleu suprimir el tauler?",
    "Loading filtered view" : "S'està carregant la visualització filtrada",
    "No due" : "Sense venciment",
    "Search for {searchQuery} in all boards" : "Busca {searchQuery} a tots els taulers",
    "No results found" : "No s'han trobat resultats",
    "{stack} in {board}" : "{stack} a {board}",
    "Click to expand description" : "Feu clic per ampliar la descripció",
    "* Created on {created}\n* Last modified on {lastMod}\n* {nbAttachments} attachments\n* {nbComments} comments" : "* Creat el {created}\n* Última modificació el dia {lastMod}\n* {nbAttachments} fitxers adjunts\n* {nbComments} comentaris",
    "{nbCards} cards" : "{nbCards} targetes",
    "No upcoming cards" : "No hi ha pròximes targetes",
    "upcoming cards" : "pròximes targetes",
    "Due on {date}" : "Venciment el dia {date}",
    "Link to a board" : "Enllaça a un tauler",
    "Link to a card" : "Enllaç una targeta",
    "Create a card" : "Crea una targeta",
    "Message from {author} in {conversationName}" : "Missatge de {author} a {conversationName}",
    "Something went wrong" : "Alguna cosa ha anat malament",
    "Failed to upload {name}" : "No s'ha pogut pujar {name}",
    "Maximum file size of {size} exceeded" : "S'ha superat la mida màxima per fitxer de {size}",
    "Error creating the share" : "S'ha produït un error en crear la compartició",
    "Share with a Deck card" : "Compartir amb una targeta de Deck",
    "Share {file} with a Deck card" : "Compartir {file} amb una targeta de Deck",
    "Share" : "Compartir",
    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Tauler és una eina d'organització a l'estil kanban dirigida a la planificació personal i a l'organització de projectes per equips integrada a Nextcloud.\n\n\n- 📥 Afegiu les tasques en targetes i poseu-les en ordre\n- 📄 Apunteu notes addicionals en markdown\n- 🔖 Assigneu etiquetes per una organització encara millor\n- 👥 Compartiu amb el vostre equip, família o amics\n- 📎 Adjunteu fitxers i encasteu-los en la descripció en markdown\n- 💬 Debateu amb el vostre equip fent servir comentaris\n- ⚡ Mantingueu el seguiment de canvis al flux d'activitat\n- 🚀 Tingueu el vostre projecte organitzat",
    "Are you sure you want to transfer the board {title} for {user} ?" : "Esteu segur que voleu transferir el tauler {title} per a {user}?",
    "Transfer the board for {user} successfully" : "Transfereix el tauler per a {user} correctament",
    "Failed to transfer the board for {user}" : "No s'ha pogut transferir el tauler per a {user}",
    "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "Esteu segur que voleu suprimir el tauler {title}? Això eliminarà totes les dades d'aquest tauler.",
    "This week" : "Aquesta setmana",
    "Are you sure you want to transfer the board {title} for {user}?" : "Esteu segur que voleu transferir el tauler {title} per a {user}?"
},
"nplurals=2; plural=(n != 1);");
