OC.L10N.register(
    "deck",
    {
    "You have created a new board {board}" : "Has creado el tablero nuevo {board}",
    "{user} has created a new board {board}" : "{user} ha creado el tablero nuevo {board}",
    "You have deleted the board {board}" : "Has eliminado el tablero {board}",
    "{user} has deleted the board {board}" : "{user} ha eliminado el tablero {board}",
    "You have restored the board {board}" : "Has restaurado el tablero {board}",
    "{user} has restored the board {board}" : "{user} ha restaurado el tablero {board}",
    "You have shared the board {board} with {acl}" : "Has compartido el tablero {board} con {acl}",
    "{user} has shared the board {board} with {acl}" : "{user} ha compartido el tablero {board} con {acl}",
    "You have removed {acl} from the board {board}" : "Has eliminado a {acl} del tablero {board}",
    "{user} has removed {acl} from the board {board}" : "{user} ha elimiando a {acl} del tablero {board}",
    "You have renamed the board {before} to {board}" : "Has renombrado el tablero {before} como {board}",
    "{user} has renamed the board {before} to {board}" : "{user} ha renombrado el tablero {before} como {board}",
    "You have archived the board {board}" : "Has archivado el tablero {board}",
    "{user} has archived the board {before}" : "{user} ha archivado el tablero {board}",
    "You have unarchived the board {board}" : "Has desarchivado el tablero {board}",
    "{user} has unarchived the board {before}" : "{user} ha desarchivado el tablero {before}",
    "You have created a new list {stack} on board {board}" : "Has creado una nueva lista {stack} del tablero {board}",
    "{user} has created a new list {stack} on board {board}" : "{user} ha creado una nueva lista {stack} del tablero {board}",
    "You have renamed list {before} to {stack} on board {board}" : "Has renombrado la lista {before} a {stack} del tablero {board}",
    "{user} has renamed list {before} to {stack} on board {board}" : "{user} ha renombrado la lista {before} a {stack} del tablero {board}",
    "You have deleted list {stack} on board {board}" : "Has eliminado la lista {stack} del tablero {board}",
    "{user} has deleted list {stack} on board {board}" : "{user} ha eliminado la lista {stack} del tablero {board}",
    "You have created card {card} in list {stack} on board {board}" : "Has creado la tarjeta {card} en la lista {stack} del tablero {board}",
    "{user} has created card {card} in list {stack} on board {board}" : "{user} ha creado la tarjeta {card} en la lista {stack} del tablero {board}",
    "You have deleted card {card} in list {stack} on board {board}" : "Has eliminado la tarjeta {card}  en la lista {stack} del tablero {board}",
    "{user} has deleted card {card} in list {stack} on board {board}" : "{user} ha borrado la tarjeta {card} en la lista {stack} del tablero {board}",
    "You have renamed the card {before} to {card}" : "Has renombrado la tarjeta {before} como {card}",
    "{user} has renamed the card {before} to {card}" : "{user} ha renombrado la tarjeta {before} como {card}",
    "You have added a description to card {card} in list {stack} on board {board}" : "Has añadido una descripción a la tarjeta {card} en la lista {stack} del tablero {board}",
    "{user} has added a description to card {card} in list {stack} on board {board}" : "{user} ha añadido una descripción a la tarjeta {card} en la lista {stack} del tablero {board}",
    "You have updated the description of card {card} in list {stack} on board {board}" : "Has actualizado la descripción de {card} en la lista {stack} del tablero {board}",
    "{user} has updated the description of the card {card} in list {stack} on board {board}" : "{user} ha actualizado la descripción de la tarjeta {card} en la lista {stack} del tablero {board}",
    "You have archived card {card} in list {stack} on board {board}" : "Has archivado la tarjeta {card} en la lista {stack} del tablero {board}",
    "{user} has archived card {card} in list {stack} on board {board}" : "{user} ha archivado la tarjeta {card} en la lista {stack} del tablero {board}",
    "You have unarchived card {card} in list {stack} on board {board}" : "Has desarchivado la tarjeta {card} en la lista {stack} del tablero {board}",
    "{user} has unarchived card {card} in list {stack} on board {board}" : "{user} ha desarchivado la tarjeta {card} en la lista {stack} del tablero {board}",
    "You have removed the due date of card {card}" : "Has eliminado la fecha de vencimiento de {card}",
    "{user} has removed the due date of card {card}" : "{user} ha eliminado la fecha de vencimiento de {card}",
    "You have set the due date of card {card} to {after}" : "Has establecido la fecha de vencimiento de {card} como {after}",
    "{user} has set the due date of card {card} to {after}" : "{user} ha establecido la fecha de vencimiento de {card} como {after}",
    "You have updated the due date of card {card} to {after}" : "Has actualizado la fecha de vencimiento de {card} para {after}",
    "{user} has updated the due date of card {card} to {after}" : "{user} ha actualizado la fecha de vencimiento de {card} para {after}",
    "You have added the tag {label} to card {card} in list {stack} on board {board}" : "Has añadido la etiqueta {label} a la tarjeta {card} en la lista {stack} del tablero {board}",
    "{user} has added the tag {label} to card {card} in list {stack} on board {board}" : "{user} ha añadido la etiqueta {label} a la tarjeta {card} en la lista {stack} del tablero {board}",
    "You have removed the tag {label} from card {card} in list {stack} on board {board}" : "Has eliminado la etiqueta {label} de la tarjeta {card} en la lista {stack} del tablero {board}",
    "{user} has removed the tag {label} from card {card} in list {stack} on board {board}" : "{user} ha elimininado la etiqueta {label} de la tarjeta{card} en la lista {stack} del tablero {board}",
    "You have assigned {assigneduser} to card {card} on board {board}" : "Has asignado a {assigneduser} para {card} en {board}",
    "{user} has assigned {assigneduser} to card {card} on board {board}" : "{user} ha asignado a {assigneduser} para {card} en {board}",
    "You have unassigned {assigneduser} from card {card} on board {board}" : "Has desasignado a {assigneduser} para {card} en {board}",
    "{user} has unassigned {assigneduser} from card {card} on board {board}" : "{user} ha asignado a {assigneduser} para {card} en {board}",
    "You have moved the card {card} from list {stackBefore} to {stack}" : "Has movido la tarjeta {card} de la lista {stackBefore} al tablero {stack}",
    "{user} has moved the card {card} from list {stackBefore} to {stack}" : "{user} ha movido la tarjeta {card} de la lista {stackBefore} al tablero {stack}",
    "You have added the attachment {attachment} to card {card}" : "Has añadido el adjunto {attachment} en {card}",
    "{user} has added the attachment {attachment} to card {card}" : "{user} ha añadido el adjunto {attachment} en {card}",
    "You have updated the attachment {attachment} on card {card}" : "Has actualizado el adjunto [attachment] en {card}",
    "{user} has updated the attachment {attachment} on card {card}" : "{user} ha actualizado el adjunto {attachment} en la tarjeta {card}",
    "You have deleted the attachment {attachment} from card {card}" : "Has eliminado el adjunto {attachment} de {card}",
    "{user} has deleted the attachment {attachment} from card {card}" : "{user} ha eliminado el adjunto {attachment} de la tarjeta {card}",
    "You have restored the attachment {attachment} to card {card}" : "Has restaurado el adjunto {attachment} a {card}",
    "{user} has restored the attachment {attachment} to card {card}" : "{user} ha restaurado el adjunto {attachment} a {card}",
    "You have commented on card {card}" : "Has comentado en la tarjeta {card}",
    "{user} has commented on card {card}" : "{user} ha comentado en {card}",
    "A <strong>card description</strong> inside the Deck app has been changed" : "Una <strong>descripción de tarjeta</strong> dentro de la app Deck ha cambiado",
    "Deck" : "Deck",
    "Changes in the <strong>Deck app</strong>" : "Cambios en la <strong>app Deck</strong>",
    "A <strong>comment</strong> was created on a card" : "Un <strong>comment</strong> ha sido creado en una tarjeta",
    "Upcoming cards" : "Próximas tarjetas",
    "Load more" : "Cargar más",
    "Personal" : "Personal",
    "The card \"%s\" on \"%s\" has been assigned to you by %s." : "La tarjeta \"%s\" en \"%s\" te ha sido asignada por %s.",
    "{user} has assigned the card {deck-card} on {deck-board} to you." : "{user} te ha asigando la tarjeta {deck-card} de {deck-board} a ti.",
    "The card \"%s\" on \"%s\" has reached its due date." : "La tarjeta \"%s\" en \"%s\" ha alcanzado su fecha límite.",
    "The card {deck-card} on {deck-board} has reached its due date." : "La tarjeta {deck-card} en {deck-board} ha alcanzado su fecha de caducidad.",
    "%s has mentioned you in a comment on \"%s\"." : "%s te ha mencionado en un comentario en \"%s\".",
    "{user} has mentioned you in a comment on {deck-card}." : "{user} te ha mencionado en un comentario de {deck-card}.",
    "The board \"%s\" has been shared with you by %s." : "El tablero \"%s\" ha sido compartido contigo por %s.",
    "{user} has shared {deck-board} with you." : "{user} ha compartido {deck-board} contigo.",
    "Card comments" : "Comentarios en tarjetas",
    "%s on %s" : "%s en %s",
    "No data was provided to create an attachment." : "No se proporcionaron datos para crear un adjunto",
    "Finished" : "Finalizado",
    "To review" : "Para revisar",
    "Action needed" : "Acción necesaria",
    "Later" : "Después",
    "copy" : "copiar",
    "To do" : "Por hacer",
    "Doing" : "Haciendo",
    "Done" : "Hecho",
    "Example Task 3" : "Tarea de ejemplo 3",
    "Example Task 2" : "Tarea de ejemplo 2",
    "Example Task 1" : "Tarea de ejemplo 1",
    "The file was uploaded" : "Se ha subido el archivo",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "El archivo subido excede la directiva upload_max_filesize en php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "El archivo subido excede la directiva MAX_FILE-SIZE directive que se especificó en el formulario web",
    "The file was only partially uploaded" : "El archivo se ha subido solo parcialmente",
    "No file was uploaded" : "No se ha subido ningún archivo",
    "Missing a temporary folder" : "Falta una carpeta temporal",
    "Could not write file to disk" : "No se ha podido escribir el archivo al disco",
    "A PHP extension stopped the file upload" : "Una extensión de PHP ha detenido la subida del archivo",
    "No file uploaded or file size exceeds maximum of %s" : "No se ha subido ningún archivo, o el tamaño del archivo excede el máximo de %s",
    "This comment has more than %s characters.\nAdded as an attachment to the card with name %s.\nAccessible on URL: %s." : "Este comentario tiene más de %s caracteres.\nAñadido como adjunto a la tarjeta con el nombre %s.\nAccesible en la URL: %s.",
    "Card not found" : "Tarjeta no encontrada",
    "Path is already shared with this card" : "La ruta ya se ha compartido con esta tarjeta",
    "Invalid date, date format must be YYYY-MM-DD" : "Fecha no válida, el formato de las fechas debe ser AAAA-MM-DD",
    "Personal planning and team project organization" : "Planificación personal y organización de proyecto de equipo",
    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in Markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your Markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Deck es una herramienta de organización de estilo kanban dirigida a la planificación personal y la organización de proyectos para equipos integrados con Nextcloud.\n\n\n- 📥 Agrega tus tareas a las tarjetas y ordénalas.\n- 📄 Escriba notas adicionales\n- 🔖 Asignar etiquetas para una organización mejor\n- 👥 Comparte con tu equipo, amigos o familia.\n- 📎 Adjuntar archivos e incrustarlos en su descripción\n- 💬 Discuta con su equipo usando comentarios.\n- ⚡ Mantenga un registro de los cambios en el flujo de actividad\n- 🚀 Organiza tu proyecto",
    "Card details" : "Detalles de la tarjeta",
    "Add board" : "Añadir tablero",
    "Select the board to link to a project" : "Selecciona el tablero que enlazar a un proyecto",
    "Search by board title" : "Buscar por título de tablero",
    "Select board" : "Selecciona tablero",
    "Create a new card" : "Crear una nueva tarjeta",
    "Select a board" : "Selecciona un tablero",
    "Select a list" : "Seleccionar una lista",
    "Card title" : "Título de la tarjeta",
    "Cancel" : "Cancelar",
    "Creating the new card …" : "Creando una nueva tarjeta …",
    "Card \"{card}\" was added to \"{board}\"" : "La tarjeta \"{card}\" fue añadida a \"{board}\"",
    "Open card" : "Abrir tarjeta",
    "Close" : "Cerrar",
    "Create card" : "Crear tarjeta",
    "Select a card" : "Seleccionar una tarjeta",
    "Select the card to link to a project" : "Selecciona la tarjeta que enlazar a un proyecto",
    "Link to card" : "Enlace a tarjeta",
    "File already exists" : "El archivo ya existe",
    "A file with the name {filename} already exists." : "Ya existe un archivo con el nombre {filename}.",
    "Do you want to overwrite it?" : "¿Desea sobreescribirlo?",
    "Overwrite file" : "Sobreescribir archivo",
    "Keep existing file" : "Mantener el archivo existente",
    "This board is read only" : "Este tablero es de sólo lectura",
    "Drop your files to upload" : "Arrastra tus archivos para subir",
    "Add card" : "Añadir tarjeta",
    "Archived cards" : "Tarjetas archivadas",
    "Add list" : "Agregar lista",
    "List name" : "Nombre de la lista",
    "Active filters" : "Filtros activos",
    "Apply filter" : "Aplicar filtro",
    "Filter by tag" : "Filtrar por etiqueta",
    "Filter by assigned user" : "Filtrar por usuario asignado",
    "Unassigned" : "No asignado",
    "Filter by due date" : "Filtrar por fecha de finalización",
    "Overdue" : "Demorado",
    "Next 24 hours" : "Próximas 24 horas",
    "Next 7 days" : "Siguientes 7 días",
    "Next 30 days" : "Siguientes 30 días",
    "No due date" : "Sin fecha de vencimiento",
    "Clear filter" : "Borrar filtro",
    "Hide archived cards" : "Ocultar tarjetas archivadas",
    "Show archived cards" : "Mostrar tarjetas archivadas",
    "Toggle compact mode" : "Mostrar/ocultar modo compacto",
    "Open details" : "Abrir detalles",
    "Details" : "Detalles",
    "Loading board" : "Cargando tablero",
    "No lists available" : "No hay listas disponibles",
    "Create a new list to add cards to this board" : "Crea una lista nueva para añadir tarjetas a este tablero",
    "Board not found" : "Tablero no encontrado",
    "Sharing" : "Compartir",
    "Tags" : "Etiquetas",
    "Deleted items" : "Elementos eliminados",
    "Timeline" : "Línea de tiempo",
    "Deleted lists" : "Listas eliminadas",
    "Undo" : "Deshacer",
    "Deleted cards" : "Cartas eliminadas",
    "Share board with a user, group or circle …" : "Compartir tablero con un usuario, grupo o círculo ...",
    "Searching for users, groups and circles …" : "Buscando usuarios, grupos o círculos...",
    "No participants found" : "No se encontraron participantes",
    "Board owner" : "Propietario del tablero",
    "(Group)" : "(Grupo)",
    "(Circle)" : "(Circle)",
    "Can edit" : "Puede editar",
    "Can share" : "Puede compartir",
    "Can manage" : "Puede gestionar",
    "Owner" : "Propietario",
    "Delete" : "Eliminar",
    "Failed to create share with {displayName}" : "Fallo al crear el recurso compartido denominado {displayName}",
    "Are you sure you want to transfer the board {title} to {user}?" : "¿Estás seguro de que quieres transferir el tablero {título} a {usuario}?",
    "Transfer the board." : "Transfiere el tablero.",
    "Transfer" : "Transferir",
    "The board has been transferred to {user}" : "El tablero ha sido transferido a {usuario}",
    "Failed to transfer the board to {user}" : "Failed to transfer the board to {user}",
    "Add a new list" : "Añadir una lista nueva",
    "Archive all cards" : "Archivar todas las tarjetas",
    "Unarchive all cards" : "Desarchivar todas las tarjetas",
    "Delete list" : "Eliminar lista",
    "Archive all cards in this list" : "Archivar todas las tarjetas en esta lista",
    "Unarchive all cards in this list" : "Desarchivar todas las tarjetas en esta lista",
    "Add a new card" : "Añadir una nueva tarjeta",
    "Card name" : "Nombre de la tarjeta",
    "List deleted" : "Lista borrada",
    "Edit" : "Editar",
    "Add a new tag" : "Añade una nueva etiqueta",
    "title and color value must be provided" : "Se debe indicar un valor para título y color ",
    "Board name" : "Nombre del tablero",
    "Members" : "Miembros",
    "Upload new files" : "Subir nuevos archivos",
    "Share from Files" : "Compartir desde Archivos",
    "Pending share" : "Pendiente de compartir",
    "Add this attachment" : "Añadir este adjunto",
    "Show in Files" : "Mostrar en Archivos",
    "Download" : "Descargar",
    "Remove attachment" : "Quitar adjunto",
    "Delete Attachment" : "Borrar adjunto",
    "Restore Attachment" : "Restaurar Adjunto",
    "File to share" : "Archivo a compartir",
    "Invalid path selected" : "Ruta seleccionada no válida",
    "Open in sidebar view" : "Abrir en vista de barra lateral",
    "Open in bigger view" : "Abrir en vista más grande",
    "Attachments" : "Adjuntos",
    "Comments" : "Comentarios",
    "Modified" : "Modificado",
    "Created" : "Creado",
    "The title cannot be empty." : "El título no puede estar vacío.",
    "No comments yet. Begin the discussion!" : "Todavía no hay comentarios. ¡Comienza la discusión!",
    "Failed to load comments" : "Fallo al cargar los comentarios",
    "Assign a tag to this card…" : "Asignar una etiqueta a esta tarjeta...",
    "Assign to users" : "Asignar a usuarios",
    "Assign to users/groups/circles" : "Asignar a usuarios/grupos/círculos",
    "Assign a user to this card…" : "Asignar un usuario a esta tarjeta...",
    "Due date" : "Fecha límite",
    "Set a due date" : "Fijar una fecha límite",
    "Remove due date" : "Eliminar fecha límite",
    "Select Date" : "Seleccione la fecha",
    "Today" : "Hoy",
    "Tomorrow" : "Mañana",
    "Next week" : "Semana siguiente",
    "Next month" : "Mes siguiente",
    "Save" : "Guardar",
    "The comment cannot be empty." : "El comentario no puede estar vacío.",
    "The comment cannot be longer than 1000 characters." : "El comentario no puede tener más de 1000  caracteres.",
    "In reply to" : "En respuesta a",
    "Cancel reply" : "Cancelar respuesta",
    "Reply" : "Responder",
    "Update" : "Actualizar",
    "Description" : "Descripción",
    "(Unsaved)" : "(Sin salvar)",
    "(Saving…)" : "(Guardando...)",
    "Formatting help" : "Ayuda de formato",
    "Edit description" : "Editar descripción",
    "View description" : "Ver descripción",
    "Add Attachment" : "Añadir adjunto",
    "Write a description …" : "Escribe una descripción...",
    "Choose attachment" : "Escoger adjunto",
    "(group)" : "(grupo)",
    "Todo items" : "Ítems pendientes",
    "{count} comments, {unread} unread" : "{count} comentarios, {unread} sin leer",
    "Edit card title" : "Editar el título de la tarjeta",
    "Assign to me" : "Asignarme a mí",
    "Unassign myself" : "Desasignarme a mí mismo",
    "Move card" : "Mover tarjeta",
    "Unarchive card" : "Desarchivar tarjeta",
    "Archive card" : "Archivar tarjeta",
    "Delete card" : "Eliminar tarjeta",
    "Move card to another board" : "Mover la tarjeta a otro tablero",
    "List is empty" : "La lista está vacía",
    "Card deleted" : "Tarjeta borrada",
    "seconds ago" : "hace unos segundos",
    "All boards" : "Todos los tableros",
    "Archived boards" : "Tableros archivados",
    "Shared with you" : "Compartido contigo",
    "Deck settings" : "Configuración del tablero",
    "Use bigger card view" : "Usar vista de tarjeta mayor",
    "Show card ID badge" : "Mostrar insignia de la ID de tarjeta",
    "Show boards in calendar/tasks" : "Mostrar tableros en calendario/tareas",
    "Limit deck usage of groups" : "Limitar el uso de Deck a grupos",
    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Limitar Deck impedirá que usuarios que no formen parte de esos grupos creen sus propios tableros. Los usuarios todavía podrán trabajar en tableros que hayan sido compartidos con ellos.",
    "Board details" : "Detalles del tablero",
    "Edit board" : "Editar tablero",
    "Clone board" : "Clonar tablero",
    "Unarchive board" : "Desarchivar tablero",
    "Archive board" : "Archivar tablero",
    "Turn on due date reminders" : "Activar recordatorios de la fecha de vencimiento",
    "Turn off due date reminders" : "Desactivar recordatorios de la fecha de vencimiento",
    "Due date reminders" : "Recordatorios de la fecha de vencimiento",
    "All cards" : "Todas las tarjetas",
    "Assigned cards" : "Tarjetas asignadas",
    "No notifications" : "No hay notificaciones",
    "Delete board" : "Eliminar tablero",
    "Board {0} deleted" : "Tablero {0} eliminado",
    "Only assigned cards" : "Sólo las tarjetas asignadas",
    "No reminder" : "No hay recordatorio",
    "An error occurred" : "Ocurrió un error",
    "Are you sure you want to delete the board {title}? This will delete all the data of this board including archived cards." : "¿Está seguro de querer eliminar el tablero {title}? Esto eliminará todos los datos del tablero incluyendo las tarjetas archivadas.",
    "Delete the board?" : "¿Borrar el tablero?",
    "Loading filtered view" : "Cargando vista filtrada",
    "No due" : "Sin finalizar",
    "Search for {searchQuery} in all boards" : "Buscar {searchQuery} en todos los tableros",
    "No results found" : "No se encontraron resultados",
    "{stack} in {board}" : "{stack} en {board}",
    "Click to expand description" : "Pulse para expandir la descripción",
    "* Created on {created}\n* Last modified on {lastMod}\n* {nbAttachments} attachments\n* {nbComments} comments" : "* Creada en {created}\n* Ultima moficiación en {lastMod}\n* {nbAttachments} adjuntos\n* {nbComments} comentarios",
    "{nbCards} cards" : "{nbCards} tarjetas",
    "No upcoming cards" : "No hay tarjetas próximas",
    "upcoming cards" : "próximas tarjetas",
    "Due on {date}" : "Vence en {date}",
    "Link to a board" : "Enlace a un tablero",
    "Link to a card" : "Enlace a una tarjeta",
    "Create a card" : "Crear una tarjeta",
    "Message from {author} in {conversationName}" : "Mensaje de {author} en {conversationName}",
    "Something went wrong" : "Algo ha ido mal",
    "Failed to upload {name}" : "Error al subir {name}",
    "Maximum file size of {size} exceeded" : "Tamaño máximo de archivo de {size} excedido",
    "Error creating the share" : "Error creando el recurso compartido",
    "Share with a Deck card" : "Compartir con una tarjeta de Deck",
    "Share {file} with a Deck card" : "Compartir {file} con una tarjeta de Deck",
    "Share" : "Compartir",
    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Deck es una herramienta de organización de estilo kanban dirigida a la planificación personal y la organización de proyectos para equipos integrados con Nextcloud.\n\n\n- 📥 Agrega tus tareas a las tarjetas y ordénalas.\n- 📄 Escriba notas adicionales\n- 🔖 Asignar etiquetas para una organización mejor\n- 👥 Comparte con tu equipo, amigos o familia.\n- 📎 Adjuntar archivos e incrustarlos en su descripción\n- 💬 Discuta con su equipo usando comentarios.\n- ⚡ Mantenga un registro de los cambios en el flujo de actividad\n- 🚀 Organiza tu proyecto",
    "Are you sure you want to transfer the board {title} for {user} ?" : "¿Estás seguro de que quieres transferir el tablero {título} a {usuario}?",
    "Transfer the board for {user} successfully" : "Transferir el tablero para {usuario} con éxito",
    "Failed to transfer the board for {user}" : "No se ha podido transferir el tablero para {usuario}",
    "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "¿Estas seguro de que quieres eliminar el tablero {title}? Esto eliminará todos los datos del tablero.",
    "This week" : "Esta semana",
    "Are you sure you want to transfer the board {title} for {user}?" : "¿Estás seguro de que quieres transferir el tablero {título} a {usuario}?"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
