.activitymessage .visualdiff ins {
	background-color: rgba(70, 186, 97, 0.2);
	text-decoration: none;
}

.activitymessage .visualdiff del {
	background-color: rgba(233, 50, 45, 0.2);
	text-decoration: none;
}

.activitymessage .visualdiff {
	overflow: scroll;
	max-height: 200px;
}

.activityTabView .avatardiv-container {
	display: inline-block;
	bottom: -3px;
	margin-left: 3px;
}

.activityTabView .avatar-name-wrapper {
	font-weight: bold;
}

.activityTabView .activitysubject a {
	font-weight: bold;
}
