OC.L10N.register(
    "deck",
    {
    "You have created a new board {board}" : "Você criou um novo painel {board}",
    "{user} has created a new board {board}" : "{user} criou um novo painel {board}",
    "You have deleted the board {board}" : "Você eliminou o painel {board}",
    "{user} has deleted the board {board}" : "{user} eliminou o painel {board}",
    "You have restored the board {board}" : "Você restaurou o painel {board}",
    "{user} has restored the board {board}" : "{user} restaurou o painel {board}",
    "You have shared the board {board} with {acl}" : "Você partilhou o painel {board} com {acl}",
    "{user} has shared the board {board} with {acl}" : "{user} partilhou o painel {board} com {acl}",
    "You have removed {acl} from the board {board}" : "Você eliminou {acl} do painel {board}",
    "{user} has removed {acl} from the board {board}" : "{user} eliminou {acl} do painel {board}",
    "You have renamed the board {before} to {board}" : "Você mudou o nome do painel {before} para {board}",
    "{user} has renamed the board {before} to {board}" : "{user} mudou o nome do painel {before} para {board}",
    "You have archived the board {board}" : "Você arquivou o painel {board}",
    "{user} has archived the board {before}" : "{user} arquivou o painel  {before}",
    "You have unarchived the board {board}" : "Você desarquivou o painel  {board}",
    "{user} has unarchived the board {before}" : "{user} desarquivou o painel {board}",
    "You have created a new list {stack} on board {board}" : "Você criou uma nova lista {stack} no painel {board}",
    "{user} has created a new list {stack} on board {board}" : "{user} criou uma nova lista {stack} no painel {board}",
    "You have renamed list {before} to {stack} on board {board}" : "Você mudou o nome da lista {before} para {stack} no painel {board}",
    "{user} has renamed list {before} to {stack} on board {board}" : "{user} mudou o nome da lista {before} para {stack} no painel {board}",
    "You have deleted list {stack} on board {board}" : "Você eliminou a lista {stack} do painel {board}",
    "{user} has deleted list {stack} on board {board}" : "{user} eliminou a lista {stack} do painel {board}",
    "You have created card {card} in list {stack} on board {board}" : "Você criou o cartão {card} na lista {stack} do painel {board}",
    "{user} has created card {card} in list {stack} on board {board}" : "{user} criou o cartão {card} na lista {stack} do painel {board}",
    "You have deleted card {card} in list {stack} on board {board}" : "Você eliminou o cartão {card} na lista {stack} do painel {board}",
    "{user} has deleted card {card} in list {stack} on board {board}" : "{user} eliminou o cartão {card} na lista {stack} do painel {board}",
    "You have renamed the card {before} to {card}" : "Você mudou o nome do cartão {before} para {card}",
    "{user} has renamed the card {before} to {card}" : "{user} mudou o nome do cartão {before} para {card}",
    "You have added a description to card {card} in list {stack} on board {board}" : "Você adicionou uma descrição ao cartão {card} na lista {stack} do painel {board}",
    "{user} has added a description to card {card} in list {stack} on board {board}" : "{user} adicionou uma descrição ao cartão {card} na lista {stack} do painel {board}",
    "You have updated the description of card {card} in list {stack} on board {board}" : "Você atualizou a descrição do cartão {card} na lista {stack} do painel {board}",
    "{user} has updated the description of the card {card} in list {stack} on board {board}" : "{user} atualizou a descrição do cartão {card} na lista {stack} do painel {board}",
    "You have archived card {card} in list {stack} on board {board}" : "Você arquivou o cartão {card} na lista {stack} do painel {board}",
    "{user} has archived card {card} in list {stack} on board {board}" : "{user} arquivou o cartão {card} na lista {stack} do painel {board}",
    "You have unarchived card {card} in list {stack} on board {board}" : "Você desarquivou o cartão {card} na lista {stack} do painel {board}",
    "{user} has unarchived card {card} in list {stack} on board {board}" : "{user} desarquivou o cartão {card} na lista {stack} do painel {board}",
    "You have removed the due date of card {card}" : "Você eliminou a data limite do cartão {card}",
    "{user} has removed the due date of card {card}" : "{user} excluiu a data limite do cartão {card}",
    "You have set the due date of card {card} to {after}" : "Você definiu a data limite do cartão {card} para {after}",
    "{user} has set the due date of card {card} to {after}" : "{user} definiu a data limite do cartão {card} para {after}",
    "You have updated the due date of card {card} to {after}" : "Você atualizou a data limite do cartão {card} para {after}",
    "{user} has updated the due date of card {card} to {after}" : "{user} atualizou a data limite do cartão {card} para {after}",
    "You have added the tag {label} to card {card} in list {stack} on board {board}" : "Você adicionou a etiqueta {label} ao cartão {card} na lista {stack} do painel {board}",
    "{user} has added the tag {label} to card {card} in list {stack} on board {board}" : "{user} adicionou a etiqueta {label} ao cartão {card} na lista {stack} do painel {board}",
    "You have removed the tag {label} from card {card} in list {stack} on board {board}" : "Você removeu a etiqueta {label} do cartão {card} na lista {stack} do painel {board}",
    "{user} has removed the tag {label} from card {card} in list {stack} on board {board}" : "{user} removeu a etiqueta {label} do cartão {card} na lista {stack} do painel {board}",
    "You have assigned {assigneduser} to card {card} on board {board}" : "Você vinculou {assigneduser} ao cartão {card} do painel {board}",
    "{user} has assigned {assigneduser} to card {card} on board {board}" : "{user} vinculou {assigneduser} ao cartão {card} do painel {board}",
    "You have unassigned {assigneduser} from card {card} on board {board}" : "Você desvinculou {assigneduser} do cartão {card} no painel {board}",
    "{user} has unassigned {assigneduser} from card {card} on board {board}" : "{user} desvinculou {assigneduser} do cartão {card} no painel {board}",
    "You have moved the card {card} from list {stackBefore} to {stack}" : "Você moveu o cartão {card} da lista {stackBefore} para {stack}",
    "{user} has moved the card {card} from list {stackBefore} to {stack}" : "{user} moveu o cartão {card} da lista {stackBefore} para {stack}",
    "You have added the attachment {attachment} to card {card}" : "Você adicionou o anexo {attachment} no cartão {card}",
    "{user} has added the attachment {attachment} to card {card}" : "{user} adicionou um anexo {attachment} ao cartão {card}",
    "You have updated the attachment {attachment} on card {card}" : "Você atualizou o anexo {attachment} do cartão {card}",
    "{user} has updated the attachment {attachment} on card {card}" : "{user} atualizou o anexo {attachment} no cartão {card}",
    "You have deleted the attachment {attachment} from card {card}" : "Você excluiu o anexo {attachment} do cartão {card}",
    "{user} has deleted the attachment {attachment} from card {card}" : "{user} eliminou o anexo {attachment} do cartão {card}",
    "You have restored the attachment {attachment} to card {card}" : "Você restaurou o anexo {attachment} do cartão {card}",
    "{user} has restored the attachment {attachment} to card {card}" : "{user} restaurou o anexo {attachment} do cartão {card}",
    "You have commented on card {card}" : "Você comentou no cartão {card}",
    "{user} has commented on card {card}" : "{user} comentou no cartão {card}",
    "A <strong>card description</strong> inside the Deck app has been changed" : "Uma <strong>descrição do cartão</strong> dentro da aplicação Quadro foi alterada",
    "Deck" : "Quadro",
    "Changes in the <strong>Deck app</strong>" : "Alterações na aplicação Quadro",
    "A <strong>comment</strong> was created on a card" : "Um <strong>comentário</strong> foi criado num cartão",
    "Upcoming cards" : "Próximos cartões",
    "Load more" : "Carregar mais",
    "Personal" : "Pessoal",
    "The card \"%s\" on \"%s\" has been assigned to you by %s." : "O cartão \"%s\" em \"%s\" foi-lhe vinculado por %s.",
    "{user} has assigned the card {deck-card} on {deck-board} to you." : "{usuário} atribuiu-lhe o cartão {deck-card} no {deck-board}.",
    "The card \"%s\" on \"%s\" has reached its due date." : "O cartão \"%s\" em \"%s\" atingiu a sua data limite.",
    "The card {deck-card} on {deck-board} has reached its due date." : "O cartão {deck-card} em {deck-board} atingiu a sua data limite.",
    "%s has mentioned you in a comment on \"%s\"." : "%s mencionou-o num comentário em \"%s\".",
    "{user} has mentioned you in a comment on {deck-card}." : "{user} mencionou-o num comentário em {deck-card}.",
    "The board \"%s\" has been shared with you by %s." : "O quadro \"%s\" foi partilhado consigo por %s.",
    "{user} has shared {deck-board} with you." : "{user} partilhou {deck-board} consigo.",
    "Card comments" : "Comentários nos cartões",
    "%s on %s" : "%s no %s",
    "No data was provided to create an attachment." : "Nenhum dado foi fornecido para criar um anexo.",
    "Finished" : "Terminado",
    "To review" : "A rever",
    "Action needed" : "Acção necessária",
    "Later" : "Mais tarde",
    "copy" : "copiar",
    "To do" : "Por fazer",
    "Doing" : "A fazer",
    "Done" : "Concluído",
    "Example Task 3" : "Tarefa de exemplo 3",
    "Example Task 2" : "Tarefa de exemplo 2",
    "Example Task 1" : "Tarefa de exemplo 1",
    "The file was uploaded" : "O ficheiro foi carregado",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "O ficheiro carregado excede a diretiva upload_max_filesize no php.ini ",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "O ficheiro carregado excede a diretiva MAX_FILE_SIZE especificada no formulário HTML",
    "The file was only partially uploaded" : "O ficheiro foi apenas parcialmente carregado",
    "No file was uploaded" : "Não foi carregado nenhum ficheiro",
    "Missing a temporary folder" : "Falta uma pasta temporária",
    "Could not write file to disk" : "Não foi possível escrever o ficheiro no disco.",
    "A PHP extension stopped the file upload" : "Uma extensão PHP parou o carregamento do ficheiro.",
    "No file uploaded or file size exceeds maximum of %s" : "Nenhum ficheiro carregado ou o tamanho do ficheiro excede o máximo de%s",
    "This comment has more than %s characters.\nAdded as an attachment to the card with name %s.\nAccessible on URL: %s." : "Este comentário tem mais de %s caracteres.\nAdicionado como um anexo ao cartão com o nome %s.\nAcessível no URL: %s.",
    "Card not found" : "Cartão não encontrado",
    "Path is already shared with this card" : "O caminho já é partilhado com este cartão",
    "Invalid date, date format must be YYYY-MM-DD" : "Data inválida, o formato da data deve ser AAAA-MM-DD",
    "Personal planning and team project organization" : "Planeamento pessoal e organização de projetos em equipa",
    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in Markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your Markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Quadro é uma ferramenta de organização ao estilo kanban voltada para o planeamento pessoal e organização de projetos para equipas integradas no Nextcloud.\n\n\n- 📥Adicione as suas tarefas aos cartões e coloque-as em ordem\n- 📄 Escreva notas adicionais em Markdown\n- 🔖 Atribua etiquetas para uma organização ainda melhor\n- 👥 Compartilhe com a sua equipa, amigos ou família\n- 📎 Anexe ficheiros e incorpore-os à descrição em Markdown\n- 💬 Debata com a sua equipa usando comentários\n- ⚡ Acompanhe as mudanças no fluxo de atividades \n- 🚀 Organize o seu projeto",
    "Card details" : "Detalhes do cartão",
    "Add board" : "Adicionar quadro",
    "Cancel" : "Cancelar",
    "Close" : "Fechar",
    "Create card" : "Criar cartão",
    "File already exists" : "O ficheiro já existe",
    "Add card" : "Adicionar um cartão",
    "Hide archived cards" : "Esconder cartões arquivados",
    "Show archived cards" : "Mostrar cartões arquivados",
    "Details" : "Detalhes",
    "Sharing" : "Partilha",
    "Tags" : "Etiquetas",
    "Timeline" : "Linha do tempo",
    "Undo" : "Desfazer",
    "(Group)" : "(Grupo)",
    "Can edit" : "Can edit",
    "Can share" : "Can share",
    "Owner" : "Proprietário",
    "Delete" : "Apagar",
    "Transfer" : "Transfere",
    "Edit" : "Editar",
    "Members" : "Membros",
    "Download" : "Transferir",
    "Attachments" : "Anexos",
    "Comments" : "Comentários",
    "Modified" : "Modificado",
    "Created" : "Criado",
    "Due date" : "Data limite",
    "Select Date" : "Escolha a data",
    "Today" : "Hoje",
    "Tomorrow" : "Amanhã",
    "Next week" : "Próxima semana",
    "Next month" : "Próximo mês",
    "Save" : "Guardar",
    "Reply" : "Resposta",
    "Update" : "Atualizar",
    "Description" : "Descrição",
    "(group)" : "(grupo)",
    "Archive card" : "Arquivar cartão",
    "Delete card" : "Eliminar cartão",
    "List is empty" : "A lista está vazia",
    "seconds ago" : "segundos atrás",
    "Archived boards" : "Quadros arquivados",
    "Shared with you" : "Shared with you",
    "Board details" : "Detalhes do quadro",
    "Edit board" : "Editar quadro",
    "Archive board" : "Arquivar quadro",
    "No notifications" : "Sem notificações",
    "Delete board" : "Eliminar quadro",
    "No reminder" : "Nenhum lembrete",
    "An error occurred" : "Ocorreu um erro",
    "Share" : "Partilhar",
    "This week" : "Esta semana"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
