OC.L10N.register(
    "deck",
    {
    "Finished" : "Deiseil",
    "The file was uploaded" : "Chaidh am faidhle a luchdadh suas",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Tha am faidhle a luchdaich thu suas a’ dol thairis air an riaghailt upload_max_filesize ann am php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Tha am faidhle a luchdaich thu suas a’ dol thairis air an riaghailt MAX_FILE_SIZE a chaidh a shònrachadh san fhoirm HTML",
    "The file was only partially uploaded" : "Cha deach ach pàirt dhen fhaidhle a luchdadh suas",
    "No file was uploaded" : "Cha deach faidhle sam bith a luchdadh suas",
    "Missing a temporary folder" : "Tha pasgan sealach a dhìth",
    "Could not write file to disk" : "Cha b’ urrainn dhuinn am faidhle a sgrìobhadh dhan diosg",
    "A PHP extension stopped the file upload" : "Chur leudachan PHP stad air luchdadh suas an fhaidhle",
    "Cancel" : "Sguir dheth",
    "Close" : "Dùin",
    "Details" : "Mion-fhiosrachadh",
    "Sharing" : "Co-roinneadh",
    "Tags" : "Tagaichean",
    "Undo" : "Neo-dhèan",
    "Delete" : "Sguab às",
    "Transfer" : "Tar-chuir",
    "Edit" : "Deasaich",
    "Download" : "Luchdaich a-nuas",
    "Today" : "An-diugh",
    "Save" : "Sàbhail",
    "seconds ago" : "diog air ais",
    "No notifications" : "Gun bhrath",
    "Share" : "Co-roinn",
    "This week" : "An t-seachdain seo"
},
"nplurals=4; plural=(n==1 || n==11) ? 0 : (n==2 || n==12) ? 1 : (n > 2 && n < 20) ? 2 : 3;");
