OC.L10N.register(
    "deck",
    {
    "You have created a new board {board}" : "Създадохте ново табло {board}",
    "{user} has created a new board {board}" : "{user}  създаде ново табло {board}",
    "You have deleted the board {board}" : "Изтрихте таблото {board}",
    "{user} has deleted the board {board}" : "{user} изтри таблото {board}",
    "You have restored the board {board}" : "Възстановихте таблото {board}",
    "{user} has restored the board {board}" : "{user}  възстанови таблото {board}",
    "You have shared the board {board} with {acl}" : "Споделихте таблото {board} с {acl}",
    "{user} has shared the board {board} with {acl}" : "{user} сподели таблото {board} с {acl}",
    "You have removed {acl} from the board {board}" : "Премахнахте {acl} от таблото {board}",
    "{user} has removed {acl} from the board {board}" : "{user} премахна {acl} от таблото {board}",
    "You have renamed the board {before} to {board}" : "Преименувахте таблото от {before} на {board}",
    "{user} has renamed the board {before} to {board}" : "{user} преименува таблото от {before} на {board}",
    "You have archived the board {board}" : "Архивирахте таблото {board}",
    "{user} has archived the board {before}" : "{user}  архивира таблото {board}",
    "You have unarchived the board {board}" : "Разархивирали сте таблото {board}",
    "{user} has unarchived the board {before}" : "{user} е разархивирал таблото {before}",
    "You have created a new list {stack} on board {board}" : "Създадохте нов списък {stack} на таблото  {board}",
    "{user} has created a new list {stack} on board {board}" : "{user} създаде нов списък {stack} на таблото  {board}",
    "You have renamed list {before} to {stack} on board {board}" : "Преименувахте списъка {before} на {stack} на таблото {board}",
    "{user} has renamed list {before} to {stack} on board {board}" : "{user} преименува списъка {before} на {stack} на таблото {board}",
    "You have deleted list {stack} on board {board}" : "Изтрихте списък {stack} на таблото {board}",
    "{user} has deleted list {stack} on board {board}" : "{user} изтри списък {stack} на таблото {board}",
    "You have created card {card} in list {stack} on board {board}" : "Създали сте карта {card} в списък {stack} на таблото {board}",
    "{user} has created card {card} in list {stack} on board {board}" : "{user} създаде карта {card} в списък {stack} на таблото {board}",
    "You have deleted card {card} in list {stack} on board {board}" : "Изтрили сте карта {card} в списък {stack} на таблото {board}",
    "{user} has deleted card {card} in list {stack} on board {board}" : "{user} изтри карта {card} в списък {stack} на таблото {board}",
    "You have renamed the card {before} to {card}" : "Преименувахте картата {before} на {card}",
    "{user} has renamed the card {before} to {card}" : "{user} преименува картата {before} на {card}",
    "You have added a description to card {card} in list {stack} on board {board}" : "Добавили сте описание към карта {card} в списък {stack} на таблото {board}",
    "{user} has added a description to card {card} in list {stack} on board {board}" : "{user} добави описание към карта {card} в списък {stack} на таблото {board}",
    "You have updated the description of card {card} in list {stack} on board {board}" : " Актуализирали сте описанието към карта {card} в списък {stack} на таблото {board}",
    "{user} has updated the description of the card {card} in list {stack} on board {board}" : " {user} актуализира описанието към карта {card} в списък {stack} на таблото {board}",
    "You have archived card {card} in list {stack} on board {board}" : "Архивирали сте карта {card} в списък {stack} на борда {board}",
    "{user} has archived card {card} in list {stack} on board {board}" : "{user}  архивира карта {card} в списък {stack} на борда {board}",
    "You have unarchived card {card} in list {stack} on board {board}" : "Разархивирали сте карта {card} в списък {stack} на борда {board}",
    "{user} has unarchived card {card} in list {stack} on board {board}" : "{user}  разархивира карта {card} в списък {stack} на борда {board}",
    "You have removed the due date of card {card}" : "Премахнахте датата на падежа на картата {card}",
    "{user} has removed the due date of card {card}" : "{user} премахна датата на падежа на картата {card}",
    "You have set the due date of card {card} to {after}" : "Задали сте датата на падежа на картата {card} на {after}",
    "{user} has set the due date of card {card} to {after}" : "{user} зададе дата на падежа на картата {card} на {after}",
    "You have updated the due date of card {card} to {after}" : "Актуализирали сте датата на падежа на картата {card} на {after}",
    "{user} has updated the due date of card {card} to {after}" : "{user} актуализира датата на падежа на картата {card} на {after}",
    "You have added the tag {label} to card {card} in list {stack} on board {board}" : "Добавихте етикет {label} към карта {card} в списък {stack} на таблото {board}",
    "{user} has added the tag {label} to card {card} in list {stack} on board {board}" : "{user} добави етикет {label} към карта {card} в списък {stack} натаблото {board}",
    "You have removed the tag {label} from card {card} in list {stack} on board {board}" : "Премахнахте етикет {label} към карта {card} в списък {stack} на таблото {board}",
    "{user} has removed the tag {label} from card {card} in list {stack} on board {board}" : "{user} премахна етикет {label} към карта {card} в списък {stack} на таблото {board}",
    "You have assigned {assigneduser} to card {card} on board {board}" : "Присвоили сте {assigneduser} на карта {card} на борда {board}",
    "{user} has assigned {assigneduser} to card {card} on board {board}" : "{user} присвои {assigneduser} на карта {card} на борда {board}",
    "You have unassigned {assigneduser} from card {card} on board {board}" : "Имате неопределен {assigneduser} на карта {card} на борда {board}",
    "{user} has unassigned {assigneduser} from card {card} on board {board}" : "{user} има неопределен {assigneduser} на карта {card} на борда {board}",
    "You have moved the card {card} from list {stackBefore} to {stack}" : "Преместихте картата {card} от списък {stackBefore} в {stack}",
    "{user} has moved the card {card} from list {stackBefore} to {stack}" : "{user} премести картата {card} от списък {stackBefore} в {stack}",
    "You have added the attachment {attachment} to card {card}" : "Добавихте прикачения файл {attachment} към карта {card}",
    "{user} has added the attachment {attachment} to card {card}" : "{user} добави прикачения файл {attachment} към карта {card}",
    "You have updated the attachment {attachment} on card {card}" : " Актуализирали сте прикачения файл {attachment} към карта {card}",
    "{user} has updated the attachment {attachment} on card {card}" : "{user} актуализира прикачения файл {attachment} към карта {card}",
    "You have deleted the attachment {attachment} from card {card}" : "Изтрихте прикачения файл {attachment} от карта {card}",
    "{user} has deleted the attachment {attachment} from card {card}" : "{user} изтри прикачения файл {attachment} към карта {card}",
    "You have restored the attachment {attachment} to card {card}" : "Възстановили сте прикачения файл {attachment} към карта {card}",
    "{user} has restored the attachment {attachment} to card {card}" : "{user} възстанови прикачения файл {attachment} към карта {card}",
    "You have commented on card {card}" : "Коментирали сте карта {card}",
    "{user} has commented on card {card}" : "{user}  коментира карта {card}",
    "A <strong>card description</strong> inside the Deck app has been changed" : "<strong>Описанието на картата</strong> в приложението Deck/набор/ е променено",
    "Deck" : "Набор",
    "Changes in the <strong>Deck app</strong>" : "Промени в <strong>приложението Deck</strong>",
    "A <strong>comment</strong> was created on a card" : "На картата е създаден <strong>коментар</strong>",
    "Upcoming cards" : "Предстоящи карти",
    "Load more" : "Зареждане на още",
    "Personal" : "Лични",
    "The card \"%s\" on \"%s\" has been assigned to you by %s." : "Картата \"%s\" на \"%s\" Ви е била възложена от %s.",
    "{user} has assigned the card {deck-card} on {deck-board} to you." : "{user} е възложил картата {deck-card} на {deck-board} на Вас.",
    "The card \"%s\" on \"%s\" has reached its due date." : "Картата \"%s\" on \"%s\" е достигнала датата на падежа си.",
    "The card {deck-card} on {deck-board} has reached its due date." : "Картата {deck-card} на {deck-board} е достигнала датата на падежа си.",
    "%s has mentioned you in a comment on \"%s\"." : "%s те спомена в коментар за “%s”",
    "{user} has mentioned you in a comment on {deck-card}." : "{user} те спомена в коментар за {deck-card}.",
    "The board \"%s\" has been shared with you by %s." : "Таблото \"%s\" е споделено с вас от%s.",
    "{user} has shared {deck-board} with you." : "{user} сподели {deck-board} с Вас.",
    "Card comments" : "Коментари на карти",
    "%s on %s" : "%s на %s",
    "No data was provided to create an attachment." : "Не бяха предоставени данни за създаване на прикачен файл.",
    "Finished" : "Готово",
    "To review" : "За преглед",
    "Action needed" : "Необходимо е действие",
    "Later" : "По-късно",
    "copy" : "Копиране",
    "To do" : "Задачи",
    "Doing" : "Задачи в процес на изпълнение",
    "Done" : "Завършено",
    "Example Task 3" : "Примерна задача 3",
    "Example Task 2" : "Примерна задача 2",
    "Example Task 1" : "Примерна задача 1",
    "The file was uploaded" : "Файлът е качен",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Размерът на каченият файл надвишава максималния размер определен от upload_max_filesize в php.ini:",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Размерът на файла надвишава максималния размер определен от MAX_FILE_SIZE в HTML формата.",
    "The file was only partially uploaded" : "Файлът е качен частично",
    "No file was uploaded" : "Нито един файл не е качен",
    "Missing a temporary folder" : "Липсва временна папка",
    "Could not write file to disk" : " Файлът не можа да бъде записан на диск",
    "A PHP extension stopped the file upload" : "PHP разширение спря качването на файла",
    "No file uploaded or file size exceeds maximum of %s" : "Няма качен файл или размерът на файла надвишава максимума от %s",
    "This comment has more than %s characters.\nAdded as an attachment to the card with name %s.\nAccessible on URL: %s." : "Този коментар има повече от %s знака.\nДобавено като прикачен файл към картата с име %s.\nДостъпно на URL: %s.",
    "Card not found" : "Катртата не е намерена",
    "Path is already shared with this card" : "Пътят вече е споделен с тази карта",
    "Invalid date, date format must be YYYY-MM-DD" : "Невалидна дата, форматът е различен от ГГГГ-ММ-ДД",
    "Personal planning and team project organization" : "Лично планиране и организация на екипни проекти",
    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in Markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your Markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Deck е инструмент за организация в стил kanban, насочен към лично планиране и организация на проекти за екипи, интегрирани с Nextcloud.\n\n\n- 📥 Добавете задачите си към карти и ги подредете\n- 📄 Запишете допълнителни бележки в  markdown формат\n- Присвояване на етикети за още по-добра организация\n- 👥 Споделете с вашия екип, приятели или семейство\n- 📎Прикачете файлове и ги вградете във вашето описание за маркиране\n- 💬Обсъдете с вашия екип, като използвате коментари\n- ⚡ Проследявайте промените в потока от дейности\n- 🚀 Организирайте проекта си",
    "Card details" : "Подробности за картата",
    "Add board" : "Добави табло",
    "Select the board to link to a project" : "Изберете таблото, което да свържете към проект",
    "Search by board title" : "Търсене по заглавие на таблото",
    "Select board" : "Избор на табло",
    "Create a new card" : "Създаване на нова карта",
    "Select a board" : "Избор на табло",
    "Select a list" : "Избор на списък",
    "Card title" : "Заглавие на карта",
    "Cancel" : "Отказ",
    "Creating the new card …" : "Създаване на новата карта ...",
    "Card \"{card}\" was added to \"{board}\"" : "Карта \"{card}\" беше добавена към \"{board}\"",
    "Open card" : "Отваряне на карта",
    "Close" : "Затваряне",
    "Create card" : "Създаване на карта",
    "Select a card" : "Избор на карта",
    "Select the card to link to a project" : "Изберете картата, която да свържете към проект",
    "Link to card" : "Връзка към карта",
    "File already exists" : "Файлът вече съществува",
    "A file with the name {filename} already exists." : "Вече съществува файл с името {filename}.",
    "Do you want to overwrite it?" : "Искате ли да го презапишете?",
    "Overwrite file" : "Презапиши файла",
    "Keep existing file" : "Запазване на съществуващ файл",
    "This board is read only" : "Таблото е само за четене",
    "Drop your files to upload" : "Пуснете вашите файлове, за да ги качите",
    "Add card" : "Добави карта",
    "Archived cards" : "Архивирани карти",
    "Add list" : "Добави списък",
    "List name" : "Име на списък",
    "Active filters" : "Актижни филтри",
    "Apply filter" : "Приложи филтър",
    "Filter by tag" : "Филтрирай по маркер",
    "Filter by assigned user" : "Филтриране по назначен потребител",
    "Unassigned" : "Неприсвоен",
    "Filter by due date" : "Филтриране по крайна дата",
    "Overdue" : "Просрочен",
    "Next 24 hours" : "Следващите 24 часа",
    "Next 7 days" : "Следващите 7 дни",
    "Next 30 days" : "Следващите 30 дни",
    "No due date" : "Няма крайна дата",
    "Clear filter" : "Изчстиване на филтър",
    "Hide archived cards" : "Скриване на архивирани карти",
    "Show archived cards" : "Показване на архивирани карти",
    "Toggle compact mode" : "Превключване на компактен режим",
    "Open details" : "Отваряне на подробности",
    "Details" : "Подробности",
    "Loading board" : "Зареждане на табло",
    "No lists available" : "Няма налична списъци.",
    "Create a new list to add cards to this board" : "Създайте нов списък, за да добавите карти към това табло",
    "Board not found" : "Таблото не е намерено",
    "Sharing" : "Споделяне",
    "Tags" : "Етикети",
    "Deleted items" : "Изтрити елементи",
    "Timeline" : "Времева линия",
    "Deleted lists" : "Изтрити списъци",
    "Undo" : "Отмяна",
    "Deleted cards" : "Изтрити карти",
    "Share board with a user, group or circle …" : "Споделяне на таблото с потребител, група или кръг ...",
    "Searching for users, groups and circles …" : "Търсене за потребители, групи и кръгове ...",
    "No participants found" : "Няма намерени участници",
    "Board owner" : "Собственик на табло",
    "(Group)" : "(Група)",
    "(Circle)" : "(Кръг)",
    "Can edit" : "Може да редактира",
    "Can share" : "Може да споделя",
    "Can manage" : "Може да управлява",
    "Owner" : "Собственик",
    "Delete" : "Изтриване",
    "Failed to create share with {displayName}" : "Създаването на споделяне с {displayName} не бе успешно",
    "Are you sure you want to transfer the board {title} to {user}?" : "Сигурни ли сте че искате да прехвърлите таблото {title} на {user}?",
    "Transfer the board." : "Прехвърлете таблото.",
    "Transfer" : "Прехвърляне",
    "The board has been transferred to {user}" : "Таблото беше прехвърлено на {user}",
    "Failed to transfer the board to {user}" : "Неуспешно прехвърляне на таблото на {user}",
    "Add a new list" : "Добавяне на нов списък",
    "Archive all cards" : "Архивира всички карти",
    "Unarchive all cards" : "Разархивиране на всички карти",
    "Delete list" : "Изтрива списък",
    "Archive all cards in this list" : "Архивира всички карти в този списък",
    "Unarchive all cards in this list" : "Разархивиране всички карти в този списък",
    "Add a new card" : "Добави нова карта",
    "Card name" : "Име на карта",
    "List deleted" : "Списъкът е изтрит",
    "Edit" : "Редакция",
    "Add a new tag" : "Добавяне на нов етикет",
    "title and color value must be provided" : "трябва да се предоставят заглавие и стойност на цвета",
    "Board name" : "Име на табло",
    "Members" : "Членове",
    "Upload new files" : "Качи нови файлове",
    "Share from Files" : "Споделяне от Файлове",
    "Pending share" : "Чакащо споделяне",
    "Add this attachment" : "Добавете този прикачен файл",
    "Show in Files" : "Показване във файлове",
    "Download" : "Изтегляне",
    "Remove attachment" : "Премахване на прикачен файл",
    "Delete Attachment" : "Изтриване на прикачен файл",
    "Restore Attachment" : "Възстановяване на прикачен файл",
    "File to share" : "Файл за споделяне",
    "Invalid path selected" : "Избран е невалиден път ",
    "Open in sidebar view" : "Отваряне в изгледа на страничната лента",
    "Open in bigger view" : "Отваря се в по-голям изглед",
    "Attachments" : "Прикачени файлове",
    "Comments" : "Коментари",
    "Modified" : "Промяна",
    "Created" : "Създаден",
    "The title cannot be empty." : "Заглавието не може да бъде празно.",
    "No comments yet. Begin the discussion!" : "Все още няма коментари. Започнете дискусията!",
    "Failed to load comments" : "Неуспешно зареждане на коментари",
    "Assign a tag to this card…" : "Присвояване на етикет на тази карта ...",
    "Assign to users" : "Зачисляване към потребители",
    "Assign to users/groups/circles" : "Зачисляване към потребители/групи/кръгове",
    "Assign a user to this card…" : "Зачисляване на потребител на тази карта ...",
    "Due date" : "Крайна дата",
    "Set a due date" : "Задаване на крайна дата",
    "Remove due date" : "Премахни крайната дата",
    "Select Date" : "Изберете дата",
    "Today" : "Днес",
    "Tomorrow" : "Утре",
    "Next week" : "Следваща седмица",
    "Next month" : "Следващия месец",
    "Save" : "Запазване",
    "The comment cannot be empty." : "Коментарът не може да бъде празен.",
    "The comment cannot be longer than 1000 characters." : "Коментарът не може да бъде по-дълъг от 1000 знака.",
    "In reply to" : "В отговор на",
    "Cancel reply" : "Отказ на отговор",
    "Reply" : "Отговори",
    "Update" : "Обновяване",
    "Description" : "Описание",
    "(Unsaved)" : " (Незаписан)",
    "(Saving…)" : "(Записване...)",
    "Formatting help" : "Помощ за форматиране",
    "Edit description" : "Редактиране на описанието",
    "View description" : "Преглед на описанието",
    "Add Attachment" : "Добавяне на прикачен файл",
    "Write a description …" : "Напишете описание ...",
    "Choose attachment" : "Избор на прикачен файл",
    "(group)" : "(група)",
    "Todo items" : "Елементи на задача за изпълнение",
    "{count} comments, {unread} unread" : "{count} коментари, {unread} непрочетени",
    "Edit card title" : "Редактиране на заглавието на карта",
    "Assign to me" : "Зачисляване към мен",
    "Unassign myself" : "Отмяна на зачисляването към мен",
    "Move card" : "Преместване на карта",
    "Unarchive card" : "Разархивиране на карта",
    "Archive card" : "Архивиране на  карта",
    "Delete card" : "Изтриване на карта",
    "Move card to another board" : "Преместване на картата на друго табло",
    "List is empty" : "Списъкът е празен",
    "Card deleted" : "Картата е изтрита",
    "seconds ago" : "преди секунди",
    "All boards" : "Всички табла",
    "Archived boards" : "Архивирани табла",
    "Shared with you" : "Споделени с вас",
    "Deck settings" : "Настройки на платформата",
    "Use bigger card view" : "Използва по-голям изглед на картата",
    "Show card ID badge" : "Показване на обозначение за самоличност на картата",
    "Show boards in calendar/tasks" : "Показване на таблата в календар / задачи",
    "Limit deck usage of groups" : "Ограничава използването на набора от групи",
    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Ограничаването на приложението Deck/набор/ ще блокира потребителите, които не са част от тези групи, да създават свои собствени табла. Потребителите все още ще могат да работят на таблата, които са споделени с тях.",
    "Board details" : "Подробности за табло",
    "Edit board" : "Редактиране на табло",
    "Clone board" : " Клониране на табло",
    "Unarchive board" : "Разархивиране натабло",
    "Archive board" : "Архивиране на табло",
    "Turn on due date reminders" : "Включва напомнянията за краен срок",
    "Turn off due date reminders" : "Изключва напомнянията за краен срок",
    "Due date reminders" : " Напомняния за краен срок",
    "All cards" : "Всички карти",
    "Assigned cards" : "Зачислени карти",
    "No notifications" : "Няма известия",
    "Delete board" : "Изтриване на табло",
    "Board {0} deleted" : "Табло {0} изтрито",
    "Only assigned cards" : "Само зачислените карти",
    "No reminder" : "Няма напомняне",
    "An error occurred" : "Възникна грешка",
    "Are you sure you want to delete the board {title}? This will delete all the data of this board including archived cards." : "Сигурни ли сте, че искате да изтриете таблото {title}? Това ще изтрие всички данни на това табло, включително архивираните карти.",
    "Delete the board?" : "Изтриване на таблото?",
    "Loading filtered view" : "Зареждане на филтриран изглед",
    "No due" : "Не се дължи",
    "Search for {searchQuery} in all boards" : "Търсене на {searchQuery} във всички табла",
    "No results found" : "Няма намерени резултати",
    "{stack} in {board}" : "{stack} в {board}",
    "Click to expand description" : "Кликване за разширяване на описанието",
    "* Created on {created}\n* Last modified on {lastMod}\n* {nbAttachments} attachments\n* {nbComments} comments" : "* Създаден на {created}\n* Последна промяна на {lastMod} \n* {nbAttachments} прикачени файлове \n* {nbComments} коментара",
    "{nbCards} cards" : "{nbCards} карти",
    "No upcoming cards" : "Няма предстоящи карти",
    "upcoming cards" : "предстоящи карти",
    "Due on {date}" : "Краен срок до {date}",
    "Link to a board" : "Линк към табло",
    "Link to a card" : "Линк към карта",
    "Create a card" : "Създаване на карта",
    "Message from {author} in {conversationName}" : "Съобщение от {author} в {conversationName}",
    "Something went wrong" : "Нещо се обърка",
    "Failed to upload {name}" : " Неуспешно качване на {name}",
    "Maximum file size of {size} exceeded" : "Максималният размер на файла от {size} е надвишен",
    "Error creating the share" : "Грешка при създаване на споделяне",
    "Share with a Deck card" : "Споделяне с Deck карта",
    "Share {file} with a Deck card" : "Споделяне {file} с Deck карта",
    "Share" : "Споделяне",
    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Deck е инструмент за организация в стил kanban, насочен към лично планиране и организация на проекти за екипи, интегрирани с Nextcloud.\n\n\n- 📥 Добавете задачите си към карти и ги подредете\n- 📄 Запишете допълнителни бележки в  markdown формат\n- Присвояване на етикети за още по-добра организация\n- 👥 Споделете с вашия екип, приятели или семейство\n- 📎Прикачете файлове и ги вградете във вашето описание за маркиране\n- 💬Обсъдете с вашия екип, като използвате коментари\n- ⚡ Проследявайте промените в потока от дейности\n- 🚀 Организирайте проекта си",
    "Are you sure you want to transfer the board {title} for {user} ?" : "Сигурни ли сте че искате да прехвърлите таблото {title} на {user}?",
    "Transfer the board for {user} successfully" : "Успешно прехвърляне на таблото към {user} ",
    "Failed to transfer the board for {user}" : "Неуспешно прехвърляне на таблото към {user}",
    "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "Сигурни ли сте, че искате да изтриете таблото {title}? Това ще изтрие всички данни на това табло.",
    "This week" : "Тази седмица",
    "Are you sure you want to transfer the board {title} for {user}?" : "Сигурни ли сте че искате да прехвърлите таблото {title} на {user}?"
},
"nplurals=2; plural=(n != 1);");
