OC.L10N.register(
    "deck",
    {
    "Personal" : "Personleg",
    "Done" : "Ferdig",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Den opplasta fila er større enn variabelen MAX_FILE_SIZE i HTML-skjemaet",
    "No file was uploaded" : "Ingen filer vart lasta opp",
    "Missing a temporary folder" : "Manglar ei mellombels mappe",
    "Cancel" : "Avbryt",
    "Close" : "Lukk",
    "Details" : "Detaljar",
    "Sharing" : "Deling",
    "Tags" : "Emneord",
    "Can edit" : "Can edit",
    "Can share" : "Can share",
    "Owner" : "Owner",
    "Delete" : "Ta bort",
    "Edit" : "Endra",
    "Download" : "Last ned",
    "Remove attachment" : "Fjern vedlegg",
    "Comments" : "Kommentarar",
    "Modified" : "Endra",
    "Created" : "Lagd",
    "Today" : "I dag",
    "Save" : "Lagre",
    "Cancel reply" : "Avbryt svar",
    "Reply" : "Svare",
    "Update" : "Oppdater",
    "Description" : "Skildring",
    "seconds ago" : "sekund sidan",
    "Shared with you" : "Shared with you",
    "An error occurred" : "Det oppstod ein feil.",
    "Share" : "Del"
},
"nplurals=2; plural=(n != 1);");
