@media print {
	/* hide stuff */
	#body-user {
		#header,
		.app-navigation,
		.app-sidebar,
		.board-header-controls,
		.board-actions,
		#app-navigation-toggle,
		#app-navigation-toggle-custom,
		div#controls.ng-scope div.crumb:not(.title),
		div#controls.ng-scope div.crumb a.bullet,
		a.ng-binding + a,
		div.card.create,
		.stack__header .action-item,
		button.card-options {
			display: none !important;
		}

		#content {
			margin: 0;
			padding: 0;
		}

		#app-content {
			margin: 0 !important;
		}
	}

	div#app-navigation-toggle.icon-menu {
		display:block;
		width:0px;
		height:0px;
		background:none;
	}

	/* title */
	div#controls.ng-scope {padding-left:20px;}
	div#controls.ng-scope div.crumb.title {
		display:inline;
		font-size: 2em;
		line-height:2.5em;
		background:none;
	}

	div#controls.ng-scope div.crumb.title a.ng-binding {
		color:#000;
		opacity:1;
	}

	/*Due, assigned-users and description*/
	div.card-controls {
		flex-direction:row;
		flex-wrap:wrap;
	}
	div.card-controls i.icon.icon-filetype-text {background:none;}
	div.card-controls i.icon.icon-filetype-text:after {
		content: attr(title);
		display:block;
		width:289px;
		height:1.5em;
		text-overflow: ellipsis;
		overflow: hidden;
		white-space: nowrap;
	}

	div.card-assigned-users {
		margin-right:10px;
	}

	ul.labels li.ng-scope span.ng-binding {
		color:#000;
		display:inline;
		padding-left:5px;
	}

	/* Layout */
	@page {
		size: A4 landscape;
		margin: 2cm;
	}

	.board {
		max-height: none !important;
		overflow: visible !important;
	}

	div#innerBoard {
		display:flex;
		flex-wrap: wrap;
	}

	div.stack.ng-scope.as-sortable-item {border-right: 1px solid #000;}

	div#innerBoard.ng-pristine.ng-untouched.ng-valid.ng-scope.ng-not-empty div.stack.ng-scope.as-sortable-item:nth-child(6n) {
		page-break-after: always;
	}
}
