OC.L10N.register(
    "deck",
    {
    "You have created a new board {board}" : "あなたは新しいボード {board} を作成しました。",
    "{user} has created a new board {board}" : "{user} が新しいボード {board} を作成しました",
    "You have deleted the board {board}" : "あなたはボード {board} を削除しました。",
    "{user} has deleted the board {board}" : "{user} がボード {board} を削除しました",
    "You have restored the board {board}" : "あなたはボード {board} を復元しました。",
    "{user} has restored the board {board}" : "{user} がボード {board} を復元しました",
    "You have shared the board {board} with {acl}" : "あなたはボード {board} を {acl} と共有しました。",
    "{user} has shared the board {board} with {acl}" : "{user}はボード{board}を{acl}と共有しました",
    "You have removed {acl} from the board {board}" : "{acl} をボード {board} から削除しました。",
    "{user} has removed {acl} from the board {board}" : "{user} がボード {board} から {acl} を削除しました",
    "You have renamed the board {before} to {board}" : "あなたは {before} のボードの名前を {board} に変更しました",
    "{user} has renamed the board {before} to {board}" : "{user} はボード {before} を {board}  に変更しました",
    "You have archived the board {board}" : "あなたはボードをアーカイブしました {board}",
    "{user} has archived the board {before}" : "{user} は {before} のボードをアーカイブしました",
    "You have unarchived the board {board}" : "ボード {board} がアーカイブされていません",
    "{user} has unarchived the board {before}" : "{user} は {before} のボードをアーカイブされていません",
    "You have created a new list {stack} on board {board}" : "ボード{board} に新しいリスト {stack} を作成しました。",
    "{user} has created a new list {stack} on board {board}" : "{user} がボード {board} に新しいリスト {stack} を作成しました",
    "You have renamed list {before} to {stack} on board {board}" : "ボード {board} のリストの名を {before} から {stack} に変更しました",
    "{user} has renamed list {before} to {stack} on board {board}" : "{user} がボード {board} のリスト名を {before} から {stack} に変更しました",
    "You have deleted list {stack} on board {board}" : "ボード {board} のリスト {stack} を削除しました。",
    "{user} has deleted list {stack} on board {board}" : "{user} がボード {board} のリスト {stack} を削除しました。",
    "You have created card {card} in list {stack} on board {board}" : "ボード{board} のリスト {stack} に カード{card} を作成しました。",
    "{user} has created card {card} in list {stack} on board {board}" : "{user} がボード {board} のリスト {stack} にカード {card} を作成しました",
    "You have deleted card {card} in list {stack} on board {board}" : "ボード{board} のリスト {stack} のカード {card} を削除しました。",
    "{user} has deleted card {card} in list {stack} on board {board}" : "{user}がボード{board}のリスト{stack}のカード{card}を削除しました",
    "You have renamed the card {before} to {card}" : "カード {before} の名前を {card} に変更しました",
    "{user} has renamed the card {before} to {card}" : "{user} が {before} カードの名前を {card} に変更しました",
    "You have added a description to card {card} in list {stack} on board {board}" : "ボード{board}のリスト{stack} のカード{card}に説明を追加しました",
    "{user} has added a description to card {card} in list {stack} on board {board}" : "{user}がボード{board}のリスト{stack}のカード{card}に説明を追加しました",
    "You have updated the description of card {card} in list {stack} on board {board}" : "ボード{board}のリスト{stack}のカード{card}の説明を更新しました",
    "{user} has updated the description of the card {card} in list {stack} on board {board}" : "{user}はボード{board}のリスト{stack}のカード{card}の説明を更新しました",
    "You have archived card {card} in list {stack} on board {board}" : "ボード {board}のリスト {stack}にあるカード {card} をアーカイブしました",
    "{user} has archived card {card} in list {stack} on board {board}" : "{user}がボード{board}のリスト{stack}にカード{card}をアーカイブしました",
    "You have unarchived card {card} in list {stack} on board {board}" : "ボード {board}のリスト {stack}にあるカード {card} をアーカイブ解除しました",
    "{user} has unarchived card {card} in list {stack} on board {board}" : "{user}がボード {board}のリスト {stack}にあるカード {card} をアーカイブ解除しました",
    "You have removed the due date of card {card}" : "カード{card}の期日を削除しました",
    "{user} has removed the due date of card {card}" : "{user}がカード{card}の期日を削除しました",
    "You have set the due date of card {card} to {after}" : "カード{card}の期日を{after}に設定しました",
    "{user} has set the due date of card {card} to {after}" : "{user}がカード{card}の期日を{after}に設定しました",
    "You have updated the due date of card {card} to {after}" : "カード{card}の期日を{after}に更新しました",
    "{user} has updated the due date of card {card} to {after}" : "{user}はカード{card}の期日を{after}に更新しました",
    "You have added the tag {label} to card {card} in list {stack} on board {board}" : "ボード{board}のリスト{stack}のカード{card}にタグ{label}を追加しました",
    "{user} has added the tag {label} to card {card} in list {stack} on board {board}" : "{user}がボード{board}のリスト{stack}のカード{card}にタグ{label}を追加しました",
    "You have removed the tag {label} from card {card} in list {stack} on board {board}" : "ボード{board}のリスト{stack}のカード{card}からタグ{label}を削除しました",
    "{user} has removed the tag {label} from card {card} in list {stack} on board {board}" : "{user}がボード{board}のリスト{stack}のカード{card}からタグ{label}を削除しました",
    "You have assigned {assigneduser} to card {card} on board {board}" : "ボード{board}のカード{card}に{assigneduser}を割り当てました",
    "{user} has assigned {assigneduser} to card {card} on board {board}" : "{user}がボード{board}のカード{card}に{assigneduser}を割り当てました",
    "You have unassigned {assigneduser} from card {card} on board {board}" : "ボード{board}のカード{card}から{assigneduser} の割り当てが解除されました",
    "{user} has unassigned {assigneduser} from card {card} on board {board}" : "{user}がボード{board}のカード{card}から{assigneduser}の割り当てを解除されました",
    "You have moved the card {card} from list {stackBefore} to {stack}" : "カード{card}をリスト{stackBefore}から{stack}に移動しました",
    "{user} has moved the card {card} from list {stackBefore} to {stack}" : "{user}がカード{card}をリスト{stackBefore}から{stack}に移動しました",
    "You have added the attachment {attachment} to card {card}" : "添付ファイル{attachment}をカード{card}に追加しました",
    "{user} has added the attachment {attachment} to card {card}" : "{user}が添付ファイル{attachment}をカード{card}に追加しました",
    "You have updated the attachment {attachment} on card {card}" : "カード{card}の添付ファイル{attachment}を更新しました",
    "{user} has updated the attachment {attachment} on card {card}" : "{user}がカード{card}の添付ファイル{attachment}を更新しました",
    "You have deleted the attachment {attachment} from card {card}" : "カード{card}から添付ファイル{attachment}を削除しました",
    "{user} has deleted the attachment {attachment} from card {card}" : "{user}がカード{card}から添付ファイル{attachment}を削除しました",
    "You have restored the attachment {attachment} to card {card}" : "添付ファイル{attachment}をカード{card}に復元しました",
    "{user} has restored the attachment {attachment} to card {card}" : "{user}が添付ファイル{attachment}をカード{card}に復元しました",
    "You have commented on card {card}" : "カード{card}にコメントしました",
    "{user} has commented on card {card}" : "{user}がカード{card}にコメントしました",
    "A <strong>card description</strong> inside the Deck app has been changed" : "デッキアプリ内の<strong>カードの説明</strong>が変更されたとき",
    "Deck" : "デッキ",
    "Changes in the <strong>Deck app</strong>" : "<strong>デッキアプリ</strong>に変更があったとき",
    "A <strong>comment</strong> was created on a card" : "カードに<strong>コメント</strong>が作成されたとき",
    "Upcoming cards" : "今後のカード",
    "Load more" : "さらに読み込む",
    "Personal" : "個人",
    "The card \"%s\" on \"%s\" has been assigned to you by %s." : "カード \"%s\"(\"%s\"に所属)が%sによってあなたに割り当てられました。",
    "{user} has assigned the card {deck-card} on {deck-board} to you." : "{user} さんが、{deck-board} で、あなたにカード「{deck-card}」を割り当てました。",
    "The card \"%s\" on \"%s\" has reached its due date." : "カード \"%s\"(\"%s\"に所属)は期日に達しました。",
    "The card {deck-card} on {deck-board} has reached its due date." : "{deck-board}上のカード「{deck-card}」は、期日を迎えました。",
    "%s has mentioned you in a comment on \"%s\"." : "%sさんは \"%s\"へのコメントであなたについて言及しました。",
    "{user} has mentioned you in a comment on {deck-card}." : "{user} さんが 「{deck-card}」のコメント内であなたについて言及しました。",
    "The board \"%s\" has been shared with you by %s." : "\"%s\" ボードは、%s からあなたに共有されています。",
    "{user} has shared {deck-board} with you." : "{user} さんが、あなたと {deck-board} を共有しました。",
    "Card comments" : "カードコメント",
    "%s on %s" : "%s が %s で",
    "No data was provided to create an attachment." : "添付ファイルを作成するためのデータは提供されていません。",
    "Finished" : "完了",
    "To review" : "レビューする",
    "Action needed" : "必要なアクション",
    "Later" : "後",
    "copy" : "コピー",
    "To do" : "To do",
    "Doing" : "行うこと",
    "Done" : "完了",
    "Example Task 3" : "タスク3の例",
    "Example Task 2" : "タスク2の例",
    "Example Task 1" : "タスク1の例",
    "The file was uploaded" : "ファイルがアップロードされました",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "アップロードされたファイルがphp.iniのupload_max_filesizeディレクティブを超えています",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "アップロードファイルはHTMLフォームで指定された MAX_FILE_SIZE の制限を超えています",
    "The file was only partially uploaded" : "ファイルは一部分にしかアップロードされていません",
    "No file was uploaded" : "ファイルはアップロードされませんでした",
    "Missing a temporary folder" : "一時領域フォルダーがありません",
    "Could not write file to disk" : "ディスクにファイルを書き込めませんでした",
    "A PHP extension stopped the file upload" : "PHP拡張でファイルのアップロードが停止されています",
    "No file uploaded or file size exceeds maximum of %s" : "ファイルがアップロードされていないか、ファイルサイズが最大 %s を超えています",
    "This comment has more than %s characters.\nAdded as an attachment to the card with name %s.\nAccessible on URL: %s." : "このコメントは、%s 文字以上含まれています。\n%sという名前で、カードに添付ファイルとして追加しました。\n次のURLでアクセス可能です: %s",
    "Card not found" : "カードが見つかりません",
    "Path is already shared with this card" : "パスは既にこのカードで共有されています",
    "Invalid date, date format must be YYYY-MM-DD" : "日付が無効です。日付形式はYYYY-MM-DDである必要があります",
    "Personal planning and team project organization" : "個人的な計画とチームのプロジェクト編成",
    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in Markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your Markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "DeckはNextcloudと統合された、チームのための個人計画とプロジェクトの組織化を目的としたカンバンスタイルのオーガナイズツールです。\n\n\n- 📥 タスクをカードに追加して整理する\n- 📄 追加のメモをマークダウン形式で書き留める\n- 🔖 より詳細な分類のために追加のラベルを割り当てる\n- 👥 チーム、友達、家族と共有\n- 📎 ファイルを添付し、マークダウンの説明に埋め込む\n- 💬 コメントを使用してチームで話し合う\n- ⚡ アクティビティストリームで変更を追跡する\n- 🚀 プロジェクトを整理する",
    "Card details" : "カード詳細",
    "Add board" : "ボードを追加",
    "Select the board to link to a project" : "プロジェクトにリンクするボードを選択",
    "Search by board title" : "ボードのタイトルで検索",
    "Select board" : "ボードを選択",
    "Create a new card" : "新しいカードを作成する",
    "Select a board" : "ボードを選択",
    "Select a list" : "リストを選択",
    "Card title" : "カードのタイトル",
    "Cancel" : "キャンセル",
    "Creating the new card …" : "新しいカードを作成しています...",
    "Card \"{card}\" was added to \"{board}\"" : "カード \"{card}\" が \"{board}\" に追加されました",
    "Open card" : "カードを開く",
    "Close" : "閉じる",
    "Create card" : "カードを作成",
    "Select a card" : "カードを選択",
    "Select the card to link to a project" : "プロジェクトにリンクするカードを選択",
    "Link to card" : "カードへリンク",
    "File already exists" : "ファイルはすでに存在します",
    "A file with the name {filename} already exists." : "そのファイル名 {filename}はすでに存在します。",
    "Do you want to overwrite it?" : "上書きしますか？",
    "Overwrite file" : "ファイルを上書き",
    "Keep existing file" : "既存のファイルを残す",
    "This board is read only" : "このボードは読み込みのみです",
    "Drop your files to upload" : "アップロードするファイルをドロップしてください",
    "Add card" : "カードを追加",
    "Archived cards" : "カードをアーカイブ",
    "Add list" : "リストを追加",
    "List name" : "リスト名",
    "Active filters" : "有効なフィルター",
    "Apply filter" : "フィルターを適用",
    "Filter by tag" : "タグによるフィルター",
    "Filter by assigned user" : "割当ユーザーでフィルター",
    "Unassigned" : "未割り当て",
    "Filter by due date" : "期限でフィルター",
    "Overdue" : "期限超過",
    "Next 24 hours" : "次の24時間",
    "Next 7 days" : "次の7日間",
    "Next 30 days" : "次の30日間",
    "No due date" : "期限なし",
    "Clear filter" : "フィルターをクリア",
    "Hide archived cards" : "アーカイブされたカードを非表示にする",
    "Show archived cards" : "アーカイブされたカードを表示する",
    "Toggle compact mode" : "コンパクトモードの切り替え",
    "Open details" : "詳細を開く",
    "Details" : "詳細",
    "Loading board" : "ボードを読み込み中",
    "No lists available" : "利用可能なリストはありません",
    "Create a new list to add cards to this board" : "このボードにカードを追加するための新しいリストを作成します",
    "Board not found" : "ボードが見つかりません",
    "Sharing" : "共有中",
    "Tags" : "タグ",
    "Deleted items" : "削除されたアイテム",
    "Timeline" : "タイムライン",
    "Deleted lists" : "削除済みリスト",
    "Undo" : "元に戻す",
    "Deleted cards" : "削除済みのカード",
    "Share board with a user, group or circle …" : "ボードをユーザー、グループまたはサークルと共有…",
    "Searching for users, groups and circles …" : "ユーザー、グループ、サークルを検索しています…",
    "No participants found" : "参加者が見つかりません",
    "Board owner" : "ボード所有者",
    "(Group)" : "(グループ)",
    "(Circle)" : "(サークル)",
    "Can edit" : "編集可能",
    "Can share" : "共有可能",
    "Can manage" : "管理可能",
    "Owner" : "所有者",
    "Delete" : "削除",
    "Failed to create share with {displayName}" : "{displayName}との共有の作成に失敗しました",
    "Are you sure you want to transfer the board {title} to {user}?" : "本当にボード {title} を {user} に転送しますか？",
    "Transfer the board." : "ボードを転送します。",
    "Transfer" : "転送",
    "The board has been transferred to {user}" : "ボードが {user} に転送されました。",
    "Failed to transfer the board to {user}" : "{user} へのボードの転送に失敗しました",
    "Add a new list" : "新しいリストを追加",
    "Archive all cards" : "すべてのカードをアーカイブする",
    "Delete list" : "リストを削除",
    "Archive all cards in this list" : "このリストのすべてのカードをアーカイブする",
    "Add a new card" : "新しいカードを追加",
    "Card name" : "カード名",
    "List deleted" : "リストが削除されました",
    "Edit" : "編集",
    "Add a new tag" : "新しいタグを追加",
    "title and color value must be provided" : "タイトルと色の値を指定する必要があります",
    "Board name" : "ボード名",
    "Members" : "メンバー",
    "Upload new files" : "新しいファイルをアップロード",
    "Share from Files" : "ファイルから共有",
    "Pending share" : "共有を保留中",
    "Add this attachment" : "この添付ファイルを追加",
    "Show in Files" : "ファイルに表示",
    "Download" : "ダウンロード",
    "Remove attachment" : "添付ファイルを削除",
    "Delete Attachment" : "添付ファイルを削除",
    "Restore Attachment" : "添付ファイルを復元",
    "File to share" : "共有するファイル",
    "Invalid path selected" : "無効なパスが選択されました",
    "Open in sidebar view" : "サイドバービューで開く",
    "Open in bigger view" : "拡大表示で開く",
    "Attachments" : "添付ファイル",
    "Comments" : "コメント",
    "Modified" : "更新日時",
    "Created" : "作成時刻",
    "The title cannot be empty." : "タイトルを空にすることはできません。",
    "No comments yet. Begin the discussion!" : "まだコメントはありません。議論を始めましょう！",
    "Failed to load comments" : "コメントの読み込みに失敗しました",
    "Assign a tag to this card…" : "タグこのをカードに割り当てる…",
    "Assign to users" : "ユーザーに割り当てる",
    "Assign to users/groups/circles" : "ユーザー/グループ/サークルに割り当てる",
    "Assign a user to this card…" : "このカードをユーザーに割り当てる…",
    "Due date" : "期限",
    "Set a due date" : "期限を設定",
    "Remove due date" : "期限を削除",
    "Select Date" : "日付を選択",
    "Today" : "今日",
    "Tomorrow" : "明日",
    "Next week" : "来週",
    "Next month" : "来月",
    "Save" : "保存",
    "The comment cannot be empty." : "コメントを空にすることはできません。",
    "The comment cannot be longer than 1000 characters." : "コメントは1000文字を超えることはできません。",
    "In reply to" : "返信",
    "Cancel reply" : "返信をキャンセル",
    "Reply" : "返信",
    "Update" : "更新",
    "Description" : "説明",
    "(Unsaved)" : "(未保存)",
    "(Saving…)" : "(保存中…)",
    "Formatting help" : "ヘルプの書式設定",
    "Edit description" : "説明を編集",
    "View description" : "説明を表示",
    "Add Attachment" : "添付ファイルを追加",
    "Write a description …" : "説明を書く…",
    "Choose attachment" : "添付ファイルを選択",
    "(group)" : "(グループ)",
    "{count} comments, {unread} unread" : "コメント {count} 件あり、 {unread} 件未読",
    "Assign to me" : "自分に割り当てる",
    "Unassign myself" : "自分への割り当てを解除",
    "Move card" : "カードの移動",
    "Unarchive card" : "カードのアーカイブを解除する",
    "Archive card" : "カードをアーカイブ",
    "Delete card" : "カードを削除する",
    "Move card to another board" : "カードを他のボードに移動",
    "List is empty" : "リストが空です",
    "Card deleted" : "カードが削除されました",
    "seconds ago" : "数秒前",
    "All boards" : "すべてのボード",
    "Archived boards" : "アーカイブ済みのボード",
    "Shared with you" : "あなたと共有済み",
    "Use bigger card view" : "大きなカードビューを使用する",
    "Show boards in calendar/tasks" : "カレンダー/タスクでボードを表示する",
    "Limit deck usage of groups" : "デッキの使用をグループに制限",
    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "デッキ作成制限は、設定したグループに非所属のユーザーがボードを作成できないようにします。非所属ユーザーは共有されているボードでのみ作業できます。",
    "Board details" : "ボードの詳細",
    "Edit board" : "ボードを編集",
    "Clone board" : "ボードを複製",
    "Unarchive board" : "ボードのアーカイブを解除",
    "Archive board" : "ボードをアーカイブ",
    "Turn on due date reminders" : "期日のリマインダーをオンにする",
    "Turn off due date reminders" : "期日のリマインダーをオフにする",
    "Due date reminders" : "期日のリマインダー",
    "All cards" : "すべてのカード",
    "Assigned cards" : "割り当てられたカード",
    "No notifications" : "非通知",
    "Delete board" : "ボードを削除",
    "Board {0} deleted" : "ボード {0} 削除済み",
    "Only assigned cards" : "割り当てられたカードのみ",
    "No reminder" : "リマインダーなし",
    "An error occurred" : "エラーが発生しました",
    "Delete the board?" : "ボードを削除しますか？",
    "Loading filtered view" : "フィルタされたビューを読み込み中",
    "No due" : "日付なし",
    "Search for {searchQuery} in all boards" : "すべてのボードで{searchQuery}を検索します",
    "No results found" : "結果が見つかりません",
    "{stack} in {board}" : "{board} 内の {stack}",
    "No upcoming cards" : "今後のカードはありません",
    "upcoming cards" : "今後のカード",
    "Link to a board" : "ボードへのリンク",
    "Link to a card" : "カードへリンク",
    "Create a card" : "カードを作成",
    "Message from {author} in {conversationName}" : "{conversationName} で {author} からのメッセージ",
    "Something went wrong" : "何かがおかしいです",
    "Failed to upload {name}" : "{name}のアップロードに失敗しました",
    "Maximum file size of {size} exceeded" : "最大ファイルサイズ（{size}）を超えています",
    "Error creating the share" : "共有の作成中にエラーが発生しました",
    "Share with a Deck card" : "デッキのカードで共有する",
    "Share {file} with a Deck card" : "{file}をデッキのカードで共有する",
    "Share" : "共有",
    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "DeckはNextcloudと統合した、チームの個人計画とプロジェクトの組織化を目的としたカンバンスタイルの組織ツールです。\n\n\n- 📥 タスクをカードに追加して整理する\n- 📄 マークダウンで追加のメモを書き留めます\n- 🔖 より良い組織のためにラベルを割り当てる\n- 👥 あなたのチーム、友人、家族と共有する\n- 📎 ファイルを添付してマークダウンの説明に埋め込む\n- 💬 コメントを使ってあなたのチームと話し合う\n- ⚡ アクティビティの流れの変化を追跡する\n- 🚀 プロジェクトを整理する",
    "Are you sure you want to transfer the board {title} for {user} ?" : "本当に、 {user} のボード {title} を転送してもよろしいですか？",
    "Transfer the board for {user} successfully" : "{user} のボードの転送に成功しました",
    "Failed to transfer the board for {user}" : "{user} のボードの転送に失敗しました",
    "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "このボード{title}を削除してもよろしいですか？この操作はこのボードのデータすべてを削除します。",
    "This week" : "今週",
    "Are you sure you want to transfer the board {title} for {user}?" : "本当に、 {user} のボード {title} を転送してもよろしいですか？"
},
"nplurals=1; plural=0;");
