OC.L10N.register(
    "deck",
    {
    "You have created a new board {board}" : "Sie haben das neue Board {board} erstellt",
    "{user} has created a new board {board}" : "{user} hat das neue Board {board} erstellt",
    "You have deleted the board {board}" : "Sie haben das Board {board} gelöscht",
    "{user} has deleted the board {board}" : "{user} hat das Board {board} gelöscht",
    "You have restored the board {board}" : "Sie haben das Board {board} wiederhergestellt",
    "{user} has restored the board {board}" : "{user} hat das Board {board} wiederhergestellt",
    "You have shared the board {board} with {acl}" : "Sie haben das Board {board} mit {acl} geteilt",
    "{user} has shared the board {board} with {acl}" : "{user} hat das Board {board} mit {acl} geteilt",
    "You have removed {acl} from the board {board}" : "Sie haben {acl} vom Board {board} entfernt",
    "{user} has removed {acl} from the board {board}" : "{user} hat {acl} vom Board {board} entfernt",
    "You have renamed the board {before} to {board}" : "Sie haben das Board {before} in {board} umbenannt",
    "{user} has renamed the board {before} to {board}" : "{user} hat das Board {before} in {board} umbenannt",
    "You have archived the board {board}" : "Sie haben das Board {board} archiviert",
    "{user} has archived the board {before}" : "{user} hat das Board {before} archiviert",
    "You have unarchived the board {board}" : "Sie haben das Board {board} dearchiviert",
    "{user} has unarchived the board {before}" : "{user} hat das Board {before} dearchiviert",
    "You have created a new list {stack} on board {board}" : "Sie haben die neue Liste {stack} auf dem Board {board} erstellt",
    "{user} has created a new list {stack} on board {board}" : "{user} hat die neue Liste {stack} auf dem Board {board} erstellt",
    "You have renamed list {before} to {stack} on board {board}" : "Sie haben die Liste {before} auf dem Board {board} in {stack} umbenannt",
    "{user} has renamed list {before} to {stack} on board {board}" : "{user} hat die Liste {before} in {stack} auf dem Board {board} umbenannt",
    "You have deleted list {stack} on board {board}" : "Sie haben die Liste {stack} auf dem Board {board} gelöscht",
    "{user} has deleted list {stack} on board {board}" : "{user} hat die Liste {stack} aus dem Board {board} entfernt",
    "You have created card {card} in list {stack} on board {board}" : "Sie haben die Karte {card} in der Liste {stack} auf dem Board {board} erstellt",
    "{user} has created card {card} in list {stack} on board {board}" : "{user} hat die Karte {card} in der Liste {stack} auf dem Board {board} erstellt",
    "You have deleted card {card} in list {stack} on board {board}" : "Sie haben die Karte {card} in der Liste {stack} auf dem Board {board} gelöscht",
    "{user} has deleted card {card} in list {stack} on board {board}" : "{user} hat die Karte {card} in der Liste {stack} auf dem Board {board} gelöscht",
    "You have renamed the card {before} to {card}" : "Sie haben die Karte {before} in {card} umbenannt",
    "{user} has renamed the card {before} to {card}" : "{user} hat die Karte {before} in {card} umbenannt",
    "You have added a description to card {card} in list {stack} on board {board}" : "Sie haben der Karte {card} in der Liste {stack} auf dem Board {board} eine Beschreibung hinzugefügt",
    "{user} has added a description to card {card} in list {stack} on board {board}" : "{user} hat der Karte {card} in der Liste {stack} auf dem Board {board} eine Beschreibung hinzugefügt",
    "You have updated the description of card {card} in list {stack} on board {board}" : "Sie haben die Beschreibung der Karte {card} in der Liste {stack} auf dem Board {board} aktualisiert",
    "{user} has updated the description of the card {card} in list {stack} on board {board}" : "{user} hat die Beschreibung der Karte {card} in der Liste {stack} auf dem Board {board} aktualisiert",
    "You have archived card {card} in list {stack} on board {board}" : "Sie haben die Karte {card} in der Liste {stack} auf dem Board {board} archiviert",
    "{user} has archived card {card} in list {stack} on board {board}" : "{user} hat die Karte {card} in der Liste {stack} auf dem Board {board} archiviert",
    "You have unarchived card {card} in list {stack} on board {board}" : "Sie haben die Karte {card} in der Liste {stack} auf dem Board {board} dearchiviert",
    "{user} has unarchived card {card} in list {stack} on board {board}" : "{user} hat die Karte {card} in der Liste {stack} auf dem Board {board} dearchiviert",
    "You have removed the due date of card {card}" : "Sie haben das Fälligkeitsdatum der Karte {card} entfernt",
    "{user} has removed the due date of card {card}" : "{user} hat das Fälligkeitsdatum der Karte {card} entfernt",
    "You have set the due date of card {card} to {after}" : "Sie haben das Fälligkeitsdatum der Karte {card} auf {after} gesetzt",
    "{user} has set the due date of card {card} to {after}" : "{user} hat das Fälligkeitsdatum der Karte {card} auf {after} gesetzt",
    "You have updated the due date of card {card} to {after}" : "Sie haben das Fälligkeitsdatum der Karte {card} auf {after} aktualisiert",
    "{user} has updated the due date of card {card} to {after}" : "{user} hat das Fälligkeitsdatum der Karte {card} auf {after} aktualisiert",
    "You have added the tag {label} to card {card} in list {stack} on board {board}" : "Sie haben der Karte {card} in der Liste {stack} auf dem Board {board} das Schlagwort {label} hinzugefügt",
    "{user} has added the tag {label} to card {card} in list {stack} on board {board}" : "{user} hat der Karte {card} in der Liste {stack} auf dem Board {board} das Schlagwort {label} hinzugefügt",
    "You have removed the tag {label} from card {card} in list {stack} on board {board}" : "Sie haben von der Karte {card} in der Liste {stack} auf dem Board {board} das Schlagwort {label} entfernt",
    "{user} has removed the tag {label} from card {card} in list {stack} on board {board}" : "{user} hat von der Karte {card} in der Liste {stack} auf dem Board {board} das Schlagwort {label} entfernt",
    "You have assigned {assigneduser} to card {card} on board {board}" : "Sie haben {assigneduser} der Karte {card} auf dem Board {board} zugewiesen",
    "{user} has assigned {assigneduser} to card {card} on board {board}" : "{user} hat {assigneduser} der Karte {card} auf dem Board {board} zugewiesen",
    "You have unassigned {assigneduser} from card {card} on board {board}" : "Sie haben die Zuweisung von {assigneduser} zur Karte {card} auf dem Board {board} aufgehoben",
    "{user} has unassigned {assigneduser} from card {card} on board {board}" : "{user} hat die Zuweisung von {assigneduser} zur Karte {card} auf dem Board {board} aufgehoben",
    "You have moved the card {card} from list {stackBefore} to {stack}" : "Sie haben die Karte {card} von der Liste {stackBefore} nach {stack} verschoben",
    "{user} has moved the card {card} from list {stackBefore} to {stack}" : "{user} hat die Karte {card} von der Liste {stackBefore} nach {stack} verschoben",
    "You have added the attachment {attachment} to card {card}" : "Sie haben den Anhang {attachment} zur Karte {card} hinzugefügt",
    "{user} has added the attachment {attachment} to card {card}" : "{user} hat den Anhang {attachment} zur Karte {card} hinzugefügt",
    "You have updated the attachment {attachment} on card {card}" : "Sie haben den Anhang {attachment} der Karte {card} aktualisiert",
    "{user} has updated the attachment {attachment} on card {card}" : "{user} hat den Anhang {attachment} der Karte {card} aktualisiert",
    "You have deleted the attachment {attachment} from card {card}" : "Sie haben den Anhang {attachment} von der Karte {card} entfernt",
    "{user} has deleted the attachment {attachment} from card {card}" : "{user} hat den Anhang {attachment} von Karte {card} entfernt",
    "You have restored the attachment {attachment} to card {card}" : "Sie haben den Anhang {attachment} der Karte {card} wiederhergestellt",
    "{user} has restored the attachment {attachment} to card {card}" : "{user} hat den Anhang {attachment} der Karte {card} wiederhergestellt",
    "You have commented on card {card}" : "Sie haben die Karte {card} kommentiert",
    "{user} has commented on card {card}" : "{user} hat die Karte {card} kommentiert",
    "A <strong>card description</strong> inside the Deck app has been changed" : "Eine <strong>Kartenbeschreibung</strong> wurde innerhalb der Deck-App geändert",
    "Deck" : "Deck",
    "Changes in the <strong>Deck app</strong>" : "Änderungen in der <strong>Deck-App</strong>",
    "A <strong>comment</strong> was created on a card" : "Ein <strong>Kommentar</strong> zu einer Karte wurde erstellt",
    "Upcoming cards" : "Anstehende Karten",
    "Load more" : "Mehr laden",
    "Personal" : "Persönlich",
    "The card \"%s\" on \"%s\" has been assigned to you by %s." : "Die Karte \"%s\" auf \"%s\" wurde Ihnen von %s zugewiesen.",
    "{user} has assigned the card {deck-card} on {deck-board} to you." : "{user} hat Ihnen die Karte {deck-card} auf {deck-board} zugewiesen.",
    "The card \"%s\" on \"%s\" has reached its due date." : "Die Karte \"%s\" in \"%s\" ist überfällig.",
    "The card {deck-card} on {deck-board} has reached its due date." : "Die Karte {deck-card} in {deck-board} ist überfällig.",
    "%s has mentioned you in a comment on \"%s\"." : "%s hat Sie in einem Kommentar zu \"%s\" erwähnt.",
    "{user} has mentioned you in a comment on {deck-card}." : "{user} hat Sie in einem Kommentar zu {deck-card} erwähnt.",
    "The board \"%s\" has been shared with you by %s." : "Das Board \"%s\" wurde von %s mit Ihnen geteilt.",
    "{user} has shared {deck-board} with you." : "{user} hat das Board {deck-board} mit Ihnen geteilt.",
    "Card comments" : "Kartenkommentare",
    "%s on %s" : "%s von %s",
    "No data was provided to create an attachment." : "Es wurden keine Daten zum Erstellen eines Anhangs bereitgestellt.",
    "Finished" : "Abgeschlossen",
    "To review" : "Zu überprüfen",
    "Action needed" : "Handlung erforderlich",
    "Later" : "Später",
    "copy" : "Kopie",
    "To do" : "Offen",
    "Doing" : "In Arbeit",
    "Done" : "Erledigt",
    "Example Task 3" : "Beispielaufgabe 3",
    "Example Task 2" : "Beispielaufgabe 2",
    "Example Task 1" : "Beispielaufgabe 1",
    "The file was uploaded" : "Die Datei wurde hochgeladen",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Die hochgeladene Datei überschreitet die upload_max_filesize-Vorgabe in php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Die Datei ist größer als die MAX_FILE_SIZE-Vorgabe, die im HTML-Formular angegeben ist",
    "The file was only partially uploaded" : "Die Datei konnte nur teilweise hochgeladen werden",
    "No file was uploaded" : "Es wurde keine Datei hochgeladen",
    "Missing a temporary folder" : "Kein temporärer Ordner vorhanden",
    "Could not write file to disk" : "Die Datei konnte nicht auf die Festplatte geschrieben werden",
    "A PHP extension stopped the file upload" : "Eine PHP-Erweiterung hat das Hochladen der Datei gestoppt",
    "No file uploaded or file size exceeds maximum of %s" : "Keine Datei hochgeladen oder die Dateigröße überschreitet %s",
    "This comment has more than %s characters.\nAdded as an attachment to the card with name %s.\nAccessible on URL: %s." : "Dieser Kommentar hat mehr als %s Zeichen.\nAls Anhang der Karte mit dem Namen %s hinzugefügt.\nZugriff über die URL: %s.",
    "Card not found" : "Karte nicht gefunden",
    "Path is already shared with this card" : "Pfad wurde bereits mit dieser Karte geteilt",
    "Invalid date, date format must be YYYY-MM-DD" : "Ungültiges Datum, zulässiges Datumsformat: JJJJ-MM-TT",
    "Personal planning and team project organization" : "Persönliche Planung und Teamprojektorganisation",
    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in Markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your Markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Deck ist ein Organisationstool im Kanban-Stil für die persönliche Planung und Projektorganisation von Teams, die in Nextcloud integriert sind.\n\n\n- 📥 Fügen Sie Ihre Aufgaben zu den Karten hinzu und ordnen Sie diese\n- 📄 Zusätzliche Hinweise in der Abschrift notieren\n- 🔖 Zuweisen von Schlagworten für noch bessere Organisation\n- 👥 Teilen Sie mit Ihrem Team, Ihren Freunden oder Ihrer Familie\n- 📎 Fügen Sie Dateien hinzu und verwende diese in Ihren Markdown-Beschreibungen\n- 💬 Diskutieren Sie mit Ihrem Team mit Kommentaren\n- ⚡ Behalten Sie Überblick über Änderungen mit dem Aktivitäten-Stream\n- 🚀 Organisieren Sie Ihr Projekt",
    "Card details" : "Karten-Details",
    "Add board" : "Board hinzufügen",
    "Select the board to link to a project" : "Wählen Sie ein Board aus, um dieses mit einem Projekt zu verknüpfen",
    "Search by board title" : "Nach einem Board suchen",
    "Select board" : "Board auswählen",
    "Create a new card" : "Neue Karte erstellen",
    "Select a board" : "Ein Board auswählen",
    "Select a list" : "Eine Liste auswählen",
    "Card title" : "Titel der Karte",
    "Cancel" : "Abbrechen",
    "Creating the new card …" : "Neue Karte wird erstellt …",
    "Card \"{card}\" was added to \"{board}\"" : "Karte \"{card}\" wurde \"{board}\" hinzugefügt",
    "Open card" : "Karte öffnen",
    "Close" : "Schließen",
    "Create card" : "Karte erstellen",
    "Select a card" : "Eine Karte auswählen",
    "Select the card to link to a project" : "Wählen Sie die Karte aus, um diese mit einem Projekt zu verknüpfen",
    "Link to card" : "Mit einer Karte verknüpfen",
    "File already exists" : "Datei bereits vorhanden",
    "A file with the name {filename} already exists." : "Eine Datei mit diesem Namen {filename} existiert bereits.",
    "Do you want to overwrite it?" : "Möchten Sie überschreiben?",
    "Overwrite file" : "Datei überschreiben",
    "Keep existing file" : "Existierende Datei behalten",
    "This board is read only" : "Dieses Board ist schreibgeschützt",
    "Drop your files to upload" : "Dateien zum Hochladen hineinziehen",
    "Add card" : "Karte hinzufügen",
    "Archived cards" : "Archivierte Karten",
    "Add list" : "Liste hinzufügen",
    "List name" : "Listenname",
    "Active filters" : "Aktive Filter",
    "Apply filter" : "Filter anwenden",
    "Filter by tag" : "Nach Schlagwort filtern",
    "Filter by assigned user" : "Nach zugewiesenem Benutzer filtern",
    "Unassigned" : "Nicht zugewiesen",
    "Filter by due date" : "Nach Fälligkeitsdatum filtern",
    "Overdue" : "Überfällig",
    "Next 24 hours" : "Die nächsten 24 Stunden",
    "Next 7 days" : "Die nächsten 7 Tage",
    "Next 30 days" : "Die nächsten 30 Tage",
    "No due date" : "Kein Fälligkeitsdatum",
    "Clear filter" : "Filter zurücksetzen",
    "Hide archived cards" : "Archivierte Karten ausblenden",
    "Show archived cards" : "Archivierte Karten anzeigen",
    "Toggle compact mode" : "Kompaktmodus umschalten",
    "Open details" : "Details öffnen",
    "Details" : "Details",
    "Loading board" : "Lade Board",
    "No lists available" : "Keine Listen verfügbar",
    "Create a new list to add cards to this board" : "Erstellen Sie eine neue Liste, um diesem Board Karten hinzuzufügen",
    "Board not found" : "Board nicht gefunden",
    "Sharing" : "Teilen",
    "Tags" : "Schlagworte",
    "Deleted items" : "Gelöschte Objekte",
    "Timeline" : "Zeitachse",
    "Deleted lists" : "Gelöschte Listen",
    "Undo" : "Rückgängig",
    "Deleted cards" : "Gelöschte Karten",
    "Share board with a user, group or circle …" : "Board mit Benutzer, Gruppe oder Kreis teilen…",
    "Searching for users, groups and circles …" : "Suche nach Benutzern, Gruppen und Kreisen …",
    "No participants found" : "Keine Teilnehmer gefunden",
    "Board owner" : "Board-Besitzer",
    "(Group)" : "(Gruppe)",
    "(Circle)" : "(Kreis)",
    "Can edit" : "kann bearbeiten",
    "Can share" : "kann teilen",
    "Can manage" : "kann verwalten",
    "Owner" : "Besitzer",
    "Delete" : "Löschen",
    "Failed to create share with {displayName}" : "Fehler beim Erstellen der Freigabe mit dem Namen {displayName}",
    "Are you sure you want to transfer the board {title} to {user}?" : "Möchten Sie wirklich das Board {title} auf {user} übertragen?",
    "Transfer the board." : "Board übertragen.",
    "Transfer" : "Übertragen",
    "The board has been transferred to {user}" : "Das Board wurde auf {user} übertragen",
    "Failed to transfer the board to {user}" : "Das Board konnte nicht auf {user} übertragen werden",
    "Add a new list" : "Eine neue Liste hinzufügen",
    "Archive all cards" : "Alle Karten archivieren",
    "Unarchive all cards" : "Alle Karten dearchivieren",
    "Delete list" : "Liste löschen",
    "Archive all cards in this list" : "Alle Karten in dieser Liste archivieren",
    "Unarchive all cards in this list" : "Alle Karten in dieser Liste dearchivieren",
    "Add a new card" : "Neue Karte hinzufügen",
    "Card name" : "Kartenname",
    "List deleted" : "Liste gelöscht",
    "Edit" : "Bearbeiten",
    "Add a new tag" : "Neues Schlagwort hinzufügen",
    "title and color value must be provided" : "Titel und Farbwert müssen angegeben werden",
    "Board name" : "Boardname",
    "Members" : "Mitglieder",
    "Upload new files" : "Neue Dateien hochladen",
    "Share from Files" : "Aus Dateien heraus teilen",
    "Pending share" : "Ausstehende Freigabe",
    "Add this attachment" : "Diesen Anhang anhängen",
    "Show in Files" : "In Dateien anzeigen",
    "Download" : "Herunterladen",
    "Remove attachment" : "Anhang entfernen",
    "Delete Attachment" : "Anhang löschen",
    "Restore Attachment" : "Anhang wiederherstellen",
    "File to share" : "Zu teilende Datei",
    "Invalid path selected" : "Ungültiger Pfad ausgewählt",
    "Open in sidebar view" : "In Seitenleiste öffnen",
    "Open in bigger view" : "In größerer Ansicht öffnen",
    "Attachments" : "Anhänge",
    "Comments" : "Kommentare",
    "Modified" : "Geändert",
    "Created" : "Erstellt",
    "The title cannot be empty." : "Der Titel darf nicht leer sein.",
    "No comments yet. Begin the discussion!" : "Bislang keine Kommentare. Beginnen Sie die Diskussion!",
    "Failed to load comments" : "Das Laden der Kommentare ist fehlgeschlagen",
    "Assign a tag to this card…" : "Dieser Karte ein Schlagwort zuweisen…",
    "Assign to users" : "Benutzern zuweisen",
    "Assign to users/groups/circles" : "An Benutzer, Gruppen oder Kreise zuweisen",
    "Assign a user to this card…" : "Diese Karte einem Benutzer zuweisen…",
    "Due date" : "Fälligkeitsdatum",
    "Set a due date" : "Ein Ablaufdatum setzen",
    "Remove due date" : "Fälligkeitsdatum löschen",
    "Select Date" : "Datum auswählen",
    "Today" : "Heute",
    "Tomorrow" : "Morgen",
    "Next week" : "Nächste Woche",
    "Next month" : "Nächsten Monat",
    "Save" : "Speichern",
    "The comment cannot be empty." : "Der Kommentar darf nicht leer sein.",
    "The comment cannot be longer than 1000 characters." : "Der Kommentar darf nicht länger als 1000 Zeichen sein.",
    "In reply to" : "Als Antwort auf",
    "Cancel reply" : "Antwort abbrechen",
    "Reply" : "Antworten",
    "Update" : "Aktualisieren",
    "Description" : "Beschreibung",
    "(Unsaved)" : "(nicht gespeichert)",
    "(Saving…)" : "(Speichere…)",
    "Formatting help" : "Formatierungshilfe",
    "Edit description" : "Beschreibung bearbeiten",
    "View description" : "Beschreibung anzeigen",
    "Add Attachment" : "Anhang anhängen",
    "Write a description …" : "Beschreibung schreiben …",
    "Choose attachment" : "Anhang auswählen",
    "(group)" : "(Gruppe)",
    "Todo items" : "Aufgaben-Elemente",
    "{count} comments, {unread} unread" : "{count} Kommentare, {unread} ungelesen",
    "Edit card title" : "Kartentitel bearbeiten",
    "Assign to me" : "Mir zuweisen",
    "Unassign myself" : "Nicht mehr mir zuweisen",
    "Move card" : "Karte verschieben",
    "Unarchive card" : "Karte dearchivieren",
    "Archive card" : "Karte archivieren",
    "Delete card" : "Karte löschen",
    "Move card to another board" : "Karte auf ein anderes Board verschieben",
    "List is empty" : "Liste ist leer",
    "Card deleted" : "Karte gelöscht",
    "seconds ago" : "Gerade eben",
    "All boards" : "Alle Boards",
    "Archived boards" : "Archivierte Boards",
    "Shared with you" : "Mit Ihnen geteilt",
    "Deck settings" : "Deck-Einstellungen",
    "Use bigger card view" : "Größere Kartenansicht verwenden",
    "Show card ID badge" : "Abzeichen mit Karten-ID zeigen",
    "Show boards in calendar/tasks" : "Board in Kalender/Aufgaben anzeigen",
    "Limit deck usage of groups" : "Nutzung auf Gruppen einschränken",
    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Wenn Sie Deck einschränken, können Benutzer, die nicht zu diesen Gruppen gehören, keine eigenen Boards erstellen. Die Benutzer können weiterhin an Boards arbeiten, die für sie freigegeben wurden.",
    "Board details" : "Board-Details",
    "Edit board" : "Board bearbeiten",
    "Clone board" : "Board klonen",
    "Unarchive board" : "Board dearchivieren",
    "Archive board" : "Board archivieren",
    "Turn on due date reminders" : "Fälligkeitserinnerungen einschalten",
    "Turn off due date reminders" : "Fälligkeitserinnerungen ausschalten",
    "Due date reminders" : "Fälligkeitserinnerungen",
    "All cards" : "Alle Karten",
    "Assigned cards" : "Zugewiesene Karten",
    "No notifications" : "Keine Benachrichtigungen",
    "Delete board" : "Board löschen",
    "Board {0} deleted" : "Board {0} gelöscht",
    "Only assigned cards" : "Nur zugewiesene Karten",
    "No reminder" : "Keine Erinnerung",
    "An error occurred" : "Es ist ein Fehler aufgetreten",
    "Are you sure you want to delete the board {title}? This will delete all the data of this board including archived cards." : "Möchten Sie das Board {title} wirklich löschen? Dadurch werden alle Daten dieses Boards einschließlich archivierter Karten gelöscht.",
    "Delete the board?" : "Das Board löschen?",
    "Loading filtered view" : "Lade gefilterte Ansicht",
    "No due" : "Kein Fälligkeitsdatum",
    "Search for {searchQuery} in all boards" : "Suche nach {searchQuery} in allen Boards",
    "No results found" : "Keine Ergebnisse gefunden",
    "{stack} in {board}" : "{stack} auf {board}",
    "Click to expand description" : "Klicken, um die Beschreibung zu erweitern",
    "* Created on {created}\n* Last modified on {lastMod}\n* {nbAttachments} attachments\n* {nbComments} comments" : "* Erstellt am {created}\n* Zuletzt geändert am {lastMod}\n* {nbAttachments} Anhänge\n* {nbComments} Kommentare",
    "{nbCards} cards" : "{nbCards} Karten",
    "No upcoming cards" : "Keine anstehenden Karten",
    "upcoming cards" : "Anstehende Karten",
    "Due on {date}" : "Fällig am {date}",
    "Link to a board" : "Mit einem Board verknüpfen",
    "Link to a card" : "Mit einer Karte verknüpfen",
    "Create a card" : "Eine Karte erstellen",
    "Message from {author} in {conversationName}" : "Nachricht von {author} in {conversationName}",
    "Something went wrong" : "Etwas ist schiefgelaufen",
    "Failed to upload {name}" : "Fehler beim Hochladen von {name}",
    "Maximum file size of {size} exceeded" : "Maximale Dateigröße von {size} überschritten",
    "Error creating the share" : "Fehler beim Erstellen der Freigabe",
    "Share with a Deck card" : "Mit einer Deck-Karte teilen",
    "Share {file} with a Deck card" : "{file} mit einer Deck-Karte teilen",
    "Share" : "Freigeben",
    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Deck ist ein Organisationstool im Kanban-Stil für die persönliche Planung und Projektorganisation von Teams, die in Nextcloud integriert sind.\n\n\n- 📥 Fügen Sie Ihre Aufgaben zu den Karten hinzu und ordnen Sie diese\n- 📄 Zusätzliche Hinweise in der Abschrift notieren\n- 🔖 Zuweisen von Schlagworten für noch bessere Organisation\n- 👥 Teilen Sie mit Ihrem Team, Ihren Freunden oder Ihrer Familie\n- 📎 Fügen Sie Dateien hinzu und verwende diese in Ihren Markdown-Beschreibungen\n- 💬 Diskutieren Sie mit Ihrem Team mit Kommentaren\n- ⚡ Behalten Sie Überblick über Änderungen mit dem Aktivitäten-Stream\n- 🚀 Organisieren Sie Ihr Projekt",
    "Are you sure you want to transfer the board {title} for {user} ?" : "Möchten Sie wirklich das Board {title} an {user} übertragen?",
    "Transfer the board for {user} successfully" : "Das Board wurde an {user} übertragen",
    "Failed to transfer the board for {user}" : "Board konnte nicht an {user} übertragen werden",
    "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "Möchten Sie wirklich dieses Board {title} mit all seinen Daten löschen?",
    "This week" : "Diese Woche",
    "Are you sure you want to transfer the board {title} for {user}?" : "Möchten Sie wirklich das Board {title} an {user} übertragen?"
},
"nplurals=2; plural=(n != 1);");
