<?php return array(
    'root' => array(
        'name' => 'nextcloud/deck',
        'pretty_version' => 'v1.8.2',
        'version' => '1.8.2.0',
        'reference' => '70fa18f1869eca3dca3abdf9ee15698c395473b9',
        'type' => 'project',
        'install_path' => __DIR__ . '/../../',
        'aliases' => array(),
        'dev' => false,
    ),
    'versions' => array(
        'cogpowered/finediff' => array(
            'pretty_version' => '0.3.1',
            'version' => '0.3.1.0',
            'reference' => '339ddc8c3afb656efed4f2f0a80e5c3d026f8ea8',
            'type' => 'library',
            'install_path' => __DIR__ . '/../cogpowered/finediff',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'justinrainbow/json-schema' => array(
            'pretty_version' => '5.2.12',
            'version' => '5.2.12.0',
            'reference' => 'ad87d5a5ca981228e0e205c2bc7dfb8e24559b60',
            'type' => 'library',
            'install_path' => __DIR__ . '/../justinrainbow/json-schema',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'nextcloud/deck' => array(
            'pretty_version' => 'v1.8.2',
            'version' => '1.8.2.0',
            'reference' => '70fa18f1869eca3dca3abdf9ee15698c395473b9',
            'type' => 'project',
            'install_path' => __DIR__ . '/../../',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
    ),
);
