OC.L10N.register(
    "deck",
    {
    "You have created a new board {board}" : "Вы создали доску «{board}»",
    "{user} has created a new board {board}" : "{user} создал(а) доску «{board}»",
    "You have deleted the board {board}" : "Вы удалили доску «{board}»",
    "{user} has deleted the board {board}" : "{user} удалил(а) доску «{board}»",
    "You have restored the board {board}" : "Вы восстановили из корзины доску «{board}»",
    "{user} has restored the board {board}" : "{user} восстановил(а) доску «{board}» из корзины",
    "You have shared the board {board} with {acl}" : "Вы предоставили {acl} доступ к рабочей доске «{board}»",
    "{user} has shared the board {board} with {acl}" : "{user} предоставил(а) {acl} доступ к доске «{board}»",
    "You have removed {acl} from the board {board}" : "Вы закрыли {acl} доступ к рабочей доске «{board}»",
    "{user} has removed {acl} from the board {board}" : "{user} закрыл(а) {acl} доступ к рабочей доске «{board}»",
    "You have renamed the board {before} to {board}" : "Вы переименовали рабочую доску из «{before}» в «{board}»",
    "{user} has renamed the board {before} to {board}" : "{user} переименовал(а) рабочую доску из «{before}» в «{board}»",
    "You have archived the board {board}" : "Вы переместили доску «{board}» в архив",
    "{user} has archived the board {before}" : "{user} переместил(а) доску «{board}» в архив",
    "You have unarchived the board {board}" : "Вы восстановили доску «{board}» из архива",
    "{user} has unarchived the board {before}" : "{user} восстановил(а) доску «{before}» из архива",
    "You have created a new list {stack} on board {board}" : "Вы создали список «{stack}» на доске «{board}»",
    "{user} has created a new list {stack} on board {board}" : "{user} создал(а) список «{stack}» на доске «{board}»",
    "You have renamed list {before} to {stack} on board {board}" : "Вы переименовали список «{before}» в «{stack}» на доске «{board}»",
    "{user} has renamed list {before} to {stack} on board {board}" : "{user} переименовал(а) список «{before}» в «{stack}» на доске «{board}»",
    "You have deleted list {stack} on board {board}" : "Вы удалили список «{stack}» на доске «{board}»",
    "{user} has deleted list {stack} on board {board}" : "{user} удалил(а) список «{stack}» на доски «{board}»",
    "You have created card {card} in list {stack} on board {board}" : "Вы создали карточку «{card}» в списке «{stack}» на доске «{board}»",
    "{user} has created card {card} in list {stack} on board {board}" : "{user} создал(а) карточку «{card}» в списке «{stack}» на доске «{board}»",
    "You have deleted card {card} in list {stack} on board {board}" : "Вы удалили карточку «{card}» в списке «{stack}» на доске «{board}»",
    "{user} has deleted card {card} in list {stack} on board {board}" : "{user} удалил(а) карточку «{card}» в списке «{stack}» на доске «{board}»",
    "You have renamed the card {before} to {card}" : "Вы переименовали карточку из «{before}» в «{card}»",
    "{user} has renamed the card {before} to {card}" : "{user} переименовал(а) карточку из «{before}» в «{card}»",
    "You have added a description to card {card} in list {stack} on board {board}" : "Вы добавили описание карточки «{card}» в списке «{stack}» на доске «{board}»",
    "{user} has added a description to card {card} in list {stack} on board {board}" : "{user} добавил(а) описание карточки «{card}» в списке «{stack}» на доске «{board}»",
    "You have updated the description of card {card} in list {stack} on board {board}" : "Вы изменили описание карточки «{card}» в списке «{stack}» на доске «{board}»",
    "{user} has updated the description of the card {card} in list {stack} on board {board}" : "{user} изменил(а) описание карточки «{card}» в списке «{stack}» на доске «{board}»",
    "You have archived card {card} in list {stack} on board {board}" : "Вы переместили в архив карточку «{card}» из списка «{stack}» на доске «{board}»",
    "{user} has archived card {card} in list {stack} on board {board}" : "{user} переместил(а) в архив карточку «{card}» из списка «{stack}» на доске «{board}»",
    "You have unarchived card {card} in list {stack} on board {board}" : "Вы восстановили из архива карточку «{card}» в список «{stack}» на доске «{board}»",
    "{user} has unarchived card {card} in list {stack} on board {board}" : "{user} восстановил(а) из архива карточку «{card}» в список «{stack}» на доске «{board}»",
    "You have removed the due date of card {card}" : "Вы удалили срок исполнения по карточке «{card}»",
    "{user} has removed the due date of card {card}" : "{user} удалил(а) срок исполнения по карточке «{card}»",
    "You have set the due date of card {card} to {after}" : "Вы задали срок исполнения по карточке «{card}» до {after}",
    "{user} has set the due date of card {card} to {after}" : "{user} задал(а) срок исполнения по карточке «{card}» до {after}",
    "You have updated the due date of card {card} to {after}" : "Вы изменили срок исполнения по карточке «{card}» до {after}",
    "{user} has updated the due date of card {card} to {after}" : "{user} изменил(а) срок исполнения по карточке «{card}» до {after}",
    "You have added the tag {label} to card {card} in list {stack} on board {board}" : "Вы добавили метку «{label}» карточке «{card}» в списке «{stack}» на доске «{board}»",
    "{user} has added the tag {label} to card {card} in list {stack} on board {board}" : "{user} добавил(а) метку «{label}» карточке «{card}» в списке «{stack}» на доске «{board}»",
    "You have removed the tag {label} from card {card} in list {stack} on board {board}" : "Вы убрали метку «{label}» с карточки «{card}» в списке «{stack}» на доске «{board}»",
    "{user} has removed the tag {label} from card {card} in list {stack} on board {board}" : "{user} убрал(а) метку «{label}» с карточки «{card}» в списке «{stack}» на доске «{board}»",
    "You have assigned {assigneduser} to card {card} on board {board}" : "Вы назначили пользователю {assigneduser} карточку «{card}» с рабочей доски «{board}»",
    "{user} has assigned {assigneduser} to card {card} on board {board}" : "{user} назначил(а) пользователю {assigneduser} карточку «{card}» с рабочей доски «{board}»",
    "You have unassigned {assigneduser} from card {card} on board {board}" : "Вы отменили назначение пользователю {assigneduser} карточки «{card}» с рабочей доски «{board}»",
    "{user} has unassigned {assigneduser} from card {card} on board {board}" : "{user} отменил(а) назначение пользователю {assigneduser} карточки «{card}» с рабочей доски «{board}»",
    "You have moved the card {card} from list {stackBefore} to {stack}" : "Вы переместили карточку «{card}» из списка «{stackBefore}» в «{stack}»",
    "{user} has moved the card {card} from list {stackBefore} to {stack}" : "{user} переместил(а) карточку «{card}» из списка «{stackBefore}» в «{stack}»",
    "You have added the attachment {attachment} to card {card}" : "Вы добавили вложение «{attachment}» в карточку «{card}»",
    "{user} has added the attachment {attachment} to card {card}" : "{user} добавил(а) вложение «{attachment}» в карточку «{card}»",
    "You have updated the attachment {attachment} on card {card}" : "Вы изменили вложение «{attachment}» в карточке «{card}»",
    "{user} has updated the attachment {attachment} on card {card}" : "{user} изменил(а) вложение «{attachment}» в карточке «{card}»",
    "You have deleted the attachment {attachment} from card {card}" : "Вы удалили вложение «{attachment}» из карточки «{card}»",
    "{user} has deleted the attachment {attachment} from card {card}" : "{user} удалил(а) вложение «{attachment}» из карточки «{card}»",
    "You have restored the attachment {attachment} to card {card}" : "Вы восстановили вложение «{attachment}» в карточке «{card}»",
    "{user} has restored the attachment {attachment} to card {card}" : "{user} восстановил(а) из корзины файл «{attachment}» в карточке «{card}»",
    "You have commented on card {card}" : "Вы добавили комментарий к карточке «{card}»",
    "{user} has commented on card {card}" : "{user} добавил(а) комментарий к карточке «{card}»",
    "A <strong>card description</strong> inside the Deck app has been changed" : "В приложении Карточки изменено <strong>описание карточки</strong> ",
    "Deck" : "Карточки",
    "Changes in the <strong>Deck app</strong>" : "Изменения в <strong>приложении Карточки</strong>",
    "A <strong>comment</strong> was created on a card" : "Добавлен <strong>комментарий</strong> к карточке",
    "Upcoming cards" : "Ожидающие выполнения",
    "Load more" : "Загрузить больше",
    "Personal" : "Личное",
    "The card \"%s\" on \"%s\" has been assigned to you by %s." : "Вам назначена карточка «%s» с рабочей доски «%s»  пользователем %s.",
    "{user} has assigned the card {deck-card} on {deck-board} to you." : "{user} назначил Вам карточку {deck-card} из {deck-board}.",
    "The card \"%s\" on \"%s\" has reached its due date." : "Сегодня дата исполнения по карточке «%s» в «%s» .",
    "The card {deck-card} on {deck-board} has reached its due date." : "Сегодня дата исполнения по карточке {deck-card} в {deck-board}.",
    "%s has mentioned you in a comment on \"%s\"." : "Вы были упомянуты пользователем %s в комментарии «%s».",
    "{user} has mentioned you in a comment on {deck-card}." : "Вы были упомянуты пользователем {user} в комментарии {deck-card}.",
    "The board \"%s\" has been shared with you by %s." : "Вам предоставлен доступ к рабочей доске «%s» пользователем %s.",
    "{user} has shared {deck-board} with you." : "{user} предоставил(а) вам доступ к {deck-board}.",
    "Card comments" : "Комментарии карточки",
    "%s on %s" : "%s на %s",
    "No data was provided to create an attachment." : "Отсутствуют данные для создания вложения.",
    "Finished" : "Завершено",
    "To review" : "Проверить",
    "Action needed" : "Требуется действие",
    "Later" : "Позже",
    "copy" : "Копировать",
    "To do" : "Ожидающие выполнения",
    "Doing" : "В работе",
    "Done" : "Выполненные",
    "Example Task 3" : "Пример задачи 3",
    "Example Task 2" : "Пример задачи 2",
    "Example Task 1" : "Пример задачи 1",
    "The file was uploaded" : "Файл загружен",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Размер загружаемого файла превышает предел, заданный в параметре «upload_max_filesize» в файле php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Размер загруженного файла превышает заданное в HTML-форме значение параметра «MAX_FILE_SIZE»",
    "The file was only partially uploaded" : "Файл получен частично",
    "No file was uploaded" : "Файл не получен",
    "Missing a temporary folder" : "Отсутствует временный каталог",
    "Could not write file to disk" : "Невозможно записать файл на диск",
    "A PHP extension stopped the file upload" : "Загрузка файла была прервана модулем расширений PHP",
    "No file uploaded or file size exceeds maximum of %s" : "Файл не получен или его размер превышает %s",
    "This comment has more than %s characters.\nAdded as an attachment to the card with name %s.\nAccessible on URL: %s." : "Этот комментарий содержит более %s символов.\nКомментарий добавлен к карточке «%s» в виде вложения.\nПостоянный адрес этого комментария: %s.",
    "Card not found" : "Карточка не найдена",
    "Path is already shared with this card" : "Этот путь уже опубликован в карточке",
    "Invalid date, date format must be YYYY-MM-DD" : "Некорректный формат даты, дата должна быть в формате YYYY-MM-DD",
    "Personal planning and team project organization" : "Личное планирование и управление проектами для команд",
    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in Markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your Markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Карточки — приложение для Nextcloud, предоставляющее возможности личного планирования и управления проектами для рабочих групп в стиле канбан.\n\n\n- 📥 Создавайте карточки задач и упорядочите их;\n- 📄 Добавляйте описания задач с возможностью использовать формат разметки «markdown»;\n- 🔖 Присваивайте ярлыки для ещё лучшей организации;\n- 👥 Делитесь со своей командой, друзьями или семьей;\n- 📎 Вкладывайте файлы в виде ссылок в описании, используя формат разметки «Markdown»;\n- 💬 Обсуждайте в комментариях;\n- ⚡ Отслеживайте изменения в ленте событий;\n- 🚀 Сделайте свой проект более организованным.",
    "Card details" : "Свойства карточки",
    "Add board" : "Добавить доску",
    "Select the board to link to a project" : "Выберите рабочую доску, чтобы связать с проектом",
    "Search by board title" : "Поиск по заголовкам досок",
    "Select board" : "Выбор рабочей доски",
    "Create a new card" : "Создать карточку",
    "Select a board" : "Выберите доску",
    "Select a list" : "Выберите список",
    "Card title" : "Заголовок карточки",
    "Cancel" : "Отменить",
    "Creating the new card …" : "Создание новой карточки...",
    "Card \"{card}\" was added to \"{board}\"" : "Карточка «{card}» была добавлена в «{board}»",
    "Open card" : "Открыть карточку",
    "Close" : "Закрыть",
    "Create card" : "Создать карточку",
    "Select a card" : "Выберите карточку",
    "Select the card to link to a project" : "Выберите карточку для связывания с проектом",
    "Link to card" : "Ссылка на карточку",
    "File already exists" : "Файл уже существует",
    "A file with the name {filename} already exists." : "Файл «{filename}» уже существует.",
    "Do you want to overwrite it?" : "Перезаписать?",
    "Overwrite file" : "Перезаписать",
    "Keep existing file" : "Сохранить имеющийся",
    "This board is read only" : "Эта доска доступна только для чтения",
    "Drop your files to upload" : "Для загрузки файлов, перетащите их сюда",
    "Add card" : "Создать карточку",
    "Archived cards" : "Карточки в архиве",
    "Add list" : "Добавить список",
    "List name" : "Название списка",
    "Active filters" : "Активные фильтры",
    "Apply filter" : "Применить фильтр",
    "Filter by tag" : "Фильтр по меткам:",
    "Filter by assigned user" : "Фильтр по назначению:",
    "Unassigned" : "не назначен",
    "Filter by due date" : "Фильтр по сроку исполнения:",
    "Overdue" : "Просроченные",
    "Next 24 hours" : "Ближайшие 24 часа",
    "Next 7 days" : "Ближайшие 7 дней",
    "Next 30 days" : "Ближайшие 30 дней",
    "No due date" : "Без назначенной даты",
    "Clear filter" : "Сбросить фильтр",
    "Hide archived cards" : "Скрыть архивные карточки",
    "Show archived cards" : "Просмотреть или скрыть архивные карточки",
    "Toggle compact mode" : "Выбор компактного или обычного режима просмотра",
    "Open details" : "Открыть подробности",
    "Details" : "Свойства",
    "Loading board" : "Загрузка доски",
    "No lists available" : "Нет ни одного списка",
    "Create a new list to add cards to this board" : "Создайте список чтобы добавить карточки на эту доску",
    "Board not found" : "Доска не найдена",
    "Sharing" : "Общий доступ",
    "Tags" : "Метки",
    "Deleted items" : "Корзина",
    "Timeline" : "История",
    "Deleted lists" : "Удалённые списки",
    "Undo" : "Отменить",
    "Deleted cards" : "Карточки в корзине",
    "Share board with a user, group or circle …" : "Поделиться с пользователями, группами или кругами…",
    "Searching for users, groups and circles …" : "Поиск пользователей, групп или кругов...",
    "No participants found" : "Не удалось найти ни одного участника",
    "Board owner" : "Владелец доски",
    "(Group)" : "(Группа)",
    "(Circle)" : "(Круг)",
    "Can edit" : "Разрешить редактировать",
    "Can share" : "Разрешить делиться с другими",
    "Can manage" : "Разрешить изменять",
    "Owner" : "Владелец",
    "Delete" : "Удалить",
    "Failed to create share with {displayName}" : "Не удалось предоставить общий доступ для {displayName}",
    "Are you sure you want to transfer the board {title} to {user}?" : "Вы уверены, что хотите передать доску {title} пользователю {user}?",
    "Transfer the board." : "Перенесите доску.",
    "Transfer" : "Передача",
    "The board has been transferred to {user}" : "Доска была передана пользователю {user}",
    "Failed to transfer the board to {user}" : "Не удалось передать доску пользователю {user}",
    "Add a new list" : "Создать список",
    "Archive all cards" : "Переместить все карточки в архив",
    "Delete list" : "Удалить список",
    "Archive all cards in this list" : "Переместить в архив все карточки текущего списка",
    "Add a new card" : "Создать карточку",
    "Card name" : "Название карточки",
    "List deleted" : "Список удалён",
    "Edit" : "Редактировать",
    "Add a new tag" : "Добавить метку",
    "title and color value must be provided" : "необходимо указать цвет и название",
    "Board name" : "Название доски",
    "Members" : "Участники",
    "Upload new files" : "Передать на сервер новые файлы",
    "Share from Files" : "Опубликовать из приложения «Файлы»",
    "Pending share" : "Ожидающие публикации",
    "Add this attachment" : "Добавить это вложение",
    "Show in Files" : "Показать в приложении «Файлы»",
    "Download" : "Скачать",
    "Remove attachment" : "Убрать вложение",
    "Delete Attachment" : "Удалить вложение",
    "Restore Attachment" : "Восстановить вложение",
    "File to share" : "Файл для публикации",
    "Invalid path selected" : "Выбран некорректный путь",
    "Open in sidebar view" : "Открыть в боковой панели",
    "Open in bigger view" : "Открыть режиме подробного просмотра",
    "Attachments" : "Вложения",
    "Comments" : "Комментарии",
    "Modified" : "Изменено",
    "Created" : "Создано",
    "The title cannot be empty." : "Название не может быть пустым",
    "No comments yet. Begin the discussion!" : "Комментарии отсутствуют, начните обсуждение!",
    "Failed to load comments" : "Сбой при загрузке комментариев",
    "Assign a tag to this card…" : "Назначить метку этой карточке…",
    "Assign to users" : "Назначить пользователям",
    "Assign to users/groups/circles" : "Назначить пользователям / группам / кругам",
    "Assign a user to this card…" : "Назначить пользователя этой карточке…",
    "Due date" : "Срок исполнения",
    "Set a due date" : "Задать дату исполнения",
    "Remove due date" : "Удалить срок исполнения",
    "Select Date" : "Выберите дату",
    "Today" : "Сегодня",
    "Tomorrow" : "Завтра",
    "Next week" : "Следующая неделя",
    "Next month" : "Следующий месяц",
    "Save" : "Сохранить",
    "The comment cannot be empty." : "Комментарий не может быть пустым.",
    "The comment cannot be longer than 1000 characters." : "Комментарий не может быть длиннее 1 000 символов.",
    "In reply to" : "В ответ",
    "Cancel reply" : "Отменить ответ",
    "Reply" : "Ответить",
    "Update" : "Обновить",
    "Description" : "Описание",
    "(Unsaved)" : "(Не сохранен)",
    "(Saving…)" : "(Сохранение...)",
    "Formatting help" : "Справка по форматированию",
    "Edit description" : "Редактировать описание",
    "View description" : "Просмотреть описание",
    "Add Attachment" : "Добавить вложение",
    "Write a description …" : "Добавьте описание...",
    "Choose attachment" : "Выберите вложение",
    "(group)" : "(группа)",
    "{count} comments, {unread} unread" : "{count} комментариев, {unread} непрочитано",
    "Assign to me" : "Назначить себе",
    "Unassign myself" : "Отказаться от назначения",
    "Move card" : "Переместить карточку",
    "Unarchive card" : "Восстановить из архива",
    "Archive card" : "Переместить в архив",
    "Delete card" : "Удалить",
    "Move card to another board" : "Переместить карточку на другую доску",
    "List is empty" : "Список не содержит записей",
    "Card deleted" : "Карточка удалена",
    "seconds ago" : "несколько секунд назад",
    "All boards" : "Все доски",
    "Archived boards" : "Архив досок",
    "Shared with you" : "Предоставленные вам",
    "Use bigger card view" : "Режим просмотра с увеличенными карточками",
    "Show boards in calendar/tasks" : "Показывать карточки в календаре и задачах",
    "Limit deck usage of groups" : "Разрешить использовать приложение Карточки только участникам заданных групп",
    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Создание собственных рабочих досок пользователям, не входящим в заданные группы, будет заблокировано. Тем не менее, такие пользователи смогут продолжить работать с общими досками, к которым у них есть доступ.  ",
    "Board details" : "Свойства доски",
    "Edit board" : "Редактировать",
    "Clone board" : "Скопировать доску",
    "Unarchive board" : "Восстановить доску из архива",
    "Archive board" : "Переместить доску в архив",
    "Turn on due date reminders" : "Включить напоминания о сроке выполнения",
    "Turn off due date reminders" : "Отключить напоминания о сроке выполнения",
    "Due date reminders" : "Напоминания о сроке выполнения",
    "All cards" : "Для всех карточек",
    "Assigned cards" : "Назначенные карточки",
    "No notifications" : "Без уведомлений",
    "Delete board" : "Удалить доску",
    "Board {0} deleted" : "Доска {0} удалена",
    "Only assigned cards" : "Только для назначенных карточек",
    "No reminder" : "Не напоминать",
    "An error occurred" : "Произошла ошибка",
    "Delete the board?" : "Удалить доску?",
    "Loading filtered view" : "Выполняется отбор",
    "No due" : "Без назначенной даты",
    "Search for {searchQuery} in all boards" : "Искать {searchQuery} на всех досках",
    "No results found" : "Результаты отсутствуют",
    "{stack} in {board}" : "«{stack}» с доски «{board}»",
    "No upcoming cards" : "Отсутствуют карточки, ожидающие выполнения",
    "upcoming cards" : "карточки, ожидающие выполнения",
    "Link to a board" : "Ссылка на доску",
    "Link to a card" : "Ссылка на карточку",
    "Create a card" : "Создать карточку",
    "Message from {author} in {conversationName}" : "Сообщение от {author} из беседы «{conversationName}»",
    "Something went wrong" : "Неизвестная ошибка",
    "Failed to upload {name}" : "Не удалось передать на сервер {name}",
    "Maximum file size of {size} exceeded" : "Превышен максимально разрешённый размер файла в  {size}",
    "Error creating the share" : "Не удалось опубликовать",
    "Share with a Deck card" : "Опубликовать в приложении Карточки",
    "Share {file} with a Deck card" : "Опубликовать «{file}» в приложении Карточки",
    "Share" : "Опубликовать",
    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Карточки — приложение для Nextcloud, предоставляющее возможности личного планирования и управления проектами для рабочих групп в стиле канбан.\n\n\n- 📥 Создавайте карточки задач и упорядочите их;\n- 📄 Добавляйте описания задач с возможностью использовать формат разметки «markdown»;\n- 🔖 Присваивайте ярлыки для ещё лучшей организации;\n- 👥 Делитесь со своей командой, друзьями или семьей;\n- 📎 Вкладывайте файлы в виде ссылок в описании, используя формат разметки «markdown»;\n- 💬 Обсуждайте в комментариях;\n- ⚡ Отслеживайте изменения в ленте событий;\n- 🚀 Сделайте свой проект более организованным.",
    "Are you sure you want to transfer the board {title} for {user} ?" : "Вы уверены, что хотите передать доску {title} для {user}?",
    "Transfer the board for {user} successfully" : "Передача доски для {user} выполнена успешно",
    "Failed to transfer the board for {user}" : "Не удалось передать доску для {user}",
    "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "Подтвердите удаление доски «{title}»; это действие приведёт к удалению также все данных, принадлежащих этой доске.",
    "This week" : "Эта неделя",
    "Are you sure you want to transfer the board {title} for {user}?" : "Вы уверены, что хотите передать доску {title} для {user}?"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
