OC.L10N.register(
    "deck",
    {
    "Deck" : "Ажлын талбар",
    "Personal" : "Хувийн",
    "Finished" : "Дуусгасан",
    "To review" : "Дахин хянах",
    "Action needed" : "Үйлдэл шаардлагатай",
    "Later" : "Хойшлуулах",
    "copy" : "Хуулах ",
    "Done" : "Хийсэн",
    "Cancel" : "болиулах",
    "Close" : "Хаах",
    "Hide archived cards" : "Архивлагдсан картуудыг нуух",
    "Show archived cards" : "Архивлагдсан картуудыг харах",
    "Details" : "Дэлгэрэнгүй",
    "Sharing" : "Түгээх",
    "Tags" : "Tag-үүд",
    "Undo" : "буцах",
    "Can edit" : "Can edit",
    "Can share" : "Can share",
    "Owner" : "Эзэмшигч",
    "Delete" : "Устгах",
    "Edit" : "Засварлах",
    "Members" : "Гишүүд",
    "Download" : "Татах",
    "Attachments" : "Хавсралт",
    "Comments" : "Сэтгэгдлүүд",
    "Modified" : "Өөрчлөгдсөн",
    "Created" : "Үүсгэсэн",
    "Today" : "өнөөдөр",
    "Tomorrow" : "маргааш",
    "Save" : "Хадгалах",
    "Reply" : "хариулт",
    "Update" : "Шинэчлэх",
    "Description" : "Тайлбар",
    "(group)" : "(бүлэг)",
    "seconds ago" : "хоёрдахь өмнө",
    "Shared with you" : "тантай хуваалцсан",
    "No notifications" : "Мэдэгдэл байхгүй",
    "Share" : "Түгээх",
    "This week" : "7 хоног"
},
"nplurals=2; plural=(n != 1);");
