OC.L10N.register(
    "deck",
    {
    "Personal" : "Persoonlik",
    "copy" : "kopie",
    "Done" : "Gereed",
    "The file was uploaded" : "Die lêer is opgelaai",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Die opgelaaide lêer oorskry die upload_max_filesize riglyn in php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Die opgelaaide lêer oorskry die MAX_FILE_SIZE riglyn wat in die HTML vorm gespesifiseer is",
    "The file was only partially uploaded" : "Die lêer is slegs gedeeltelik op gelaai",
    "No file was uploaded" : "Geen lêer is opgelaai",
    "Missing a temporary folder" : "Ontbrekende tydelike gids",
    "A PHP extension stopped the file upload" : "’n PHP-uitbreiding het die oplaai gestaak",
    "Cancel" : "Kanselleer",
    "Close" : "Sluit",
    "File already exists" : "Lêer bestaan reeds",
    "Open details" : "Open besonderhede",
    "Details" : "Besonderhede",
    "Tags" : "Etikette",
    "No participants found" : "Geen deelnemers gevind",
    "Can edit" : "Kan redigeer",
    "Can share" : "Kan deel",
    "Owner" : "Eienaar",
    "Delete" : "Skrap",
    "Edit" : "Wysig",
    "Download" : "Laai af",
    "Comments" : "Kommentare",
    "Modified" : "Gewysig",
    "Created" : "Geskep",
    "Due date" : "Sperdatum",
    "Select Date" : "Kies Datum",
    "Today" : "Vandag",
    "Tomorrow" : "Môre",
    "Save" : "Stoor",
    "Reply" : "Antwoord",
    "Update" : "Werk by",
    "Description" : "Beskrywing",
    "seconds ago" : "sekondes gelede",
    "Shared with you" : "Met u gedeel",
    "No notifications" : "Geen kennisgewings",
    "An error occurred" : "'n Fout het voorgekom",
    "Share" : "Deel",
    "This week" : "Vandeesweek"
},
"nplurals=2; plural=(n != 1);");
