OC.L10N.register(
    "deck",
    {
    "Deck" : "Deck",
    "Personal" : "Personal",
    "%s on %s" : "%s en %s",
    "Finished" : "Finó",
    "Action needed" : "Precísase aición",
    "Later" : "Más sero",
    "Done" : "Fecho",
    "The file was uploaded" : "Xubióse'l ficheru",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "El ficheru xubíu perpasa la direutiva de xuba upload_max_filesize en php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "El ficheru xubíu perpasa la direutiva \"MAX_FILE_SIZE\" especificada nel formulariu HTML",
    "No file was uploaded" : "Nun se xubieron fichjeros",
    "Missing a temporary folder" : "Falta un direutoriu temporal",
    "Could not write file to disk" : "Nun pudo escribise nel discu'l ficheru",
    "A PHP extension stopped the file upload" : "Una estensión de PHP paró la xuba de ficheros",
    "Invalid date, date format must be YYYY-MM-DD" : "Data non válida, el formatu ha ser AAAA-MM-DD",
    "Cancel" : "Encaboxar",
    "Close" : "Zarrar",
    "File already exists" : "Yá esiste'l ficheru",
    "Show archived cards" : "Amosar tarxetes archivaes",
    "Details" : "Detalles",
    "Sharing" : "Compartiendo",
    "Tags" : "Etiquetes",
    "Undo" : "Desfacer",
    "Can edit" : "Can edit",
    "Can share" : "Can share",
    "Owner" : "Owner",
    "Delete" : "Desaniciar",
    "Edit" : "Editar",
    "Members" : "Miembros",
    "Download" : "Baxar",
    "Attachments" : "Axuntos",
    "Comments" : "Comentarios",
    "Modified" : "Modificóse'l",
    "Created" : "Creóse",
    "Today" : "Güei",
    "Tomorrow" : "Mañana",
    "Save" : "Guardar",
    "Reply" : "Rempuesta",
    "Update" : "Anovar",
    "Description" : "Descripción",
    "(group)" : "(grupu)",
    "seconds ago" : "hai segundos",
    "Shared with you" : "Shared with you",
    "No notifications" : "Ensin avisos",
    "Share" : "Share",
    "This week" : "Esta selmana"
},
"nplurals=2; plural=(n != 1);");
