OC.L10N.register(
    "deck",
    {
    "You have created a new board {board}" : "Hai creato una nuova lavagna {board}",
    "{user} has created a new board {board}" : "{user} ha creato una nuova lavagna {board}",
    "You have deleted the board {board}" : "Hai eliminato la lavagna {board}",
    "{user} has deleted the board {board}" : "{user} ha eliminato la lavagna {board}",
    "You have restored the board {board}" : "Hai ripristinato la lavagna {board}",
    "{user} has restored the board {board}" : "{user} ha ripristinato la lavagna {board}",
    "You have shared the board {board} with {acl}" : "Hai condiviso la lavagna {board} con {acl}",
    "{user} has shared the board {board} with {acl}" : "{user} ha condiviso la lavagna {board} con {acl}",
    "You have removed {acl} from the board {board}" : "Hai rimosso {acl} dalla lavagna {board}",
    "{user} has removed {acl} from the board {board}" : "{user} ha rimosso {acl} dalla lavagna {board}",
    "You have renamed the board {before} to {board}" : "Hai rinominato la lavagna {before} in {board}",
    "{user} has renamed the board {before} to {board}" : "{user} ha rinominato la lavagna {before} in {board}",
    "You have archived the board {board}" : "Hai archiviato la lavagna {board}",
    "{user} has archived the board {before}" : "{user} ha archiviato la lavagna {before}",
    "You have unarchived the board {board}" : "Hai annullato l'archiviazione della lavagna {board}",
    "{user} has unarchived the board {before}" : "{user} ha annullato l'archiviazione della lavagna {board}",
    "You have created a new list {stack} on board {board}" : "Hai creato un nuovo elenco {stack} sulla lavagna {board}",
    "{user} has created a new list {stack} on board {board}" : "{user} ha creato un nuovo elenco {stack} sulla lavagna {board}",
    "You have renamed list {before} to {stack} on board {board}" : "Hai rinominato l'elenco {before} in {stack} sulla lavagna {board}",
    "{user} has renamed list {before} to {stack} on board {board}" : "{user} ha rinominato l'elenco {before} in {stack} sulla lavagna {board}",
    "You have deleted list {stack} on board {board}" : "Hai eliminato l'elenco {stack} sulla lavagna {board}",
    "{user} has deleted list {stack} on board {board}" : "{user} ha eliminato l'elenco {stack} sulla lavagna {board}",
    "You have created card {card} in list {stack} on board {board}" : "Hai creato la scheda {card} nell'elenco {stack} sulla lavagna {board}",
    "{user} has created card {card} in list {stack} on board {board}" : "{user} ha creato la scheda {card} nell'elenco {stack} sulla lavagna {board}",
    "You have deleted card {card} in list {stack} on board {board}" : "Hai eliminato la scheda {card} nell'elenco {stack} sulla lavagna {board}",
    "{user} has deleted card {card} in list {stack} on board {board}" : "{user} ha creato la scheda {card} nell'elenco {stack} sulla lavagna {board}",
    "You have renamed the card {before} to {card}" : "Hai rinominato la scheda {before} in {card}",
    "{user} has renamed the card {before} to {card}" : "{user} ha rinominato la scheda {before} in {card}",
    "You have added a description to card {card} in list {stack} on board {board}" : "Hai aggiunto una descrizione alla scheda {card} nell'elenco {stack} sulla lavagna {board}",
    "{user} has added a description to card {card} in list {stack} on board {board}" : "{user} ha aggiunto una descrizione alla scheda {card} nell'elenco {stack} sulla lavagna {board}",
    "You have updated the description of card {card} in list {stack} on board {board}" : "Hai aggiornato la descrizione della scheda {card} nell'elenco {stack} sulla lavagna {board}",
    "{user} has updated the description of the card {card} in list {stack} on board {board}" : "{user} ha aggiornato la descrizione della scheda {card} nell'elenco {stack} sulla lavagna {board}",
    "You have archived card {card} in list {stack} on board {board}" : "Hai archiviato la scheda {card} nell'elenco {stack} sulla lavagna {board}",
    "{user} has archived card {card} in list {stack} on board {board}" : "{user} ha archiviato la scheda {card} nell'elenco {stack} sulla lavagna {board}",
    "You have unarchived card {card} in list {stack} on board {board}" : "Hai annullato l'archiviazione della scheda {card} nell'elenco {stack} sulla lavagna {board}",
    "{user} has unarchived card {card} in list {stack} on board {board}" : "{user} ha annullato l'archiviazione della scheda {card} nell'elenco {stack} sulla lavagna {board}",
    "You have removed the due date of card {card}" : "Hai rimosso la data di scadenza della scheda {card}",
    "{user} has removed the due date of card {card}" : "{user} ha rimosso la data di scadenza dalla scheda {card}",
    "You have set the due date of card {card} to {after}" : "Hai impostato la data di scadenza della scheda {card} a {after}",
    "{user} has set the due date of card {card} to {after}" : "{user} ha impostato la data di scadenza della scheda {card} a {after}",
    "You have updated the due date of card {card} to {after}" : "Hai aggiornato la data di scadenza della scheda {card} a {after}",
    "{user} has updated the due date of card {card} to {after}" : "{user} ha aggiornato la data di scadenza della scheda {card} a {after}",
    "You have added the tag {label} to card {card} in list {stack} on board {board}" : "Hai aggiunto l'etichetta {label} alla scheda {card} nell'elenco {stack} sulla lavagna {board}",
    "{user} has added the tag {label} to card {card} in list {stack} on board {board}" : "{user} ha aggiunto l'etichetta {label} alla scheda {card} nell'elenco {stack} sulla lavagna {board}",
    "You have removed the tag {label} from card {card} in list {stack} on board {board}" : "Hai rimosso l'etichetta {label} alla scheda {card} nell'elenco {stack} sulla lavagna {board}",
    "{user} has removed the tag {label} from card {card} in list {stack} on board {board}" : "{user} ha rimosso l'etichetta {label} alla scheda {card} nell'elenco {stack} sulla lavagna {board}",
    "You have assigned {assigneduser} to card {card} on board {board}" : "Hai assegnato {assigneduser} alla scheda {card} sulla lavagna {board}",
    "{user} has assigned {assigneduser} to card {card} on board {board}" : "{user} ha assegnato {assigneduser} alla scheda {card} sulla lavagna {board}",
    "You have unassigned {assigneduser} from card {card} on board {board}" : "Hai annullato l'assegnazione di {assigneduser} da scheda {card} sulla lavagna {board}",
    "{user} has unassigned {assigneduser} from card {card} on board {board}" : "{user} ha annullato l'assegnazione di {assigneduser} dalla scheda {card} sulla lavagna {board}",
    "You have moved the card {card} from list {stackBefore} to {stack}" : "Hai spostato la scheda {card} dall'elenco {stackBefore} in {stack}",
    "{user} has moved the card {card} from list {stackBefore} to {stack}" : "{user} ha spostato la scheda {card} dall'elenco {stackBefore} in {stack}",
    "You have added the attachment {attachment} to card {card}" : "Hai aggiunto l'allegato {attachment} alla scheda {card}",
    "{user} has added the attachment {attachment} to card {card}" : "{user} ha aggiunto l'allegato {attachment} alla scheda {card}",
    "You have updated the attachment {attachment} on card {card}" : "Hai aggiornato l'allegato {attachment} sulla scheda {card}",
    "{user} has updated the attachment {attachment} on card {card}" : "{user} ha aggiornato l'allegato {attachment} nella scheda {card}",
    "You have deleted the attachment {attachment} from card {card}" : "Hai eliminato l'allegato {attachment} dalla scheda {card}",
    "{user} has deleted the attachment {attachment} from card {card}" : "{user} ha eliminato l'allegato {attachment} dalla scheda {card}",
    "You have restored the attachment {attachment} to card {card}" : "Hai ripristinato l'allegato {attachment} nella scheda {card}",
    "{user} has restored the attachment {attachment} to card {card}" : "{user} ha ripristinato l'allegato {attachment} nella scheda {card}",
    "You have commented on card {card}" : "Hai commentato sulla scheda {card}",
    "{user} has commented on card {card}" : "{user} ha commentato sulla scheda {card}",
    "A <strong>card description</strong> inside the Deck app has been changed" : "La <strong>descrizione di una scheda</strong> nell'applicazione Deck è stata modificata",
    "Deck" : "Deck",
    "Changes in the <strong>Deck app</strong>" : "Modifiche nell'<strong>applicazione Deck</strong>",
    "A <strong>comment</strong> was created on a card" : "Un <strong>commento</strong> è stato creato su una scheda",
    "Upcoming cards" : "Prossime schede",
    "Load more" : "Carica altro",
    "Personal" : "Personale",
    "The card \"%s\" on \"%s\" has been assigned to you by %s." : "La scheda \"%s\" in \"%s\" ti è stata assegnata da %s.",
    "{user} has assigned the card {deck-card} on {deck-board} to you." : "{user} ti ha assegnato la scheda {deck-card} in {deck-board}.",
    "The card \"%s\" on \"%s\" has reached its due date." : "La scheda \"%s\" in \"%s\" ha raggiunto la sua data di scadenza.",
    "The card {deck-card} on {deck-board} has reached its due date." : "La scheda {deck-card} in {deck-board} ha raggiunto la sua data di scadenza.",
    "%s has mentioned you in a comment on \"%s\"." : "%s ti ha menzionato in un commento su \"%s\".",
    "{user} has mentioned you in a comment on {deck-card}." : "{user} ti ha menzionato in un commento su {deck-card}.",
    "The board \"%s\" has been shared with you by %s." : "La lavagna \"%s\" è stata condivisa con te da %s.",
    "{user} has shared {deck-board} with you." : "{user} ha condiviso {deck-board} con te.",
    "Card comments" : "Commenti",
    "%s on %s" : "%s su %s",
    "No data was provided to create an attachment." : "Non è  stato fornito alcun dato per creare un allegato.",
    "Finished" : "Finito",
    "To review" : "Da revisionare",
    "Action needed" : "Azione necessaria",
    "Later" : "Dopo",
    "copy" : "copia",
    "To do" : "Da fare",
    "Doing" : "In corso",
    "Done" : "Fatto",
    "Example Task 3" : "Attività di esempio 3",
    "Example Task 2" : "Attività di esempio 2",
    "Example Task 1" : "Attività di esempio 1",
    "The file was uploaded" : "Il file è stato caricato",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Il file caricato supera la direttiva upload_max_filesize in php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Il file caricato supera la direttiva MAX_FILE_SIZE specificata nel modulo HTML",
    "The file was only partially uploaded" : "Il file è stato caricato solo parzialmente",
    "No file was uploaded" : "Non è stato caricato alcun file",
    "Missing a temporary folder" : "Manca una cartella temporanea",
    "Could not write file to disk" : "Impossibile scrivere il file su disco",
    "A PHP extension stopped the file upload" : "Un'estensione PHP ha fermato il caricamento del file",
    "No file uploaded or file size exceeds maximum of %s" : "Nessun file caricato o la dimensione del file supera il massimo di %s",
    "This comment has more than %s characters.\nAdded as an attachment to the card with name %s.\nAccessible on URL: %s." : "Questo commento contiene più di %s caratteri.\nAggiunto come allegato alla scheda con nome %s.\nAccessibile su URL: %s.",
    "Card not found" : "Scheda non trovata",
    "Path is already shared with this card" : "Il percorso è già condiviso con questa scheda",
    "Invalid date, date format must be YYYY-MM-DD" : "Data non valida, il formato della data deve essere AAAA-MM-GG",
    "Personal planning and team project organization" : "Pianificazione personale e organizzazione dei progetti di squadra",
    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in Markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your Markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Deck è uno strumento di organizzazione in stile kanban destinato alla pianificazione personale e all'organizzazione di progetti per squadre integrato con Nextcloud.\n\n\n- 📥 Aggiungi le tue attività alle schede e tienile in ordine\n- 📄 Scrivi note aggiuntive in Markdown\n- 🔖 Assegna etichette per un'organizzazione ancora migliore\n- 👥 Condividi con la tua squadra, amici o famiglia\n- 📎 Allega file e integrali nella tua descrizione Markdown\n- 💬 Discuti con la tua squadra utilizzando i commenti\n- ⚡ Tieni traccia dei cambiamenti nel flusso delle attività\n- 🚀 Organizza il tuo progetto",
    "Card details" : "Dettagli scheda",
    "Add board" : "Aggiungi lavagna",
    "Select the board to link to a project" : "Seleziona la lavagna da collegare a un progetto",
    "Search by board title" : "Cerca per titolo della lavagna",
    "Select board" : "Seleziona lavagna",
    "Create a new card" : "Crea una nuova scheda",
    "Select a board" : "Seleziona una lavagna",
    "Select a list" : "Seleziona un elenco",
    "Card title" : "Titolo scheda",
    "Cancel" : "Annulla",
    "Creating the new card …" : "Creazione della nuova scheda...",
    "Card \"{card}\" was added to \"{board}\"" : "La scheda \"{card}\" è stata aggiunta a \"{board}\"",
    "Open card" : "Apri scheda",
    "Close" : "Chiudi",
    "Create card" : "Crea scheda",
    "Select a card" : "Seleziona una scheda",
    "Select the card to link to a project" : "Seleziona la scheda da collegare a un progetto",
    "Link to card" : " Collega una scheda",
    "File already exists" : "Il file esiste già",
    "A file with the name {filename} already exists." : "Un file con il nome {filename} esiste già.",
    "Do you want to overwrite it?" : "Vuoi sovrascriverlo?",
    "Overwrite file" : "Sovrascrivi file",
    "Keep existing file" : "Mantieni file esistente",
    "This board is read only" : "Questa lavagna è in sola lettura",
    "Drop your files to upload" : "Rilascia i tuoi file per caricarli",
    "Add card" : "Aggiungi scheda",
    "Archived cards" : "Schede archiviate",
    "Add list" : "Aggiungi elenco",
    "List name" : "Nome elenco",
    "Apply filter" : "Applica filtro",
    "Filter by tag" : "Filtra per etichette",
    "Filter by assigned user" : "Filtra per utente assegnato",
    "Unassigned" : "Non assegnato",
    "Filter by due date" : "Filtra per data di scadenza",
    "Overdue" : "Scadenza",
    "Next 24 hours" : "Prossime 24 ore",
    "Next 7 days" : "7 giorni successivi",
    "Next 30 days" : "30 giorni successivi",
    "No due date" : "Nessuna data di scadenza",
    "Clear filter" : "Pulisci il filtro",
    "Hide archived cards" : "Nascondi le schede archiviate",
    "Show archived cards" : "Mostra le carte archiviate",
    "Toggle compact mode" : "Commuta la modalità compatta",
    "Open details" : "Apri i dettagli",
    "Details" : "Dettagli",
    "Loading board" : "Caricamento lavagna",
    "No lists available" : "Nessun elenco disponibile",
    "Create a new list to add cards to this board" : "Crea un nuovo elenco per aggiungere schede a questa lavagna",
    "Board not found" : "Lavagna non trovata",
    "Sharing" : "Condivisione",
    "Tags" : "Etichette",
    "Deleted items" : "Elementi eliminati",
    "Timeline" : "Linea temporale",
    "Deleted lists" : "Elenchi eliminati",
    "Undo" : "Annulla",
    "Deleted cards" : "Schede eliminate",
    "Share board with a user, group or circle …" : "Condividi lavagna con un utente, gruppo o cerchia…",
    "Searching for users, groups and circles …" : "Ricerca di utenti, gruppi e cerchie…",
    "No participants found" : "Nessun partecipante trovato",
    "Board owner" : "Proprietario della lavagna",
    "(Group)" : "(Gruppo)",
    "(Circle)" : "(Cerchia)",
    "Can edit" : "Può modificare",
    "Can share" : "Può condividere",
    "Can manage" : "Può gestire",
    "Owner" : "Proprietario",
    "Delete" : "Elimina",
    "Failed to create share with {displayName}" : "Creazione della condivisione con {displayName} non riuscita",
    "Transfer" : "Trasferisci",
    "Add a new list" : "Aggiungi un nuovo elenco",
    "Archive all cards" : "Archivia tutte le schede",
    "Delete list" : "Elimina elenco",
    "Archive all cards in this list" : "Archivia tutte le schede in questo elenco",
    "Add a new card" : "Aggiungi una nuova scheda",
    "Card name" : "Nome scheda",
    "List deleted" : "Elenco eliminato",
    "Edit" : "Modifica",
    "Add a new tag" : "Aggiungi una nuova etichetta",
    "title and color value must be provided" : "devono essere forniti il titolo e il valore del colore",
    "Board name" : "Nome della lavagna",
    "Members" : "Membri",
    "Upload new files" : "Carica nuovi file",
    "Share from Files" : "Condividi da File",
    "Pending share" : "Condivisione in attesa",
    "Add this attachment" : "Aggiungi questo allegato",
    "Show in Files" : "Mostra in File",
    "Download" : "Scarica",
    "Remove attachment" : "Rimuovi allegato",
    "Delete Attachment" : "Elimina allegato",
    "Restore Attachment" : "Ripristina allegato",
    "File to share" : "File da condividere",
    "Invalid path selected" : "Percorso selezionato non valido",
    "Open in sidebar view" : "Apri nella barra laterale",
    "Open in bigger view" : "Apri in una vista più grande",
    "Attachments" : "Allegati",
    "Comments" : "Commenti",
    "Modified" : "Modificato",
    "Created" : "Creato il",
    "The title cannot be empty." : "Il titolo non può essere vuoto.",
    "No comments yet. Begin the discussion!" : "Ancora nessun commento. Inizia la discussione.",
    "Failed to load comments" : "Caricamento commenti non riuscito",
    "Assign a tag to this card…" : "Assegna un'etichetta a questa scheda…",
    "Assign to users" : "Assegna a utenti",
    "Assign to users/groups/circles" : "Assegna a utenti/gruppi/cerchie",
    "Assign a user to this card…" : "Assegna un utente a questa scheda…",
    "Due date" : "Data di scadenza",
    "Set a due date" : "Imposta una data di scadenza",
    "Remove due date" : "Rimuovi data di scadenza",
    "Select Date" : "Seleziona data",
    "Today" : "Oggi",
    "Tomorrow" : "Domani",
    "Next week" : "Settimana successiva",
    "Next month" : "Mese successivo",
    "Save" : "Salva",
    "The comment cannot be empty." : "Il commento non può essere vuoto.",
    "The comment cannot be longer than 1000 characters." : "Il commento non può essere più lungo di 1000 caratteri.",
    "In reply to" : "In risposta a",
    "Cancel reply" : "Annulla risposta",
    "Reply" : "Rispondi",
    "Update" : "Aggiorna",
    "Description" : "Descrizione",
    "(Unsaved)" : "(Non salvata)",
    "(Saving…)" : "(Salvataggio...)",
    "Formatting help" : "Guida di formattazione",
    "Edit description" : "Modifica descrizione",
    "View description" : "Visualizza descrizione",
    "Add Attachment" : "Aggiungi allegato",
    "Write a description …" : "Scrivi una descrizione…",
    "Choose attachment" : "Scegli allegato",
    "(group)" : "(gruppo)",
    "{count} comments, {unread} unread" : "{count} commenti, {unread} non letti",
    "Assign to me" : "Assegna a me",
    "Unassign myself" : "Rimuovi assegnazione da me",
    "Move card" : "Sposta scheda",
    "Unarchive card" : "Recupera lavagna dall'archivio",
    "Archive card" : "Archivia scheda",
    "Delete card" : "Elimina scheda",
    "Move card to another board" : "Sposta scheda in un'altra lavagna",
    "List is empty" : "L'elenco è vuoto",
    "Card deleted" : "Scheda eliminata",
    "seconds ago" : "secondi fa",
    "All boards" : "Tutte le lavagne",
    "Archived boards" : "Lavagne archiviate",
    "Shared with you" : "Condiviso con te",
    "Use bigger card view" : "Usa la vista con schede più grandi",
    "Show boards in calendar/tasks" : "Mostra le lavagne in calendario/attività",
    "Limit deck usage of groups" : "Limita utilizzo di Deck dei gruppi",
    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "La limitazione di Deck impedirà agli utenti che non fanno parte di tali gruppi di creare le proprie lavagne. Gli utenti saranno ancora in grado di lavorare sulle lavagne che sono state condivise con loro,",
    "Board details" : "Dettagli lavagna",
    "Edit board" : "Modifica lavagna",
    "Clone board" : "Clona lavagna",
    "Unarchive board" : "Recupera lavagna dall'archivio",
    "Archive board" : "Archivia lavagna",
    "Turn on due date reminders" : "Attiva promemoria per le date di scadenza",
    "Turn off due date reminders" : "Disattiva promemoria per le date di scadenza",
    "Due date reminders" : "Promemoria delle date di scadenza",
    "All cards" : "Tutte le schede",
    "Assigned cards" : "Schede assegnate",
    "No notifications" : "Nessuna notifica",
    "Delete board" : "Elimina lavagna",
    "Board {0} deleted" : "Lavagna {0} eliminata",
    "Only assigned cards" : "Solo le schede assegnate",
    "No reminder" : "Nessun promemoria",
    "An error occurred" : "Si è verificato un errore",
    "Delete the board?" : "Vuoi eliminare la lavagna?",
    "Loading filtered view" : "Caricamento della vista filtrata",
    "No due" : "Nessuna scadenza",
    "Search for {searchQuery} in all boards" : "Risultato di ricerca per \"{search}\" in tutte le lavagne",
    "No results found" : "Nessun risultato trovato",
    "{stack} in {board}" : "{stack} in {board}",
    "No upcoming cards" : "Nessuna scheda rimasta",
    "upcoming cards" : "prossime schede",
    "Link to a board" : "Collega a una lavagna",
    "Link to a card" : " Collega a una scheda",
    "Create a card" : "Crea una scheda",
    "Message from {author} in {conversationName}" : "Messaggio da {author} in {conversationName}",
    "Something went wrong" : "Qualcosa non ha funzionato",
    "Failed to upload {name}" : "Caricamenti di {name} non riuscito",
    "Maximum file size of {size} exceeded" : "Dimensione massima dei file di {size} superata",
    "Error creating the share" : "Errore durante la creazione della condivisione",
    "Share with a Deck card" : "Condividi con una scheda di Deck",
    "Share {file} with a Deck card" : "Condividi {file} con una scheda di Deck",
    "Share" : "Condividi",
    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Deck è uno strumento di organizzazione in stile kanban destinato alla pianificazione personale e all'organizzazione di progetti per squadre integrato con Nextcloud.\n\n\n- 📥 Aggiungi le tue attività alle schede e tienile in ordine\n- 📄 Scrivi note aggiuntive in markdown\n- 🔖 Assegna etichette per un'organizzazione ancora migliore\n- 👥 Condividi con la tua squadra, amici o famiglia\n- 📎 Allega file e integrali nella tua descrizione markdown\n- 💬 Discuti con la tua squadra utilizzando i commenti\n- ⚡ Tieni traccia dei cambiamenti nel flusso delle attività\n- 🚀 Organizza il tuo progetto",
    "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "Sei sicuro di voler eliminare la lavagna {title}? Questo eliminerà tutti i dati di questa lavagna?",
    "This week" : "Questa settimana"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
